diff -pruN 2.3.3op1-5/backend/usb-libusb.c 2.3.3op2-2/backend/usb-libusb.c
--- 2.3.3op1-5/backend/usb-libusb.c	2020-11-27 14:25:26.000000000 +0000
+++ 2.3.3op2-2/backend/usb-libusb.c	2021-02-01 21:10:25.000000000 +0000
@@ -1690,45 +1690,24 @@ static void *read_thread(void *reference
   unsigned char		readbuffer[512];
   int			rbytes;
   int			readstatus;
-  struct timeval	now,
-			delay,
-			end,
-			timeleft;
 
 
   (void)reference;
 
- /*
-  * Read frequency: once every 250 milliseconds.
-  */
-
-  delay.tv_sec = 0;
-  delay.tv_usec = 250000;
-
   do
   {
    /*
-    * Remember when we started so we can throttle the loop after the read
-    * call...
-    */
-
-    gettimeofday(&now, NULL);
-
-   /*
-    * Calculate what 250 milliSeconds are in absolute time...
+    * Try reading from the OUT (to host) endpoint...
     */
 
-    timeradd(&now, &delay, &end);
-
     rbytes     = sizeof(readbuffer);
     readstatus = libusb_bulk_transfer(g.printer->handle,
 				      g.printer->read_endp,
 				      readbuffer, rbytes,
-				      &rbytes, 60000);
+				      &rbytes, 250);
     if (readstatus == LIBUSB_SUCCESS && rbytes > 0)
     {
-      fprintf(stderr, "DEBUG: Read %d bytes of back-channel data...\n",
-              (int)rbytes);
+      fprintf(stderr, "DEBUG: Read %d bytes of back-channel data...\n", (int)rbytes);
       cupsBackChannelWrite((const char *)readbuffer, (size_t)rbytes, 1.0);
     }
     else if (readstatus == LIBUSB_ERROR_TIMEOUT)
@@ -1743,15 +1722,9 @@ static void *read_thread(void *reference
     */
 
     if ((g.wait_eof || !g.read_thread_stop))
-    {
-      gettimeofday(&now, NULL);
-      if (timercmp(&now, &end, <))
-      {
-	timersub(&end, &now, &timeleft);
-	usleep(1000000 * timeleft.tv_sec + timeleft.tv_usec);
-      }
-    }
-  } while (g.wait_eof || !g.read_thread_stop);
+      usleep(250000);
+  }
+  while (g.wait_eof || !g.read_thread_stop);
 
  /*
   * Let the main thread know that we have completed the read thread...
diff -pruN 2.3.3op1-5/cgi-bin/help-index.c 2.3.3op2-2/cgi-bin/help-index.c
--- 2.3.3op1-5/cgi-bin/help-index.c	2020-11-27 14:25:26.000000000 +0000
+++ 2.3.3op2-2/cgi-bin/help-index.c	2021-02-01 21:10:25.000000000 +0000
@@ -579,7 +579,7 @@ helpSearchIndex(help_index_t *hi,	/* I -
   */
 
   for (; node; node = (help_node_t *)cupsArrayNext(hi->nodes))
-    if (section && strcmp(node->section, section))
+    if (node->section && section && strcmp(node->section, section))
       continue;
     else if (filename && strcmp(node->filename, filename))
       continue;
diff -pruN 2.3.3op1-5/CHANGES-OPENPRINTING.md 2.3.3op2-2/CHANGES-OPENPRINTING.md
--- 2.3.3op1-5/CHANGES-OPENPRINTING.md	2020-11-27 14:25:26.000000000 +0000
+++ 2.3.3op2-2/CHANGES-OPENPRINTING.md	2021-02-01 21:10:25.000000000 +0000
@@ -1,6 +1,27 @@
 OpenPrinting CUPS Changes
 =========================
 
+Changes in CUPS v2.3.3op2
+-------------------------
+
+- Security: Fixed a buffer (read) overflow in the `ippReadIO` function
+  (CVE-2020-10001)
+- Clarified the documentation for the "Listen" directive (Issue #53)
+- Fixed duplicate ColorModel entries for AirPrint printers (Issue 59)
+- Fixed directory/permission defaults for Debian kfreebsd-based systems
+  (Issue #60, Issue #61)
+- Fixed crash bug in `ppdOpen` (Issue #64, Issue #78)
+- Fixed regression in `snprintf` emulation function (Issue #67)
+- The scheduler's systemd service file now waits for the nslcd service to start
+  (Issue #69)
+- The libusb-based USB backend now uses a simpler read timer implementation to
+  avoid a regression in a previous change (Issue #72)
+- The PPD caching code now only tracks the `APPrinterIconPath` value on macOS
+  (Issue #73)
+- Fixed segfault in help.cgi when searching in man pages (Issue #81)
+- Root certificates were incorrectly stored in "~/.cups/ssl".
+
+
 Changes in CUPS v2.3.3op1
 -------------------------
 
diff -pruN 2.3.3op1-5/config-scripts/cups-compiler.m4 2.3.3op2-2/config-scripts/cups-compiler.m4
--- 2.3.3op1-5/config-scripts/cups-compiler.m4	2020-11-27 14:25:26.000000000 +0000
+++ 2.3.3op2-2/config-scripts/cups-compiler.m4	2021-02-01 21:10:25.000000000 +0000
@@ -169,7 +169,7 @@ if test -n "$GCC"; then
 	fi
 
 	# Add useful warning options for tracking down problems...
-	WARNING_OPTIONS="-Wall -Wno-format-y2k -Wunused -Wno-unused-result -Wsign-conversion"
+	WARNING_OPTIONS="-Wall -Wno-format-y2k -Wunused -Wno-unused-result -Wsign-conversion -Wno-deprecated-declarations"
 
 	# Test GCC version for certain warning flags since -Werror
 	# doesn't trigger...
diff -pruN 2.3.3op1-5/config-scripts/cups-defaults.m4 2.3.3op2-2/config-scripts/cups-defaults.m4
--- 2.3.3op1-5/config-scripts/cups-defaults.m4	2020-11-27 14:25:26.000000000 +0000
+++ 2.3.3op2-2/config-scripts/cups-defaults.m4	2021-02-01 21:10:25.000000000 +0000
@@ -53,7 +53,7 @@ dnl Default executable file permissions
 AC_ARG_WITH(exe_file_perm, [  --with-exe-file-perm    set default executable permissions value, default=0555],
 	CUPS_EXE_FILE_PERM="$withval",
 	[case "$host_os_name" in
-		linux* | gnu*)
+		linux* | gnu* | *-gnu)
 			CUPS_EXE_FILE_PERM="755"
 			;;
 		*)
diff -pruN 2.3.3op1-5/config-scripts/cups-directories.m4 2.3.3op2-2/config-scripts/cups-directories.m4
--- 2.3.3op1-5/config-scripts/cups-directories.m4	2020-11-27 14:25:26.000000000 +0000
+++ 2.3.3op2-2/config-scripts/cups-directories.m4	2021-02-01 21:10:25.000000000 +0000
@@ -262,6 +262,11 @@ AC_SUBST(CUPS_REQUESTS)
 
 # Server executables...
 case "$host_os_name" in
+	*-gnu)
+		# GNUs
+		INSTALL_SYSV="install-sysv"
+		CUPS_SERVERBIN="$exec_prefix/lib/cups"
+		;;
 	*bsd* | darwin*)
 		# *BSD and Darwin (macOS)
 		INSTALL_SYSV=""
diff -pruN 2.3.3op1-5/configure 2.3.3op2-2/configure
--- 2.3.3op1-5/configure	2020-11-27 14:25:26.000000000 +0000
+++ 2.3.3op2-2/configure	2021-02-01 21:10:25.000000000 +0000
@@ -1,11 +1,11 @@
 #! /bin/sh
 # Guess values for system-dependent variables and create Makefiles.
-# Generated by GNU Autoconf 2.69 for CUPS 2.3.3op1.
+# Generated by GNU Autoconf 2.70 for CUPS 2.3.3op2.
 #
 # Report bugs to <https://github.com/openprinting/cups/issues>.
 #
 #
-# Copyright (C) 1992-1996, 1998-2012 Free Software Foundation, Inc.
+# Copyright (C) 1992-1996, 1998-2017, 2020 Free Software Foundation, Inc.
 #
 #
 # This configure script is free software; the Free Software Foundation
@@ -16,14 +16,16 @@
 
 # Be more Bourne compatible
 DUALCASE=1; export DUALCASE # for MKS sh
-if test -n "${ZSH_VERSION+set}" && (emulate sh) >/dev/null 2>&1; then :
+as_nop=:
+if test ${ZSH_VERSION+y} && (emulate sh) >/dev/null 2>&1
+then :
   emulate sh
   NULLCMD=:
   # Pre-4.2 versions of Zsh do word splitting on ${1+"$@"}, which
   # is contrary to our usage.  Disable this feature.
   alias -g '${1+"$@"}'='"$@"'
   setopt NO_GLOB_SUBST
-else
+else $as_nop
   case `(set -o) 2>/dev/null` in #(
   *posix*) :
     set -o posix ;; #(
@@ -33,46 +35,46 @@ esac
 fi
 
 
+
+# Reset variables that may have inherited troublesome values from
+# the environment.
+
+# IFS needs to be set, to space, tab, and newline, in precisely that order.
+# (If _AS_PATH_WALK were called with IFS unset, it would have the
+# side effect of setting IFS to empty, thus disabling word splitting.)
+# Quoting is to prevent editors from complaining about space-tab.
 as_nl='
 '
 export as_nl
-# Printing a long string crashes Solaris 7 /usr/bin/printf.
-as_echo='\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\'
-as_echo=$as_echo$as_echo$as_echo$as_echo$as_echo
-as_echo=$as_echo$as_echo$as_echo$as_echo$as_echo$as_echo
-# Prefer a ksh shell builtin over an external printf program on Solaris,
-# but without wasting forks for bash or zsh.
-if test -z "$BASH_VERSION$ZSH_VERSION" \
-    && (test "X`print -r -- $as_echo`" = "X$as_echo") 2>/dev/null; then
-  as_echo='print -r --'
-  as_echo_n='print -rn --'
-elif (test "X`printf %s $as_echo`" = "X$as_echo") 2>/dev/null; then
-  as_echo='printf %s\n'
-  as_echo_n='printf %s'
-else
-  if test "X`(/usr/ucb/echo -n -n $as_echo) 2>/dev/null`" = "X-n $as_echo"; then
-    as_echo_body='eval /usr/ucb/echo -n "$1$as_nl"'
-    as_echo_n='/usr/ucb/echo -n'
-  else
-    as_echo_body='eval expr "X$1" : "X\\(.*\\)"'
-    as_echo_n_body='eval
-      arg=$1;
-      case $arg in #(
-      *"$as_nl"*)
-	expr "X$arg" : "X\\(.*\\)$as_nl";
-	arg=`expr "X$arg" : ".*$as_nl\\(.*\\)"`;;
-      esac;
-      expr "X$arg" : "X\\(.*\\)" | tr -d "$as_nl"
-    '
-    export as_echo_n_body
-    as_echo_n='sh -c $as_echo_n_body as_echo'
-  fi
-  export as_echo_body
-  as_echo='sh -c $as_echo_body as_echo'
-fi
+IFS=" ""	$as_nl"
+
+PS1='$ '
+PS2='> '
+PS4='+ '
+
+# Ensure predictable behavior from utilities with locale-dependent output.
+LC_ALL=C
+export LC_ALL
+LANGUAGE=C
+export LANGUAGE
+
+# We cannot yet rely on "unset" to work, but we need these variables
+# to be unset--not just set to an empty or harmless value--now, to
+# avoid bugs in old shells (e.g. pre-3.0 UWIN ksh).  This construct
+# also avoids known problems related to "unset" and subshell syntax
+# in other old shells (e.g. bash 2.01 and pdksh 5.2.14).
+for as_var in BASH_ENV ENV MAIL MAILPATH CDPATH
+do eval test \${$as_var+y} \
+  && ( (unset $as_var) || exit 1) >/dev/null 2>&1 && unset $as_var || :
+done
+
+# Ensure that fds 0, 1, and 2 are open.
+if (exec 3>&0) 2>/dev/null; then :; else exec 0</dev/null; fi
+if (exec 3>&1) 2>/dev/null; then :; else exec 1>/dev/null; fi
+if (exec 3>&2)            ; then :; else exec 2>/dev/null; fi
 
 # The user is always right.
-if test "${PATH_SEPARATOR+set}" != set; then
+if ${PATH_SEPARATOR+false} :; then
   PATH_SEPARATOR=:
   (PATH='/bin;/bin'; FPATH=$PATH; sh -c :) >/dev/null 2>&1 && {
     (PATH='/bin:/bin'; FPATH=$PATH; sh -c :) >/dev/null 2>&1 ||
@@ -81,13 +83,6 @@ if test "${PATH_SEPARATOR+set}" != set;
 fi
 
 
-# IFS
-# We need space, tab and new line, in precisely that order.  Quoting is
-# there to prevent editors from complaining about space-tab.
-# (If _AS_PATH_WALK were called with IFS unset, it would disable word
-# splitting by setting IFS to empty value.)
-IFS=" ""	$as_nl"
-
 # Find who we are.  Look in the path if we contain no directory separator.
 as_myself=
 case $0 in #((
@@ -96,8 +91,12 @@ case $0 in #((
 for as_dir in $PATH
 do
   IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
-    test -r "$as_dir/$0" && as_myself=$as_dir/$0 && break
+  case $as_dir in #(((
+    '') as_dir=./ ;;
+    */) ;;
+    *) as_dir=$as_dir/ ;;
+  esac
+    test -r "$as_dir$0" && as_myself=$as_dir$0 && break
   done
 IFS=$as_save_IFS
 
@@ -109,30 +108,10 @@ if test "x$as_myself" = x; then
   as_myself=$0
 fi
 if test ! -f "$as_myself"; then
-  $as_echo "$as_myself: error: cannot find myself; rerun with an absolute file name" >&2
+  printf "%s\n" "$as_myself: error: cannot find myself; rerun with an absolute file name" >&2
   exit 1
 fi
 
-# Unset variables that we do not need and which cause bugs (e.g. in
-# pre-3.0 UWIN ksh).  But do not cause bugs in bash 2.01; the "|| exit 1"
-# suppresses any "Segmentation fault" message there.  '((' could
-# trigger a bug in pdksh 5.2.14.
-for as_var in BASH_ENV ENV MAIL MAILPATH
-do eval test x\${$as_var+set} = xset \
-  && ( (unset $as_var) || exit 1) >/dev/null 2>&1 && unset $as_var || :
-done
-PS1='$ '
-PS2='> '
-PS4='+ '
-
-# NLS nuisances.
-LC_ALL=C
-export LC_ALL
-LANGUAGE=C
-export LANGUAGE
-
-# CDPATH.
-(unset CDPATH) >/dev/null 2>&1 && unset CDPATH
 
 # Use a proper internal environment variable to ensure we don't fall
   # into an infinite loop, continuously re-executing ourselves.
@@ -154,20 +133,22 @@ esac
 exec $CONFIG_SHELL $as_opts "$as_myself" ${1+"$@"}
 # Admittedly, this is quite paranoid, since all the known shells bail
 # out after a failed `exec'.
-$as_echo "$0: could not re-execute with $CONFIG_SHELL" >&2
-as_fn_exit 255
+printf "%s\n" "$0: could not re-execute with $CONFIG_SHELL" >&2
+exit 255
   fi
   # We don't want this to propagate to other subprocesses.
           { _as_can_reexec=; unset _as_can_reexec;}
 if test "x$CONFIG_SHELL" = x; then
-  as_bourne_compatible="if test -n \"\${ZSH_VERSION+set}\" && (emulate sh) >/dev/null 2>&1; then :
+  as_bourne_compatible="as_nop=:
+if test \${ZSH_VERSION+y} && (emulate sh) >/dev/null 2>&1
+then :
   emulate sh
   NULLCMD=:
   # Pre-4.2 versions of Zsh do word splitting on \${1+\"\$@\"}, which
   # is contrary to our usage.  Disable this feature.
   alias -g '\${1+\"\$@\"}'='\"\$@\"'
   setopt NO_GLOB_SUBST
-else
+else \$as_nop
   case \`(set -o) 2>/dev/null\` in #(
   *posix*) :
     set -o posix ;; #(
@@ -187,42 +168,53 @@ as_fn_success || { exitcode=1; echo as_f
 as_fn_failure && { exitcode=1; echo as_fn_failure succeeded.; }
 as_fn_ret_success || { exitcode=1; echo as_fn_ret_success failed.; }
 as_fn_ret_failure && { exitcode=1; echo as_fn_ret_failure succeeded.; }
-if ( set x; as_fn_ret_success y && test x = \"\$1\" ); then :
+if ( set x; as_fn_ret_success y && test x = \"\$1\" )
+then :
 
-else
+else \$as_nop
   exitcode=1; echo positional parameters were not saved.
 fi
 test x\$exitcode = x0 || exit 1
+blah=\$(echo \$(echo blah))
+test x\"\$blah\" = xblah || exit 1
 test -x / || exit 1"
   as_suggested="  as_lineno_1=";as_suggested=$as_suggested$LINENO;as_suggested=$as_suggested" as_lineno_1a=\$LINENO
   as_lineno_2=";as_suggested=$as_suggested$LINENO;as_suggested=$as_suggested" as_lineno_2a=\$LINENO
   eval 'test \"x\$as_lineno_1'\$as_run'\" != \"x\$as_lineno_2'\$as_run'\" &&
   test \"x\`expr \$as_lineno_1'\$as_run' + 1\`\" = \"x\$as_lineno_2'\$as_run'\"' || exit 1
 test \$(( 1 + 1 )) = 2 || exit 1"
-  if (eval "$as_required") 2>/dev/null; then :
+  if (eval "$as_required") 2>/dev/null
+then :
   as_have_required=yes
-else
+else $as_nop
   as_have_required=no
 fi
-  if test x$as_have_required = xyes && (eval "$as_suggested") 2>/dev/null; then :
+  if test x$as_have_required = xyes && (eval "$as_suggested") 2>/dev/null
+then :
 
-else
+else $as_nop
   as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
 as_found=false
 for as_dir in /bin$PATH_SEPARATOR/usr/bin$PATH_SEPARATOR$PATH
 do
   IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
+  case $as_dir in #(((
+    '') as_dir=./ ;;
+    */) ;;
+    *) as_dir=$as_dir/ ;;
+  esac
   as_found=:
   case $as_dir in #(
 	 /*)
 	   for as_base in sh bash ksh sh5; do
 	     # Try only shells that exist, to save several forks.
-	     as_shell=$as_dir/$as_base
+	     as_shell=$as_dir$as_base
 	     if { test -f "$as_shell" || test -f "$as_shell.exe"; } &&
-		    { $as_echo "$as_bourne_compatible""$as_required" | as_run=a "$as_shell"; } 2>/dev/null; then :
+		    as_run=a "$as_shell" -c "$as_bourne_compatible""$as_required" 2>/dev/null
+then :
   CONFIG_SHELL=$as_shell as_have_required=yes
-		   if { $as_echo "$as_bourne_compatible""$as_suggested" | as_run=a "$as_shell"; } 2>/dev/null; then :
+		   if as_run=a "$as_shell" -c "$as_bourne_compatible""$as_suggested" 2>/dev/null
+then :
   break 2
 fi
 fi
@@ -230,14 +222,21 @@ fi
        esac
   as_found=false
 done
-$as_found || { if { test -f "$SHELL" || test -f "$SHELL.exe"; } &&
-	      { $as_echo "$as_bourne_compatible""$as_required" | as_run=a "$SHELL"; } 2>/dev/null; then :
-  CONFIG_SHELL=$SHELL as_have_required=yes
-fi; }
 IFS=$as_save_IFS
+if $as_found
+then :
+
+else $as_nop
+  if { test -f "$SHELL" || test -f "$SHELL.exe"; } &&
+	      as_run=a "$SHELL" -c "$as_bourne_compatible""$as_required" 2>/dev/null
+then :
+  CONFIG_SHELL=$SHELL as_have_required=yes
+fi
+fi
 
 
-      if test "x$CONFIG_SHELL" != x; then :
+      if test "x$CONFIG_SHELL" != x
+then :
   export CONFIG_SHELL
              # We cannot yet assume a decent shell, so we have to provide a
 # neutralization value for shells without unset; and this also
@@ -255,18 +254,19 @@ esac
 exec $CONFIG_SHELL $as_opts "$as_myself" ${1+"$@"}
 # Admittedly, this is quite paranoid, since all the known shells bail
 # out after a failed `exec'.
-$as_echo "$0: could not re-execute with $CONFIG_SHELL" >&2
+printf "%s\n" "$0: could not re-execute with $CONFIG_SHELL" >&2
 exit 255
 fi
 
-    if test x$as_have_required = xno; then :
-  $as_echo "$0: This script requires a shell more modern than all"
-  $as_echo "$0: the shells that I found on your system."
-  if test x${ZSH_VERSION+set} = xset ; then
-    $as_echo "$0: In particular, zsh $ZSH_VERSION has bugs and should"
-    $as_echo "$0: be upgraded to zsh 4.3.4 or later."
+    if test x$as_have_required = xno
+then :
+  printf "%s\n" "$0: This script requires a shell more modern than all"
+  printf "%s\n" "$0: the shells that I found on your system."
+  if test ${ZSH_VERSION+y} ; then
+    printf "%s\n" "$0: In particular, zsh $ZSH_VERSION has bugs and should"
+    printf "%s\n" "$0: be upgraded to zsh 4.3.4 or later."
   else
-    $as_echo "$0: Please tell bug-autoconf@gnu.org and
+    printf "%s\n" "$0: Please tell bug-autoconf@gnu.org and
 $0: https://github.com/openprinting/cups/issues about your
 $0: system, including any error possibly output before this
 $0: message. Then install a modern shell, or manually run
@@ -294,6 +294,7 @@ as_fn_unset ()
 }
 as_unset=as_fn_unset
 
+
 # as_fn_set_status STATUS
 # -----------------------
 # Set $? to STATUS, without forking.
@@ -311,6 +312,14 @@ as_fn_exit ()
   as_fn_set_status $1
   exit $1
 } # as_fn_exit
+# as_fn_nop
+# ---------
+# Do nothing but, unlike ":", preserve the value of $?.
+as_fn_nop ()
+{
+  return $?
+}
+as_nop=as_fn_nop
 
 # as_fn_mkdir_p
 # -------------
@@ -325,7 +334,7 @@ as_fn_mkdir_p ()
     as_dirs=
     while :; do
       case $as_dir in #(
-      *\'*) as_qdir=`$as_echo "$as_dir" | sed "s/'/'\\\\\\\\''/g"`;; #'(
+      *\'*) as_qdir=`printf "%s\n" "$as_dir" | sed "s/'/'\\\\\\\\''/g"`;; #'(
       *) as_qdir=$as_dir;;
       esac
       as_dirs="'$as_qdir' $as_dirs"
@@ -334,7 +343,7 @@ $as_expr X"$as_dir" : 'X\(.*[^/]\)//*[^/
 	 X"$as_dir" : 'X\(//\)[^/]' \| \
 	 X"$as_dir" : 'X\(//\)$' \| \
 	 X"$as_dir" : 'X\(/\)' \| . 2>/dev/null ||
-$as_echo X"$as_dir" |
+printf "%s\n" X"$as_dir" |
     sed '/^X\(.*[^/]\)\/\/*[^/][^/]*\/*$/{
 	    s//\1/
 	    q
@@ -373,12 +382,13 @@ as_fn_executable_p ()
 # advantage of any shell optimizations that allow amortized linear growth over
 # repeated appends, instead of the typical quadratic growth present in naive
 # implementations.
-if (eval "as_var=1; as_var+=2; test x\$as_var = x12") 2>/dev/null; then :
+if (eval "as_var=1; as_var+=2; test x\$as_var = x12") 2>/dev/null
+then :
   eval 'as_fn_append ()
   {
     eval $1+=\$2
   }'
-else
+else $as_nop
   as_fn_append ()
   {
     eval $1=\$$1\$2
@@ -390,18 +400,27 @@ fi # as_fn_append
 # Perform arithmetic evaluation on the ARGs, and store the result in the
 # global $as_val. Take advantage of shells that can avoid forks. The arguments
 # must be portable across $(()) and expr.
-if (eval "test \$(( 1 + 1 )) = 2") 2>/dev/null; then :
+if (eval "test \$(( 1 + 1 )) = 2") 2>/dev/null
+then :
   eval 'as_fn_arith ()
   {
     as_val=$(( $* ))
   }'
-else
+else $as_nop
   as_fn_arith ()
   {
     as_val=`expr "$@" || test $? -eq 1`
   }
 fi # as_fn_arith
 
+# as_fn_nop
+# ---------
+# Do nothing but, unlike ":", preserve the value of $?.
+as_fn_nop ()
+{
+  return $?
+}
+as_nop=as_fn_nop
 
 # as_fn_error STATUS ERROR [LINENO LOG_FD]
 # ----------------------------------------
@@ -413,9 +432,9 @@ as_fn_error ()
   as_status=$1; test $as_status -eq 0 && as_status=1
   if test "$4"; then
     as_lineno=${as_lineno-"$3"} as_lineno_stack=as_lineno_stack=$as_lineno_stack
-    $as_echo "$as_me:${as_lineno-$LINENO}: error: $2" >&$4
+    printf "%s\n" "$as_me:${as_lineno-$LINENO}: error: $2" >&$4
   fi
-  $as_echo "$as_me: error: $2" >&2
+  printf "%s\n" "$as_me: error: $2" >&2
   as_fn_exit $as_status
 } # as_fn_error
 
@@ -442,7 +461,7 @@ as_me=`$as_basename -- "$0" ||
 $as_expr X/"$0" : '.*/\([^/][^/]*\)/*$' \| \
 	 X"$0" : 'X\(//\)$' \| \
 	 X"$0" : 'X\(/\)' \| . 2>/dev/null ||
-$as_echo X/"$0" |
+printf "%s\n" X/"$0" |
     sed '/^.*\/\([^/][^/]*\)\/*$/{
 	    s//\1/
 	    q
@@ -486,7 +505,7 @@ as_cr_alnum=$as_cr_Letters$as_cr_digits
       s/-\n.*//
     ' >$as_me.lineno &&
   chmod +x "$as_me.lineno" ||
-    { $as_echo "$as_me: error: cannot create $as_me.lineno; rerun with a POSIX shell" >&2; as_fn_exit 1; }
+    { printf "%s\n" "$as_me: error: cannot create $as_me.lineno; rerun with a POSIX shell" >&2; as_fn_exit 1; }
 
   # If we had to re-execute with $CONFIG_SHELL, we're ensured to have
   # already done that, so ensure we don't try to do so again and fall
@@ -500,6 +519,10 @@ as_cr_alnum=$as_cr_Letters$as_cr_digits
   exit
 }
 
+
+# Determine whether it's possible to make 'echo' print without a newline.
+# These variables are no longer used directly by Autoconf, but are AC_SUBSTed
+# for compatibility with existing Makefiles.
 ECHO_C= ECHO_N= ECHO_T=
 case `echo -n x` in #(((((
 -n*)
@@ -513,6 +536,13 @@ case `echo -n x` in #(((((
   ECHO_N='-n';;
 esac
 
+# For backward compatibility with old third-party macros, we provide
+# the shell variables $as_echo and $as_echo_n.  New code should use
+# AS_ECHO(["message"]) and AS_ECHO_N(["message"]), respectively.
+as_echo='printf %s\n'
+as_echo_n='printf %s'
+
+
 rm -f conf$$ conf$$.exe conf$$.file
 if test -d conf$$.dir; then
   rm -f conf$$.dir/conf$$.file
@@ -580,47 +610,43 @@ MAKEFLAGS=
 # Identity of this package.
 PACKAGE_NAME='CUPS'
 PACKAGE_TARNAME='cups'
-PACKAGE_VERSION='2.3.3op1'
-PACKAGE_STRING='CUPS 2.3.3op1'
+PACKAGE_VERSION='2.3.3op2'
+PACKAGE_STRING='CUPS 2.3.3op2'
 PACKAGE_BUGREPORT='https://github.com/openprinting/cups/issues'
 PACKAGE_URL='https://openprinting.github.io/'
 
 # Factoring default headers for most tests.
 ac_includes_default="\
-#include <stdio.h>
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-#ifdef HAVE_SYS_STAT_H
-# include <sys/stat.h>
+#include <stddef.h>
+#ifdef HAVE_STDIO_H
+# include <stdio.h>
 #endif
-#ifdef STDC_HEADERS
+#ifdef HAVE_STDLIB_H
 # include <stdlib.h>
-# include <stddef.h>
-#else
-# ifdef HAVE_STDLIB_H
-#  include <stdlib.h>
-# endif
 #endif
 #ifdef HAVE_STRING_H
-# if !defined STDC_HEADERS && defined HAVE_MEMORY_H
-#  include <memory.h>
-# endif
 # include <string.h>
 #endif
-#ifdef HAVE_STRINGS_H
-# include <strings.h>
-#endif
 #ifdef HAVE_INTTYPES_H
 # include <inttypes.h>
 #endif
 #ifdef HAVE_STDINT_H
 # include <stdint.h>
 #endif
+#ifdef HAVE_STRINGS_H
+# include <strings.h>
+#endif
+#ifdef HAVE_SYS_TYPES_H
+# include <sys/types.h>
+#endif
+#ifdef HAVE_SYS_STAT_H
+# include <sys/stat.h>
+#endif
 #ifdef HAVE_UNISTD_H
 # include <unistd.h>
 #endif"
 
+ac_header_c_list=
 ac_default_prefix=/
 ac_subst_vars='LTLIBOBJS
 LIBOBJS
@@ -812,6 +838,7 @@ infodir
 docdir
 oldincludedir
 includedir
+runstatedir
 localstatedir
 sharedstatedir
 sysconfdir
@@ -971,6 +998,7 @@ datadir='${datarootdir}'
 sysconfdir='${prefix}/etc'
 sharedstatedir='${prefix}/com'
 localstatedir='${prefix}/var'
+runstatedir='${localstatedir}/run'
 includedir='${prefix}/include'
 oldincludedir='/usr/include'
 docdir='${datarootdir}/doc/${PACKAGE_TARNAME}'
@@ -1000,8 +1028,6 @@ do
   *)    ac_optarg=yes ;;
   esac
 
-  # Accept the important Cygnus configure options, so we can diagnose typos.
-
   case $ac_dashdash$ac_option in
   --)
     ac_dashdash=yes ;;
@@ -1042,9 +1068,9 @@ do
     ac_useropt=`expr "x$ac_option" : 'x-*disable-\(.*\)'`
     # Reject names that are not valid shell variable names.
     expr "x$ac_useropt" : ".*[^-+._$as_cr_alnum]" >/dev/null &&
-      as_fn_error $? "invalid feature name: $ac_useropt"
+      as_fn_error $? "invalid feature name: \`$ac_useropt'"
     ac_useropt_orig=$ac_useropt
-    ac_useropt=`$as_echo "$ac_useropt" | sed 's/[-+.]/_/g'`
+    ac_useropt=`printf "%s\n" "$ac_useropt" | sed 's/[-+.]/_/g'`
     case $ac_user_opts in
       *"
 "enable_$ac_useropt"
@@ -1068,9 +1094,9 @@ do
     ac_useropt=`expr "x$ac_option" : 'x-*enable-\([^=]*\)'`
     # Reject names that are not valid shell variable names.
     expr "x$ac_useropt" : ".*[^-+._$as_cr_alnum]" >/dev/null &&
-      as_fn_error $? "invalid feature name: $ac_useropt"
+      as_fn_error $? "invalid feature name: \`$ac_useropt'"
     ac_useropt_orig=$ac_useropt
-    ac_useropt=`$as_echo "$ac_useropt" | sed 's/[-+.]/_/g'`
+    ac_useropt=`printf "%s\n" "$ac_useropt" | sed 's/[-+.]/_/g'`
     case $ac_user_opts in
       *"
 "enable_$ac_useropt"
@@ -1223,6 +1249,15 @@ do
   | -silent | --silent | --silen | --sile | --sil)
     silent=yes ;;
 
+  -runstatedir | --runstatedir | --runstatedi | --runstated \
+  | --runstate | --runstat | --runsta | --runst | --runs \
+  | --run | --ru | --r)
+    ac_prev=runstatedir ;;
+  -runstatedir=* | --runstatedir=* | --runstatedi=* | --runstated=* \
+  | --runstate=* | --runstat=* | --runsta=* | --runst=* | --runs=* \
+  | --run=* | --ru=* | --r=*)
+    runstatedir=$ac_optarg ;;
+
   -sbindir | --sbindir | --sbindi | --sbind | --sbin | --sbi | --sb)
     ac_prev=sbindir ;;
   -sbindir=* | --sbindir=* | --sbindi=* | --sbind=* | --sbin=* \
@@ -1272,9 +1307,9 @@ do
     ac_useropt=`expr "x$ac_option" : 'x-*with-\([^=]*\)'`
     # Reject names that are not valid shell variable names.
     expr "x$ac_useropt" : ".*[^-+._$as_cr_alnum]" >/dev/null &&
-      as_fn_error $? "invalid package name: $ac_useropt"
+      as_fn_error $? "invalid package name: \`$ac_useropt'"
     ac_useropt_orig=$ac_useropt
-    ac_useropt=`$as_echo "$ac_useropt" | sed 's/[-+.]/_/g'`
+    ac_useropt=`printf "%s\n" "$ac_useropt" | sed 's/[-+.]/_/g'`
     case $ac_user_opts in
       *"
 "with_$ac_useropt"
@@ -1288,9 +1323,9 @@ do
     ac_useropt=`expr "x$ac_option" : 'x-*without-\(.*\)'`
     # Reject names that are not valid shell variable names.
     expr "x$ac_useropt" : ".*[^-+._$as_cr_alnum]" >/dev/null &&
-      as_fn_error $? "invalid package name: $ac_useropt"
+      as_fn_error $? "invalid package name: \`$ac_useropt'"
     ac_useropt_orig=$ac_useropt
-    ac_useropt=`$as_echo "$ac_useropt" | sed 's/[-+.]/_/g'`
+    ac_useropt=`printf "%s\n" "$ac_useropt" | sed 's/[-+.]/_/g'`
     case $ac_user_opts in
       *"
 "with_$ac_useropt"
@@ -1334,9 +1369,9 @@ Try \`$0 --help' for more information"
 
   *)
     # FIXME: should be removed in autoconf 3.0.
-    $as_echo "$as_me: WARNING: you should use --build, --host, --target" >&2
+    printf "%s\n" "$as_me: WARNING: you should use --build, --host, --target" >&2
     expr "x$ac_option" : ".*[^-._$as_cr_alnum]" >/dev/null &&
-      $as_echo "$as_me: WARNING: invalid host type: $ac_option" >&2
+      printf "%s\n" "$as_me: WARNING: invalid host type: $ac_option" >&2
     : "${build_alias=$ac_option} ${host_alias=$ac_option} ${target_alias=$ac_option}"
     ;;
 
@@ -1352,7 +1387,7 @@ if test -n "$ac_unrecognized_opts"; then
   case $enable_option_checking in
     no) ;;
     fatal) as_fn_error $? "unrecognized options: $ac_unrecognized_opts" ;;
-    *)     $as_echo "$as_me: WARNING: unrecognized options: $ac_unrecognized_opts" >&2 ;;
+    *)     printf "%s\n" "$as_me: WARNING: unrecognized options: $ac_unrecognized_opts" >&2 ;;
   esac
 fi
 
@@ -1360,7 +1395,7 @@ fi
 for ac_var in	exec_prefix prefix bindir sbindir libexecdir datarootdir \
 		datadir sysconfdir sharedstatedir localstatedir includedir \
 		oldincludedir docdir infodir htmldir dvidir pdfdir psdir \
-		libdir localedir mandir
+		libdir localedir mandir runstatedir
 do
   eval ac_val=\$$ac_var
   # Remove trailing slashes.
@@ -1416,7 +1451,7 @@ $as_expr X"$as_myself" : 'X\(.*[^/]\)//*
 	 X"$as_myself" : 'X\(//\)[^/]' \| \
 	 X"$as_myself" : 'X\(//\)$' \| \
 	 X"$as_myself" : 'X\(/\)' \| . 2>/dev/null ||
-$as_echo X"$as_myself" |
+printf "%s\n" X"$as_myself" |
     sed '/^X\(.*[^/]\)\/\/*[^/][^/]*\/*$/{
 	    s//\1/
 	    q
@@ -1473,7 +1508,7 @@ if test "$ac_init_help" = "long"; then
   # Omit some internal or obsolete options to make the list less imposing.
   # This message is too long to be a string in the A/UX 3.1 sh.
   cat <<_ACEOF
-\`configure' configures CUPS 2.3.3op1 to adapt to many kinds of systems.
+\`configure' configures CUPS 2.3.3op2 to adapt to many kinds of systems.
 
 Usage: $0 [OPTION]... [VAR=VALUE]...
 
@@ -1513,6 +1548,7 @@ Fine tuning of the installation director
   --sysconfdir=DIR        read-only single-machine data [PREFIX/etc]
   --sharedstatedir=DIR    modifiable architecture-independent data [PREFIX/com]
   --localstatedir=DIR     modifiable single-machine data [PREFIX/var]
+  --runstatedir=DIR       modifiable per-process data [LOCALSTATEDIR/run]
   --libdir=DIR            object code libraries [EPREFIX/lib]
   --includedir=DIR        C header files [PREFIX/include]
   --oldincludedir=DIR     C header files for non-gcc [/usr/include]
@@ -1538,7 +1574,7 @@ fi
 
 if test -n "$ac_init_help"; then
   case $ac_init_help in
-     short | recursive ) echo "Configuration of CUPS 2.3.3op1:";;
+     short | recursive ) echo "Configuration of CUPS 2.3.3op2:";;
    esac
   cat <<\_ACEOF
 
@@ -1675,9 +1711,9 @@ if test "$ac_init_help" = "recursive"; t
 case "$ac_dir" in
 .) ac_dir_suffix= ac_top_builddir_sub=. ac_top_build_prefix= ;;
 *)
-  ac_dir_suffix=/`$as_echo "$ac_dir" | sed 's|^\.[\\/]||'`
+  ac_dir_suffix=/`printf "%s\n" "$ac_dir" | sed 's|^\.[\\/]||'`
   # A ".." for each directory in $ac_dir_suffix.
-  ac_top_builddir_sub=`$as_echo "$ac_dir_suffix" | sed 's|/[^\\/]*|/..|g;s|/||'`
+  ac_top_builddir_sub=`printf "%s\n" "$ac_dir_suffix" | sed 's|/[^\\/]*|/..|g;s|/||'`
   case $ac_top_builddir_sub in
   "") ac_top_builddir_sub=. ac_top_build_prefix= ;;
   *)  ac_top_build_prefix=$ac_top_builddir_sub/ ;;
@@ -1705,7 +1741,8 @@ esac
 ac_abs_srcdir=$ac_abs_top_srcdir$ac_dir_suffix
 
     cd "$ac_dir" || { ac_status=$?; continue; }
-    # Check for guested configure.
+    # Check for configure.gnu first; this name is used for a wrapper for
+    # Metaconfig's "Configure" on case-insensitive file systems.
     if test -f "$ac_srcdir/configure.gnu"; then
       echo &&
       $SHELL "$ac_srcdir/configure.gnu" --help=recursive
@@ -1713,7 +1750,7 @@ ac_abs_srcdir=$ac_abs_top_srcdir$ac_dir_
       echo &&
       $SHELL "$ac_srcdir/configure" --help=recursive
     else
-      $as_echo "$as_me: WARNING: no configuration information is in $ac_dir" >&2
+      printf "%s\n" "$as_me: WARNING: no configuration information is in $ac_dir" >&2
     fi || ac_status=$?
     cd "$ac_pwd" || { ac_status=$?; break; }
   done
@@ -1722,10 +1759,10 @@ fi
 test -n "$ac_init_help" && exit $ac_status
 if $ac_init_version; then
   cat <<\_ACEOF
-CUPS configure 2.3.3op1
-generated by GNU Autoconf 2.69
+CUPS configure 2.3.3op2
+generated by GNU Autoconf 2.70
 
-Copyright (C) 2012 Free Software Foundation, Inc.
+Copyright (C) 2020 Free Software Foundation, Inc.
 This configure script is free software; the Free Software Foundation
 gives unlimited permission to copy, distribute and modify it.
 _ACEOF
@@ -1742,14 +1779,14 @@ fi
 ac_fn_c_try_compile ()
 {
   as_lineno=${as_lineno-"$1"} as_lineno_stack=as_lineno_stack=$as_lineno_stack
-  rm -f conftest.$ac_objext
+  rm -f conftest.$ac_objext conftest.beam
   if { { ac_try="$ac_compile"
 case "(($ac_try" in
   *\"* | *\`* | *\\*) ac_try_echo=\$ac_try;;
   *) ac_try_echo=$ac_try;;
 esac
 eval ac_try_echo="\"\$as_me:${as_lineno-$LINENO}: $ac_try_echo\""
-$as_echo "$ac_try_echo"; } >&5
+printf "%s\n" "$ac_try_echo"; } >&5
   (eval "$ac_compile") 2>conftest.err
   ac_status=$?
   if test -s conftest.err; then
@@ -1757,14 +1794,15 @@ $as_echo "$ac_try_echo"; } >&5
     cat conftest.er1 >&5
     mv -f conftest.er1 conftest.err
   fi
-  $as_echo "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
+  printf "%s\n" "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
   test $ac_status = 0; } && {
 	 test -z "$ac_c_werror_flag" ||
 	 test ! -s conftest.err
-       } && test -s conftest.$ac_objext; then :
+       } && test -s conftest.$ac_objext
+then :
   ac_retval=0
-else
-  $as_echo "$as_me: failed program was:" >&5
+else $as_nop
+  printf "%s\n" "$as_me: failed program was:" >&5
 sed 's/^/| /' conftest.$ac_ext >&5
 
 	ac_retval=1
@@ -1786,7 +1824,7 @@ case "(($ac_try" in
   *) ac_try_echo=$ac_try;;
 esac
 eval ac_try_echo="\"\$as_me:${as_lineno-$LINENO}: $ac_try_echo\""
-$as_echo "$ac_try_echo"; } >&5
+printf "%s\n" "$ac_try_echo"; } >&5
   (eval "$ac_cpp conftest.$ac_ext") 2>conftest.err
   ac_status=$?
   if test -s conftest.err; then
@@ -1794,14 +1832,15 @@ $as_echo "$ac_try_echo"; } >&5
     cat conftest.er1 >&5
     mv -f conftest.er1 conftest.err
   fi
-  $as_echo "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
+  printf "%s\n" "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
   test $ac_status = 0; } > conftest.i && {
 	 test -z "$ac_c_preproc_warn_flag$ac_c_werror_flag" ||
 	 test ! -s conftest.err
-       }; then :
+       }
+then :
   ac_retval=0
-else
-  $as_echo "$as_me: failed program was:" >&5
+else $as_nop
+  printf "%s\n" "$as_me: failed program was:" >&5
 sed 's/^/| /' conftest.$ac_ext >&5
 
     ac_retval=1
@@ -1817,14 +1856,14 @@ fi
 ac_fn_cxx_try_compile ()
 {
   as_lineno=${as_lineno-"$1"} as_lineno_stack=as_lineno_stack=$as_lineno_stack
-  rm -f conftest.$ac_objext
+  rm -f conftest.$ac_objext conftest.beam
   if { { ac_try="$ac_compile"
 case "(($ac_try" in
   *\"* | *\`* | *\\*) ac_try_echo=\$ac_try;;
   *) ac_try_echo=$ac_try;;
 esac
 eval ac_try_echo="\"\$as_me:${as_lineno-$LINENO}: $ac_try_echo\""
-$as_echo "$ac_try_echo"; } >&5
+printf "%s\n" "$ac_try_echo"; } >&5
   (eval "$ac_compile") 2>conftest.err
   ac_status=$?
   if test -s conftest.err; then
@@ -1832,14 +1871,15 @@ $as_echo "$ac_try_echo"; } >&5
     cat conftest.er1 >&5
     mv -f conftest.er1 conftest.err
   fi
-  $as_echo "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
+  printf "%s\n" "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
   test $ac_status = 0; } && {
 	 test -z "$ac_cxx_werror_flag" ||
 	 test ! -s conftest.err
-       } && test -s conftest.$ac_objext; then :
+       } && test -s conftest.$ac_objext
+then :
   ac_retval=0
-else
-  $as_echo "$as_me: failed program was:" >&5
+else $as_nop
+  printf "%s\n" "$as_me: failed program was:" >&5
 sed 's/^/| /' conftest.$ac_ext >&5
 
 	ac_retval=1
@@ -1855,14 +1895,14 @@ fi
 ac_fn_c_try_link ()
 {
   as_lineno=${as_lineno-"$1"} as_lineno_stack=as_lineno_stack=$as_lineno_stack
-  rm -f conftest.$ac_objext conftest$ac_exeext
+  rm -f conftest.$ac_objext conftest.beam conftest$ac_exeext
   if { { ac_try="$ac_link"
 case "(($ac_try" in
   *\"* | *\`* | *\\*) ac_try_echo=\$ac_try;;
   *) ac_try_echo=$ac_try;;
 esac
 eval ac_try_echo="\"\$as_me:${as_lineno-$LINENO}: $ac_try_echo\""
-$as_echo "$ac_try_echo"; } >&5
+printf "%s\n" "$ac_try_echo"; } >&5
   (eval "$ac_link") 2>conftest.err
   ac_status=$?
   if test -s conftest.err; then
@@ -1870,17 +1910,18 @@ $as_echo "$ac_try_echo"; } >&5
     cat conftest.er1 >&5
     mv -f conftest.er1 conftest.err
   fi
-  $as_echo "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
+  printf "%s\n" "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
   test $ac_status = 0; } && {
 	 test -z "$ac_c_werror_flag" ||
 	 test ! -s conftest.err
        } && test -s conftest$ac_exeext && {
 	 test "$cross_compiling" = yes ||
 	 test -x conftest$ac_exeext
-       }; then :
+       }
+then :
   ac_retval=0
-else
-  $as_echo "$as_me: failed program was:" >&5
+else $as_nop
+  printf "%s\n" "$as_me: failed program was:" >&5
 sed 's/^/| /' conftest.$ac_ext >&5
 
 	ac_retval=1
@@ -1895,139 +1936,6 @@ fi
 
 } # ac_fn_c_try_link
 
-# ac_fn_c_try_run LINENO
-# ----------------------
-# Try to link conftest.$ac_ext, and return whether this succeeded. Assumes
-# that executables *can* be run.
-ac_fn_c_try_run ()
-{
-  as_lineno=${as_lineno-"$1"} as_lineno_stack=as_lineno_stack=$as_lineno_stack
-  if { { ac_try="$ac_link"
-case "(($ac_try" in
-  *\"* | *\`* | *\\*) ac_try_echo=\$ac_try;;
-  *) ac_try_echo=$ac_try;;
-esac
-eval ac_try_echo="\"\$as_me:${as_lineno-$LINENO}: $ac_try_echo\""
-$as_echo "$ac_try_echo"; } >&5
-  (eval "$ac_link") 2>&5
-  ac_status=$?
-  $as_echo "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
-  test $ac_status = 0; } && { ac_try='./conftest$ac_exeext'
-  { { case "(($ac_try" in
-  *\"* | *\`* | *\\*) ac_try_echo=\$ac_try;;
-  *) ac_try_echo=$ac_try;;
-esac
-eval ac_try_echo="\"\$as_me:${as_lineno-$LINENO}: $ac_try_echo\""
-$as_echo "$ac_try_echo"; } >&5
-  (eval "$ac_try") 2>&5
-  ac_status=$?
-  $as_echo "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
-  test $ac_status = 0; }; }; then :
-  ac_retval=0
-else
-  $as_echo "$as_me: program exited with status $ac_status" >&5
-       $as_echo "$as_me: failed program was:" >&5
-sed 's/^/| /' conftest.$ac_ext >&5
-
-       ac_retval=$ac_status
-fi
-  rm -rf conftest.dSYM conftest_ipa8_conftest.oo
-  eval $as_lineno_stack; ${as_lineno_stack:+:} unset as_lineno
-  as_fn_set_status $ac_retval
-
-} # ac_fn_c_try_run
-
-# ac_fn_c_check_header_mongrel LINENO HEADER VAR INCLUDES
-# -------------------------------------------------------
-# Tests whether HEADER exists, giving a warning if it cannot be compiled using
-# the include files in INCLUDES and setting the cache variable VAR
-# accordingly.
-ac_fn_c_check_header_mongrel ()
-{
-  as_lineno=${as_lineno-"$1"} as_lineno_stack=as_lineno_stack=$as_lineno_stack
-  if eval \${$3+:} false; then :
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $2" >&5
-$as_echo_n "checking for $2... " >&6; }
-if eval \${$3+:} false; then :
-  $as_echo_n "(cached) " >&6
-fi
-eval ac_res=\$$3
-	       { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_res" >&5
-$as_echo "$ac_res" >&6; }
-else
-  # Is the header compilable?
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking $2 usability" >&5
-$as_echo_n "checking $2 usability... " >&6; }
-cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
-$4
-#include <$2>
-_ACEOF
-if ac_fn_c_try_compile "$LINENO"; then :
-  ac_header_compiler=yes
-else
-  ac_header_compiler=no
-fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_header_compiler" >&5
-$as_echo "$ac_header_compiler" >&6; }
-
-# Is the header present?
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking $2 presence" >&5
-$as_echo_n "checking $2 presence... " >&6; }
-cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
-#include <$2>
-_ACEOF
-if ac_fn_c_try_cpp "$LINENO"; then :
-  ac_header_preproc=yes
-else
-  ac_header_preproc=no
-fi
-rm -f conftest.err conftest.i conftest.$ac_ext
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_header_preproc" >&5
-$as_echo "$ac_header_preproc" >&6; }
-
-# So?  What about this header?
-case $ac_header_compiler:$ac_header_preproc:$ac_c_preproc_warn_flag in #((
-  yes:no: )
-    { $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: $2: accepted by the compiler, rejected by the preprocessor!" >&5
-$as_echo "$as_me: WARNING: $2: accepted by the compiler, rejected by the preprocessor!" >&2;}
-    { $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: $2: proceeding with the compiler's result" >&5
-$as_echo "$as_me: WARNING: $2: proceeding with the compiler's result" >&2;}
-    ;;
-  no:yes:* )
-    { $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: $2: present but cannot be compiled" >&5
-$as_echo "$as_me: WARNING: $2: present but cannot be compiled" >&2;}
-    { $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: $2:     check for missing prerequisite headers?" >&5
-$as_echo "$as_me: WARNING: $2:     check for missing prerequisite headers?" >&2;}
-    { $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: $2: see the Autoconf documentation" >&5
-$as_echo "$as_me: WARNING: $2: see the Autoconf documentation" >&2;}
-    { $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: $2:     section \"Present But Cannot Be Compiled\"" >&5
-$as_echo "$as_me: WARNING: $2:     section \"Present But Cannot Be Compiled\"" >&2;}
-    { $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: $2: proceeding with the compiler's result" >&5
-$as_echo "$as_me: WARNING: $2: proceeding with the compiler's result" >&2;}
-( $as_echo "## ---------------------------------------------------------- ##
-## Report this to https://github.com/openprinting/cups/issues ##
-## ---------------------------------------------------------- ##"
-     ) | sed "s/^/$as_me: WARNING:     /" >&2
-    ;;
-esac
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $2" >&5
-$as_echo_n "checking for $2... " >&6; }
-if eval \${$3+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
-  eval "$3=\$ac_header_compiler"
-fi
-eval ac_res=\$$3
-	       { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_res" >&5
-$as_echo "$ac_res" >&6; }
-fi
-  eval $as_lineno_stack; ${as_lineno_stack:+:} unset as_lineno
-
-} # ac_fn_c_check_header_mongrel
-
 # ac_fn_c_check_header_compile LINENO HEADER VAR INCLUDES
 # -------------------------------------------------------
 # Tests whether HEADER exists and can be compiled using the include files in
@@ -2035,26 +1943,28 @@ fi
 ac_fn_c_check_header_compile ()
 {
   as_lineno=${as_lineno-"$1"} as_lineno_stack=as_lineno_stack=$as_lineno_stack
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $2" >&5
-$as_echo_n "checking for $2... " >&6; }
-if eval \${$3+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for $2" >&5
+printf %s "checking for $2... " >&6; }
+if eval test \${$3+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
 $4
 #include <$2>
 _ACEOF
-if ac_fn_c_try_compile "$LINENO"; then :
+if ac_fn_c_try_compile "$LINENO"
+then :
   eval "$3=yes"
-else
+else $as_nop
   eval "$3=no"
 fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
+rm -f core conftest.err conftest.$ac_objext conftest.beam conftest.$ac_ext
 fi
 eval ac_res=\$$3
-	       { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_res" >&5
-$as_echo "$ac_res" >&6; }
+	       { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_res" >&5
+printf "%s\n" "$ac_res" >&6; }
   eval $as_lineno_stack; ${as_lineno_stack:+:} unset as_lineno
 
 } # ac_fn_c_check_header_compile
@@ -2065,11 +1975,12 @@ $as_echo "$ac_res" >&6; }
 ac_fn_c_check_func ()
 {
   as_lineno=${as_lineno-"$1"} as_lineno_stack=as_lineno_stack=$as_lineno_stack
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $2" >&5
-$as_echo_n "checking for $2... " >&6; }
-if eval \${$3+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for $2" >&5
+printf %s "checking for $2... " >&6; }
+if eval test \${$3+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
 /* Define $2 to an innocuous variant, in case <limits.h> declares $2.
@@ -2077,16 +1988,9 @@ else
 #define $2 innocuous_$2
 
 /* System header to define __stub macros and hopefully few prototypes,
-    which can conflict with char $2 (); below.
-    Prefer <limits.h> to <assert.h> if __STDC__ is defined, since
-    <limits.h> exists even on freestanding compilers.  */
-
-#ifdef __STDC__
-# include <limits.h>
-#else
-# include <assert.h>
-#endif
+   which can conflict with char $2 (); below.  */
 
+#include <limits.h>
 #undef $2
 
 /* Override any GCC internal prototype to avoid an error.
@@ -2104,24 +2008,25 @@ choke me
 #endif
 
 int
-main ()
+main (void)
 {
 return $2 ();
   ;
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
+if ac_fn_c_try_link "$LINENO"
+then :
   eval "$3=yes"
-else
+else $as_nop
   eval "$3=no"
 fi
-rm -f core conftest.err conftest.$ac_objext \
+rm -f core conftest.err conftest.$ac_objext conftest.beam \
     conftest$ac_exeext conftest.$ac_ext
 fi
 eval ac_res=\$$3
-	       { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_res" >&5
-$as_echo "$ac_res" >&6; }
+	       { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_res" >&5
+printf "%s\n" "$ac_res" >&6; }
   eval $as_lineno_stack; ${as_lineno_stack:+:} unset as_lineno
 
 } # ac_fn_c_check_func
@@ -2133,16 +2038,17 @@ $as_echo "$ac_res" >&6; }
 ac_fn_c_check_member ()
 {
   as_lineno=${as_lineno-"$1"} as_lineno_stack=as_lineno_stack=$as_lineno_stack
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $2.$3" >&5
-$as_echo_n "checking for $2.$3... " >&6; }
-if eval \${$4+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for $2.$3" >&5
+printf %s "checking for $2.$3... " >&6; }
+if eval test \${$4+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
 $5
 int
-main ()
+main (void)
 {
 static $2 ac_aggr;
 if (ac_aggr.$3)
@@ -2151,14 +2057,15 @@ return 0;
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_compile "$LINENO"; then :
+if ac_fn_c_try_compile "$LINENO"
+then :
   eval "$4=yes"
-else
+else $as_nop
   cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
 $5
 int
-main ()
+main (void)
 {
 static $2 ac_aggr;
 if (sizeof ac_aggr.$3)
@@ -2167,29 +2074,50 @@ return 0;
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_compile "$LINENO"; then :
+if ac_fn_c_try_compile "$LINENO"
+then :
   eval "$4=yes"
-else
+else $as_nop
   eval "$4=no"
 fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
+rm -f core conftest.err conftest.$ac_objext conftest.beam conftest.$ac_ext
 fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
+rm -f core conftest.err conftest.$ac_objext conftest.beam conftest.$ac_ext
 fi
 eval ac_res=\$$4
-	       { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_res" >&5
-$as_echo "$ac_res" >&6; }
+	       { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_res" >&5
+printf "%s\n" "$ac_res" >&6; }
   eval $as_lineno_stack; ${as_lineno_stack:+:} unset as_lineno
 
 } # ac_fn_c_check_member
+ac_configure_args_raw=
+for ac_arg
+do
+  case $ac_arg in
+  *\'*)
+    ac_arg=`printf "%s\n" "$ac_arg" | sed "s/'/'\\\\\\\\''/g"` ;;
+  esac
+  as_fn_append ac_configure_args_raw " '$ac_arg'"
+done
+
+case $ac_configure_args_raw in
+  *$as_nl*)
+    ac_safe_unquote= ;;
+  *)
+    ac_unsafe_z='|&;<>()$`\\"*?[ ''	' # This string ends in space, tab.
+    ac_unsafe_a="$ac_unsafe_z#~"
+    ac_safe_unquote="s/ '\\([^$ac_unsafe_a][^$ac_unsafe_z]*\\)'/ \\1/g"
+    ac_configure_args_raw=`      printf "%s\n" "$ac_configure_args_raw" | sed "$ac_safe_unquote"`;;
+esac
+
 cat >config.log <<_ACEOF
 This file contains any messages produced by compilers while
 running configure, to aid debugging if configure makes a mistake.
 
-It was created by CUPS $as_me 2.3.3op1, which was
-generated by GNU Autoconf 2.69.  Invocation command line was
+It was created by CUPS $as_me 2.3.3op2, which was
+generated by GNU Autoconf 2.70.  Invocation command line was
 
-  $ $0 $@
+  $ $0$ac_configure_args_raw
 
 _ACEOF
 exec 5>>config.log
@@ -2222,8 +2150,12 @@ as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
 for as_dir in $PATH
 do
   IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
-    $as_echo "PATH: $as_dir"
+  case $as_dir in #(((
+    '') as_dir=./ ;;
+    */) ;;
+    *) as_dir=$as_dir/ ;;
+  esac
+    printf "%s\n" "PATH: $as_dir"
   done
 IFS=$as_save_IFS
 
@@ -2258,7 +2190,7 @@ do
     | -silent | --silent | --silen | --sile | --sil)
       continue ;;
     *\'*)
-      ac_arg=`$as_echo "$ac_arg" | sed "s/'/'\\\\\\\\''/g"` ;;
+      ac_arg=`printf "%s\n" "$ac_arg" | sed "s/'/'\\\\\\\\''/g"` ;;
     esac
     case $ac_pass in
     1) as_fn_append ac_configure_args0 " '$ac_arg'" ;;
@@ -2293,11 +2225,13 @@ done
 # WARNING: Use '\'' to represent an apostrophe within the trap.
 # WARNING: Do not start the trap code with a newline, due to a FreeBSD 4.0 bug.
 trap 'exit_status=$?
+  # Sanitize IFS.
+  IFS=" ""	$as_nl"
   # Save into config.log some information that might help in debugging.
   {
     echo
 
-    $as_echo "## ---------------- ##
+    printf "%s\n" "## ---------------- ##
 ## Cache variables. ##
 ## ---------------- ##"
     echo
@@ -2308,8 +2242,8 @@ trap 'exit_status=$?
     case $ac_val in #(
     *${as_nl}*)
       case $ac_var in #(
-      *_cv_*) { $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: cache variable $ac_var contains a newline" >&5
-$as_echo "$as_me: WARNING: cache variable $ac_var contains a newline" >&2;} ;;
+      *_cv_*) { printf "%s\n" "$as_me:${as_lineno-$LINENO}: WARNING: cache variable $ac_var contains a newline" >&5
+printf "%s\n" "$as_me: WARNING: cache variable $ac_var contains a newline" >&2;} ;;
       esac
       case $ac_var in #(
       _ | IFS | as_nl) ;; #(
@@ -2333,7 +2267,7 @@ $as_echo "$as_me: WARNING: cache variabl
 )
     echo
 
-    $as_echo "## ----------------- ##
+    printf "%s\n" "## ----------------- ##
 ## Output variables. ##
 ## ----------------- ##"
     echo
@@ -2341,14 +2275,14 @@ $as_echo "$as_me: WARNING: cache variabl
     do
       eval ac_val=\$$ac_var
       case $ac_val in
-      *\'\''*) ac_val=`$as_echo "$ac_val" | sed "s/'\''/'\''\\\\\\\\'\'''\''/g"`;;
+      *\'\''*) ac_val=`printf "%s\n" "$ac_val" | sed "s/'\''/'\''\\\\\\\\'\'''\''/g"`;;
       esac
-      $as_echo "$ac_var='\''$ac_val'\''"
+      printf "%s\n" "$ac_var='\''$ac_val'\''"
     done | sort
     echo
 
     if test -n "$ac_subst_files"; then
-      $as_echo "## ------------------- ##
+      printf "%s\n" "## ------------------- ##
 ## File substitutions. ##
 ## ------------------- ##"
       echo
@@ -2356,15 +2290,15 @@ $as_echo "$as_me: WARNING: cache variabl
       do
 	eval ac_val=\$$ac_var
 	case $ac_val in
-	*\'\''*) ac_val=`$as_echo "$ac_val" | sed "s/'\''/'\''\\\\\\\\'\'''\''/g"`;;
+	*\'\''*) ac_val=`printf "%s\n" "$ac_val" | sed "s/'\''/'\''\\\\\\\\'\'''\''/g"`;;
 	esac
-	$as_echo "$ac_var='\''$ac_val'\''"
+	printf "%s\n" "$ac_var='\''$ac_val'\''"
       done | sort
       echo
     fi
 
     if test -s confdefs.h; then
-      $as_echo "## ----------- ##
+      printf "%s\n" "## ----------- ##
 ## confdefs.h. ##
 ## ----------- ##"
       echo
@@ -2372,8 +2306,8 @@ $as_echo "$as_me: WARNING: cache variabl
       echo
     fi
     test "$ac_signal" != 0 &&
-      $as_echo "$as_me: caught signal $ac_signal"
-    $as_echo "$as_me: exit $exit_status"
+      printf "%s\n" "$as_me: caught signal $ac_signal"
+    printf "%s\n" "$as_me: exit $exit_status"
   } >&5
   rm -f core *.core core.conftest.* &&
     rm -f -r conftest* confdefs* conf$$* $ac_clean_files &&
@@ -2387,63 +2321,48 @@ ac_signal=0
 # confdefs.h avoids OS command line length limits that DEFS can exceed.
 rm -f -r conftest* confdefs.h
 
-$as_echo "/* confdefs.h */" > confdefs.h
+printf "%s\n" "/* confdefs.h */" > confdefs.h
 
 # Predefined preprocessor variables.
 
-cat >>confdefs.h <<_ACEOF
-#define PACKAGE_NAME "$PACKAGE_NAME"
-_ACEOF
+printf "%s\n" "#define PACKAGE_NAME \"$PACKAGE_NAME\"" >>confdefs.h
 
-cat >>confdefs.h <<_ACEOF
-#define PACKAGE_TARNAME "$PACKAGE_TARNAME"
-_ACEOF
+printf "%s\n" "#define PACKAGE_TARNAME \"$PACKAGE_TARNAME\"" >>confdefs.h
 
-cat >>confdefs.h <<_ACEOF
-#define PACKAGE_VERSION "$PACKAGE_VERSION"
-_ACEOF
+printf "%s\n" "#define PACKAGE_VERSION \"$PACKAGE_VERSION\"" >>confdefs.h
 
-cat >>confdefs.h <<_ACEOF
-#define PACKAGE_STRING "$PACKAGE_STRING"
-_ACEOF
+printf "%s\n" "#define PACKAGE_STRING \"$PACKAGE_STRING\"" >>confdefs.h
 
-cat >>confdefs.h <<_ACEOF
-#define PACKAGE_BUGREPORT "$PACKAGE_BUGREPORT"
-_ACEOF
+printf "%s\n" "#define PACKAGE_BUGREPORT \"$PACKAGE_BUGREPORT\"" >>confdefs.h
 
-cat >>confdefs.h <<_ACEOF
-#define PACKAGE_URL "$PACKAGE_URL"
-_ACEOF
+printf "%s\n" "#define PACKAGE_URL \"$PACKAGE_URL\"" >>confdefs.h
 
 
 # Let the site file select an alternate cache file if it wants to.
 # Prefer an explicitly selected file to automatically selected ones.
-ac_site_file1=NONE
-ac_site_file2=NONE
 if test -n "$CONFIG_SITE"; then
-  # We do not want a PATH search for config.site.
-  case $CONFIG_SITE in #((
-    -*)  ac_site_file1=./$CONFIG_SITE;;
-    */*) ac_site_file1=$CONFIG_SITE;;
-    *)   ac_site_file1=./$CONFIG_SITE;;
-  esac
+  ac_site_files="$CONFIG_SITE"
 elif test "x$prefix" != xNONE; then
-  ac_site_file1=$prefix/share/config.site
-  ac_site_file2=$prefix/etc/config.site
+  ac_site_files="$prefix/share/config.site $prefix/etc/config.site"
 else
-  ac_site_file1=$ac_default_prefix/share/config.site
-  ac_site_file2=$ac_default_prefix/etc/config.site
+  ac_site_files="$ac_default_prefix/share/config.site $ac_default_prefix/etc/config.site"
 fi
-for ac_site_file in "$ac_site_file1" "$ac_site_file2"
+
+for ac_site_file in $ac_site_files
 do
-  test "x$ac_site_file" = xNONE && continue
-  if test /dev/null != "$ac_site_file" && test -r "$ac_site_file"; then
-    { $as_echo "$as_me:${as_lineno-$LINENO}: loading site script $ac_site_file" >&5
-$as_echo "$as_me: loading site script $ac_site_file" >&6;}
+  case $ac_site_file in #(
+  */*) :
+     ;; #(
+  *) :
+    ac_site_file=./$ac_site_file ;;
+esac
+  if test -f "$ac_site_file" && test -r "$ac_site_file"; then
+    { printf "%s\n" "$as_me:${as_lineno-$LINENO}: loading site script $ac_site_file" >&5
+printf "%s\n" "$as_me: loading site script $ac_site_file" >&6;}
     sed 's/^/| /' "$ac_site_file" >&5
     . "$ac_site_file" \
-      || { { $as_echo "$as_me:${as_lineno-$LINENO}: error: in \`$ac_pwd':" >&5
-$as_echo "$as_me: error: in \`$ac_pwd':" >&2;}
+      || { { printf "%s\n" "$as_me:${as_lineno-$LINENO}: error: in \`$ac_pwd':" >&5
+printf "%s\n" "$as_me: error: in \`$ac_pwd':" >&2;}
 as_fn_error $? "failed to load site script $ac_site_file
 See \`config.log' for more details" "$LINENO" 5; }
   fi
@@ -2453,138 +2372,745 @@ if test -r "$cache_file"; then
   # Some versions of bash will fail to source /dev/null (special files
   # actually), so we avoid doing that.  DJGPP emulates it as a regular file.
   if test /dev/null != "$cache_file" && test -f "$cache_file"; then
-    { $as_echo "$as_me:${as_lineno-$LINENO}: loading cache $cache_file" >&5
-$as_echo "$as_me: loading cache $cache_file" >&6;}
+    { printf "%s\n" "$as_me:${as_lineno-$LINENO}: loading cache $cache_file" >&5
+printf "%s\n" "$as_me: loading cache $cache_file" >&6;}
     case $cache_file in
       [\\/]* | ?:[\\/]* ) . "$cache_file";;
       *)                      . "./$cache_file";;
     esac
   fi
 else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: creating cache $cache_file" >&5
-$as_echo "$as_me: creating cache $cache_file" >&6;}
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: creating cache $cache_file" >&5
+printf "%s\n" "$as_me: creating cache $cache_file" >&6;}
   >$cache_file
 fi
 
-# Check that the precious variables saved in the cache have kept the same
-# value.
-ac_cache_corrupted=false
-for ac_var in $ac_precious_vars; do
-  eval ac_old_set=\$ac_cv_env_${ac_var}_set
-  eval ac_new_set=\$ac_env_${ac_var}_set
-  eval ac_old_val=\$ac_cv_env_${ac_var}_value
-  eval ac_new_val=\$ac_env_${ac_var}_value
-  case $ac_old_set,$ac_new_set in
-    set,)
-      { $as_echo "$as_me:${as_lineno-$LINENO}: error: \`$ac_var' was set to \`$ac_old_val' in the previous run" >&5
-$as_echo "$as_me: error: \`$ac_var' was set to \`$ac_old_val' in the previous run" >&2;}
-      ac_cache_corrupted=: ;;
-    ,set)
-      { $as_echo "$as_me:${as_lineno-$LINENO}: error: \`$ac_var' was not set in the previous run" >&5
-$as_echo "$as_me: error: \`$ac_var' was not set in the previous run" >&2;}
-      ac_cache_corrupted=: ;;
-    ,);;
-    *)
-      if test "x$ac_old_val" != "x$ac_new_val"; then
-	# differences in whitespace do not lead to failure.
-	ac_old_val_w=`echo x $ac_old_val`
-	ac_new_val_w=`echo x $ac_new_val`
-	if test "$ac_old_val_w" != "$ac_new_val_w"; then
-	  { $as_echo "$as_me:${as_lineno-$LINENO}: error: \`$ac_var' has changed since the previous run:" >&5
-$as_echo "$as_me: error: \`$ac_var' has changed since the previous run:" >&2;}
-	  ac_cache_corrupted=:
-	else
-	  { $as_echo "$as_me:${as_lineno-$LINENO}: warning: ignoring whitespace changes in \`$ac_var' since the previous run:" >&5
-$as_echo "$as_me: warning: ignoring whitespace changes in \`$ac_var' since the previous run:" >&2;}
-	  eval $ac_var=\$ac_old_val
-	fi
-	{ $as_echo "$as_me:${as_lineno-$LINENO}:   former value:  \`$ac_old_val'" >&5
-$as_echo "$as_me:   former value:  \`$ac_old_val'" >&2;}
-	{ $as_echo "$as_me:${as_lineno-$LINENO}:   current value: \`$ac_new_val'" >&5
-$as_echo "$as_me:   current value: \`$ac_new_val'" >&2;}
-      fi;;
-  esac
-  # Pass precious variables to config.status.
-  if test "$ac_new_set" = set; then
-    case $ac_new_val in
-    *\'*) ac_arg=$ac_var=`$as_echo "$ac_new_val" | sed "s/'/'\\\\\\\\''/g"` ;;
-    *) ac_arg=$ac_var=$ac_new_val ;;
-    esac
-    case " $ac_configure_args " in
-      *" '$ac_arg' "*) ;; # Avoid dups.  Use of quotes ensures accuracy.
-      *) as_fn_append ac_configure_args " '$ac_arg'" ;;
-    esac
-  fi
-done
-if $ac_cache_corrupted; then
-  { $as_echo "$as_me:${as_lineno-$LINENO}: error: in \`$ac_pwd':" >&5
-$as_echo "$as_me: error: in \`$ac_pwd':" >&2;}
-  { $as_echo "$as_me:${as_lineno-$LINENO}: error: changes in the environment can compromise the build" >&5
-$as_echo "$as_me: error: changes in the environment can compromise the build" >&2;}
-  as_fn_error $? "run \`make distclean' and/or \`rm $cache_file' and start over" "$LINENO" 5
-fi
-## -------------------- ##
-## Main body of script. ##
-## -------------------- ##
+# Test code for whether the C compiler supports C89 (global declarations)
+ac_c_conftest_c89_globals='
+/* Does the compiler advertise C89 conformance?
+   Do not test the value of __STDC__, because some compilers set it to 0
+   while being otherwise adequately conformant. */
+#if !defined __STDC__
+# error "Compiler does not advertise C89 conformance"
+#endif
 
-ac_ext=c
-ac_cpp='$CPP $CPPFLAGS'
-ac_compile='$CC -c $CFLAGS $CPPFLAGS conftest.$ac_ext >&5'
-ac_link='$CC -o conftest$ac_exeext $CFLAGS $CPPFLAGS $LDFLAGS conftest.$ac_ext $LIBS >&5'
-ac_compiler_gnu=$ac_cv_c_compiler_gnu
+#include <stddef.h>
+#include <stdarg.h>
+struct stat;
+/* Most of the following tests are stolen from RCS 5.7 src/conf.sh.  */
+struct buf { int x; };
+struct buf * (*rcsopen) (struct buf *, struct stat *, int);
+static char *e (p, i)
+     char **p;
+     int i;
+{
+  return p[i];
+}
+static char *f (char * (*g) (char **, int), char **p, ...)
+{
+  char *s;
+  va_list v;
+  va_start (v,p);
+  s = g (p, va_arg (v,int));
+  va_end (v);
+  return s;
+}
 
+/* OSF 4.0 Compaq cc is some sort of almost-ANSI by default.  It has
+   function prototypes and stuff, but not \xHH hex character constants.
+   These do not provoke an error unfortunately, instead are silently treated
+   as an "x".  The following induces an error, until -std is added to get
+   proper ANSI mode.  Curiously \x00 != x always comes out true, for an
+   array size at least.  It is necessary to write \x00 == 0 to get something
+   that is true only with -std.  */
+int osf4_cc_array ['\''\x00'\'' == 0 ? 1 : -1];
 
+/* IBM C 6 for AIX is almost-ANSI by default, but it replaces macro parameters
+   inside strings and character constants.  */
+#define FOO(x) '\''x'\''
+int xlc6_cc_array[FOO(a) == '\''x'\'' ? 1 : -1];
 
+int test (int i, double x);
+struct s1 {int (*f) (int a);};
+struct s2 {int (*f) (double a);};
+int pairnames (int, char **, int *(*)(struct buf *, struct stat *, int),
+               int, int);'
 
-ac_aux_dir=
-for ac_dir in "$srcdir" "$srcdir/.." "$srcdir/../.."; do
-  if test -f "$ac_dir/install-sh"; then
-    ac_aux_dir=$ac_dir
-    ac_install_sh="$ac_aux_dir/install-sh -c"
-    break
-  elif test -f "$ac_dir/install.sh"; then
-    ac_aux_dir=$ac_dir
-    ac_install_sh="$ac_aux_dir/install.sh -c"
-    break
-  elif test -f "$ac_dir/shtool"; then
-    ac_aux_dir=$ac_dir
-    ac_install_sh="$ac_aux_dir/shtool install -c"
-    break
-  fi
-done
-if test -z "$ac_aux_dir"; then
-  as_fn_error $? "cannot find install-sh, install.sh, or shtool in \"$srcdir\" \"$srcdir/..\" \"$srcdir/../..\"" "$LINENO" 5
-fi
+# Test code for whether the C compiler supports C89 (body of main).
+ac_c_conftest_c89_main='
+ok |= (argc == 0 || f (e, argv, 0) != argv[0] || f (e, argv, 1) != argv[1]);
+'
 
-# These three variables are undocumented and unsupported,
-# and are intended to be withdrawn in a future Autoconf release.
-# They can cause serious problems if a builder's source tree is in a directory
-# whose full name contains unusual characters.
-ac_config_guess="$SHELL $ac_aux_dir/config.guess"  # Please don't use this var.
-ac_config_sub="$SHELL $ac_aux_dir/config.sub"  # Please don't use this var.
-ac_configure="$SHELL $ac_aux_dir/configure"  # Please don't use this var.
+# Test code for whether the C compiler supports C99 (global declarations)
+ac_c_conftest_c99_globals='
+// Does the compiler advertise C99 conformance?
+#if !defined __STDC_VERSION__ || __STDC_VERSION__ < 199901L
+# error "Compiler does not advertise C99 conformance"
+#endif
+
+#include <stdbool.h>
+extern int puts (const char *);
+extern int printf (const char *, ...);
+extern int dprintf (int, const char *, ...);
+extern void *malloc (size_t);
+
+// Check varargs macros.  These examples are taken from C99 6.10.3.5.
+// dprintf is used instead of fprintf to avoid needing to declare
+// FILE and stderr.
+#define debug(...) dprintf (2, __VA_ARGS__)
+#define showlist(...) puts (#__VA_ARGS__)
+#define report(test,...) ((test) ? puts (#test) : printf (__VA_ARGS__))
+static void
+test_varargs_macros (void)
+{
+  int x = 1234;
+  int y = 5678;
+  debug ("Flag");
+  debug ("X = %d\n", x);
+  showlist (The first, second, and third items.);
+  report (x>y, "x is %d but y is %d", x, y);
+}
+
+// Check long long types.
+#define BIG64 18446744073709551615ull
+#define BIG32 4294967295ul
+#define BIG_OK (BIG64 / BIG32 == 4294967297ull && BIG64 % BIG32 == 0)
+#if !BIG_OK
+  #error "your preprocessor is broken"
+#endif
+#if BIG_OK
+#else
+  #error "your preprocessor is broken"
+#endif
+static long long int bignum = -9223372036854775807LL;
+static unsigned long long int ubignum = BIG64;
 
+struct incomplete_array
+{
+  int datasize;
+  double data[];
+};
 
-# Make sure we can run config.sub.
-$SHELL "$ac_aux_dir/config.sub" sun4 >/dev/null 2>&1 ||
-  as_fn_error $? "cannot run $SHELL $ac_aux_dir/config.sub" "$LINENO" 5
-
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking build system type" >&5
-$as_echo_n "checking build system type... " >&6; }
-if ${ac_cv_build+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+struct named_init {
+  int number;
+  const wchar_t *name;
+  double average;
+};
+
+typedef const char *ccp;
+
+static inline int
+test_restrict (ccp restrict text)
+{
+  // See if C++-style comments work.
+  // Iterate through items via the restricted pointer.
+  // Also check for declarations in for loops.
+  for (unsigned int i = 0; *(text+i) != '\''\0'\''; ++i)
+    continue;
+  return 0;
+}
+
+// Check varargs and va_copy.
+static bool
+test_varargs (const char *format, ...)
+{
+  va_list args;
+  va_start (args, format);
+  va_list args_copy;
+  va_copy (args_copy, args);
+
+  const char *str = "";
+  int number = 0;
+  float fnumber = 0;
+
+  while (*format)
+    {
+      switch (*format++)
+	{
+	case '\''s'\'': // string
+	  str = va_arg (args_copy, const char *);
+	  break;
+	case '\''d'\'': // int
+	  number = va_arg (args_copy, int);
+	  break;
+	case '\''f'\'': // float
+	  fnumber = va_arg (args_copy, double);
+	  break;
+	default:
+	  break;
+	}
+    }
+  va_end (args_copy);
+  va_end (args);
+
+  return *str && number && fnumber;
+}
+'
+
+# Test code for whether the C compiler supports C99 (body of main).
+ac_c_conftest_c99_main='
+  // Check bool.
+  _Bool success = false;
+  success |= (argc != 0);
+
+  // Check restrict.
+  if (test_restrict ("String literal") == 0)
+    success = true;
+  char *restrict newvar = "Another string";
+
+  // Check varargs.
+  success &= test_varargs ("s, d'\'' f .", "string", 65, 34.234);
+  test_varargs_macros ();
+
+  // Check flexible array members.
+  struct incomplete_array *ia =
+    malloc (sizeof (struct incomplete_array) + (sizeof (double) * 10));
+  ia->datasize = 10;
+  for (int i = 0; i < ia->datasize; ++i)
+    ia->data[i] = i * 1.234;
+
+  // Check named initializers.
+  struct named_init ni = {
+    .number = 34,
+    .name = L"Test wide string",
+    .average = 543.34343,
+  };
+
+  ni.number = 58;
+
+  int dynamic_array[ni.number];
+  dynamic_array[0] = argv[0][0];
+  dynamic_array[ni.number - 1] = 543;
+
+  // work around unused variable warnings
+  ok |= (!success || bignum == 0LL || ubignum == 0uLL || newvar[0] == '\''x'\''
+	 || dynamic_array[ni.number - 1] != 543);
+'
+
+# Test code for whether the C compiler supports C11 (global declarations)
+ac_c_conftest_c11_globals='
+// Does the compiler advertise C11 conformance?
+#if !defined __STDC_VERSION__ || __STDC_VERSION__ < 201112L
+# error "Compiler does not advertise C11 conformance"
+#endif
+
+// Check _Alignas.
+char _Alignas (double) aligned_as_double;
+char _Alignas (0) no_special_alignment;
+extern char aligned_as_int;
+char _Alignas (0) _Alignas (int) aligned_as_int;
+
+// Check _Alignof.
+enum
+{
+  int_alignment = _Alignof (int),
+  int_array_alignment = _Alignof (int[100]),
+  char_alignment = _Alignof (char)
+};
+_Static_assert (0 < -_Alignof (int), "_Alignof is signed");
+
+// Check _Noreturn.
+int _Noreturn does_not_return (void) { for (;;) continue; }
+
+// Check _Static_assert.
+struct test_static_assert
+{
+  int x;
+  _Static_assert (sizeof (int) <= sizeof (long int),
+                  "_Static_assert does not work in struct");
+  long int y;
+};
+
+// Check UTF-8 literals.
+#define u8 syntax error!
+char const utf8_literal[] = u8"happens to be ASCII" "another string";
+
+// Check duplicate typedefs.
+typedef long *long_ptr;
+typedef long int *long_ptr;
+typedef long_ptr long_ptr;
+
+// Anonymous structures and unions -- taken from C11 6.7.2.1 Example 1.
+struct anonymous
+{
+  union {
+    struct { int i; int j; };
+    struct { int k; long int l; } w;
+  };
+  int m;
+} v1;
+'
+
+# Test code for whether the C compiler supports C11 (body of main).
+ac_c_conftest_c11_main='
+  _Static_assert ((offsetof (struct anonymous, i)
+		   == offsetof (struct anonymous, w.k)),
+		  "Anonymous union alignment botch");
+  v1.i = 2;
+  v1.w.k = 5;
+  ok |= v1.i != 5;
+'
+
+# Test code for whether the C compiler supports C11 (complete).
+ac_c_conftest_c11_program="${ac_c_conftest_c89_globals}
+${ac_c_conftest_c99_globals}
+${ac_c_conftest_c11_globals}
+
+int
+main (int argc, char **argv)
+{
+  int ok = 0;
+  ${ac_c_conftest_c89_main}
+  ${ac_c_conftest_c99_main}
+  ${ac_c_conftest_c11_main}
+  return ok;
+}
+"
+
+# Test code for whether the C compiler supports C99 (complete).
+ac_c_conftest_c99_program="${ac_c_conftest_c89_globals}
+${ac_c_conftest_c99_globals}
+
+int
+main (int argc, char **argv)
+{
+  int ok = 0;
+  ${ac_c_conftest_c89_main}
+  ${ac_c_conftest_c99_main}
+  return ok;
+}
+"
+
+# Test code for whether the C compiler supports C89 (complete).
+ac_c_conftest_c89_program="${ac_c_conftest_c89_globals}
+
+int
+main (int argc, char **argv)
+{
+  int ok = 0;
+  ${ac_c_conftest_c89_main}
+  return ok;
+}
+"
+
+# Test code for whether the C++ compiler supports C++98 (global declarations)
+ac_cxx_conftest_cxx98_globals='
+// Does the compiler advertise C++98 conformance?
+#if !defined __cplusplus || __cplusplus < 199711L
+# error "Compiler does not advertise C++98 conformance"
+#endif
+
+// These inclusions are to reject old compilers that
+// lack the unsuffixed header files.
+#include <cstdlib>
+#include <exception>
+
+// <cassert> and <cstring> are *not* freestanding headers in C++98.
+extern void assert (int);
+namespace std {
+  extern int strcmp (const char *, const char *);
+}
+
+// Namespaces, exceptions, and templates were all added after "C++ 2.0".
+using std::exception;
+using std::strcmp;
+
+namespace {
+
+void test_exception_syntax()
+{
+  try {
+    throw "test";
+  } catch (const char *s) {
+    // Extra parentheses suppress a warning when building autoconf itself,
+    // due to lint rules shared with more typical C programs.
+    assert (!(strcmp) (s, "test"));
+  }
+}
+
+template <typename T> struct test_template
+{
+  T const val;
+  explicit test_template(T t) : val(t) {}
+  template <typename U> T add(U u) { return static_cast<T>(u) + val; }
+};
+
+} // anonymous namespace
+'
+
+# Test code for whether the C++ compiler supports C++98 (body of main)
+ac_cxx_conftest_cxx98_main='
+  assert (argc);
+  assert (! argv[0]);
+{
+  test_exception_syntax ();
+  test_template<double> tt (2.0);
+  assert (tt.add (4) == 6.0);
+  assert (true && !false);
+}
+'
+
+# Test code for whether the C++ compiler supports C++11 (global declarations)
+ac_cxx_conftest_cxx11_globals='
+// Does the compiler advertise C++ 2011 conformance?
+#if !defined __cplusplus || __cplusplus < 201103L
+# error "Compiler does not advertise C++11 conformance"
+#endif
+
+namespace cxx11test
+{
+  constexpr int get_val() { return 20; }
+
+  struct testinit
+  {
+    int i;
+    double d;
+  };
+
+  class delegate
+  {
+  public:
+    delegate(int n) : n(n) {}
+    delegate(): delegate(2354) {}
+
+    virtual int getval() { return this->n; };
+  protected:
+    int n;
+  };
+
+  class overridden : public delegate
+  {
+  public:
+    overridden(int n): delegate(n) {}
+    virtual int getval() override final { return this->n * 2; }
+  };
+
+  class nocopy
+  {
+  public:
+    nocopy(int i): i(i) {}
+    nocopy() = default;
+    nocopy(const nocopy&) = delete;
+    nocopy & operator=(const nocopy&) = delete;
+  private:
+    int i;
+  };
+
+  // for testing lambda expressions
+  template <typename Ret, typename Fn> Ret eval(Fn f, Ret v)
+  {
+    return f(v);
+  }
+
+  // for testing variadic templates and trailing return types
+  template <typename V> auto sum(V first) -> V
+  {
+    return first;
+  }
+  template <typename V, typename... Args> auto sum(V first, Args... rest) -> V
+  {
+    return first + sum(rest...);
+  }
+}
+'
+
+# Test code for whether the C++ compiler supports C++11 (body of main)
+ac_cxx_conftest_cxx11_main='
+{
+  // Test auto and decltype
+  auto a1 = 6538;
+  auto a2 = 48573953.4;
+  auto a3 = "String literal";
+
+  int total = 0;
+  for (auto i = a3; *i; ++i) { total += *i; }
+
+  decltype(a2) a4 = 34895.034;
+}
+{
+  // Test constexpr
+  short sa[cxx11test::get_val()] = { 0 };
+}
+{
+  // Test initializer lists
+  cxx11test::testinit il = { 4323, 435234.23544 };
+}
+{
+  // Test range-based for
+  int array[] = {9, 7, 13, 15, 4, 18, 12, 10, 5, 3,
+                 14, 19, 17, 8, 6, 20, 16, 2, 11, 1};
+  for (auto &x : array) { x += 23; }
+}
+{
+  // Test lambda expressions
+  using cxx11test::eval;
+  assert (eval ([](int x) { return x*2; }, 21) == 42);
+  double d = 2.0;
+  assert (eval ([&](double x) { return d += x; }, 3.0) == 5.0);
+  assert (d == 5.0);
+  assert (eval ([=](double x) mutable { return d += x; }, 4.0) == 9.0);
+  assert (d == 5.0);
+}
+{
+  // Test use of variadic templates
+  using cxx11test::sum;
+  auto a = sum(1);
+  auto b = sum(1, 2);
+  auto c = sum(1.0, 2.0, 3.0);
+}
+{
+  // Test constructor delegation
+  cxx11test::delegate d1;
+  cxx11test::delegate d2();
+  cxx11test::delegate d3(45);
+}
+{
+  // Test override and final
+  cxx11test::overridden o1(55464);
+}
+{
+  // Test nullptr
+  char *c = nullptr;
+}
+{
+  // Test template brackets
+  test_template<::test_template<int>> v(test_template<int>(12));
+}
+{
+  // Unicode literals
+  char const *utf8 = u8"UTF-8 string \u2500";
+  char16_t const *utf16 = u"UTF-8 string \u2500";
+  char32_t const *utf32 = U"UTF-32 string \u2500";
+}
+'
+
+# Test code for whether the C compiler supports C++11 (complete).
+ac_cxx_conftest_cxx11_program="${ac_cxx_conftest_cxx98_globals}
+${ac_cxx_conftest_cxx11_globals}
+
+int
+main (int argc, char **argv)
+{
+  int ok = 0;
+  ${ac_cxx_conftest_cxx98_main}
+  ${ac_cxx_conftest_cxx11_main}
+  return ok;
+}
+"
+
+# Test code for whether the C compiler supports C++98 (complete).
+ac_cxx_conftest_cxx98_program="${ac_cxx_conftest_cxx98_globals}
+int
+main (int argc, char **argv)
+{
+  int ok = 0;
+  ${ac_cxx_conftest_cxx98_main}
+  return ok;
+}
+"
+
+as_fn_append ac_header_c_list " stdio.h stdio_h HAVE_STDIO_H"
+as_fn_append ac_header_c_list " stdlib.h stdlib_h HAVE_STDLIB_H"
+as_fn_append ac_header_c_list " string.h string_h HAVE_STRING_H"
+as_fn_append ac_header_c_list " inttypes.h inttypes_h HAVE_INTTYPES_H"
+as_fn_append ac_header_c_list " stdint.h stdint_h HAVE_STDINT_H"
+as_fn_append ac_header_c_list " strings.h strings_h HAVE_STRINGS_H"
+as_fn_append ac_header_c_list " sys/stat.h sys_stat_h HAVE_SYS_STAT_H"
+as_fn_append ac_header_c_list " sys/types.h sys_types_h HAVE_SYS_TYPES_H"
+as_fn_append ac_header_c_list " unistd.h unistd_h HAVE_UNISTD_H"
+
+# Auxiliary files required by this configure script.
+ac_aux_files="config.guess config.sub"
+
+# Locations in which to look for auxiliary files.
+ac_aux_dir_candidates="${srcdir}${PATH_SEPARATOR}${srcdir}/..${PATH_SEPARATOR}${srcdir}/../.."
+
+# Search for a directory containing all of the required auxiliary files,
+# $ac_aux_files, from the $PATH-style list $ac_aux_dir_candidates.
+# If we don't find one directory that contains all the files we need,
+# we report the set of missing files from the *first* directory in
+# $ac_aux_dir_candidates and give up.
+ac_missing_aux_files=""
+ac_first_candidate=:
+printf "%s\n" "$as_me:${as_lineno-$LINENO}: looking for aux files: $ac_aux_files" >&5
+as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
+as_found=false
+for as_dir in $ac_aux_dir_candidates
+do
+  IFS=$as_save_IFS
+  case $as_dir in #(((
+    '') as_dir=./ ;;
+    */) ;;
+    *) as_dir=$as_dir/ ;;
+  esac
+  as_found=:
+
+  printf "%s\n" "$as_me:${as_lineno-$LINENO}:  trying $as_dir" >&5
+  ac_aux_dir_found=yes
+  ac_install_sh=
+  for ac_aux in $ac_aux_files
+  do
+    # As a special case, if "install-sh" is required, that requirement
+    # can be satisfied by any of "install-sh", "install.sh", or "shtool",
+    # and $ac_install_sh is set appropriately for whichever one is found.
+    if test x"$ac_aux" = x"install-sh"
+    then
+      if test -f "${as_dir}install-sh"; then
+        printf "%s\n" "$as_me:${as_lineno-$LINENO}:   ${as_dir}install-sh found" >&5
+        ac_install_sh="${as_dir}install-sh -c"
+      elif test -f "${as_dir}install.sh"; then
+        printf "%s\n" "$as_me:${as_lineno-$LINENO}:   ${as_dir}install.sh found" >&5
+        ac_install_sh="${as_dir}install.sh -c"
+      elif test -f "${as_dir}shtool"; then
+        printf "%s\n" "$as_me:${as_lineno-$LINENO}:   ${as_dir}shtool found" >&5
+        ac_install_sh="${as_dir}shtool install -c"
+      else
+        ac_aux_dir_found=no
+        if $ac_first_candidate; then
+          ac_missing_aux_files="${ac_missing_aux_files} install-sh"
+        else
+          break
+        fi
+      fi
+    else
+      if test -f "${as_dir}${ac_aux}"; then
+        printf "%s\n" "$as_me:${as_lineno-$LINENO}:   ${as_dir}${ac_aux} found" >&5
+      else
+        ac_aux_dir_found=no
+        if $ac_first_candidate; then
+          ac_missing_aux_files="${ac_missing_aux_files} ${ac_aux}"
+        else
+          break
+        fi
+      fi
+    fi
+  done
+  if test "$ac_aux_dir_found" = yes; then
+    ac_aux_dir="$as_dir"
+    break
+  fi
+  ac_first_candidate=false
+
+  as_found=false
+done
+IFS=$as_save_IFS
+if $as_found
+then :
+
+else $as_nop
+  as_fn_error $? "cannot find required auxiliary files:$ac_missing_aux_files" "$LINENO" 5
+fi
+
+
+# These three variables are undocumented and unsupported,
+# and are intended to be withdrawn in a future Autoconf release.
+# They can cause serious problems if a builder's source tree is in a directory
+# whose full name contains unusual characters.
+if test -f "${ac_aux_dir}config.guess"; then
+  ac_config_guess="$SHELL ${ac_aux_dir}config.guess"
+fi
+if test -f "${ac_aux_dir}config.sub"; then
+  ac_config_sub="$SHELL ${ac_aux_dir}config.sub"
+fi
+if test -f "$ac_aux_dir/configure"; then
+  ac_configure="$SHELL ${ac_aux_dir}configure"
+fi
+
+# Check that the precious variables saved in the cache have kept the same
+# value.
+ac_cache_corrupted=false
+for ac_var in $ac_precious_vars; do
+  eval ac_old_set=\$ac_cv_env_${ac_var}_set
+  eval ac_new_set=\$ac_env_${ac_var}_set
+  eval ac_old_val=\$ac_cv_env_${ac_var}_value
+  eval ac_new_val=\$ac_env_${ac_var}_value
+  case $ac_old_set,$ac_new_set in
+    set,)
+      { printf "%s\n" "$as_me:${as_lineno-$LINENO}: error: \`$ac_var' was set to \`$ac_old_val' in the previous run" >&5
+printf "%s\n" "$as_me: error: \`$ac_var' was set to \`$ac_old_val' in the previous run" >&2;}
+      ac_cache_corrupted=: ;;
+    ,set)
+      { printf "%s\n" "$as_me:${as_lineno-$LINENO}: error: \`$ac_var' was not set in the previous run" >&5
+printf "%s\n" "$as_me: error: \`$ac_var' was not set in the previous run" >&2;}
+      ac_cache_corrupted=: ;;
+    ,);;
+    *)
+      if test "x$ac_old_val" != "x$ac_new_val"; then
+	# differences in whitespace do not lead to failure.
+	ac_old_val_w=`echo x $ac_old_val`
+	ac_new_val_w=`echo x $ac_new_val`
+	if test "$ac_old_val_w" != "$ac_new_val_w"; then
+	  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: error: \`$ac_var' has changed since the previous run:" >&5
+printf "%s\n" "$as_me: error: \`$ac_var' has changed since the previous run:" >&2;}
+	  ac_cache_corrupted=:
+	else
+	  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: warning: ignoring whitespace changes in \`$ac_var' since the previous run:" >&5
+printf "%s\n" "$as_me: warning: ignoring whitespace changes in \`$ac_var' since the previous run:" >&2;}
+	  eval $ac_var=\$ac_old_val
+	fi
+	{ printf "%s\n" "$as_me:${as_lineno-$LINENO}:   former value:  \`$ac_old_val'" >&5
+printf "%s\n" "$as_me:   former value:  \`$ac_old_val'" >&2;}
+	{ printf "%s\n" "$as_me:${as_lineno-$LINENO}:   current value: \`$ac_new_val'" >&5
+printf "%s\n" "$as_me:   current value: \`$ac_new_val'" >&2;}
+      fi;;
+  esac
+  # Pass precious variables to config.status.
+  if test "$ac_new_set" = set; then
+    case $ac_new_val in
+    *\'*) ac_arg=$ac_var=`printf "%s\n" "$ac_new_val" | sed "s/'/'\\\\\\\\''/g"` ;;
+    *) ac_arg=$ac_var=$ac_new_val ;;
+    esac
+    case " $ac_configure_args " in
+      *" '$ac_arg' "*) ;; # Avoid dups.  Use of quotes ensures accuracy.
+      *) as_fn_append ac_configure_args " '$ac_arg'" ;;
+    esac
+  fi
+done
+if $ac_cache_corrupted; then
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: error: in \`$ac_pwd':" >&5
+printf "%s\n" "$as_me: error: in \`$ac_pwd':" >&2;}
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: error: changes in the environment can compromise the build" >&5
+printf "%s\n" "$as_me: error: changes in the environment can compromise the build" >&2;}
+  as_fn_error $? "run \`${MAKE-make} distclean' and/or \`rm $cache_file'
+	    and start over" "$LINENO" 5
+fi
+## -------------------- ##
+## Main body of script. ##
+## -------------------- ##
+
+ac_ext=c
+ac_cpp='$CPP $CPPFLAGS'
+ac_compile='$CC -c $CFLAGS $CPPFLAGS conftest.$ac_ext >&5'
+ac_link='$CC -o conftest$ac_exeext $CFLAGS $CPPFLAGS $LDFLAGS conftest.$ac_ext $LIBS >&5'
+ac_compiler_gnu=$ac_cv_c_compiler_gnu
+
+
+
+
+
+
+
+  # Make sure we can run config.sub.
+$SHELL "${ac_aux_dir}config.sub" sun4 >/dev/null 2>&1 ||
+  as_fn_error $? "cannot run $SHELL ${ac_aux_dir}config.sub" "$LINENO" 5
+
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking build system type" >&5
+printf %s "checking build system type... " >&6; }
+if test ${ac_cv_build+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   ac_build_alias=$build_alias
 test "x$ac_build_alias" = x &&
-  ac_build_alias=`$SHELL "$ac_aux_dir/config.guess"`
+  ac_build_alias=`$SHELL "${ac_aux_dir}config.guess"`
 test "x$ac_build_alias" = x &&
   as_fn_error $? "cannot guess build type; you must specify one" "$LINENO" 5
-ac_cv_build=`$SHELL "$ac_aux_dir/config.sub" $ac_build_alias` ||
-  as_fn_error $? "$SHELL $ac_aux_dir/config.sub $ac_build_alias failed" "$LINENO" 5
+ac_cv_build=`$SHELL "${ac_aux_dir}config.sub" $ac_build_alias` ||
+  as_fn_error $? "$SHELL ${ac_aux_dir}config.sub $ac_build_alias failed" "$LINENO" 5
 
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_build" >&5
-$as_echo "$ac_cv_build" >&6; }
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_build" >&5
+printf "%s\n" "$ac_cv_build" >&6; }
 case $ac_cv_build in
 *-*-*) ;;
 *) as_fn_error $? "invalid value of canonical build" "$LINENO" 5;;
@@ -2603,21 +3129,22 @@ IFS=$ac_save_IFS
 case $build_os in *\ *) build_os=`echo "$build_os" | sed 's/ /-/g'`;; esac
 
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking host system type" >&5
-$as_echo_n "checking host system type... " >&6; }
-if ${ac_cv_host+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking host system type" >&5
+printf %s "checking host system type... " >&6; }
+if test ${ac_cv_host+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   if test "x$host_alias" = x; then
   ac_cv_host=$ac_cv_build
 else
-  ac_cv_host=`$SHELL "$ac_aux_dir/config.sub" $host_alias` ||
-    as_fn_error $? "$SHELL $ac_aux_dir/config.sub $host_alias failed" "$LINENO" 5
+  ac_cv_host=`$SHELL "${ac_aux_dir}config.sub" $host_alias` ||
+    as_fn_error $? "$SHELL ${ac_aux_dir}config.sub $host_alias failed" "$LINENO" 5
 fi
 
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_host" >&5
-$as_echo "$ac_cv_host" >&6; }
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_host" >&5
+printf "%s\n" "$ac_cv_host" >&6; }
 case $ac_cv_host in
 *-*-*) ;;
 *) as_fn_error $? "invalid value of canonical host" "$LINENO" 5;;
@@ -2657,11 +3184,12 @@ for ac_prog in codesign true
 do
   # Extract the first word of "$ac_prog", so it can be a program name with args.
 set dummy $ac_prog; ac_word=$2
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
-$as_echo_n "checking for $ac_word... " >&6; }
-if ${ac_cv_path_CODE_SIGN+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
+printf %s "checking for $ac_word... " >&6; }
+if test ${ac_cv_path_CODE_SIGN+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   case $CODE_SIGN in
   [\\/]* | ?:[\\/]*)
   ac_cv_path_CODE_SIGN="$CODE_SIGN" # Let the user override the test with a path.
@@ -2671,11 +3199,15 @@ else
 for as_dir in $PATH
 do
   IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
+  case $as_dir in #(((
+    '') as_dir=./ ;;
+    */) ;;
+    *) as_dir=$as_dir/ ;;
+  esac
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
-    ac_cv_path_CODE_SIGN="$as_dir/$ac_word$ac_exec_ext"
-    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
+  if as_fn_executable_p "$as_dir$ac_word$ac_exec_ext"; then
+    ac_cv_path_CODE_SIGN="$as_dir$ac_word$ac_exec_ext"
+    printf "%s\n" "$as_me:${as_lineno-$LINENO}: found $as_dir$ac_word$ac_exec_ext" >&5
     break 2
   fi
 done
@@ -2687,11 +3219,11 @@ esac
 fi
 CODE_SIGN=$ac_cv_path_CODE_SIGN
 if test -n "$CODE_SIGN"; then
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $CODE_SIGN" >&5
-$as_echo "$CODE_SIGN" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $CODE_SIGN" >&5
+printf "%s\n" "$CODE_SIGN" >&6; }
 else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: no" >&5
+printf "%s\n" "no" >&6; }
 fi
 
 
@@ -2703,13 +3235,14 @@ done
 ac_config_headers="$ac_config_headers config.h"
 
 
-CUPS_VERSION="2.3.3op1"
+CUPS_VERSION="2.3.3op2"
 CUPS_REVISION=""
 CUPS_BUILD="cups-$CUPS_VERSION"
 
 
 # Check whether --with-cups_build was given.
-if test "${with_cups_build+set}" = set; then :
+if test ${with_cups_build+y}
+then :
   withval=$with_cups_build; CUPS_BUILD="$withval"
 fi
 
@@ -2717,13 +3250,9 @@ fi
 
 
 
-cat >>confdefs.h <<_ACEOF
-#define CUPS_SVERSION "CUPS v$CUPS_VERSION$CUPS_REVISION"
-_ACEOF
+printf "%s\n" "#define CUPS_SVERSION \"CUPS v$CUPS_VERSION$CUPS_REVISION\"" >>confdefs.h
 
-cat >>confdefs.h <<_ACEOF
-#define CUPS_MINIMAL "CUPS/$CUPS_VERSION$CUPS_REVISION"
-_ACEOF
+printf "%s\n" "#define CUPS_MINIMAL \"CUPS/$CUPS_VERSION$CUPS_REVISION\"" >>confdefs.h
 
 
 CFLAGS="${CFLAGS:=}"
@@ -2735,11 +3264,12 @@ for ac_prog in gawk mawk nawk awk
 do
   # Extract the first word of "$ac_prog", so it can be a program name with args.
 set dummy $ac_prog; ac_word=$2
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
-$as_echo_n "checking for $ac_word... " >&6; }
-if ${ac_cv_prog_AWK+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
+printf %s "checking for $ac_word... " >&6; }
+if test ${ac_cv_prog_AWK+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   if test -n "$AWK"; then
   ac_cv_prog_AWK="$AWK" # Let the user override the test.
 else
@@ -2747,11 +3277,15 @@ as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
 for as_dir in $PATH
 do
   IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
+  case $as_dir in #(((
+    '') as_dir=./ ;;
+    */) ;;
+    *) as_dir=$as_dir/ ;;
+  esac
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
+  if as_fn_executable_p "$as_dir$ac_word$ac_exec_ext"; then
     ac_cv_prog_AWK="$ac_prog"
-    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
+    printf "%s\n" "$as_me:${as_lineno-$LINENO}: found $as_dir$ac_word$ac_exec_ext" >&5
     break 2
   fi
 done
@@ -2762,17 +3296,26 @@ fi
 fi
 AWK=$ac_cv_prog_AWK
 if test -n "$AWK"; then
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $AWK" >&5
-$as_echo "$AWK" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $AWK" >&5
+printf "%s\n" "$AWK" >&6; }
 else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: no" >&5
+printf "%s\n" "no" >&6; }
 fi
 
 
   test -n "$AWK" && break
 done
 
+
+
+
+
+
+
+
+
+
 ac_ext=c
 ac_cpp='$CPP $CPPFLAGS'
 ac_compile='$CC -c $CFLAGS $CPPFLAGS conftest.$ac_ext >&5'
@@ -2783,11 +3326,12 @@ if test -n "$ac_tool_prefix"; then
   do
     # Extract the first word of "$ac_tool_prefix$ac_prog", so it can be a program name with args.
 set dummy $ac_tool_prefix$ac_prog; ac_word=$2
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
-$as_echo_n "checking for $ac_word... " >&6; }
-if ${ac_cv_prog_CC+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
+printf %s "checking for $ac_word... " >&6; }
+if test ${ac_cv_prog_CC+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   if test -n "$CC"; then
   ac_cv_prog_CC="$CC" # Let the user override the test.
 else
@@ -2795,11 +3339,15 @@ as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
 for as_dir in $PATH
 do
   IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
+  case $as_dir in #(((
+    '') as_dir=./ ;;
+    */) ;;
+    *) as_dir=$as_dir/ ;;
+  esac
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
+  if as_fn_executable_p "$as_dir$ac_word$ac_exec_ext"; then
     ac_cv_prog_CC="$ac_tool_prefix$ac_prog"
-    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
+    printf "%s\n" "$as_me:${as_lineno-$LINENO}: found $as_dir$ac_word$ac_exec_ext" >&5
     break 2
   fi
 done
@@ -2810,11 +3358,11 @@ fi
 fi
 CC=$ac_cv_prog_CC
 if test -n "$CC"; then
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $CC" >&5
-$as_echo "$CC" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $CC" >&5
+printf "%s\n" "$CC" >&6; }
 else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: no" >&5
+printf "%s\n" "no" >&6; }
 fi
 
 
@@ -2827,11 +3375,12 @@ if test -z "$CC"; then
 do
   # Extract the first word of "$ac_prog", so it can be a program name with args.
 set dummy $ac_prog; ac_word=$2
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
-$as_echo_n "checking for $ac_word... " >&6; }
-if ${ac_cv_prog_ac_ct_CC+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
+printf %s "checking for $ac_word... " >&6; }
+if test ${ac_cv_prog_ac_ct_CC+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   if test -n "$ac_ct_CC"; then
   ac_cv_prog_ac_ct_CC="$ac_ct_CC" # Let the user override the test.
 else
@@ -2839,11 +3388,15 @@ as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
 for as_dir in $PATH
 do
   IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
+  case $as_dir in #(((
+    '') as_dir=./ ;;
+    */) ;;
+    *) as_dir=$as_dir/ ;;
+  esac
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
+  if as_fn_executable_p "$as_dir$ac_word$ac_exec_ext"; then
     ac_cv_prog_ac_ct_CC="$ac_prog"
-    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
+    printf "%s\n" "$as_me:${as_lineno-$LINENO}: found $as_dir$ac_word$ac_exec_ext" >&5
     break 2
   fi
 done
@@ -2854,11 +3407,11 @@ fi
 fi
 ac_ct_CC=$ac_cv_prog_ac_ct_CC
 if test -n "$ac_ct_CC"; then
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_ct_CC" >&5
-$as_echo "$ac_ct_CC" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_ct_CC" >&5
+printf "%s\n" "$ac_ct_CC" >&6; }
 else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: no" >&5
+printf "%s\n" "no" >&6; }
 fi
 
 
@@ -2870,8 +3423,8 @@ done
   else
     case $cross_compiling:$ac_tool_warned in
 yes:)
-{ $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: using cross tools not prefixed with host triplet" >&5
-$as_echo "$as_me: WARNING: using cross tools not prefixed with host triplet" >&2;}
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: WARNING: using cross tools not prefixed with host triplet" >&5
+printf "%s\n" "$as_me: WARNING: using cross tools not prefixed with host triplet" >&2;}
 ac_tool_warned=yes ;;
 esac
     CC=$ac_ct_CC
@@ -2879,23 +3432,23 @@ esac
 fi
 
 
-test -z "$CC" && { { $as_echo "$as_me:${as_lineno-$LINENO}: error: in \`$ac_pwd':" >&5
-$as_echo "$as_me: error: in \`$ac_pwd':" >&2;}
+test -z "$CC" && { { printf "%s\n" "$as_me:${as_lineno-$LINENO}: error: in \`$ac_pwd':" >&5
+printf "%s\n" "$as_me: error: in \`$ac_pwd':" >&2;}
 as_fn_error $? "no acceptable C compiler found in \$PATH
 See \`config.log' for more details" "$LINENO" 5; }
 
 # Provide some information about the compiler.
-$as_echo "$as_me:${as_lineno-$LINENO}: checking for C compiler version" >&5
+printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for C compiler version" >&5
 set X $ac_compile
 ac_compiler=$2
-for ac_option in --version -v -V -qversion; do
+for ac_option in --version -v -V -qversion -version; do
   { { ac_try="$ac_compiler $ac_option >&5"
 case "(($ac_try" in
   *\"* | *\`* | *\\*) ac_try_echo=\$ac_try;;
   *) ac_try_echo=$ac_try;;
 esac
 eval ac_try_echo="\"\$as_me:${as_lineno-$LINENO}: $ac_try_echo\""
-$as_echo "$ac_try_echo"; } >&5
+printf "%s\n" "$ac_try_echo"; } >&5
   (eval "$ac_compiler $ac_option >&5") 2>conftest.err
   ac_status=$?
   if test -s conftest.err; then
@@ -2905,7 +3458,7 @@ $as_echo "$ac_try_echo"; } >&5
     cat conftest.er1 >&5
   fi
   rm -f conftest.er1 conftest.err
-  $as_echo "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
+  printf "%s\n" "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
   test $ac_status = 0; }
 done
 
@@ -2913,7 +3466,7 @@ cat confdefs.h - <<_ACEOF >conftest.$ac_
 /* end confdefs.h.  */
 
 int
-main ()
+main (void)
 {
 
   ;
@@ -2925,9 +3478,9 @@ ac_clean_files="$ac_clean_files a.out a.
 # Try to create an executable without -o first, disregard a.out.
 # It will help us diagnose broken compilers, and finding out an intuition
 # of exeext.
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether the C compiler works" >&5
-$as_echo_n "checking whether the C compiler works... " >&6; }
-ac_link_default=`$as_echo "$ac_link" | sed 's/ -o *conftest[^ ]*//'`
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking whether the C compiler works" >&5
+printf %s "checking whether the C compiler works... " >&6; }
+ac_link_default=`printf "%s\n" "$ac_link" | sed 's/ -o *conftest[^ ]*//'`
 
 # The possible output files:
 ac_files="a.out conftest.exe conftest a.exe a_out.exe b.out conftest.*"
@@ -2948,11 +3501,12 @@ case "(($ac_try" in
   *) ac_try_echo=$ac_try;;
 esac
 eval ac_try_echo="\"\$as_me:${as_lineno-$LINENO}: $ac_try_echo\""
-$as_echo "$ac_try_echo"; } >&5
+printf "%s\n" "$ac_try_echo"; } >&5
   (eval "$ac_link_default") 2>&5
   ac_status=$?
-  $as_echo "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
-  test $ac_status = 0; }; then :
+  printf "%s\n" "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
+  test $ac_status = 0; }
+then :
   # Autoconf-2.13 could set the ac_cv_exeext variable to `no'.
 # So ignore a value of `no', otherwise this would lead to `EXEEXT = no'
 # in a Makefile.  We should not override ac_cv_exeext if it was cached,
@@ -2969,7 +3523,7 @@ do
 	# certainly right.
 	break;;
     *.* )
-	if test "${ac_cv_exeext+set}" = set && test "$ac_cv_exeext" != no;
+	if test ${ac_cv_exeext+y} && test "$ac_cv_exeext" != no;
 	then :; else
 	   ac_cv_exeext=`expr "$ac_file" : '[^.]*\(\..*\)'`
 	fi
@@ -2985,44 +3539,46 @@ do
 done
 test "$ac_cv_exeext" = no && ac_cv_exeext=
 
-else
+else $as_nop
   ac_file=''
 fi
-if test -z "$ac_file"; then :
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
-$as_echo "$as_me: failed program was:" >&5
+if test -z "$ac_file"
+then :
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: no" >&5
+printf "%s\n" "no" >&6; }
+printf "%s\n" "$as_me: failed program was:" >&5
 sed 's/^/| /' conftest.$ac_ext >&5
 
-{ { $as_echo "$as_me:${as_lineno-$LINENO}: error: in \`$ac_pwd':" >&5
-$as_echo "$as_me: error: in \`$ac_pwd':" >&2;}
+{ { printf "%s\n" "$as_me:${as_lineno-$LINENO}: error: in \`$ac_pwd':" >&5
+printf "%s\n" "$as_me: error: in \`$ac_pwd':" >&2;}
 as_fn_error 77 "C compiler cannot create executables
 See \`config.log' for more details" "$LINENO" 5; }
-else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: yes" >&5
-$as_echo "yes" >&6; }
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for C compiler default output file name" >&5
-$as_echo_n "checking for C compiler default output file name... " >&6; }
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_file" >&5
-$as_echo "$ac_file" >&6; }
+else $as_nop
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: yes" >&5
+printf "%s\n" "yes" >&6; }
+fi
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for C compiler default output file name" >&5
+printf %s "checking for C compiler default output file name... " >&6; }
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_file" >&5
+printf "%s\n" "$ac_file" >&6; }
 ac_exeext=$ac_cv_exeext
 
 rm -f -r a.out a.out.dSYM a.exe conftest$ac_cv_exeext b.out
 ac_clean_files=$ac_clean_files_save
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for suffix of executables" >&5
-$as_echo_n "checking for suffix of executables... " >&6; }
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for suffix of executables" >&5
+printf %s "checking for suffix of executables... " >&6; }
 if { { ac_try="$ac_link"
 case "(($ac_try" in
   *\"* | *\`* | *\\*) ac_try_echo=\$ac_try;;
   *) ac_try_echo=$ac_try;;
 esac
 eval ac_try_echo="\"\$as_me:${as_lineno-$LINENO}: $ac_try_echo\""
-$as_echo "$ac_try_echo"; } >&5
+printf "%s\n" "$ac_try_echo"; } >&5
   (eval "$ac_link") 2>&5
   ac_status=$?
-  $as_echo "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
-  test $ac_status = 0; }; then :
+  printf "%s\n" "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
+  test $ac_status = 0; }
+then :
   # If both `conftest.exe' and `conftest' are `present' (well, observable)
 # catch `conftest.exe'.  For instance with Cygwin, `ls conftest' will
 # work properly (i.e., refer to `conftest.exe'), while it won't with
@@ -3036,15 +3592,15 @@ for ac_file in conftest.exe conftest con
     * ) break;;
   esac
 done
-else
-  { { $as_echo "$as_me:${as_lineno-$LINENO}: error: in \`$ac_pwd':" >&5
-$as_echo "$as_me: error: in \`$ac_pwd':" >&2;}
+else $as_nop
+  { { printf "%s\n" "$as_me:${as_lineno-$LINENO}: error: in \`$ac_pwd':" >&5
+printf "%s\n" "$as_me: error: in \`$ac_pwd':" >&2;}
 as_fn_error $? "cannot compute suffix of executables: cannot compile and link
 See \`config.log' for more details" "$LINENO" 5; }
 fi
 rm -f conftest conftest$ac_cv_exeext
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_exeext" >&5
-$as_echo "$ac_cv_exeext" >&6; }
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_exeext" >&5
+printf "%s\n" "$ac_cv_exeext" >&6; }
 
 rm -f conftest.$ac_ext
 EXEEXT=$ac_cv_exeext
@@ -3053,7 +3609,7 @@ cat confdefs.h - <<_ACEOF >conftest.$ac_
 /* end confdefs.h.  */
 #include <stdio.h>
 int
-main ()
+main (void)
 {
 FILE *f = fopen ("conftest.out", "w");
  return ferror (f) || fclose (f) != 0;
@@ -3065,8 +3621,8 @@ _ACEOF
 ac_clean_files="$ac_clean_files conftest.out"
 # Check that the compiler produces executables we can run.  If not, either
 # the compiler is broken, or we cross compile.
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether we are cross compiling" >&5
-$as_echo_n "checking whether we are cross compiling... " >&6; }
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking whether we are cross compiling" >&5
+printf %s "checking whether we are cross compiling... " >&6; }
 if test "$cross_compiling" != yes; then
   { { ac_try="$ac_link"
 case "(($ac_try" in
@@ -3074,10 +3630,10 @@ case "(($ac_try" in
   *) ac_try_echo=$ac_try;;
 esac
 eval ac_try_echo="\"\$as_me:${as_lineno-$LINENO}: $ac_try_echo\""
-$as_echo "$ac_try_echo"; } >&5
+printf "%s\n" "$ac_try_echo"; } >&5
   (eval "$ac_link") 2>&5
   ac_status=$?
-  $as_echo "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
+  printf "%s\n" "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
   test $ac_status = 0; }
   if { ac_try='./conftest$ac_cv_exeext'
   { { case "(($ac_try" in
@@ -3085,39 +3641,40 @@ $as_echo "$ac_try_echo"; } >&5
   *) ac_try_echo=$ac_try;;
 esac
 eval ac_try_echo="\"\$as_me:${as_lineno-$LINENO}: $ac_try_echo\""
-$as_echo "$ac_try_echo"; } >&5
+printf "%s\n" "$ac_try_echo"; } >&5
   (eval "$ac_try") 2>&5
   ac_status=$?
-  $as_echo "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
+  printf "%s\n" "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
   test $ac_status = 0; }; }; then
     cross_compiling=no
   else
     if test "$cross_compiling" = maybe; then
 	cross_compiling=yes
     else
-	{ { $as_echo "$as_me:${as_lineno-$LINENO}: error: in \`$ac_pwd':" >&5
-$as_echo "$as_me: error: in \`$ac_pwd':" >&2;}
-as_fn_error $? "cannot run C compiled programs.
+	{ { printf "%s\n" "$as_me:${as_lineno-$LINENO}: error: in \`$ac_pwd':" >&5
+printf "%s\n" "$as_me: error: in \`$ac_pwd':" >&2;}
+as_fn_error 77 "cannot run C compiled programs.
 If you meant to cross compile, use \`--host'.
 See \`config.log' for more details" "$LINENO" 5; }
     fi
   fi
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $cross_compiling" >&5
-$as_echo "$cross_compiling" >&6; }
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $cross_compiling" >&5
+printf "%s\n" "$cross_compiling" >&6; }
 
 rm -f conftest.$ac_ext conftest$ac_cv_exeext conftest.out
 ac_clean_files=$ac_clean_files_save
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for suffix of object files" >&5
-$as_echo_n "checking for suffix of object files... " >&6; }
-if ${ac_cv_objext+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for suffix of object files" >&5
+printf %s "checking for suffix of object files... " >&6; }
+if test ${ac_cv_objext+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
 
 int
-main ()
+main (void)
 {
 
   ;
@@ -3131,11 +3688,12 @@ case "(($ac_try" in
   *) ac_try_echo=$ac_try;;
 esac
 eval ac_try_echo="\"\$as_me:${as_lineno-$LINENO}: $ac_try_echo\""
-$as_echo "$ac_try_echo"; } >&5
+printf "%s\n" "$ac_try_echo"; } >&5
   (eval "$ac_compile") 2>&5
   ac_status=$?
-  $as_echo "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
-  test $ac_status = 0; }; then :
+  printf "%s\n" "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
+  test $ac_status = 0; }
+then :
   for ac_file in conftest.o conftest.obj conftest.*; do
   test -f "$ac_file" || continue;
   case $ac_file in
@@ -3144,31 +3702,32 @@ $as_echo "$ac_try_echo"; } >&5
        break;;
   esac
 done
-else
-  $as_echo "$as_me: failed program was:" >&5
+else $as_nop
+  printf "%s\n" "$as_me: failed program was:" >&5
 sed 's/^/| /' conftest.$ac_ext >&5
 
-{ { $as_echo "$as_me:${as_lineno-$LINENO}: error: in \`$ac_pwd':" >&5
-$as_echo "$as_me: error: in \`$ac_pwd':" >&2;}
+{ { printf "%s\n" "$as_me:${as_lineno-$LINENO}: error: in \`$ac_pwd':" >&5
+printf "%s\n" "$as_me: error: in \`$ac_pwd':" >&2;}
 as_fn_error $? "cannot compute suffix of object files: cannot compile
 See \`config.log' for more details" "$LINENO" 5; }
 fi
 rm -f conftest.$ac_cv_objext conftest.$ac_ext
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_objext" >&5
-$as_echo "$ac_cv_objext" >&6; }
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_objext" >&5
+printf "%s\n" "$ac_cv_objext" >&6; }
 OBJEXT=$ac_cv_objext
 ac_objext=$OBJEXT
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether we are using the GNU C compiler" >&5
-$as_echo_n "checking whether we are using the GNU C compiler... " >&6; }
-if ${ac_cv_c_compiler_gnu+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking whether the compiler supports GNU C" >&5
+printf %s "checking whether the compiler supports GNU C... " >&6; }
+if test ${ac_cv_c_compiler_gnu+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
 
 int
-main ()
+main (void)
 {
 #ifndef __GNUC__
        choke me
@@ -3178,29 +3737,33 @@ main ()
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_compile "$LINENO"; then :
+if ac_fn_c_try_compile "$LINENO"
+then :
   ac_compiler_gnu=yes
-else
+else $as_nop
   ac_compiler_gnu=no
 fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
+rm -f core conftest.err conftest.$ac_objext conftest.beam conftest.$ac_ext
 ac_cv_c_compiler_gnu=$ac_compiler_gnu
 
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_c_compiler_gnu" >&5
-$as_echo "$ac_cv_c_compiler_gnu" >&6; }
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_c_compiler_gnu" >&5
+printf "%s\n" "$ac_cv_c_compiler_gnu" >&6; }
+ac_compiler_gnu=$ac_cv_c_compiler_gnu
+
 if test $ac_compiler_gnu = yes; then
   GCC=yes
 else
   GCC=
 fi
-ac_test_CFLAGS=${CFLAGS+set}
+ac_test_CFLAGS=${CFLAGS+y}
 ac_save_CFLAGS=$CFLAGS
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC accepts -g" >&5
-$as_echo_n "checking whether $CC accepts -g... " >&6; }
-if ${ac_cv_prog_cc_g+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking whether $CC accepts -g" >&5
+printf %s "checking whether $CC accepts -g... " >&6; }
+if test ${ac_cv_prog_cc_g+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   ac_save_c_werror_flag=$ac_c_werror_flag
    ac_c_werror_flag=yes
    ac_cv_prog_cc_g=no
@@ -3209,57 +3772,60 @@ else
 /* end confdefs.h.  */
 
 int
-main ()
+main (void)
 {
 
   ;
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_compile "$LINENO"; then :
+if ac_fn_c_try_compile "$LINENO"
+then :
   ac_cv_prog_cc_g=yes
-else
+else $as_nop
   CFLAGS=""
       cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
 
 int
-main ()
+main (void)
 {
 
   ;
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_compile "$LINENO"; then :
+if ac_fn_c_try_compile "$LINENO"
+then :
 
-else
+else $as_nop
   ac_c_werror_flag=$ac_save_c_werror_flag
 	 CFLAGS="-g"
 	 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
 
 int
-main ()
+main (void)
 {
 
   ;
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_compile "$LINENO"; then :
+if ac_fn_c_try_compile "$LINENO"
+then :
   ac_cv_prog_cc_g=yes
 fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
+rm -f core conftest.err conftest.$ac_objext conftest.beam conftest.$ac_ext
 fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
+rm -f core conftest.err conftest.$ac_objext conftest.beam conftest.$ac_ext
 fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
+rm -f core conftest.err conftest.$ac_objext conftest.beam conftest.$ac_ext
    ac_c_werror_flag=$ac_save_c_werror_flag
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_prog_cc_g" >&5
-$as_echo "$ac_cv_prog_cc_g" >&6; }
-if test "$ac_test_CFLAGS" = set; then
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_prog_cc_g" >&5
+printf "%s\n" "$ac_cv_prog_cc_g" >&6; }
+if test $ac_test_CFLAGS; then
   CFLAGS=$ac_save_CFLAGS
 elif test $ac_cv_prog_cc_g = yes; then
   if test "$GCC" = yes; then
@@ -3274,73 +3840,119 @@ else
     CFLAGS=
   fi
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $CC option to accept ISO C89" >&5
-$as_echo_n "checking for $CC option to accept ISO C89... " >&6; }
-if ${ac_cv_prog_cc_c89+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
-  ac_cv_prog_cc_c89=no
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for $CC option to enable C11 features" >&5
+printf %s "checking for $CC option to enable C11 features... " >&6; }
+if test ${ac_cv_prog_cc_c11+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
+  ac_cv_prog_cc_c11=no
 ac_save_CC=$CC
 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
-#include <stdarg.h>
-#include <stdio.h>
-struct stat;
-/* Most of the following tests are stolen from RCS 5.7's src/conf.sh.  */
-struct buf { int x; };
-FILE * (*rcsopen) (struct buf *, struct stat *, int);
-static char *e (p, i)
-     char **p;
-     int i;
-{
-  return p[i];
-}
-static char *f (char * (*g) (char **, int), char **p, ...)
-{
-  char *s;
-  va_list v;
-  va_start (v,p);
-  s = g (p, va_arg (v,int));
-  va_end (v);
-  return s;
-}
-
-/* OSF 4.0 Compaq cc is some sort of almost-ANSI by default.  It has
-   function prototypes and stuff, but not '\xHH' hex character constants.
-   These don't provoke an error unfortunately, instead are silently treated
-   as 'x'.  The following induces an error, until -std is added to get
-   proper ANSI mode.  Curiously '\x00'!='x' always comes out true, for an
-   array size at least.  It's necessary to write '\x00'==0 to get something
-   that's true only with -std.  */
-int osf4_cc_array ['\x00' == 0 ? 1 : -1];
+$ac_c_conftest_c11_program
+_ACEOF
+for ac_arg in '' -std=gnu11
+do
+  CC="$ac_save_CC $ac_arg"
+  if ac_fn_c_try_compile "$LINENO"
+then :
+  ac_cv_prog_cc_c11=$ac_arg
+fi
+rm -f core conftest.err conftest.$ac_objext conftest.beam
+  test "x$ac_cv_prog_cc_c11" != "xno" && break
+done
+rm -f conftest.$ac_ext
+CC=$ac_save_CC
 
-/* IBM C 6 for AIX is almost-ANSI by default, but it replaces macro parameters
-   inside strings and character constants.  */
-#define FOO(x) 'x'
-int xlc6_cc_array[FOO(a) == 'x' ? 1 : -1];
+fi
+# AC_CACHE_VAL
+ac_prog_cc_stdc_options=
+case "x$ac_cv_prog_cc_c11" in #(
+  x) :
+    { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: none needed" >&5
+printf "%s\n" "none needed" >&6; } ;; #(
+  xno) :
+    { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: unsupported" >&5
+printf "%s\n" "unsupported" >&6; } ;; #(
+  *) :
+    ac_prog_cc_stdc_options=" $ac_cv_prog_cc_c11"
+    CC="$CC$ac_prog_cc_stdc_options"
+    { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_prog_cc_c11" >&5
+printf "%s\n" "$ac_cv_prog_cc_c11" >&6; } ;;
+esac
+if test "x$ac_cv_prog_cc_c11" != xno
+then :
+  ac_prog_cc_stdc=c11
+		 ac_cv_prog_cc_stdc=$ac_cv_prog_cc_c11
+else $as_nop
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for $CC option to enable C99 features" >&5
+printf %s "checking for $CC option to enable C99 features... " >&6; }
+if test ${ac_cv_prog_cc_c99+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
+  ac_cv_prog_cc_c99=no
+ac_save_CC=$CC
+cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+$ac_c_conftest_c89_program
+_ACEOF
+for ac_arg in '' -std=gnu99 -std=c99 -c99 -AC99 -D_STDC_C99= -qlanglvl=extc1x -qlanglvl=extc99
+do
+  CC="$ac_save_CC $ac_arg"
+  if ac_fn_c_try_compile "$LINENO"
+then :
+  ac_cv_prog_cc_c99=$ac_arg
+fi
+rm -f core conftest.err conftest.$ac_objext conftest.beam
+  test "x$ac_cv_prog_cc_c99" != "xno" && break
+done
+rm -f conftest.$ac_ext
+CC=$ac_save_CC
 
-int test (int i, double x);
-struct s1 {int (*f) (int a);};
-struct s2 {int (*f) (double a);};
-int pairnames (int, char **, FILE *(*)(struct buf *, struct stat *, int), int, int);
-int argc;
-char **argv;
-int
-main ()
-{
-return f (e, argv, 0) != argv[0]  ||  f (e, argv, 1) != argv[1];
-  ;
-  return 0;
-}
+fi
+# AC_CACHE_VAL
+ac_prog_cc_stdc_options=
+case "x$ac_cv_prog_cc_c99" in #(
+  x) :
+    { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: none needed" >&5
+printf "%s\n" "none needed" >&6; } ;; #(
+  xno) :
+    { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: unsupported" >&5
+printf "%s\n" "unsupported" >&6; } ;; #(
+  *) :
+    ac_prog_cc_stdc_options=" $ac_cv_prog_cc_c99"
+    CC="$CC$ac_prog_cc_stdc_options"
+    { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_prog_cc_c99" >&5
+printf "%s\n" "$ac_cv_prog_cc_c99" >&6; } ;;
+esac
+if test "x$ac_cv_prog_cc_c99" != xno
+then :
+  ac_prog_cc_stdc=c99
+		    ac_cv_prog_cc_stdc=$ac_cv_prog_cc_c99
+else $as_nop
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for $CC option to enable C89 features" >&5
+printf %s "checking for $CC option to enable C89 features... " >&6; }
+if test ${ac_cv_prog_cc_c89+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
+  ac_cv_prog_cc_c89=no
+ac_save_CC=$CC
+cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+$ac_c_conftest_c89_program
 _ACEOF
 for ac_arg in '' -qlanglvl=extc89 -qlanglvl=ansi -std \
 	-Ae "-Aa -D_HPUX_SOURCE" "-Xc -D__EXTENSIONS__"
 do
   CC="$ac_save_CC $ac_arg"
-  if ac_fn_c_try_compile "$LINENO"; then :
+  if ac_fn_c_try_compile "$LINENO"
+then :
   ac_cv_prog_cc_c89=$ac_arg
 fi
-rm -f core conftest.err conftest.$ac_objext
+rm -f core conftest.err conftest.$ac_objext conftest.beam
   test "x$ac_cv_prog_cc_c89" != "xno" && break
 done
 rm -f conftest.$ac_ext
@@ -3348,19 +3960,30 @@ CC=$ac_save_CC
 
 fi
 # AC_CACHE_VAL
-case "x$ac_cv_prog_cc_c89" in
-  x)
-    { $as_echo "$as_me:${as_lineno-$LINENO}: result: none needed" >&5
-$as_echo "none needed" >&6; } ;;
-  xno)
-    { $as_echo "$as_me:${as_lineno-$LINENO}: result: unsupported" >&5
-$as_echo "unsupported" >&6; } ;;
-  *)
-    CC="$CC $ac_cv_prog_cc_c89"
-    { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_prog_cc_c89" >&5
-$as_echo "$ac_cv_prog_cc_c89" >&6; } ;;
-esac
-if test "x$ac_cv_prog_cc_c89" != xno; then :
+ac_prog_cc_stdc_options=
+case "x$ac_cv_prog_cc_c89" in #(
+  x) :
+    { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: none needed" >&5
+printf "%s\n" "none needed" >&6; } ;; #(
+  xno) :
+    { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: unsupported" >&5
+printf "%s\n" "unsupported" >&6; } ;; #(
+  *) :
+    ac_prog_cc_stdc_options=" $ac_cv_prog_cc_c89"
+    CC="$CC$ac_prog_cc_stdc_options"
+    { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_prog_cc_c89" >&5
+printf "%s\n" "$ac_cv_prog_cc_c89" >&6; } ;;
+esac
+if test "x$ac_cv_prog_cc_c89" != xno
+then :
+  ac_prog_cc_stdc=c89
+		       ac_cv_prog_cc_stdc=$ac_cv_prog_cc_c89
+else $as_nop
+  ac_prog_cc_stdc=no
+		       ac_cv_prog_cc_stdc=no
+fi
+
+fi
 
 fi
 
@@ -3375,40 +3998,36 @@ ac_cpp='$CPP $CPPFLAGS'
 ac_compile='$CC -c $CFLAGS $CPPFLAGS conftest.$ac_ext >&5'
 ac_link='$CC -o conftest$ac_exeext $CFLAGS $CPPFLAGS $LDFLAGS conftest.$ac_ext $LIBS >&5'
 ac_compiler_gnu=$ac_cv_c_compiler_gnu
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking how to run the C preprocessor" >&5
-$as_echo_n "checking how to run the C preprocessor... " >&6; }
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking how to run the C preprocessor" >&5
+printf %s "checking how to run the C preprocessor... " >&6; }
 # On Suns, sometimes $CPP names a directory.
 if test -n "$CPP" && test -d "$CPP"; then
   CPP=
 fi
 if test -z "$CPP"; then
-  if ${ac_cv_prog_CPP+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
-      # Double quotes because CPP needs to be expanded
-    for CPP in "$CC -E" "$CC -E -traditional-cpp" "/lib/cpp"
+  if test ${ac_cv_prog_CPP+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
+      # Double quotes because $CC needs to be expanded
+    for CPP in "$CC -E" "$CC -E -traditional-cpp" cpp /lib/cpp
     do
       ac_preproc_ok=false
 for ac_c_preproc_warn_flag in '' yes
 do
   # Use a header file that comes with gcc, so configuring glibc
   # with a fresh cross-compiler works.
-  # Prefer <limits.h> to <assert.h> if __STDC__ is defined, since
-  # <limits.h> exists even on freestanding compilers.
   # On the NeXT, cc -E runs the code through the compiler's parser,
   # not just through cpp. "Syntax error" is here to catch this case.
   cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
-#ifdef __STDC__
-# include <limits.h>
-#else
-# include <assert.h>
-#endif
+#include <limits.h>
 		     Syntax error
 _ACEOF
-if ac_fn_c_try_cpp "$LINENO"; then :
+if ac_fn_c_try_cpp "$LINENO"
+then :
 
-else
+else $as_nop
   # Broken: fails on valid input.
 continue
 fi
@@ -3420,10 +4039,11 @@ rm -f conftest.err conftest.i conftest.$
 /* end confdefs.h.  */
 #include <ac_nonexistent.h>
 _ACEOF
-if ac_fn_c_try_cpp "$LINENO"; then :
+if ac_fn_c_try_cpp "$LINENO"
+then :
   # Broken: success on invalid input.
 continue
-else
+else $as_nop
   # Passes both tests.
 ac_preproc_ok=:
 break
@@ -3433,7 +4053,8 @@ rm -f conftest.err conftest.i conftest.$
 done
 # Because of `break', _AC_PREPROC_IFELSE's cleaning code was skipped.
 rm -f conftest.i conftest.err conftest.$ac_ext
-if $ac_preproc_ok; then :
+if $ac_preproc_ok
+then :
   break
 fi
 
@@ -3445,29 +4066,24 @@ fi
 else
   ac_cv_prog_CPP=$CPP
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $CPP" >&5
-$as_echo "$CPP" >&6; }
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $CPP" >&5
+printf "%s\n" "$CPP" >&6; }
 ac_preproc_ok=false
 for ac_c_preproc_warn_flag in '' yes
 do
   # Use a header file that comes with gcc, so configuring glibc
   # with a fresh cross-compiler works.
-  # Prefer <limits.h> to <assert.h> if __STDC__ is defined, since
-  # <limits.h> exists even on freestanding compilers.
   # On the NeXT, cc -E runs the code through the compiler's parser,
   # not just through cpp. "Syntax error" is here to catch this case.
   cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
-#ifdef __STDC__
-# include <limits.h>
-#else
-# include <assert.h>
-#endif
+#include <limits.h>
 		     Syntax error
 _ACEOF
-if ac_fn_c_try_cpp "$LINENO"; then :
+if ac_fn_c_try_cpp "$LINENO"
+then :
 
-else
+else $as_nop
   # Broken: fails on valid input.
 continue
 fi
@@ -3479,10 +4095,11 @@ rm -f conftest.err conftest.i conftest.$
 /* end confdefs.h.  */
 #include <ac_nonexistent.h>
 _ACEOF
-if ac_fn_c_try_cpp "$LINENO"; then :
+if ac_fn_c_try_cpp "$LINENO"
+then :
   # Broken: success on invalid input.
 continue
-else
+else $as_nop
   # Passes both tests.
 ac_preproc_ok=:
 break
@@ -3492,11 +4109,12 @@ rm -f conftest.err conftest.i conftest.$
 done
 # Because of `break', _AC_PREPROC_IFELSE's cleaning code was skipped.
 rm -f conftest.i conftest.err conftest.$ac_ext
-if $ac_preproc_ok; then :
+if $ac_preproc_ok
+then :
 
-else
-  { { $as_echo "$as_me:${as_lineno-$LINENO}: error: in \`$ac_pwd':" >&5
-$as_echo "$as_me: error: in \`$ac_pwd':" >&2;}
+else $as_nop
+  { { printf "%s\n" "$as_me:${as_lineno-$LINENO}: error: in \`$ac_pwd':" >&5
+printf "%s\n" "$as_me: error: in \`$ac_pwd':" >&2;}
 as_fn_error $? "C preprocessor \"$CPP\" fails sanity check
 See \`config.log' for more details" "$LINENO" 5; }
 fi
@@ -3507,6 +4125,12 @@ ac_compile='$CC -c $CFLAGS $CPPFLAGS con
 ac_link='$CC -o conftest$ac_exeext $CFLAGS $CPPFLAGS $LDFLAGS conftest.$ac_ext $LIBS >&5'
 ac_compiler_gnu=$ac_cv_c_compiler_gnu
 
+
+
+
+
+
+
 ac_ext=cpp
 ac_cpp='$CXXCPP $CPPFLAGS'
 ac_compile='$CXX -c $CXXFLAGS $CPPFLAGS conftest.$ac_ext >&5'
@@ -3521,11 +4145,12 @@ if test -z "$CXX"; then
   do
     # Extract the first word of "$ac_tool_prefix$ac_prog", so it can be a program name with args.
 set dummy $ac_tool_prefix$ac_prog; ac_word=$2
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
-$as_echo_n "checking for $ac_word... " >&6; }
-if ${ac_cv_prog_CXX+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
+printf %s "checking for $ac_word... " >&6; }
+if test ${ac_cv_prog_CXX+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   if test -n "$CXX"; then
   ac_cv_prog_CXX="$CXX" # Let the user override the test.
 else
@@ -3533,11 +4158,15 @@ as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
 for as_dir in $PATH
 do
   IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
+  case $as_dir in #(((
+    '') as_dir=./ ;;
+    */) ;;
+    *) as_dir=$as_dir/ ;;
+  esac
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
+  if as_fn_executable_p "$as_dir$ac_word$ac_exec_ext"; then
     ac_cv_prog_CXX="$ac_tool_prefix$ac_prog"
-    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
+    printf "%s\n" "$as_me:${as_lineno-$LINENO}: found $as_dir$ac_word$ac_exec_ext" >&5
     break 2
   fi
 done
@@ -3548,11 +4177,11 @@ fi
 fi
 CXX=$ac_cv_prog_CXX
 if test -n "$CXX"; then
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $CXX" >&5
-$as_echo "$CXX" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $CXX" >&5
+printf "%s\n" "$CXX" >&6; }
 else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: no" >&5
+printf "%s\n" "no" >&6; }
 fi
 
 
@@ -3565,11 +4194,12 @@ if test -z "$CXX"; then
 do
   # Extract the first word of "$ac_prog", so it can be a program name with args.
 set dummy $ac_prog; ac_word=$2
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
-$as_echo_n "checking for $ac_word... " >&6; }
-if ${ac_cv_prog_ac_ct_CXX+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
+printf %s "checking for $ac_word... " >&6; }
+if test ${ac_cv_prog_ac_ct_CXX+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   if test -n "$ac_ct_CXX"; then
   ac_cv_prog_ac_ct_CXX="$ac_ct_CXX" # Let the user override the test.
 else
@@ -3577,11 +4207,15 @@ as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
 for as_dir in $PATH
 do
   IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
+  case $as_dir in #(((
+    '') as_dir=./ ;;
+    */) ;;
+    *) as_dir=$as_dir/ ;;
+  esac
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
+  if as_fn_executable_p "$as_dir$ac_word$ac_exec_ext"; then
     ac_cv_prog_ac_ct_CXX="$ac_prog"
-    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
+    printf "%s\n" "$as_me:${as_lineno-$LINENO}: found $as_dir$ac_word$ac_exec_ext" >&5
     break 2
   fi
 done
@@ -3592,11 +4226,11 @@ fi
 fi
 ac_ct_CXX=$ac_cv_prog_ac_ct_CXX
 if test -n "$ac_ct_CXX"; then
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_ct_CXX" >&5
-$as_echo "$ac_ct_CXX" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_ct_CXX" >&5
+printf "%s\n" "$ac_ct_CXX" >&6; }
 else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: no" >&5
+printf "%s\n" "no" >&6; }
 fi
 
 
@@ -3608,8 +4242,8 @@ done
   else
     case $cross_compiling:$ac_tool_warned in
 yes:)
-{ $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: using cross tools not prefixed with host triplet" >&5
-$as_echo "$as_me: WARNING: using cross tools not prefixed with host triplet" >&2;}
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: WARNING: using cross tools not prefixed with host triplet" >&5
+printf "%s\n" "$as_me: WARNING: using cross tools not prefixed with host triplet" >&2;}
 ac_tool_warned=yes ;;
 esac
     CXX=$ac_ct_CXX
@@ -3619,7 +4253,7 @@ fi
   fi
 fi
 # Provide some information about the compiler.
-$as_echo "$as_me:${as_lineno-$LINENO}: checking for C++ compiler version" >&5
+printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for C++ compiler version" >&5
 set X $ac_compile
 ac_compiler=$2
 for ac_option in --version -v -V -qversion; do
@@ -3629,7 +4263,7 @@ case "(($ac_try" in
   *) ac_try_echo=$ac_try;;
 esac
 eval ac_try_echo="\"\$as_me:${as_lineno-$LINENO}: $ac_try_echo\""
-$as_echo "$ac_try_echo"; } >&5
+printf "%s\n" "$ac_try_echo"; } >&5
   (eval "$ac_compiler $ac_option >&5") 2>conftest.err
   ac_status=$?
   if test -s conftest.err; then
@@ -3639,20 +4273,21 @@ $as_echo "$ac_try_echo"; } >&5
     cat conftest.er1 >&5
   fi
   rm -f conftest.er1 conftest.err
-  $as_echo "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
+  printf "%s\n" "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
   test $ac_status = 0; }
 done
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether we are using the GNU C++ compiler" >&5
-$as_echo_n "checking whether we are using the GNU C++ compiler... " >&6; }
-if ${ac_cv_cxx_compiler_gnu+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking whether the compiler supports GNU C++" >&5
+printf %s "checking whether the compiler supports GNU C++... " >&6; }
+if test ${ac_cv_cxx_compiler_gnu+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
 
 int
-main ()
+main (void)
 {
 #ifndef __GNUC__
        choke me
@@ -3662,29 +4297,33 @@ main ()
   return 0;
 }
 _ACEOF
-if ac_fn_cxx_try_compile "$LINENO"; then :
+if ac_fn_cxx_try_compile "$LINENO"
+then :
   ac_compiler_gnu=yes
-else
+else $as_nop
   ac_compiler_gnu=no
 fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
+rm -f core conftest.err conftest.$ac_objext conftest.beam conftest.$ac_ext
 ac_cv_cxx_compiler_gnu=$ac_compiler_gnu
 
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_cxx_compiler_gnu" >&5
-$as_echo "$ac_cv_cxx_compiler_gnu" >&6; }
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_cxx_compiler_gnu" >&5
+printf "%s\n" "$ac_cv_cxx_compiler_gnu" >&6; }
+ac_compiler_gnu=$ac_cv_cxx_compiler_gnu
+
 if test $ac_compiler_gnu = yes; then
   GXX=yes
 else
   GXX=
 fi
-ac_test_CXXFLAGS=${CXXFLAGS+set}
+ac_test_CXXFLAGS=${CXXFLAGS+y}
 ac_save_CXXFLAGS=$CXXFLAGS
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CXX accepts -g" >&5
-$as_echo_n "checking whether $CXX accepts -g... " >&6; }
-if ${ac_cv_prog_cxx_g+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking whether $CXX accepts -g" >&5
+printf %s "checking whether $CXX accepts -g... " >&6; }
+if test ${ac_cv_prog_cxx_g+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   ac_save_cxx_werror_flag=$ac_cxx_werror_flag
    ac_cxx_werror_flag=yes
    ac_cv_prog_cxx_g=no
@@ -3693,57 +4332,60 @@ else
 /* end confdefs.h.  */
 
 int
-main ()
+main (void)
 {
 
   ;
   return 0;
 }
 _ACEOF
-if ac_fn_cxx_try_compile "$LINENO"; then :
+if ac_fn_cxx_try_compile "$LINENO"
+then :
   ac_cv_prog_cxx_g=yes
-else
+else $as_nop
   CXXFLAGS=""
       cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
 
 int
-main ()
+main (void)
 {
 
   ;
   return 0;
 }
 _ACEOF
-if ac_fn_cxx_try_compile "$LINENO"; then :
+if ac_fn_cxx_try_compile "$LINENO"
+then :
 
-else
+else $as_nop
   ac_cxx_werror_flag=$ac_save_cxx_werror_flag
 	 CXXFLAGS="-g"
 	 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
 
 int
-main ()
+main (void)
 {
 
   ;
   return 0;
 }
 _ACEOF
-if ac_fn_cxx_try_compile "$LINENO"; then :
+if ac_fn_cxx_try_compile "$LINENO"
+then :
   ac_cv_prog_cxx_g=yes
 fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
+rm -f core conftest.err conftest.$ac_objext conftest.beam conftest.$ac_ext
 fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
+rm -f core conftest.err conftest.$ac_objext conftest.beam conftest.$ac_ext
 fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
+rm -f core conftest.err conftest.$ac_objext conftest.beam conftest.$ac_ext
    ac_cxx_werror_flag=$ac_save_cxx_werror_flag
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_prog_cxx_g" >&5
-$as_echo "$ac_cv_prog_cxx_g" >&6; }
-if test "$ac_test_CXXFLAGS" = set; then
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_prog_cxx_g" >&5
+printf "%s\n" "$ac_cv_prog_cxx_g" >&6; }
+if test $ac_test_CXXFLAGS; then
   CXXFLAGS=$ac_save_CXXFLAGS
 elif test $ac_cv_prog_cxx_g = yes; then
   if test "$GXX" = yes; then
@@ -3758,6 +4400,105 @@ else
     CXXFLAGS=
   fi
 fi
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for $CXX option to enable C++11 features" >&5
+printf %s "checking for $CXX option to enable C++11 features... " >&6; }
+if test ${ac_cv_prog_cxx_cxx11+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
+  ac_cv_prog_cxx_cxx11=no
+ac_save_CXX=$CXX
+cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+$ac_cxx_conftest_cxx11_program
+_ACEOF
+for ac_arg in '' -std=gnu++11 -std=c++11 -std=gnu++0x -std=c++0x -qlanglvl=extended0x -AA
+do
+  CXX="$ac_save_CXX $ac_arg"
+  if ac_fn_cxx_try_compile "$LINENO"
+then :
+  ac_cv_prog_cxx_cxx11=$ac_arg
+fi
+rm -f core conftest.err conftest.$ac_objext conftest.beam
+  test "x$ac_cv_prog_cxx_cxx11" != "xno" && break
+done
+rm -f conftest.$ac_ext
+CXX=$ac_save_CXX
+
+fi
+# AC_CACHE_VAL
+ac_prog_cxx_stdcxx_options=
+case "x$ac_cv_prog_cxx_cxx11" in #(
+  x) :
+    { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: none needed" >&5
+printf "%s\n" "none needed" >&6; } ;; #(
+  xno) :
+    { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: unsupported" >&5
+printf "%s\n" "unsupported" >&6; } ;; #(
+  *) :
+    ac_prog_cxx_stdcxx_options=" $ac_cv_prog_cxx_cxx11"
+    CXX=$CXX$ac_prog_cxx_stdcxx_options
+    { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_prog_cxx_cxx11" >&5
+printf "%s\n" "$ac_cv_prog_cxx_cxx11" >&6; } ;;
+esac
+if test "x$ac_cv_prog_cxx_cxx11" != xno
+then :
+  ac_prog_cxx_stdcxx=cxx11
+		    ac_cv_prog_cxx_stdcxx=$ac_cv_prog_cxx_cxx11
+		    ac_cv_prog_cxx_cxx98=$ac_cv_prog_cxx_cxx11
+else $as_nop
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for $CXX option to enable C++98 features" >&5
+printf %s "checking for $CXX option to enable C++98 features... " >&6; }
+if test ${ac_cv_prog_cxx_cxx98+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
+  ac_cv_prog_cxx_cxx98=no
+ac_save_CXX=$CXX
+cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+$ac_cxx_conftest_cxx98_program
+_ACEOF
+for ac_arg in '' -std=gnu++98 -std=c++98 -qlanglvl=extended -AA
+do
+  CXX="$ac_save_CXX $ac_arg"
+  if ac_fn_cxx_try_compile "$LINENO"
+then :
+  ac_cv_prog_cxx_cxx98=$ac_arg
+fi
+rm -f core conftest.err conftest.$ac_objext conftest.beam
+  test "x$ac_cv_prog_cxx_cxx98" != "xno" && break
+done
+rm -f conftest.$ac_ext
+CXX=$ac_save_CXX
+
+fi
+# AC_CACHE_VAL
+ac_prog_cxx_stdcxx_options=
+case "x$ac_cv_prog_cxx_cxx98" in #(
+  x) :
+    { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: none needed" >&5
+printf "%s\n" "none needed" >&6; } ;; #(
+  xno) :
+    { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: unsupported" >&5
+printf "%s\n" "unsupported" >&6; } ;; #(
+  *) :
+    ac_prog_cxx_stdcxx_options=" $ac_cv_prog_cxx_cxx98"
+    CXX=$CXX$ac_prog_cxx_stdcxx_options
+    { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_prog_cxx_cxx98" >&5
+printf "%s\n" "$ac_cv_prog_cxx_cxx98" >&6; } ;;
+esac
+if test "x$ac_cv_prog_cxx_cxx98" != xno
+then :
+  ac_prog_cxx_stdcxx=cxx98
+		        ac_cv_prog_cxx_stdcxx=$ac_cv_prog_cxx_cxx98
+else $as_nop
+  ac_prog_cxx_stdcxx=no
+		        ac_cv_prog_cxx_stdcxx=no
+fi
+
+fi
+
 ac_ext=c
 ac_cpp='$CPP $CPPFLAGS'
 ac_compile='$CC -c $CFLAGS $CPPFLAGS conftest.$ac_ext >&5'
@@ -3767,11 +4508,12 @@ ac_compiler_gnu=$ac_cv_c_compiler_gnu
 if test -n "$ac_tool_prefix"; then
   # Extract the first word of "${ac_tool_prefix}ranlib", so it can be a program name with args.
 set dummy ${ac_tool_prefix}ranlib; ac_word=$2
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
-$as_echo_n "checking for $ac_word... " >&6; }
-if ${ac_cv_prog_RANLIB+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
+printf %s "checking for $ac_word... " >&6; }
+if test ${ac_cv_prog_RANLIB+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   if test -n "$RANLIB"; then
   ac_cv_prog_RANLIB="$RANLIB" # Let the user override the test.
 else
@@ -3779,11 +4521,15 @@ as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
 for as_dir in $PATH
 do
   IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
+  case $as_dir in #(((
+    '') as_dir=./ ;;
+    */) ;;
+    *) as_dir=$as_dir/ ;;
+  esac
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
+  if as_fn_executable_p "$as_dir$ac_word$ac_exec_ext"; then
     ac_cv_prog_RANLIB="${ac_tool_prefix}ranlib"
-    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
+    printf "%s\n" "$as_me:${as_lineno-$LINENO}: found $as_dir$ac_word$ac_exec_ext" >&5
     break 2
   fi
 done
@@ -3794,11 +4540,11 @@ fi
 fi
 RANLIB=$ac_cv_prog_RANLIB
 if test -n "$RANLIB"; then
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $RANLIB" >&5
-$as_echo "$RANLIB" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $RANLIB" >&5
+printf "%s\n" "$RANLIB" >&6; }
 else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: no" >&5
+printf "%s\n" "no" >&6; }
 fi
 
 
@@ -3807,11 +4553,12 @@ if test -z "$ac_cv_prog_RANLIB"; then
   ac_ct_RANLIB=$RANLIB
   # Extract the first word of "ranlib", so it can be a program name with args.
 set dummy ranlib; ac_word=$2
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
-$as_echo_n "checking for $ac_word... " >&6; }
-if ${ac_cv_prog_ac_ct_RANLIB+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
+printf %s "checking for $ac_word... " >&6; }
+if test ${ac_cv_prog_ac_ct_RANLIB+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   if test -n "$ac_ct_RANLIB"; then
   ac_cv_prog_ac_ct_RANLIB="$ac_ct_RANLIB" # Let the user override the test.
 else
@@ -3819,11 +4566,15 @@ as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
 for as_dir in $PATH
 do
   IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
+  case $as_dir in #(((
+    '') as_dir=./ ;;
+    */) ;;
+    *) as_dir=$as_dir/ ;;
+  esac
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
+  if as_fn_executable_p "$as_dir$ac_word$ac_exec_ext"; then
     ac_cv_prog_ac_ct_RANLIB="ranlib"
-    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
+    printf "%s\n" "$as_me:${as_lineno-$LINENO}: found $as_dir$ac_word$ac_exec_ext" >&5
     break 2
   fi
 done
@@ -3834,11 +4585,11 @@ fi
 fi
 ac_ct_RANLIB=$ac_cv_prog_ac_ct_RANLIB
 if test -n "$ac_ct_RANLIB"; then
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_ct_RANLIB" >&5
-$as_echo "$ac_ct_RANLIB" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_ct_RANLIB" >&5
+printf "%s\n" "$ac_ct_RANLIB" >&6; }
 else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: no" >&5
+printf "%s\n" "no" >&6; }
 fi
 
   if test "x$ac_ct_RANLIB" = x; then
@@ -3846,8 +4597,8 @@ fi
   else
     case $cross_compiling:$ac_tool_warned in
 yes:)
-{ $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: using cross tools not prefixed with host triplet" >&5
-$as_echo "$as_me: WARNING: using cross tools not prefixed with host triplet" >&2;}
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: WARNING: using cross tools not prefixed with host triplet" >&5
+printf "%s\n" "$as_me: WARNING: using cross tools not prefixed with host triplet" >&2;}
 ac_tool_warned=yes ;;
 esac
     RANLIB=$ac_ct_RANLIB
@@ -3858,11 +4609,12 @@ fi
 
 # Extract the first word of "ar", so it can be a program name with args.
 set dummy ar; ac_word=$2
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
-$as_echo_n "checking for $ac_word... " >&6; }
-if ${ac_cv_path_AR+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
+printf %s "checking for $ac_word... " >&6; }
+if test ${ac_cv_path_AR+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   case $AR in
   [\\/]* | ?:[\\/]*)
   ac_cv_path_AR="$AR" # Let the user override the test with a path.
@@ -3872,11 +4624,15 @@ else
 for as_dir in $PATH
 do
   IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
+  case $as_dir in #(((
+    '') as_dir=./ ;;
+    */) ;;
+    *) as_dir=$as_dir/ ;;
+  esac
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
-    ac_cv_path_AR="$as_dir/$ac_word$ac_exec_ext"
-    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
+  if as_fn_executable_p "$as_dir$ac_word$ac_exec_ext"; then
+    ac_cv_path_AR="$as_dir$ac_word$ac_exec_ext"
+    printf "%s\n" "$as_me:${as_lineno-$LINENO}: found $as_dir$ac_word$ac_exec_ext" >&5
     break 2
   fi
 done
@@ -3888,21 +4644,22 @@ esac
 fi
 AR=$ac_cv_path_AR
 if test -n "$AR"; then
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $AR" >&5
-$as_echo "$AR" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $AR" >&5
+printf "%s\n" "$AR" >&6; }
 else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: no" >&5
+printf "%s\n" "no" >&6; }
 fi
 
 
 # Extract the first word of "chmod", so it can be a program name with args.
 set dummy chmod; ac_word=$2
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
-$as_echo_n "checking for $ac_word... " >&6; }
-if ${ac_cv_path_CHMOD+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
+printf %s "checking for $ac_word... " >&6; }
+if test ${ac_cv_path_CHMOD+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   case $CHMOD in
   [\\/]* | ?:[\\/]*)
   ac_cv_path_CHMOD="$CHMOD" # Let the user override the test with a path.
@@ -3912,11 +4669,15 @@ else
 for as_dir in $PATH
 do
   IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
+  case $as_dir in #(((
+    '') as_dir=./ ;;
+    */) ;;
+    *) as_dir=$as_dir/ ;;
+  esac
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
-    ac_cv_path_CHMOD="$as_dir/$ac_word$ac_exec_ext"
-    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
+  if as_fn_executable_p "$as_dir$ac_word$ac_exec_ext"; then
+    ac_cv_path_CHMOD="$as_dir$ac_word$ac_exec_ext"
+    printf "%s\n" "$as_me:${as_lineno-$LINENO}: found $as_dir$ac_word$ac_exec_ext" >&5
     break 2
   fi
 done
@@ -3928,21 +4689,22 @@ esac
 fi
 CHMOD=$ac_cv_path_CHMOD
 if test -n "$CHMOD"; then
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $CHMOD" >&5
-$as_echo "$CHMOD" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $CHMOD" >&5
+printf "%s\n" "$CHMOD" >&6; }
 else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: no" >&5
+printf "%s\n" "no" >&6; }
 fi
 
 
 # Extract the first word of "gzip", so it can be a program name with args.
 set dummy gzip; ac_word=$2
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
-$as_echo_n "checking for $ac_word... " >&6; }
-if ${ac_cv_path_GZIPPROG+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
+printf %s "checking for $ac_word... " >&6; }
+if test ${ac_cv_path_GZIPPROG+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   case $GZIPPROG in
   [\\/]* | ?:[\\/]*)
   ac_cv_path_GZIPPROG="$GZIPPROG" # Let the user override the test with a path.
@@ -3952,11 +4714,15 @@ else
 for as_dir in $PATH
 do
   IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
+  case $as_dir in #(((
+    '') as_dir=./ ;;
+    */) ;;
+    *) as_dir=$as_dir/ ;;
+  esac
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
-    ac_cv_path_GZIPPROG="$as_dir/$ac_word$ac_exec_ext"
-    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
+  if as_fn_executable_p "$as_dir$ac_word$ac_exec_ext"; then
+    ac_cv_path_GZIPPROG="$as_dir$ac_word$ac_exec_ext"
+    printf "%s\n" "$as_me:${as_lineno-$LINENO}: found $as_dir$ac_word$ac_exec_ext" >&5
     break 2
   fi
 done
@@ -3968,27 +4734,28 @@ esac
 fi
 GZIPPROG=$ac_cv_path_GZIPPROG
 if test -n "$GZIPPROG"; then
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $GZIPPROG" >&5
-$as_echo "$GZIPPROG" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $GZIPPROG" >&5
+printf "%s\n" "$GZIPPROG" >&6; }
 else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: no" >&5
+printf "%s\n" "no" >&6; }
 fi
 
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for install-sh script" >&5
-$as_echo_n "checking for install-sh script... " >&6; }
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for install-sh script" >&5
+printf %s "checking for install-sh script... " >&6; }
 INSTALL="`pwd`/install-sh"
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: using $INSTALL" >&5
-$as_echo "using $INSTALL" >&6; }
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: using $INSTALL" >&5
+printf "%s\n" "using $INSTALL" >&6; }
 # Extract the first word of "ld", so it can be a program name with args.
 set dummy ld; ac_word=$2
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
-$as_echo_n "checking for $ac_word... " >&6; }
-if ${ac_cv_path_LD+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
+printf %s "checking for $ac_word... " >&6; }
+if test ${ac_cv_path_LD+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   case $LD in
   [\\/]* | ?:[\\/]*)
   ac_cv_path_LD="$LD" # Let the user override the test with a path.
@@ -3998,11 +4765,15 @@ else
 for as_dir in $PATH
 do
   IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
+  case $as_dir in #(((
+    '') as_dir=./ ;;
+    */) ;;
+    *) as_dir=$as_dir/ ;;
+  esac
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
-    ac_cv_path_LD="$as_dir/$ac_word$ac_exec_ext"
-    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
+  if as_fn_executable_p "$as_dir$ac_word$ac_exec_ext"; then
+    ac_cv_path_LD="$as_dir$ac_word$ac_exec_ext"
+    printf "%s\n" "$as_me:${as_lineno-$LINENO}: found $as_dir$ac_word$ac_exec_ext" >&5
     break 2
   fi
 done
@@ -4014,21 +4785,22 @@ esac
 fi
 LD=$ac_cv_path_LD
 if test -n "$LD"; then
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $LD" >&5
-$as_echo "$LD" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $LD" >&5
+printf "%s\n" "$LD" >&6; }
 else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: no" >&5
+printf "%s\n" "no" >&6; }
 fi
 
 
 # Extract the first word of "ln", so it can be a program name with args.
 set dummy ln; ac_word=$2
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
-$as_echo_n "checking for $ac_word... " >&6; }
-if ${ac_cv_path_LN+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
+printf %s "checking for $ac_word... " >&6; }
+if test ${ac_cv_path_LN+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   case $LN in
   [\\/]* | ?:[\\/]*)
   ac_cv_path_LN="$LN" # Let the user override the test with a path.
@@ -4038,11 +4810,15 @@ else
 for as_dir in $PATH
 do
   IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
+  case $as_dir in #(((
+    '') as_dir=./ ;;
+    */) ;;
+    *) as_dir=$as_dir/ ;;
+  esac
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
-    ac_cv_path_LN="$as_dir/$ac_word$ac_exec_ext"
-    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
+  if as_fn_executable_p "$as_dir$ac_word$ac_exec_ext"; then
+    ac_cv_path_LN="$as_dir$ac_word$ac_exec_ext"
+    printf "%s\n" "$as_me:${as_lineno-$LINENO}: found $as_dir$ac_word$ac_exec_ext" >&5
     break 2
   fi
 done
@@ -4054,21 +4830,22 @@ esac
 fi
 LN=$ac_cv_path_LN
 if test -n "$LN"; then
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $LN" >&5
-$as_echo "$LN" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $LN" >&5
+printf "%s\n" "$LN" >&6; }
 else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: no" >&5
+printf "%s\n" "no" >&6; }
 fi
 
 
 # Extract the first word of "mkdir", so it can be a program name with args.
 set dummy mkdir; ac_word=$2
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
-$as_echo_n "checking for $ac_word... " >&6; }
-if ${ac_cv_path_MKDIR+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
+printf %s "checking for $ac_word... " >&6; }
+if test ${ac_cv_path_MKDIR+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   case $MKDIR in
   [\\/]* | ?:[\\/]*)
   ac_cv_path_MKDIR="$MKDIR" # Let the user override the test with a path.
@@ -4078,11 +4855,15 @@ else
 for as_dir in $PATH
 do
   IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
+  case $as_dir in #(((
+    '') as_dir=./ ;;
+    */) ;;
+    *) as_dir=$as_dir/ ;;
+  esac
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
-    ac_cv_path_MKDIR="$as_dir/$ac_word$ac_exec_ext"
-    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
+  if as_fn_executable_p "$as_dir$ac_word$ac_exec_ext"; then
+    ac_cv_path_MKDIR="$as_dir$ac_word$ac_exec_ext"
+    printf "%s\n" "$as_me:${as_lineno-$LINENO}: found $as_dir$ac_word$ac_exec_ext" >&5
     break 2
   fi
 done
@@ -4094,21 +4875,22 @@ esac
 fi
 MKDIR=$ac_cv_path_MKDIR
 if test -n "$MKDIR"; then
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $MKDIR" >&5
-$as_echo "$MKDIR" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $MKDIR" >&5
+printf "%s\n" "$MKDIR" >&6; }
 else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: no" >&5
+printf "%s\n" "no" >&6; }
 fi
 
 
 # Extract the first word of "mv", so it can be a program name with args.
 set dummy mv; ac_word=$2
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
-$as_echo_n "checking for $ac_word... " >&6; }
-if ${ac_cv_path_MV+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
+printf %s "checking for $ac_word... " >&6; }
+if test ${ac_cv_path_MV+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   case $MV in
   [\\/]* | ?:[\\/]*)
   ac_cv_path_MV="$MV" # Let the user override the test with a path.
@@ -4118,11 +4900,15 @@ else
 for as_dir in $PATH
 do
   IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
+  case $as_dir in #(((
+    '') as_dir=./ ;;
+    */) ;;
+    *) as_dir=$as_dir/ ;;
+  esac
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
-    ac_cv_path_MV="$as_dir/$ac_word$ac_exec_ext"
-    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
+  if as_fn_executable_p "$as_dir$ac_word$ac_exec_ext"; then
+    ac_cv_path_MV="$as_dir$ac_word$ac_exec_ext"
+    printf "%s\n" "$as_me:${as_lineno-$LINENO}: found $as_dir$ac_word$ac_exec_ext" >&5
     break 2
   fi
 done
@@ -4134,21 +4920,22 @@ esac
 fi
 MV=$ac_cv_path_MV
 if test -n "$MV"; then
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $MV" >&5
-$as_echo "$MV" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $MV" >&5
+printf "%s\n" "$MV" >&6; }
 else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: no" >&5
+printf "%s\n" "no" >&6; }
 fi
 
 
 # Extract the first word of "rm", so it can be a program name with args.
 set dummy rm; ac_word=$2
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
-$as_echo_n "checking for $ac_word... " >&6; }
-if ${ac_cv_path_RM+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
+printf %s "checking for $ac_word... " >&6; }
+if test ${ac_cv_path_RM+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   case $RM in
   [\\/]* | ?:[\\/]*)
   ac_cv_path_RM="$RM" # Let the user override the test with a path.
@@ -4158,11 +4945,15 @@ else
 for as_dir in $PATH
 do
   IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
+  case $as_dir in #(((
+    '') as_dir=./ ;;
+    */) ;;
+    *) as_dir=$as_dir/ ;;
+  esac
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
-    ac_cv_path_RM="$as_dir/$ac_word$ac_exec_ext"
-    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
+  if as_fn_executable_p "$as_dir$ac_word$ac_exec_ext"; then
+    ac_cv_path_RM="$as_dir$ac_word$ac_exec_ext"
+    printf "%s\n" "$as_me:${as_lineno-$LINENO}: found $as_dir$ac_word$ac_exec_ext" >&5
     break 2
   fi
 done
@@ -4174,21 +4965,22 @@ esac
 fi
 RM=$ac_cv_path_RM
 if test -n "$RM"; then
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $RM" >&5
-$as_echo "$RM" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $RM" >&5
+printf "%s\n" "$RM" >&6; }
 else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: no" >&5
+printf "%s\n" "no" >&6; }
 fi
 
 
 # Extract the first word of "rmdir", so it can be a program name with args.
 set dummy rmdir; ac_word=$2
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
-$as_echo_n "checking for $ac_word... " >&6; }
-if ${ac_cv_path_RMDIR+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
+printf %s "checking for $ac_word... " >&6; }
+if test ${ac_cv_path_RMDIR+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   case $RMDIR in
   [\\/]* | ?:[\\/]*)
   ac_cv_path_RMDIR="$RMDIR" # Let the user override the test with a path.
@@ -4198,11 +4990,15 @@ else
 for as_dir in $PATH
 do
   IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
+  case $as_dir in #(((
+    '') as_dir=./ ;;
+    */) ;;
+    *) as_dir=$as_dir/ ;;
+  esac
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
-    ac_cv_path_RMDIR="$as_dir/$ac_word$ac_exec_ext"
-    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
+  if as_fn_executable_p "$as_dir$ac_word$ac_exec_ext"; then
+    ac_cv_path_RMDIR="$as_dir$ac_word$ac_exec_ext"
+    printf "%s\n" "$as_me:${as_lineno-$LINENO}: found $as_dir$ac_word$ac_exec_ext" >&5
     break 2
   fi
 done
@@ -4214,21 +5010,22 @@ esac
 fi
 RMDIR=$ac_cv_path_RMDIR
 if test -n "$RMDIR"; then
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $RMDIR" >&5
-$as_echo "$RMDIR" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $RMDIR" >&5
+printf "%s\n" "$RMDIR" >&6; }
 else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: no" >&5
+printf "%s\n" "no" >&6; }
 fi
 
 
 # Extract the first word of "sed", so it can be a program name with args.
 set dummy sed; ac_word=$2
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
-$as_echo_n "checking for $ac_word... " >&6; }
-if ${ac_cv_path_SED+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
+printf %s "checking for $ac_word... " >&6; }
+if test ${ac_cv_path_SED+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   case $SED in
   [\\/]* | ?:[\\/]*)
   ac_cv_path_SED="$SED" # Let the user override the test with a path.
@@ -4238,11 +5035,15 @@ else
 for as_dir in $PATH
 do
   IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
+  case $as_dir in #(((
+    '') as_dir=./ ;;
+    */) ;;
+    *) as_dir=$as_dir/ ;;
+  esac
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
-    ac_cv_path_SED="$as_dir/$ac_word$ac_exec_ext"
-    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
+  if as_fn_executable_p "$as_dir$ac_word$ac_exec_ext"; then
+    ac_cv_path_SED="$as_dir$ac_word$ac_exec_ext"
+    printf "%s\n" "$as_me:${as_lineno-$LINENO}: found $as_dir$ac_word$ac_exec_ext" >&5
     break 2
   fi
 done
@@ -4254,21 +5055,22 @@ esac
 fi
 SED=$ac_cv_path_SED
 if test -n "$SED"; then
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $SED" >&5
-$as_echo "$SED" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $SED" >&5
+printf "%s\n" "$SED" >&6; }
 else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: no" >&5
+printf "%s\n" "no" >&6; }
 fi
 
 
 # Extract the first word of "xdg-open", so it can be a program name with args.
 set dummy xdg-open; ac_word=$2
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
-$as_echo_n "checking for $ac_word... " >&6; }
-if ${ac_cv_path_XDGOPEN+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
+printf %s "checking for $ac_word... " >&6; }
+if test ${ac_cv_path_XDGOPEN+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   case $XDGOPEN in
   [\\/]* | ?:[\\/]*)
   ac_cv_path_XDGOPEN="$XDGOPEN" # Let the user override the test with a path.
@@ -4278,11 +5080,15 @@ else
 for as_dir in $PATH
 do
   IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
+  case $as_dir in #(((
+    '') as_dir=./ ;;
+    */) ;;
+    *) as_dir=$as_dir/ ;;
+  esac
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
-    ac_cv_path_XDGOPEN="$as_dir/$ac_word$ac_exec_ext"
-    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
+  if as_fn_executable_p "$as_dir$ac_word$ac_exec_ext"; then
+    ac_cv_path_XDGOPEN="$as_dir$ac_word$ac_exec_ext"
+    printf "%s\n" "$as_me:${as_lineno-$LINENO}: found $as_dir$ac_word$ac_exec_ext" >&5
     break 2
   fi
 done
@@ -4294,11 +5100,11 @@ esac
 fi
 XDGOPEN=$ac_cv_path_XDGOPEN
 if test -n "$XDGOPEN"; then
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $XDGOPEN" >&5
-$as_echo "$XDGOPEN" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $XDGOPEN" >&5
+printf "%s\n" "$XDGOPEN" >&6; }
 else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: no" >&5
+printf "%s\n" "no" >&6; }
 fi
 
 
@@ -4319,7 +5125,8 @@ fi
 
 INSTALLSTATIC=""
 # Check whether --enable-static was given.
-if test "${enable_static+set}" = set; then :
+if test ${enable_static+y}
+then :
   enableval=$enable_static;
 fi
 
@@ -4334,11 +5141,12 @@ fi
 if test -n "$ac_tool_prefix"; then
   # Extract the first word of "${ac_tool_prefix}pkg-config", so it can be a program name with args.
 set dummy ${ac_tool_prefix}pkg-config; ac_word=$2
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
-$as_echo_n "checking for $ac_word... " >&6; }
-if ${ac_cv_path_PKGCONFIG+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
+printf %s "checking for $ac_word... " >&6; }
+if test ${ac_cv_path_PKGCONFIG+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   case $PKGCONFIG in
   [\\/]* | ?:[\\/]*)
   ac_cv_path_PKGCONFIG="$PKGCONFIG" # Let the user override the test with a path.
@@ -4348,11 +5156,15 @@ else
 for as_dir in $PATH
 do
   IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
+  case $as_dir in #(((
+    '') as_dir=./ ;;
+    */) ;;
+    *) as_dir=$as_dir/ ;;
+  esac
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
-    ac_cv_path_PKGCONFIG="$as_dir/$ac_word$ac_exec_ext"
-    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
+  if as_fn_executable_p "$as_dir$ac_word$ac_exec_ext"; then
+    ac_cv_path_PKGCONFIG="$as_dir$ac_word$ac_exec_ext"
+    printf "%s\n" "$as_me:${as_lineno-$LINENO}: found $as_dir$ac_word$ac_exec_ext" >&5
     break 2
   fi
 done
@@ -4364,11 +5176,11 @@ esac
 fi
 PKGCONFIG=$ac_cv_path_PKGCONFIG
 if test -n "$PKGCONFIG"; then
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $PKGCONFIG" >&5
-$as_echo "$PKGCONFIG" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $PKGCONFIG" >&5
+printf "%s\n" "$PKGCONFIG" >&6; }
 else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: no" >&5
+printf "%s\n" "no" >&6; }
 fi
 
 
@@ -4377,11 +5189,12 @@ if test -z "$ac_cv_path_PKGCONFIG"; then
   ac_pt_PKGCONFIG=$PKGCONFIG
   # Extract the first word of "pkg-config", so it can be a program name with args.
 set dummy pkg-config; ac_word=$2
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
-$as_echo_n "checking for $ac_word... " >&6; }
-if ${ac_cv_path_ac_pt_PKGCONFIG+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
+printf %s "checking for $ac_word... " >&6; }
+if test ${ac_cv_path_ac_pt_PKGCONFIG+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   case $ac_pt_PKGCONFIG in
   [\\/]* | ?:[\\/]*)
   ac_cv_path_ac_pt_PKGCONFIG="$ac_pt_PKGCONFIG" # Let the user override the test with a path.
@@ -4391,11 +5204,15 @@ else
 for as_dir in $PATH
 do
   IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
+  case $as_dir in #(((
+    '') as_dir=./ ;;
+    */) ;;
+    *) as_dir=$as_dir/ ;;
+  esac
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
-    ac_cv_path_ac_pt_PKGCONFIG="$as_dir/$ac_word$ac_exec_ext"
-    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
+  if as_fn_executable_p "$as_dir$ac_word$ac_exec_ext"; then
+    ac_cv_path_ac_pt_PKGCONFIG="$as_dir$ac_word$ac_exec_ext"
+    printf "%s\n" "$as_me:${as_lineno-$LINENO}: found $as_dir$ac_word$ac_exec_ext" >&5
     break 2
   fi
 done
@@ -4407,11 +5224,11 @@ esac
 fi
 ac_pt_PKGCONFIG=$ac_cv_path_ac_pt_PKGCONFIG
 if test -n "$ac_pt_PKGCONFIG"; then
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_pt_PKGCONFIG" >&5
-$as_echo "$ac_pt_PKGCONFIG" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_pt_PKGCONFIG" >&5
+printf "%s\n" "$ac_pt_PKGCONFIG" >&6; }
 else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: no" >&5
+printf "%s\n" "no" >&6; }
 fi
 
   if test "x$ac_pt_PKGCONFIG" = x; then
@@ -4419,8 +5236,8 @@ fi
   else
     case $cross_compiling:$ac_tool_warned in
 yes:)
-{ $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: using cross tools not prefixed with host triplet" >&5
-$as_echo "$as_me: WARNING: using cross tools not prefixed with host triplet" >&2;}
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: WARNING: using cross tools not prefixed with host triplet" >&5
+printf "%s\n" "$as_me: WARNING: using cross tools not prefixed with host triplet" >&2;}
 ac_tool_warned=yes ;;
 esac
     PKGCONFIG=$ac_pt_PKGCONFIG
@@ -4431,11 +5248,12 @@ fi
 
 
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for library containing abs" >&5
-$as_echo_n "checking for library containing abs... " >&6; }
-if ${ac_cv_search_abs+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for library containing abs" >&5
+printf %s "checking for library containing abs... " >&6; }
+if test ${ac_cv_search_abs+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   ac_func_search_save_LIBS=$LIBS
 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
@@ -4443,56 +5261,59 @@ cat confdefs.h - <<_ACEOF >conftest.$ac_
 /* Override any GCC internal prototype to avoid an error.
    Use char because int might match the return type of a GCC
    builtin and then its argument prototype would still apply.  */
-#ifdef __cplusplus
-extern "C"
-#endif
 char abs ();
 int
-main ()
+main (void)
 {
 return abs ();
   ;
   return 0;
 }
 _ACEOF
-for ac_lib in '' m; do
+for ac_lib in '' m
+do
   if test -z "$ac_lib"; then
     ac_res="none required"
   else
     ac_res=-l$ac_lib
     LIBS="-l$ac_lib  $ac_func_search_save_LIBS"
   fi
-  if ac_fn_c_try_link "$LINENO"; then :
+  if ac_fn_c_try_link "$LINENO"
+then :
   ac_cv_search_abs=$ac_res
 fi
-rm -f core conftest.err conftest.$ac_objext \
+rm -f core conftest.err conftest.$ac_objext conftest.beam \
     conftest$ac_exeext
-  if ${ac_cv_search_abs+:} false; then :
+  if test ${ac_cv_search_abs+y}
+then :
   break
 fi
 done
-if ${ac_cv_search_abs+:} false; then :
+if test ${ac_cv_search_abs+y}
+then :
 
-else
+else $as_nop
   ac_cv_search_abs=no
 fi
 rm conftest.$ac_ext
 LIBS=$ac_func_search_save_LIBS
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_search_abs" >&5
-$as_echo "$ac_cv_search_abs" >&6; }
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_search_abs" >&5
+printf "%s\n" "$ac_cv_search_abs" >&6; }
 ac_res=$ac_cv_search_abs
-if test "$ac_res" != no; then :
+if test "$ac_res" != no
+then :
   test "$ac_res" = "none required" || LIBS="$ac_res $LIBS"
-  $as_echo "#define HAVE_ABS 1" >>confdefs.h
+  printf "%s\n" "#define HAVE_ABS 1" >>confdefs.h
 
 fi
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for library containing crypt" >&5
-$as_echo_n "checking for library containing crypt... " >&6; }
-if ${ac_cv_search_crypt+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for library containing crypt" >&5
+printf %s "checking for library containing crypt... " >&6; }
+if test ${ac_cv_search_crypt+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   ac_func_search_save_LIBS=$LIBS
 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
@@ -4500,55 +5321,58 @@ cat confdefs.h - <<_ACEOF >conftest.$ac_
 /* Override any GCC internal prototype to avoid an error.
    Use char because int might match the return type of a GCC
    builtin and then its argument prototype would still apply.  */
-#ifdef __cplusplus
-extern "C"
-#endif
 char crypt ();
 int
-main ()
+main (void)
 {
 return crypt ();
   ;
   return 0;
 }
 _ACEOF
-for ac_lib in '' crypt; do
+for ac_lib in '' crypt
+do
   if test -z "$ac_lib"; then
     ac_res="none required"
   else
     ac_res=-l$ac_lib
     LIBS="-l$ac_lib  $ac_func_search_save_LIBS"
   fi
-  if ac_fn_c_try_link "$LINENO"; then :
+  if ac_fn_c_try_link "$LINENO"
+then :
   ac_cv_search_crypt=$ac_res
 fi
-rm -f core conftest.err conftest.$ac_objext \
+rm -f core conftest.err conftest.$ac_objext conftest.beam \
     conftest$ac_exeext
-  if ${ac_cv_search_crypt+:} false; then :
+  if test ${ac_cv_search_crypt+y}
+then :
   break
 fi
 done
-if ${ac_cv_search_crypt+:} false; then :
+if test ${ac_cv_search_crypt+y}
+then :
 
-else
+else $as_nop
   ac_cv_search_crypt=no
 fi
 rm conftest.$ac_ext
 LIBS=$ac_func_search_save_LIBS
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_search_crypt" >&5
-$as_echo "$ac_cv_search_crypt" >&6; }
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_search_crypt" >&5
+printf "%s\n" "$ac_cv_search_crypt" >&6; }
 ac_res=$ac_cv_search_crypt
-if test "$ac_res" != no; then :
+if test "$ac_res" != no
+then :
   test "$ac_res" = "none required" || LIBS="$ac_res $LIBS"
 
 fi
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for library containing fmod" >&5
-$as_echo_n "checking for library containing fmod... " >&6; }
-if ${ac_cv_search_fmod+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for library containing fmod" >&5
+printf %s "checking for library containing fmod... " >&6; }
+if test ${ac_cv_search_fmod+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   ac_func_search_save_LIBS=$LIBS
 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
@@ -4556,55 +5380,58 @@ cat confdefs.h - <<_ACEOF >conftest.$ac_
 /* Override any GCC internal prototype to avoid an error.
    Use char because int might match the return type of a GCC
    builtin and then its argument prototype would still apply.  */
-#ifdef __cplusplus
-extern "C"
-#endif
 char fmod ();
 int
-main ()
+main (void)
 {
 return fmod ();
   ;
   return 0;
 }
 _ACEOF
-for ac_lib in '' m; do
+for ac_lib in '' m
+do
   if test -z "$ac_lib"; then
     ac_res="none required"
   else
     ac_res=-l$ac_lib
     LIBS="-l$ac_lib  $ac_func_search_save_LIBS"
   fi
-  if ac_fn_c_try_link "$LINENO"; then :
+  if ac_fn_c_try_link "$LINENO"
+then :
   ac_cv_search_fmod=$ac_res
 fi
-rm -f core conftest.err conftest.$ac_objext \
+rm -f core conftest.err conftest.$ac_objext conftest.beam \
     conftest$ac_exeext
-  if ${ac_cv_search_fmod+:} false; then :
+  if test ${ac_cv_search_fmod+y}
+then :
   break
 fi
 done
-if ${ac_cv_search_fmod+:} false; then :
+if test ${ac_cv_search_fmod+y}
+then :
 
-else
+else $as_nop
   ac_cv_search_fmod=no
 fi
 rm conftest.$ac_ext
 LIBS=$ac_func_search_save_LIBS
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_search_fmod" >&5
-$as_echo "$ac_cv_search_fmod" >&6; }
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_search_fmod" >&5
+printf "%s\n" "$ac_cv_search_fmod" >&6; }
 ac_res=$ac_cv_search_fmod
-if test "$ac_res" != no; then :
+if test "$ac_res" != no
+then :
   test "$ac_res" = "none required" || LIBS="$ac_res $LIBS"
 
 fi
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for library containing getspent" >&5
-$as_echo_n "checking for library containing getspent... " >&6; }
-if ${ac_cv_search_getspent+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for library containing getspent" >&5
+printf %s "checking for library containing getspent... " >&6; }
+if test ${ac_cv_search_getspent+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   ac_func_search_save_LIBS=$LIBS
 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
@@ -4612,46 +5439,48 @@ cat confdefs.h - <<_ACEOF >conftest.$ac_
 /* Override any GCC internal prototype to avoid an error.
    Use char because int might match the return type of a GCC
    builtin and then its argument prototype would still apply.  */
-#ifdef __cplusplus
-extern "C"
-#endif
 char getspent ();
 int
-main ()
+main (void)
 {
 return getspent ();
   ;
   return 0;
 }
 _ACEOF
-for ac_lib in '' sec gen; do
+for ac_lib in '' sec gen
+do
   if test -z "$ac_lib"; then
     ac_res="none required"
   else
     ac_res=-l$ac_lib
     LIBS="-l$ac_lib  $ac_func_search_save_LIBS"
   fi
-  if ac_fn_c_try_link "$LINENO"; then :
+  if ac_fn_c_try_link "$LINENO"
+then :
   ac_cv_search_getspent=$ac_res
 fi
-rm -f core conftest.err conftest.$ac_objext \
+rm -f core conftest.err conftest.$ac_objext conftest.beam \
     conftest$ac_exeext
-  if ${ac_cv_search_getspent+:} false; then :
+  if test ${ac_cv_search_getspent+y}
+then :
   break
 fi
 done
-if ${ac_cv_search_getspent+:} false; then :
+if test ${ac_cv_search_getspent+y}
+then :
 
-else
+else $as_nop
   ac_cv_search_getspent=no
 fi
 rm conftest.$ac_ext
 LIBS=$ac_func_search_save_LIBS
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_search_getspent" >&5
-$as_echo "$ac_cv_search_getspent" >&6; }
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_search_getspent" >&5
+printf "%s\n" "$ac_cv_search_getspent" >&6; }
 ac_res=$ac_cv_search_getspent
-if test "$ac_res" != no; then :
+if test "$ac_res" != no
+then :
   test "$ac_res" = "none required" || LIBS="$ac_res $LIBS"
 
 fi
@@ -4659,7 +5488,8 @@ fi
 
 LIBMALLOC=""
 # Check whether --enable-mallinfo was given.
-if test "${enable_mallinfo+set}" = set; then :
+if test ${enable_mallinfo+y}
+then :
   enableval=$enable_mallinfo;
 fi
 
@@ -4667,11 +5497,12 @@ fi
 if test x$enable_mallinfo = xyes; then
 	SAVELIBS="$LIBS"
 	LIBS=""
-	{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for library containing mallinfo" >&5
-$as_echo_n "checking for library containing mallinfo... " >&6; }
-if ${ac_cv_search_mallinfo+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+	{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for library containing mallinfo" >&5
+printf %s "checking for library containing mallinfo... " >&6; }
+if test ${ac_cv_search_mallinfo+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   ac_func_search_save_LIBS=$LIBS
 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
@@ -4679,48 +5510,50 @@ cat confdefs.h - <<_ACEOF >conftest.$ac_
 /* Override any GCC internal prototype to avoid an error.
    Use char because int might match the return type of a GCC
    builtin and then its argument prototype would still apply.  */
-#ifdef __cplusplus
-extern "C"
-#endif
 char mallinfo ();
 int
-main ()
+main (void)
 {
 return mallinfo ();
   ;
   return 0;
 }
 _ACEOF
-for ac_lib in '' malloc; do
+for ac_lib in '' malloc
+do
   if test -z "$ac_lib"; then
     ac_res="none required"
   else
     ac_res=-l$ac_lib
     LIBS="-l$ac_lib  $ac_func_search_save_LIBS"
   fi
-  if ac_fn_c_try_link "$LINENO"; then :
+  if ac_fn_c_try_link "$LINENO"
+then :
   ac_cv_search_mallinfo=$ac_res
 fi
-rm -f core conftest.err conftest.$ac_objext \
+rm -f core conftest.err conftest.$ac_objext conftest.beam \
     conftest$ac_exeext
-  if ${ac_cv_search_mallinfo+:} false; then :
+  if test ${ac_cv_search_mallinfo+y}
+then :
   break
 fi
 done
-if ${ac_cv_search_mallinfo+:} false; then :
+if test ${ac_cv_search_mallinfo+y}
+then :
 
-else
+else $as_nop
   ac_cv_search_mallinfo=no
 fi
 rm conftest.$ac_ext
 LIBS=$ac_func_search_save_LIBS
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_search_mallinfo" >&5
-$as_echo "$ac_cv_search_mallinfo" >&6; }
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_search_mallinfo" >&5
+printf "%s\n" "$ac_cv_search_mallinfo" >&6; }
 ac_res=$ac_cv_search_mallinfo
-if test "$ac_res" != no; then :
+if test "$ac_res" != no
+then :
   test "$ac_res" = "none required" || LIBS="$ac_res $LIBS"
-  $as_echo "#define HAVE_MALLINFO 1" >>confdefs.h
+  printf "%s\n" "#define HAVE_MALLINFO 1" >>confdefs.h
 
 fi
 
@@ -4731,17 +5564,19 @@ fi
 
 
 # Check whether --enable-libpaper was given.
-if test "${enable_libpaper+set}" = set; then :
+if test ${enable_libpaper+y}
+then :
   enableval=$enable_libpaper;
 fi
 
 
 if test x$enable_libpaper = xyes; then
-	{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for systempapername in -lpaper" >&5
-$as_echo_n "checking for systempapername in -lpaper... " >&6; }
-if ${ac_cv_lib_paper_systempapername+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+	{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for systempapername in -lpaper" >&5
+printf %s "checking for systempapername in -lpaper... " >&6; }
+if test ${ac_cv_lib_paper_systempapername+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lpaper  $LIBS"
 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
@@ -4750,34 +5585,33 @@ cat confdefs.h - <<_ACEOF >conftest.$ac_
 /* Override any GCC internal prototype to avoid an error.
    Use char because int might match the return type of a GCC
    builtin and then its argument prototype would still apply.  */
-#ifdef __cplusplus
-extern "C"
-#endif
 char systempapername ();
 int
-main ()
+main (void)
 {
 return systempapername ();
   ;
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
+if ac_fn_c_try_link "$LINENO"
+then :
   ac_cv_lib_paper_systempapername=yes
-else
+else $as_nop
   ac_cv_lib_paper_systempapername=no
 fi
-rm -f core conftest.err conftest.$ac_objext \
+rm -f core conftest.err conftest.$ac_objext conftest.beam \
     conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_lib_paper_systempapername" >&5
-$as_echo "$ac_cv_lib_paper_systempapername" >&6; }
-if test "x$ac_cv_lib_paper_systempapername" = xyes; then :
-  $as_echo "#define HAVE_LIBPAPER 1" >>confdefs.h
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_lib_paper_systempapername" >&5
+printf "%s\n" "$ac_cv_lib_paper_systempapername" >&6; }
+if test "x$ac_cv_lib_paper_systempapername" = xyes
+then :
+  printf "%s\n" "#define HAVE_LIBPAPER 1" >>confdefs.h
 
 		LIBPAPER="-lpaper"
-else
+else $as_nop
   LIBPAPER=""
 fi
 
@@ -4786,12 +5620,41 @@ else
 fi
 
 
+ac_header= ac_cache=
+for ac_item in $ac_header_c_list
+do
+  if test $ac_cache; then
+    ac_fn_c_check_header_compile "$LINENO" $ac_header ac_cv_header_$ac_cache "$ac_includes_default"
+    if eval test \"x\$ac_cv_header_$ac_cache\" = xyes; then
+      printf "%s\n" "#define $ac_item 1" >> confdefs.h
+    fi
+    ac_header= ac_cache=
+  elif test $ac_header; then
+    ac_cache=$ac_item
+  else
+    ac_header=$ac_item
+  fi
+done
+
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for grep that handles long lines and -e" >&5
-$as_echo_n "checking for grep that handles long lines and -e... " >&6; }
-if ${ac_cv_path_GREP+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+
+
+
+
+
+
+if test $ac_cv_header_stdlib_h = yes && test $ac_cv_header_string_h = yes
+then :
+
+printf "%s\n" "#define STDC_HEADERS 1" >>confdefs.h
+
+fi
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for grep that handles long lines and -e" >&5
+printf %s "checking for grep that handles long lines and -e... " >&6; }
+if test ${ac_cv_path_GREP+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   if test -z "$GREP"; then
   ac_path_GREP_found=false
   # Loop through the user's path and test for each of PROGNAME-LIST
@@ -4799,10 +5662,15 @@ else
 for as_dir in $PATH$PATH_SEPARATOR/usr/xpg4/bin
 do
   IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
-    for ac_prog in grep ggrep; do
+  case $as_dir in #(((
+    '') as_dir=./ ;;
+    */) ;;
+    *) as_dir=$as_dir/ ;;
+  esac
+    for ac_prog in grep ggrep
+   do
     for ac_exec_ext in '' $ac_executable_extensions; do
-      ac_path_GREP="$as_dir/$ac_prog$ac_exec_ext"
+      ac_path_GREP="$as_dir$ac_prog$ac_exec_ext"
       as_fn_executable_p "$ac_path_GREP" || continue
 # Check for GNU ac_path_GREP and select it if it is found.
   # Check for GNU $ac_path_GREP
@@ -4811,13 +5679,13 @@ case `"$ac_path_GREP" --version 2>&1` in
   ac_cv_path_GREP="$ac_path_GREP" ac_path_GREP_found=:;;
 *)
   ac_count=0
-  $as_echo_n 0123456789 >"conftest.in"
+  printf %s 0123456789 >"conftest.in"
   while :
   do
     cat "conftest.in" "conftest.in" >"conftest.tmp"
     mv "conftest.tmp" "conftest.in"
     cp "conftest.in" "conftest.nl"
-    $as_echo 'GREP' >> "conftest.nl"
+    printf "%s\n" 'GREP' >> "conftest.nl"
     "$ac_path_GREP" -e 'GREP$' -e '-(cannot match)-' < "conftest.nl" >"conftest.out" 2>/dev/null || break
     diff "conftest.out" "conftest.nl" >/dev/null 2>&1 || break
     as_fn_arith $ac_count + 1 && ac_count=$as_val
@@ -4845,16 +5713,20 @@ else
 fi
 
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_path_GREP" >&5
-$as_echo "$ac_cv_path_GREP" >&6; }
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_path_GREP" >&5
+printf "%s\n" "$ac_cv_path_GREP" >&6; }
  GREP="$ac_cv_path_GREP"
 
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for egrep" >&5
-$as_echo_n "checking for egrep... " >&6; }
-if ${ac_cv_path_EGREP+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+# Autoupdate added the next two lines to ensure that your configure
+# script's behavior did not change.  They are probably safe to remove.
+
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for egrep" >&5
+printf %s "checking for egrep... " >&6; }
+if test ${ac_cv_path_EGREP+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   if echo a | $GREP -E '(a|b)' >/dev/null 2>&1
    then ac_cv_path_EGREP="$GREP -E"
    else
@@ -4865,10 +5737,15 @@ else
 for as_dir in $PATH$PATH_SEPARATOR/usr/xpg4/bin
 do
   IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
-    for ac_prog in egrep; do
+  case $as_dir in #(((
+    '') as_dir=./ ;;
+    */) ;;
+    *) as_dir=$as_dir/ ;;
+  esac
+    for ac_prog in egrep
+   do
     for ac_exec_ext in '' $ac_executable_extensions; do
-      ac_path_EGREP="$as_dir/$ac_prog$ac_exec_ext"
+      ac_path_EGREP="$as_dir$ac_prog$ac_exec_ext"
       as_fn_executable_p "$ac_path_EGREP" || continue
 # Check for GNU ac_path_EGREP and select it if it is found.
   # Check for GNU $ac_path_EGREP
@@ -4877,13 +5754,13 @@ case `"$ac_path_EGREP" --version 2>&1` i
   ac_cv_path_EGREP="$ac_path_EGREP" ac_path_EGREP_found=:;;
 *)
   ac_count=0
-  $as_echo_n 0123456789 >"conftest.in"
+  printf %s 0123456789 >"conftest.in"
   while :
   do
     cat "conftest.in" "conftest.in" >"conftest.tmp"
     mv "conftest.tmp" "conftest.in"
     cp "conftest.in" "conftest.nl"
-    $as_echo 'EGREP' >> "conftest.nl"
+    printf "%s\n" 'EGREP' >> "conftest.nl"
     "$ac_path_EGREP" 'EGREP$' < "conftest.nl" >"conftest.out" 2>/dev/null || break
     diff "conftest.out" "conftest.nl" >/dev/null 2>&1 || break
     as_fn_arith $ac_count + 1 && ac_count=$as_val
@@ -4912,234 +5789,108 @@ fi
 
    fi
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_path_EGREP" >&5
-$as_echo "$ac_cv_path_EGREP" >&6; }
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_path_EGREP" >&5
+printf "%s\n" "$ac_cv_path_EGREP" >&6; }
  EGREP="$ac_cv_path_EGREP"
 
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for ANSI C header files" >&5
-$as_echo_n "checking for ANSI C header files... " >&6; }
-if ${ac_cv_header_stdc+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
-#include <stdlib.h>
-#include <stdarg.h>
-#include <string.h>
-#include <float.h>
-
-int
-main ()
-{
-
-  ;
-  return 0;
-}
-_ACEOF
-if ac_fn_c_try_compile "$LINENO"; then :
-  ac_cv_header_stdc=yes
-else
-  ac_cv_header_stdc=no
-fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
-
-if test $ac_cv_header_stdc = yes; then
-  # SunOS 4.x string.h does not declare mem*, contrary to ANSI.
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
-#include <string.h>
-
-_ACEOF
-if (eval "$ac_cpp conftest.$ac_ext") 2>&5 |
-  $EGREP "memchr" >/dev/null 2>&1; then :
-
-else
-  ac_cv_header_stdc=no
-fi
-rm -f conftest*
-
-fi
-
-if test $ac_cv_header_stdc = yes; then
-  # ISC 2.0.2 stdlib.h does not declare free, contrary to ANSI.
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
-#include <stdlib.h>
-
-_ACEOF
-if (eval "$ac_cpp conftest.$ac_ext") 2>&5 |
-  $EGREP "free" >/dev/null 2>&1; then :
-
-else
-  ac_cv_header_stdc=no
-fi
-rm -f conftest*
-
-fi
-
-if test $ac_cv_header_stdc = yes; then
-  # /bin/cc in Irix-4.0.5 gets non-ANSI ctype macros unless using -ansi.
-  if test "$cross_compiling" = yes; then :
-  :
-else
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
-#include <ctype.h>
-#include <stdlib.h>
-#if ((' ' & 0x0FF) == 0x020)
-# define ISLOWER(c) ('a' <= (c) && (c) <= 'z')
-# define TOUPPER(c) (ISLOWER(c) ? 'A' + ((c) - 'a') : (c))
-#else
-# define ISLOWER(c) \
-		   (('a' <= (c) && (c) <= 'i') \
-		     || ('j' <= (c) && (c) <= 'r') \
-		     || ('s' <= (c) && (c) <= 'z'))
-# define TOUPPER(c) (ISLOWER(c) ? ((c) | 0x40) : (c))
-#endif
-
-#define XOR(e, f) (((e) && !(f)) || (!(e) && (f)))
-int
-main ()
-{
-  int i;
-  for (i = 0; i < 256; i++)
-    if (XOR (islower (i), ISLOWER (i))
-	|| toupper (i) != TOUPPER (i))
-      return 2;
-  return 0;
-}
-_ACEOF
-if ac_fn_c_try_run "$LINENO"; then :
-
-else
-  ac_cv_header_stdc=no
-fi
-rm -f core *.core core.conftest.* gmon.out bb.out conftest$ac_exeext \
-  conftest.$ac_objext conftest.beam conftest.$ac_ext
-fi
-
-fi
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_header_stdc" >&5
-$as_echo "$ac_cv_header_stdc" >&6; }
-if test $ac_cv_header_stdc = yes; then
-
-$as_echo "#define STDC_HEADERS 1" >>confdefs.h
-
-fi
-
-# On IRIX 5.3, sys/types and inttypes.h are conflicting.
-for ac_header in sys/types.h sys/stat.h stdlib.h string.h memory.h strings.h \
-		  inttypes.h stdint.h unistd.h
-do :
-  as_ac_Header=`$as_echo "ac_cv_header_$ac_header" | $as_tr_sh`
-ac_fn_c_check_header_compile "$LINENO" "$ac_header" "$as_ac_Header" "$ac_includes_default
-"
-if eval test \"x\$"$as_ac_Header"\" = x"yes"; then :
-  cat >>confdefs.h <<_ACEOF
-#define `$as_echo "HAVE_$ac_header" | $as_tr_cpp` 1
-_ACEOF
-
-fi
-
-done
-
 
-ac_fn_c_check_header_mongrel "$LINENO" "stdlib.h" "ac_cv_header_stdlib_h" "$ac_includes_default"
-if test "x$ac_cv_header_stdlib_h" = xyes; then :
-  $as_echo "#define HAVE_STDLIB_H 1" >>confdefs.h
+ac_fn_c_check_header_compile "$LINENO" "stdlib.h" "ac_cv_header_stdlib_h" "$ac_includes_default"
+if test "x$ac_cv_header_stdlib_h" = xyes
+then :
+  printf "%s\n" "#define HAVE_STDLIB_H 1" >>confdefs.h
 
 fi
 
-
-ac_fn_c_check_header_mongrel "$LINENO" "crypt.h" "ac_cv_header_crypt_h" "$ac_includes_default"
-if test "x$ac_cv_header_crypt_h" = xyes; then :
-  $as_echo "#define HAVE_CRYPT_H 1" >>confdefs.h
+ac_fn_c_check_header_compile "$LINENO" "crypt.h" "ac_cv_header_crypt_h" "$ac_includes_default"
+if test "x$ac_cv_header_crypt_h" = xyes
+then :
+  printf "%s\n" "#define HAVE_CRYPT_H 1" >>confdefs.h
 
 fi
 
-
-ac_fn_c_check_header_mongrel "$LINENO" "langinfo.h" "ac_cv_header_langinfo_h" "$ac_includes_default"
-if test "x$ac_cv_header_langinfo_h" = xyes; then :
-  $as_echo "#define HAVE_LANGINFO_H 1" >>confdefs.h
+ac_fn_c_check_header_compile "$LINENO" "langinfo.h" "ac_cv_header_langinfo_h" "$ac_includes_default"
+if test "x$ac_cv_header_langinfo_h" = xyes
+then :
+  printf "%s\n" "#define HAVE_LANGINFO_H 1" >>confdefs.h
 
 fi
 
-
-ac_fn_c_check_header_mongrel "$LINENO" "malloc.h" "ac_cv_header_malloc_h" "$ac_includes_default"
-if test "x$ac_cv_header_malloc_h" = xyes; then :
-  $as_echo "#define HAVE_MALLOC_H 1" >>confdefs.h
+ac_fn_c_check_header_compile "$LINENO" "malloc.h" "ac_cv_header_malloc_h" "$ac_includes_default"
+if test "x$ac_cv_header_malloc_h" = xyes
+then :
+  printf "%s\n" "#define HAVE_MALLOC_H 1" >>confdefs.h
 
 fi
 
-
-ac_fn_c_check_header_mongrel "$LINENO" "shadow.h" "ac_cv_header_shadow_h" "$ac_includes_default"
-if test "x$ac_cv_header_shadow_h" = xyes; then :
-  $as_echo "#define HAVE_SHADOW_H 1" >>confdefs.h
+ac_fn_c_check_header_compile "$LINENO" "shadow.h" "ac_cv_header_shadow_h" "$ac_includes_default"
+if test "x$ac_cv_header_shadow_h" = xyes
+then :
+  printf "%s\n" "#define HAVE_SHADOW_H 1" >>confdefs.h
 
 fi
 
-
-ac_fn_c_check_header_mongrel "$LINENO" "stdint.h" "ac_cv_header_stdint_h" "$ac_includes_default"
-if test "x$ac_cv_header_stdint_h" = xyes; then :
-  $as_echo "#define HAVE_STDINT_H 1" >>confdefs.h
+ac_fn_c_check_header_compile "$LINENO" "stdint.h" "ac_cv_header_stdint_h" "$ac_includes_default"
+if test "x$ac_cv_header_stdint_h" = xyes
+then :
+  printf "%s\n" "#define HAVE_STDINT_H 1" >>confdefs.h
 
 fi
 
-
-ac_fn_c_check_header_mongrel "$LINENO" "string.h" "ac_cv_header_string_h" "$ac_includes_default"
-if test "x$ac_cv_header_string_h" = xyes; then :
-  $as_echo "#define HAVE_STRING_H 1" >>confdefs.h
+ac_fn_c_check_header_compile "$LINENO" "string.h" "ac_cv_header_string_h" "$ac_includes_default"
+if test "x$ac_cv_header_string_h" = xyes
+then :
+  printf "%s\n" "#define HAVE_STRING_H 1" >>confdefs.h
 
 fi
 
-
-ac_fn_c_check_header_mongrel "$LINENO" "strings.h" "ac_cv_header_strings_h" "$ac_includes_default"
-if test "x$ac_cv_header_strings_h" = xyes; then :
-  $as_echo "#define HAVE_STRINGS_H 1" >>confdefs.h
+ac_fn_c_check_header_compile "$LINENO" "strings.h" "ac_cv_header_strings_h" "$ac_includes_default"
+if test "x$ac_cv_header_strings_h" = xyes
+then :
+  printf "%s\n" "#define HAVE_STRINGS_H 1" >>confdefs.h
 
 fi
 
-
-ac_fn_c_check_header_mongrel "$LINENO" "bstring.h" "ac_cv_header_bstring_h" "$ac_includes_default"
-if test "x$ac_cv_header_bstring_h" = xyes; then :
-  $as_echo "#define HAVE_BSTRING_H 1" >>confdefs.h
+ac_fn_c_check_header_compile "$LINENO" "bstring.h" "ac_cv_header_bstring_h" "$ac_includes_default"
+if test "x$ac_cv_header_bstring_h" = xyes
+then :
+  printf "%s\n" "#define HAVE_BSTRING_H 1" >>confdefs.h
 
 fi
 
-
-ac_fn_c_check_header_mongrel "$LINENO" "sys/ioctl.h" "ac_cv_header_sys_ioctl_h" "$ac_includes_default"
-if test "x$ac_cv_header_sys_ioctl_h" = xyes; then :
-  $as_echo "#define HAVE_SYS_IOCTL_H 1" >>confdefs.h
+ac_fn_c_check_header_compile "$LINENO" "sys/ioctl.h" "ac_cv_header_sys_ioctl_h" "$ac_includes_default"
+if test "x$ac_cv_header_sys_ioctl_h" = xyes
+then :
+  printf "%s\n" "#define HAVE_SYS_IOCTL_H 1" >>confdefs.h
 
 fi
 
-
-ac_fn_c_check_header_mongrel "$LINENO" "sys/param.h" "ac_cv_header_sys_param_h" "$ac_includes_default"
-if test "x$ac_cv_header_sys_param_h" = xyes; then :
-  $as_echo "#define HAVE_SYS_PARAM_H 1" >>confdefs.h
+ac_fn_c_check_header_compile "$LINENO" "sys/param.h" "ac_cv_header_sys_param_h" "$ac_includes_default"
+if test "x$ac_cv_header_sys_param_h" = xyes
+then :
+  printf "%s\n" "#define HAVE_SYS_PARAM_H 1" >>confdefs.h
 
 fi
 
-
-ac_fn_c_check_header_mongrel "$LINENO" "sys/ucred.h" "ac_cv_header_sys_ucred_h" "$ac_includes_default"
-if test "x$ac_cv_header_sys_ucred_h" = xyes; then :
-  $as_echo "#define HAVE_SYS_UCRED_H 1" >>confdefs.h
+ac_fn_c_check_header_compile "$LINENO" "sys/ucred.h" "ac_cv_header_sys_ucred_h" "$ac_includes_default"
+if test "x$ac_cv_header_sys_ucred_h" = xyes
+then :
+  printf "%s\n" "#define HAVE_SYS_UCRED_H 1" >>confdefs.h
 
 fi
 
 
-
-ac_fn_c_check_header_mongrel "$LINENO" "iconv.h" "ac_cv_header_iconv_h" "$ac_includes_default"
-if test "x$ac_cv_header_iconv_h" = xyes; then :
+ac_fn_c_check_header_compile "$LINENO" "iconv.h" "ac_cv_header_iconv_h" "$ac_includes_default"
+if test "x$ac_cv_header_iconv_h" = xyes
+then :
   SAVELIBS="$LIBS"
 	LIBS=""
-	{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for library containing iconv_open" >&5
-$as_echo_n "checking for library containing iconv_open... " >&6; }
-if ${ac_cv_search_iconv_open+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+	{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for library containing iconv_open" >&5
+printf %s "checking for library containing iconv_open... " >&6; }
+if test ${ac_cv_search_iconv_open+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   ac_func_search_save_LIBS=$LIBS
 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
@@ -5147,57 +5898,60 @@ cat confdefs.h - <<_ACEOF >conftest.$ac_
 /* Override any GCC internal prototype to avoid an error.
    Use char because int might match the return type of a GCC
    builtin and then its argument prototype would still apply.  */
-#ifdef __cplusplus
-extern "C"
-#endif
 char iconv_open ();
 int
-main ()
+main (void)
 {
 return iconv_open ();
   ;
   return 0;
 }
 _ACEOF
-for ac_lib in '' iconv; do
+for ac_lib in '' iconv
+do
   if test -z "$ac_lib"; then
     ac_res="none required"
   else
     ac_res=-l$ac_lib
     LIBS="-l$ac_lib  $ac_func_search_save_LIBS"
   fi
-  if ac_fn_c_try_link "$LINENO"; then :
+  if ac_fn_c_try_link "$LINENO"
+then :
   ac_cv_search_iconv_open=$ac_res
 fi
-rm -f core conftest.err conftest.$ac_objext \
+rm -f core conftest.err conftest.$ac_objext conftest.beam \
     conftest$ac_exeext
-  if ${ac_cv_search_iconv_open+:} false; then :
+  if test ${ac_cv_search_iconv_open+y}
+then :
   break
 fi
 done
-if ${ac_cv_search_iconv_open+:} false; then :
+if test ${ac_cv_search_iconv_open+y}
+then :
 
-else
+else $as_nop
   ac_cv_search_iconv_open=no
 fi
 rm conftest.$ac_ext
 LIBS=$ac_func_search_save_LIBS
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_search_iconv_open" >&5
-$as_echo "$ac_cv_search_iconv_open" >&6; }
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_search_iconv_open" >&5
+printf "%s\n" "$ac_cv_search_iconv_open" >&6; }
 ac_res=$ac_cv_search_iconv_open
-if test "$ac_res" != no; then :
+if test "$ac_res" != no
+then :
   test "$ac_res" = "none required" || LIBS="$ac_res $LIBS"
-  $as_echo "#define HAVE_ICONV_H 1" >>confdefs.h
+  printf "%s\n" "#define HAVE_ICONV_H 1" >>confdefs.h
 
 		SAVELIBS="$SAVELIBS $LIBS"
 fi
 
-	{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for library containing libiconv_open" >&5
-$as_echo_n "checking for library containing libiconv_open... " >&6; }
-if ${ac_cv_search_libiconv_open+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+	{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for library containing libiconv_open" >&5
+printf %s "checking for library containing libiconv_open... " >&6; }
+if test ${ac_cv_search_libiconv_open+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   ac_func_search_save_LIBS=$LIBS
 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
@@ -5205,48 +5959,50 @@ cat confdefs.h - <<_ACEOF >conftest.$ac_
 /* Override any GCC internal prototype to avoid an error.
    Use char because int might match the return type of a GCC
    builtin and then its argument prototype would still apply.  */
-#ifdef __cplusplus
-extern "C"
-#endif
 char libiconv_open ();
 int
-main ()
+main (void)
 {
 return libiconv_open ();
   ;
   return 0;
 }
 _ACEOF
-for ac_lib in '' iconv; do
+for ac_lib in '' iconv
+do
   if test -z "$ac_lib"; then
     ac_res="none required"
   else
     ac_res=-l$ac_lib
     LIBS="-l$ac_lib  $ac_func_search_save_LIBS"
   fi
-  if ac_fn_c_try_link "$LINENO"; then :
+  if ac_fn_c_try_link "$LINENO"
+then :
   ac_cv_search_libiconv_open=$ac_res
 fi
-rm -f core conftest.err conftest.$ac_objext \
+rm -f core conftest.err conftest.$ac_objext conftest.beam \
     conftest$ac_exeext
-  if ${ac_cv_search_libiconv_open+:} false; then :
+  if test ${ac_cv_search_libiconv_open+y}
+then :
   break
 fi
 done
-if ${ac_cv_search_libiconv_open+:} false; then :
+if test ${ac_cv_search_libiconv_open+y}
+then :
 
-else
+else $as_nop
   ac_cv_search_libiconv_open=no
 fi
 rm conftest.$ac_ext
 LIBS=$ac_func_search_save_LIBS
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_search_libiconv_open" >&5
-$as_echo "$ac_cv_search_libiconv_open" >&6; }
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_search_libiconv_open" >&5
+printf "%s\n" "$ac_cv_search_libiconv_open" >&6; }
 ac_res=$ac_cv_search_libiconv_open
-if test "$ac_res" != no; then :
+if test "$ac_res" != no
+then :
   test "$ac_res" = "none required" || LIBS="$ac_res $LIBS"
-  $as_echo "#define HAVE_ICONV_H 1" >>confdefs.h
+  printf "%s\n" "#define HAVE_ICONV_H 1" >>confdefs.h
 
 		SAVELIBS="$SAVELIBS $LIBS"
 fi
@@ -5255,124 +6011,127 @@ fi
 fi
 
 
-
-ac_fn_c_check_header_mongrel "$LINENO" "sys/mount.h" "ac_cv_header_sys_mount_h" "$ac_includes_default"
-if test "x$ac_cv_header_sys_mount_h" = xyes; then :
-  $as_echo "#define HAVE_SYS_MOUNT_H 1" >>confdefs.h
+ac_fn_c_check_header_compile "$LINENO" "sys/mount.h" "ac_cv_header_sys_mount_h" "$ac_includes_default"
+if test "x$ac_cv_header_sys_mount_h" = xyes
+then :
+  printf "%s\n" "#define HAVE_SYS_MOUNT_H 1" >>confdefs.h
 
 fi
 
-
-ac_fn_c_check_header_mongrel "$LINENO" "sys/statfs.h" "ac_cv_header_sys_statfs_h" "$ac_includes_default"
-if test "x$ac_cv_header_sys_statfs_h" = xyes; then :
-  $as_echo "#define HAVE_SYS_STATFS_H 1" >>confdefs.h
+ac_fn_c_check_header_compile "$LINENO" "sys/statfs.h" "ac_cv_header_sys_statfs_h" "$ac_includes_default"
+if test "x$ac_cv_header_sys_statfs_h" = xyes
+then :
+  printf "%s\n" "#define HAVE_SYS_STATFS_H 1" >>confdefs.h
 
 fi
 
+ac_fn_c_check_header_compile "$LINENO" "sys/statvfs.h" "ac_cv_header_sys_statvfs_h" "$ac_includes_default"
+if test "x$ac_cv_header_sys_statvfs_h" = xyes
+then :
+  printf "%s\n" "#define HAVE_SYS_STATVFS_H 1" >>confdefs.h
 
-ac_fn_c_check_header_mongrel "$LINENO" "sys/statvfs.h" "ac_cv_header_sys_statvfs_h" "$ac_includes_default"
-if test "x$ac_cv_header_sys_statvfs_h" = xyes; then :
-  $as_echo "#define HAVE_SYS_STATVFS_H 1" >>confdefs.h
+fi
+
+ac_fn_c_check_header_compile "$LINENO" "sys/vfs.h" "ac_cv_header_sys_vfs_h" "$ac_includes_default"
+if test "x$ac_cv_header_sys_vfs_h" = xyes
+then :
+  printf "%s\n" "#define HAVE_SYS_VFS_H 1" >>confdefs.h
 
 fi
 
+ac_fn_c_check_func "$LINENO" "statfs" "ac_cv_func_statfs"
+if test "x$ac_cv_func_statfs" = xyes
+then :
+  printf "%s\n" "#define HAVE_STATFS 1" >>confdefs.h
 
-ac_fn_c_check_header_mongrel "$LINENO" "sys/vfs.h" "ac_cv_header_sys_vfs_h" "$ac_includes_default"
-if test "x$ac_cv_header_sys_vfs_h" = xyes; then :
-  $as_echo "#define HAVE_SYS_VFS_H 1" >>confdefs.h
+fi
+ac_fn_c_check_func "$LINENO" "statvfs" "ac_cv_func_statvfs"
+if test "x$ac_cv_func_statvfs" = xyes
+then :
+  printf "%s\n" "#define HAVE_STATVFS 1" >>confdefs.h
 
 fi
 
 
-for ac_func in statfs statvfs
-do :
-  as_ac_var=`$as_echo "ac_cv_func_$ac_func" | $as_tr_sh`
-ac_fn_c_check_func "$LINENO" "$ac_func" "$as_ac_var"
-if eval test \"x\$"$as_ac_var"\" = x"yes"; then :
-  cat >>confdefs.h <<_ACEOF
-#define `$as_echo "HAVE_$ac_func" | $as_tr_cpp` 1
-_ACEOF
+ac_fn_c_check_func "$LINENO" "strdup" "ac_cv_func_strdup"
+if test "x$ac_cv_func_strdup" = xyes
+then :
+  printf "%s\n" "#define HAVE_STRDUP 1" >>confdefs.h
 
 fi
-done
+ac_fn_c_check_func "$LINENO" "strlcat" "ac_cv_func_strlcat"
+if test "x$ac_cv_func_strlcat" = xyes
+then :
+  printf "%s\n" "#define HAVE_STRLCAT 1" >>confdefs.h
 
-
-for ac_func in strdup strlcat strlcpy
-do :
-  as_ac_var=`$as_echo "ac_cv_func_$ac_func" | $as_tr_sh`
-ac_fn_c_check_func "$LINENO" "$ac_func" "$as_ac_var"
-if eval test \"x\$"$as_ac_var"\" = x"yes"; then :
-  cat >>confdefs.h <<_ACEOF
-#define `$as_echo "HAVE_$ac_func" | $as_tr_cpp` 1
-_ACEOF
+fi
+ac_fn_c_check_func "$LINENO" "strlcpy" "ac_cv_func_strlcpy"
+if test "x$ac_cv_func_strlcpy" = xyes
+then :
+  printf "%s\n" "#define HAVE_STRLCPY 1" >>confdefs.h
 
 fi
-done
 
 if test "$host_os_name" = "hp-ux" -a "$host_os_version" = "1020"; then
 	echo Forcing snprintf emulation for HP-UX.
 else
-	for ac_func in snprintf vsnprintf
-do :
-  as_ac_var=`$as_echo "ac_cv_func_$ac_func" | $as_tr_sh`
-ac_fn_c_check_func "$LINENO" "$ac_func" "$as_ac_var"
-if eval test \"x\$"$as_ac_var"\" = x"yes"; then :
-  cat >>confdefs.h <<_ACEOF
-#define `$as_echo "HAVE_$ac_func" | $as_tr_cpp` 1
-_ACEOF
+	ac_fn_c_check_func "$LINENO" "snprintf" "ac_cv_func_snprintf"
+if test "x$ac_cv_func_snprintf" = xyes
+then :
+  printf "%s\n" "#define HAVE_SNPRINTF 1" >>confdefs.h
 
 fi
-done
+ac_fn_c_check_func "$LINENO" "vsnprintf" "ac_cv_func_vsnprintf"
+if test "x$ac_cv_func_vsnprintf" = xyes
+then :
+  printf "%s\n" "#define HAVE_VSNPRINTF 1" >>confdefs.h
 
 fi
 
-for ac_func in random lrand48 arc4random
-do :
-  as_ac_var=`$as_echo "ac_cv_func_$ac_func" | $as_tr_sh`
-ac_fn_c_check_func "$LINENO" "$ac_func" "$as_ac_var"
-if eval test \"x\$"$as_ac_var"\" = x"yes"; then :
-  cat >>confdefs.h <<_ACEOF
-#define `$as_echo "HAVE_$ac_func" | $as_tr_cpp` 1
-_ACEOF
+fi
+
+ac_fn_c_check_func "$LINENO" "random" "ac_cv_func_random"
+if test "x$ac_cv_func_random" = xyes
+then :
+  printf "%s\n" "#define HAVE_RANDOM 1" >>confdefs.h
 
 fi
-done
+ac_fn_c_check_func "$LINENO" "lrand48" "ac_cv_func_lrand48"
+if test "x$ac_cv_func_lrand48" = xyes
+then :
+  printf "%s\n" "#define HAVE_LRAND48 1" >>confdefs.h
+
+fi
+ac_fn_c_check_func "$LINENO" "arc4random" "ac_cv_func_arc4random"
+if test "x$ac_cv_func_arc4random" = xyes
+then :
+  printf "%s\n" "#define HAVE_ARC4RANDOM 1" >>confdefs.h
 
+fi
 
-for ac_func in geteuid
-do :
-  ac_fn_c_check_func "$LINENO" "geteuid" "ac_cv_func_geteuid"
-if test "x$ac_cv_func_geteuid" = xyes; then :
-  cat >>confdefs.h <<_ACEOF
-#define HAVE_GETEUID 1
-_ACEOF
+
+ac_fn_c_check_func "$LINENO" "geteuid" "ac_cv_func_geteuid"
+if test "x$ac_cv_func_geteuid" = xyes
+then :
+  printf "%s\n" "#define HAVE_GETEUID 1" >>confdefs.h
 
 fi
-done
 
 
-for ac_func in setpgid
-do :
-  ac_fn_c_check_func "$LINENO" "setpgid" "ac_cv_func_setpgid"
-if test "x$ac_cv_func_setpgid" = xyes; then :
-  cat >>confdefs.h <<_ACEOF
-#define HAVE_SETPGID 1
-_ACEOF
+ac_fn_c_check_func "$LINENO" "setpgid" "ac_cv_func_setpgid"
+if test "x$ac_cv_func_setpgid" = xyes
+then :
+  printf "%s\n" "#define HAVE_SETPGID 1" >>confdefs.h
 
 fi
-done
 
 
-for ac_func in vsyslog
-do :
-  ac_fn_c_check_func "$LINENO" "vsyslog" "ac_cv_func_vsyslog"
-if test "x$ac_cv_func_vsyslog" = xyes; then :
-  cat >>confdefs.h <<_ACEOF
-#define HAVE_VSYSLOG 1
-_ACEOF
+ac_fn_c_check_func "$LINENO" "vsyslog" "ac_cv_func_vsyslog"
+if test "x$ac_cv_func_vsyslog" = xyes
+then :
+  printf "%s\n" "#define HAVE_VSYSLOG 1" >>confdefs.h
 
 fi
-done
 
 
 case "$host_os_name" in
@@ -5381,76 +6140,61 @@ case "$host_os_name" in
 		;;
 	*)
 		# Use sigset on other platforms, if available
-		for ac_func in sigset
-do :
-  ac_fn_c_check_func "$LINENO" "sigset" "ac_cv_func_sigset"
-if test "x$ac_cv_func_sigset" = xyes; then :
-  cat >>confdefs.h <<_ACEOF
-#define HAVE_SIGSET 1
-_ACEOF
+		ac_fn_c_check_func "$LINENO" "sigset" "ac_cv_func_sigset"
+if test "x$ac_cv_func_sigset" = xyes
+then :
+  printf "%s\n" "#define HAVE_SIGSET 1" >>confdefs.h
 
 fi
-done
 
 		;;
 esac
 
-for ac_func in sigaction
-do :
-  ac_fn_c_check_func "$LINENO" "sigaction" "ac_cv_func_sigaction"
-if test "x$ac_cv_func_sigaction" = xyes; then :
-  cat >>confdefs.h <<_ACEOF
-#define HAVE_SIGACTION 1
-_ACEOF
+ac_fn_c_check_func "$LINENO" "sigaction" "ac_cv_func_sigaction"
+if test "x$ac_cv_func_sigaction" = xyes
+then :
+  printf "%s\n" "#define HAVE_SIGACTION 1" >>confdefs.h
 
 fi
-done
 
 
-for ac_func in waitpid wait3
-do :
-  as_ac_var=`$as_echo "ac_cv_func_$ac_func" | $as_tr_sh`
-ac_fn_c_check_func "$LINENO" "$ac_func" "$as_ac_var"
-if eval test \"x\$"$as_ac_var"\" = x"yes"; then :
-  cat >>confdefs.h <<_ACEOF
-#define `$as_echo "HAVE_$ac_func" | $as_tr_cpp` 1
-_ACEOF
+ac_fn_c_check_func "$LINENO" "waitpid" "ac_cv_func_waitpid"
+if test "x$ac_cv_func_waitpid" = xyes
+then :
+  printf "%s\n" "#define HAVE_WAITPID 1" >>confdefs.h
 
 fi
-done
+ac_fn_c_check_func "$LINENO" "wait3" "ac_cv_func_wait3"
+if test "x$ac_cv_func_wait3" = xyes
+then :
+  printf "%s\n" "#define HAVE_WAIT3 1" >>confdefs.h
 
+fi
 
-for ac_func in posix_spawn
-do :
-  ac_fn_c_check_func "$LINENO" "posix_spawn" "ac_cv_func_posix_spawn"
-if test "x$ac_cv_func_posix_spawn" = xyes; then :
-  cat >>confdefs.h <<_ACEOF
-#define HAVE_POSIX_SPAWN 1
-_ACEOF
+
+ac_fn_c_check_func "$LINENO" "posix_spawn" "ac_cv_func_posix_spawn"
+if test "x$ac_cv_func_posix_spawn" = xyes
+then :
+  printf "%s\n" "#define HAVE_POSIX_SPAWN 1" >>confdefs.h
 
 fi
-done
 
 
-for ac_func in getgrouplist
-do :
-  ac_fn_c_check_func "$LINENO" "getgrouplist" "ac_cv_func_getgrouplist"
-if test "x$ac_cv_func_getgrouplist" = xyes; then :
-  cat >>confdefs.h <<_ACEOF
-#define HAVE_GETGROUPLIST 1
-_ACEOF
+ac_fn_c_check_func "$LINENO" "getgrouplist" "ac_cv_func_getgrouplist"
+if test "x$ac_cv_func_getgrouplist" = xyes
+then :
+  printf "%s\n" "#define HAVE_GETGROUPLIST 1" >>confdefs.h
 
 fi
-done
 
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for tm_gmtoff member in tm structure" >&5
-$as_echo_n "checking for tm_gmtoff member in tm structure... " >&6; }
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for tm_gmtoff member in tm structure" >&5
+printf %s "checking for tm_gmtoff member in tm structure... " >&6; }
 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
 #include <time.h>
 int
-main ()
+main (void)
 {
 struct tm t;
 	int o = t.tm_gmtoff;
@@ -5458,24 +6202,25 @@ struct tm t;
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_compile "$LINENO"; then :
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: yes" >&5
-$as_echo "yes" >&6; }
-	$as_echo "#define HAVE_TM_GMTOFF 1" >>confdefs.h
-
-else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
+if ac_fn_c_try_compile "$LINENO"
+then :
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: yes" >&5
+printf "%s\n" "yes" >&6; }
+	printf "%s\n" "#define HAVE_TM_GMTOFF 1" >>confdefs.h
+
+else $as_nop
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: no" >&5
+printf "%s\n" "no" >&6; }
 fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
+rm -f core conftest.err conftest.$ac_objext conftest.beam conftest.$ac_ext
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for st_gen member in stat structure" >&5
-$as_echo_n "checking for st_gen member in stat structure... " >&6; }
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for st_gen member in stat structure" >&5
+printf %s "checking for st_gen member in stat structure... " >&6; }
 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
 #include <sys/stat.h>
 int
-main ()
+main (void)
 {
 struct stat t;
 	int o = t.st_gen;
@@ -5483,31 +6228,29 @@ struct stat t;
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_compile "$LINENO"; then :
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: yes" >&5
-$as_echo "yes" >&6; }
-	$as_echo "#define HAVE_ST_GEN 1" >>confdefs.h
-
-else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
-fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
-
-for ac_func in removefile
-do :
-  ac_fn_c_check_func "$LINENO" "removefile" "ac_cv_func_removefile"
-if test "x$ac_cv_func_removefile" = xyes; then :
-  cat >>confdefs.h <<_ACEOF
-#define HAVE_REMOVEFILE 1
-_ACEOF
+if ac_fn_c_try_compile "$LINENO"
+then :
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: yes" >&5
+printf "%s\n" "yes" >&6; }
+	printf "%s\n" "#define HAVE_ST_GEN 1" >>confdefs.h
+
+else $as_nop
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: no" >&5
+printf "%s\n" "no" >&6; }
+fi
+rm -f core conftest.err conftest.$ac_objext conftest.beam conftest.$ac_ext
+
+ac_fn_c_check_func "$LINENO" "removefile" "ac_cv_func_removefile"
+if test "x$ac_cv_func_removefile" = xyes
+then :
+  printf "%s\n" "#define HAVE_REMOVEFILE 1" >>confdefs.h
 
 fi
-done
 
 
 # Check whether --enable-libusb was given.
-if test "${enable_libusb+set}" = set; then :
+if test ${enable_libusb+y}
+then :
   enableval=$enable_libusb;
 fi
 
@@ -5519,19 +6262,19 @@ USBQUIRKS=""
 
 if test "x$PKGCONFIG" != x; then
 	if test x$enable_libusb != xno -a $host_os_name != darwin; then
-		{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for libusb-1.0" >&5
-$as_echo_n "checking for libusb-1.0... " >&6; }
+		{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for libusb-1.0" >&5
+printf %s "checking for libusb-1.0... " >&6; }
 		if $PKGCONFIG --exists libusb-1.0; then
-			{ $as_echo "$as_me:${as_lineno-$LINENO}: result: yes" >&5
-$as_echo "yes" >&6; }
-			$as_echo "#define HAVE_LIBUSB 1" >>confdefs.h
+			{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: yes" >&5
+printf "%s\n" "yes" >&6; }
+			printf "%s\n" "#define HAVE_LIBUSB 1" >>confdefs.h
 
 			CFLAGS="$CFLAGS `$PKGCONFIG --cflags libusb-1.0`"
 			LIBUSB="`$PKGCONFIG --libs libusb-1.0`"
 			USBQUIRKS="\$(DATADIR)/usb"
 		else
-			{ $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
+			{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: no" >&5
+printf "%s\n" "no" >&6; }
 			if test x$enable_libusb = xyes; then
 				as_fn_error $? "libusb required for --enable-libusb." "$LINENO" 5
 			fi
@@ -5542,7 +6285,8 @@ elif test x$enable_libusb = xyes; then
 fi
 
 # Check whether --enable-tcp_wrappers was given.
-if test "${enable_tcp_wrappers+set}" = set; then :
+if test ${enable_tcp_wrappers+y}
+then :
   enableval=$enable_tcp_wrappers;
 fi
 
@@ -5551,11 +6295,12 @@ LIBWRAP=""
 
 
 if test x$enable_tcp_wrappers = xyes; then
-	{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for hosts_access in -lwrap" >&5
-$as_echo_n "checking for hosts_access in -lwrap... " >&6; }
-if ${ac_cv_lib_wrap_hosts_access+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+	{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for hosts_access in -lwrap" >&5
+printf %s "checking for hosts_access in -lwrap... " >&6; }
+if test ${ac_cv_lib_wrap_hosts_access+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lwrap  $LIBS"
 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
@@ -5564,52 +6309,53 @@ cat confdefs.h - <<_ACEOF >conftest.$ac_
 /* Override any GCC internal prototype to avoid an error.
    Use char because int might match the return type of a GCC
    builtin and then its argument prototype would still apply.  */
-#ifdef __cplusplus
-extern "C"
-#endif
 char hosts_access ();
 int
-main ()
+main (void)
 {
 return hosts_access ();
   ;
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
+if ac_fn_c_try_link "$LINENO"
+then :
   ac_cv_lib_wrap_hosts_access=yes
-else
+else $as_nop
   ac_cv_lib_wrap_hosts_access=no
 fi
-rm -f core conftest.err conftest.$ac_objext \
+rm -f core conftest.err conftest.$ac_objext conftest.beam \
     conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_lib_wrap_hosts_access" >&5
-$as_echo "$ac_cv_lib_wrap_hosts_access" >&6; }
-if test "x$ac_cv_lib_wrap_hosts_access" = xyes; then :
-
-		ac_fn_c_check_header_mongrel "$LINENO" "tcpd.h" "ac_cv_header_tcpd_h" "$ac_includes_default"
-if test "x$ac_cv_header_tcpd_h" = xyes; then :
-  $as_echo "#define HAVE_TCPD_H 1" >>confdefs.h
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_lib_wrap_hosts_access" >&5
+printf "%s\n" "$ac_cv_lib_wrap_hosts_access" >&6; }
+if test "x$ac_cv_lib_wrap_hosts_access" = xyes
+then :
+
+		ac_fn_c_check_header_compile "$LINENO" "tcpd.h" "ac_cv_header_tcpd_h" "$ac_includes_default"
+if test "x$ac_cv_header_tcpd_h" = xyes
+then :
+  printf "%s\n" "#define HAVE_TCPD_H 1" >>confdefs.h
 
 			LIBWRAP="-lwrap"
 fi
 
-
 fi
 
 fi
 
 INSTALL_GZIP=""
 LIBZ=""
-ac_fn_c_check_header_mongrel "$LINENO" "zlib.h" "ac_cv_header_zlib_h" "$ac_includes_default"
-if test "x$ac_cv_header_zlib_h" = xyes; then :
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking for gzgets in -lz" >&5
-$as_echo_n "checking for gzgets in -lz... " >&6; }
-if ${ac_cv_lib_z_gzgets+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+ac_fn_c_check_header_compile "$LINENO" "zlib.h" "ac_cv_header_zlib_h" "$ac_includes_default"
+if test "x$ac_cv_header_zlib_h" = xyes
+then :
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for gzgets in -lz" >&5
+printf %s "checking for gzgets in -lz... " >&6; }
+if test ${ac_cv_lib_z_gzgets+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lz  $LIBS"
 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
@@ -5618,40 +6364,40 @@ cat confdefs.h - <<_ACEOF >conftest.$ac_
 /* Override any GCC internal prototype to avoid an error.
    Use char because int might match the return type of a GCC
    builtin and then its argument prototype would still apply.  */
-#ifdef __cplusplus
-extern "C"
-#endif
 char gzgets ();
 int
-main ()
+main (void)
 {
 return gzgets ();
   ;
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
+if ac_fn_c_try_link "$LINENO"
+then :
   ac_cv_lib_z_gzgets=yes
-else
+else $as_nop
   ac_cv_lib_z_gzgets=no
 fi
-rm -f core conftest.err conftest.$ac_objext \
+rm -f core conftest.err conftest.$ac_objext conftest.beam \
     conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_lib_z_gzgets" >&5
-$as_echo "$ac_cv_lib_z_gzgets" >&6; }
-if test "x$ac_cv_lib_z_gzgets" = xyes; then :
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_lib_z_gzgets" >&5
+printf "%s\n" "$ac_cv_lib_z_gzgets" >&6; }
+if test "x$ac_cv_lib_z_gzgets" = xyes
+then :
 
-	$as_echo "#define HAVE_LIBZ 1" >>confdefs.h
+	printf "%s\n" "#define HAVE_LIBZ 1" >>confdefs.h
 
 	LIBZ="-lz"
 	LIBS="$LIBS -lz"
-	{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for inflateCopy in -lz" >&5
-$as_echo_n "checking for inflateCopy in -lz... " >&6; }
-if ${ac_cv_lib_z_inflateCopy+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+	{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for inflateCopy in -lz" >&5
+printf %s "checking for inflateCopy in -lz... " >&6; }
+if test ${ac_cv_lib_z_inflateCopy+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lz  $LIBS"
 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
@@ -5660,31 +6406,30 @@ cat confdefs.h - <<_ACEOF >conftest.$ac_
 /* Override any GCC internal prototype to avoid an error.
    Use char because int might match the return type of a GCC
    builtin and then its argument prototype would still apply.  */
-#ifdef __cplusplus
-extern "C"
-#endif
 char inflateCopy ();
 int
-main ()
+main (void)
 {
 return inflateCopy ();
   ;
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
+if ac_fn_c_try_link "$LINENO"
+then :
   ac_cv_lib_z_inflateCopy=yes
-else
+else $as_nop
   ac_cv_lib_z_inflateCopy=no
 fi
-rm -f core conftest.err conftest.$ac_objext \
+rm -f core conftest.err conftest.$ac_objext conftest.beam \
     conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_lib_z_inflateCopy" >&5
-$as_echo "$ac_cv_lib_z_inflateCopy" >&6; }
-if test "x$ac_cv_lib_z_inflateCopy" = xyes; then :
-  $as_echo "#define HAVE_INFLATECOPY 1" >>confdefs.h
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_lib_z_inflateCopy" >&5
+printf "%s\n" "$ac_cv_lib_z_inflateCopy" >&6; }
+if test "x$ac_cv_lib_z_inflateCopy" = xyes
+then :
+  printf "%s\n" "#define HAVE_INFLATECOPY 1" >>confdefs.h
 
 fi
 
@@ -5698,7 +6443,6 @@ fi
 
 
 
-
 case $host_os_name in
         darwin* | *bsd*)
                 ARFLAGS="-rcv"
@@ -5718,16 +6462,18 @@ SERVERLIBS=""
 SAVELIBS="$LIBS"
 LIBS=""
 # Check whether --enable-acl was given.
-if test "${enable_acl+set}" = set; then :
+if test ${enable_acl+y}
+then :
   enableval=$enable_acl;
 fi
 
 if test "x$enable_acl" != xno; then
-	{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for library containing acl_init" >&5
-$as_echo_n "checking for library containing acl_init... " >&6; }
-if ${ac_cv_search_acl_init+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+	{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for library containing acl_init" >&5
+printf %s "checking for library containing acl_init... " >&6; }
+if test ${ac_cv_search_acl_init+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   ac_func_search_save_LIBS=$LIBS
 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
@@ -5735,48 +6481,50 @@ cat confdefs.h - <<_ACEOF >conftest.$ac_
 /* Override any GCC internal prototype to avoid an error.
    Use char because int might match the return type of a GCC
    builtin and then its argument prototype would still apply.  */
-#ifdef __cplusplus
-extern "C"
-#endif
 char acl_init ();
 int
-main ()
+main (void)
 {
 return acl_init ();
   ;
   return 0;
 }
 _ACEOF
-for ac_lib in '' acl; do
+for ac_lib in '' acl
+do
   if test -z "$ac_lib"; then
     ac_res="none required"
   else
     ac_res=-l$ac_lib
     LIBS="-l$ac_lib  $ac_func_search_save_LIBS"
   fi
-  if ac_fn_c_try_link "$LINENO"; then :
+  if ac_fn_c_try_link "$LINENO"
+then :
   ac_cv_search_acl_init=$ac_res
 fi
-rm -f core conftest.err conftest.$ac_objext \
+rm -f core conftest.err conftest.$ac_objext conftest.beam \
     conftest$ac_exeext
-  if ${ac_cv_search_acl_init+:} false; then :
+  if test ${ac_cv_search_acl_init+y}
+then :
   break
 fi
 done
-if ${ac_cv_search_acl_init+:} false; then :
+if test ${ac_cv_search_acl_init+y}
+then :
 
-else
+else $as_nop
   ac_cv_search_acl_init=no
 fi
 rm conftest.$ac_ext
 LIBS=$ac_func_search_save_LIBS
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_search_acl_init" >&5
-$as_echo "$ac_cv_search_acl_init" >&6; }
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_search_acl_init" >&5
+printf "%s\n" "$ac_cv_search_acl_init" >&6; }
 ac_res=$ac_cv_search_acl_init
-if test "$ac_res" != no; then :
+if test "$ac_res" != no
+then :
   test "$ac_res" = "none required" || LIBS="$ac_res $LIBS"
-  $as_echo "#define HAVE_ACL_INIT 1" >>confdefs.h
+  printf "%s\n" "#define HAVE_ACL_INIT 1" >>confdefs.h
 
 fi
 
@@ -5789,24 +6537,26 @@ DBUS_NOTIFIER=""
 DBUS_NOTIFIERLIBS=""
 
 # Check whether --enable-dbus was given.
-if test "${enable_dbus+set}" = set; then :
+if test ${enable_dbus+y}
+then :
   enableval=$enable_dbus;
 fi
 
 
 # Check whether --with-dbusdir was given.
-if test "${with_dbusdir+set}" = set; then :
+if test ${with_dbusdir+y}
+then :
   withval=$with_dbusdir; DBUSDIR="$withval"
 fi
 
 
 if test "x$enable_dbus" != xno -a "x$PKGCONFIG" != x -a "x$host_os_name" != xdarwin; then
-	{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for DBUS" >&5
-$as_echo_n "checking for DBUS... " >&6; }
+	{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for DBUS" >&5
+printf %s "checking for DBUS... " >&6; }
 	if $PKGCONFIG --exists dbus-1; then
-		{ $as_echo "$as_me:${as_lineno-$LINENO}: result: yes" >&5
-$as_echo "yes" >&6; }
-		$as_echo "#define HAVE_DBUS 1" >>confdefs.h
+		{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: yes" >&5
+printf "%s\n" "yes" >&6; }
+		printf "%s\n" "#define HAVE_DBUS 1" >>confdefs.h
 
 		CFLAGS="$CFLAGS `$PKGCONFIG --cflags dbus-1` -DDBUS_API_SUBJECT_TO_CHANGE"
 		SERVERLIBS="$SERVERLIBS `$PKGCONFIG --libs dbus-1`"
@@ -5815,14 +6565,16 @@ $as_echo "yes" >&6; }
 		SAVELIBS="$LIBS"
 		LIBS="$LIBS $DBUS_NOTIFIERLIBS"
 		ac_fn_c_check_func "$LINENO" "dbus_message_iter_init_append" "ac_cv_func_dbus_message_iter_init_append"
-if test "x$ac_cv_func_dbus_message_iter_init_append" = xyes; then :
-  $as_echo "#define HAVE_DBUS_MESSAGE_ITER_INIT_APPEND 1" >>confdefs.h
+if test "x$ac_cv_func_dbus_message_iter_init_append" = xyes
+then :
+  printf "%s\n" "#define HAVE_DBUS_MESSAGE_ITER_INIT_APPEND 1" >>confdefs.h
 
 fi
 
 		ac_fn_c_check_func "$LINENO" "dbus_threads_init" "ac_cv_func_dbus_threads_init"
-if test "x$ac_cv_func_dbus_threads_init" = xyes; then :
-  $as_echo "#define HAVE_DBUS_THREADS_INIT 1" >>confdefs.h
+if test "x$ac_cv_func_dbus_threads_init" = xyes
+then :
+  printf "%s\n" "#define HAVE_DBUS_THREADS_INIT 1" >>confdefs.h
 
 fi
 
@@ -5831,8 +6583,8 @@ fi
 			DBUSDIR="/etc/dbus-1"
 		fi
 	else
-		{ $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
+		{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: no" >&5
+printf "%s\n" "no" >&6; }
 	fi
 fi
 
@@ -5851,107 +6603,102 @@ case $host_os_name in
                 SERVERLIBS="$SERVERLIBS -framework IOKit -weak_framework ApplicationServices"
                 LIBS="-framework CoreFoundation -framework Security $LIBS"
 
-				ac_fn_c_check_header_mongrel "$LINENO" "ApplicationServices/ApplicationServices.h" "ac_cv_header_ApplicationServices_ApplicationServices_h" "$ac_includes_default"
-if test "x$ac_cv_header_ApplicationServices_ApplicationServices_h" = xyes; then :
-  $as_echo "#define HAVE_APPLICATIONSERVICES_H 1" >>confdefs.h
+				ac_fn_c_check_header_compile "$LINENO" "ApplicationServices/ApplicationServices.h" "ac_cv_header_ApplicationServices_ApplicationServices_h" "$ac_includes_default"
+if test "x$ac_cv_header_ApplicationServices_ApplicationServices_h" = xyes
+then :
+  printf "%s\n" "#define HAVE_APPLICATIONSERVICES_H 1" >>confdefs.h
 
 fi
 
-
-		ac_fn_c_check_header_mongrel "$LINENO" "CoreFoundation/CoreFoundation.h" "ac_cv_header_CoreFoundation_CoreFoundation_h" "$ac_includes_default"
-if test "x$ac_cv_header_CoreFoundation_CoreFoundation_h" = xyes; then :
-  $as_echo "#define HAVE_COREFOUNDATION_H 1" >>confdefs.h
+		ac_fn_c_check_header_compile "$LINENO" "CoreFoundation/CoreFoundation.h" "ac_cv_header_CoreFoundation_CoreFoundation_h" "$ac_includes_default"
+if test "x$ac_cv_header_CoreFoundation_CoreFoundation_h" = xyes
+then :
+  printf "%s\n" "#define HAVE_COREFOUNDATION_H 1" >>confdefs.h
 
 fi
 
 
-
 				SAVELIBS="$LIBS"
 		LIBS="-framework SystemConfiguration $LIBS"
-		for ac_func in SCDynamicStoreCopyComputerName
+
+  for ac_func in SCDynamicStoreCopyComputerName
 do :
   ac_fn_c_check_func "$LINENO" "SCDynamicStoreCopyComputerName" "ac_cv_func_SCDynamicStoreCopyComputerName"
-if test "x$ac_cv_func_SCDynamicStoreCopyComputerName" = xyes; then :
-  cat >>confdefs.h <<_ACEOF
-#define HAVE_SCDYNAMICSTORECOPYCOMPUTERNAME 1
-_ACEOF
+if test "x$ac_cv_func_SCDynamicStoreCopyComputerName" = xyes
+then :
+  printf "%s\n" "#define HAVE_SCDYNAMICSTORECOPYCOMPUTERNAME 1" >>confdefs.h
 
-		    $as_echo "#define HAVE_SCDYNAMICSTORECOPYCOMPUTERNAME 1" >>confdefs.h
+		    printf "%s\n" "#define HAVE_SCDYNAMICSTORECOPYCOMPUTERNAME 1" >>confdefs.h
 
-else
+else $as_nop
 
 		    LIBS="$SAVELIBS"
 fi
-done
 
+done
 
-				ac_fn_c_check_header_mongrel "$LINENO" "membership.h" "ac_cv_header_membership_h" "$ac_includes_default"
-if test "x$ac_cv_header_membership_h" = xyes; then :
-  $as_echo "#define HAVE_MEMBERSHIP_H 1" >>confdefs.h
+				ac_fn_c_check_header_compile "$LINENO" "membership.h" "ac_cv_header_membership_h" "$ac_includes_default"
+if test "x$ac_cv_header_membership_h" = xyes
+then :
+  printf "%s\n" "#define HAVE_MEMBERSHIP_H 1" >>confdefs.h
 
 fi
 
-
-		for ac_func in mbr_uid_to_uuid
-do :
-  ac_fn_c_check_func "$LINENO" "mbr_uid_to_uuid" "ac_cv_func_mbr_uid_to_uuid"
-if test "x$ac_cv_func_mbr_uid_to_uuid" = xyes; then :
-  cat >>confdefs.h <<_ACEOF
-#define HAVE_MBR_UID_TO_UUID 1
-_ACEOF
+		ac_fn_c_check_func "$LINENO" "mbr_uid_to_uuid" "ac_cv_func_mbr_uid_to_uuid"
+if test "x$ac_cv_func_mbr_uid_to_uuid" = xyes
+then :
+  printf "%s\n" "#define HAVE_MBR_UID_TO_UUID 1" >>confdefs.h
 
 fi
-done
 
 
-				ac_fn_c_check_header_mongrel "$LINENO" "dlfcn.h" "ac_cv_header_dlfcn_h" "$ac_includes_default"
-if test "x$ac_cv_header_dlfcn_h" = xyes; then :
-  $as_echo "#define HAVE_DLFCN_H 1" >>confdefs.h
+				ac_fn_c_check_header_compile "$LINENO" "dlfcn.h" "ac_cv_header_dlfcn_h" "$ac_includes_default"
+if test "x$ac_cv_header_dlfcn_h" = xyes
+then :
+  printf "%s\n" "#define HAVE_DLFCN_H 1" >>confdefs.h
 
 fi
 
 
-
-				ac_fn_c_check_header_mongrel "$LINENO" "notify.h" "ac_cv_header_notify_h" "$ac_includes_default"
-if test "x$ac_cv_header_notify_h" = xyes; then :
-  $as_echo "#define HAVE_NOTIFY_H 1" >>confdefs.h
+				ac_fn_c_check_header_compile "$LINENO" "notify.h" "ac_cv_header_notify_h" "$ac_includes_default"
+if test "x$ac_cv_header_notify_h" = xyes
+then :
+  printf "%s\n" "#define HAVE_NOTIFY_H 1" >>confdefs.h
 
 fi
 
-
-		for ac_func in notify_post
-do :
-  ac_fn_c_check_func "$LINENO" "notify_post" "ac_cv_func_notify_post"
-if test "x$ac_cv_func_notify_post" = xyes; then :
-  cat >>confdefs.h <<_ACEOF
-#define HAVE_NOTIFY_POST 1
-_ACEOF
+		ac_fn_c_check_func "$LINENO" "notify_post" "ac_cv_func_notify_post"
+if test "x$ac_cv_func_notify_post" = xyes
+then :
+  printf "%s\n" "#define HAVE_NOTIFY_POST 1" >>confdefs.h
 
 fi
-done
 
 
 
 # Check whether --with-adminkey was given.
-if test "${with_adminkey+set}" = set; then :
+if test ${with_adminkey+y}
+then :
   withval=$with_adminkey; default_adminkey="$withval"
-else
+else $as_nop
   default_adminkey="default"
 fi
 
 
 # Check whether --with-operkey was given.
-if test "${with_operkey+set}" = set; then :
+if test ${with_operkey+y}
+then :
   withval=$with_operkey; default_operkey="$withval"
-else
+else $as_nop
   default_operkey="default"
 fi
 
 
-		ac_fn_c_check_header_mongrel "$LINENO" "Security/Authorization.h" "ac_cv_header_Security_Authorization_h" "$ac_includes_default"
-if test "x$ac_cv_header_Security_Authorization_h" = xyes; then :
+		ac_fn_c_check_header_compile "$LINENO" "Security/Authorization.h" "ac_cv_header_Security_Authorization_h" "$ac_includes_default"
+if test "x$ac_cv_header_Security_Authorization_h" = xyes
+then :
 
-			$as_echo "#define HAVE_AUTHORIZATION_H 1" >>confdefs.h
+			printf "%s\n" "#define HAVE_AUTHORIZATION_H 1" >>confdefs.h
 
 
 			if test "x$default_adminkey" != xdefault; then
@@ -5970,49 +6717,44 @@ if test "x$ac_cv_header_Security_Authori
 fi
 
 
-
 				if test $host_os_version -ge 100; then
-			ac_fn_c_check_header_mongrel "$LINENO" "sandbox.h" "ac_cv_header_sandbox_h" "$ac_includes_default"
-if test "x$ac_cv_header_sandbox_h" = xyes; then :
-  $as_echo "#define HAVE_SANDBOX_H 1" >>confdefs.h
+			ac_fn_c_check_header_compile "$LINENO" "sandbox.h" "ac_cv_header_sandbox_h" "$ac_includes_default"
+if test "x$ac_cv_header_sandbox_h" = xyes
+then :
+  printf "%s\n" "#define HAVE_SANDBOX_H 1" >>confdefs.h
 
 fi
 
-
 		fi
 		if test $host_os_version -ge 110 -a $host_os_version -lt 120; then
 			# Broken public headers in 10.7.x...
-			{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for sandbox/private.h presence" >&5
-$as_echo_n "checking for sandbox/private.h presence... " >&6; }
+			{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for sandbox/private.h presence" >&5
+printf %s "checking for sandbox/private.h presence... " >&6; }
 			if test -f /usr/local/include/sandbox/private.h; then
-				{ $as_echo "$as_me:${as_lineno-$LINENO}: result: yes" >&5
-$as_echo "yes" >&6; }
+				{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: yes" >&5
+printf "%s\n" "yes" >&6; }
 			else
-				{ $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
+				{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: no" >&5
+printf "%s\n" "no" >&6; }
 				as_fn_error $? "Run 'sudo mkdir -p /usr/local/include/sandbox' and 'sudo touch /usr/local/include/sandbox/private.h' to build CUPS." "$LINENO" 5
 			fi
 		fi
 
-				ac_fn_c_check_header_mongrel "$LINENO" "xpc/xpc.h" "ac_cv_header_xpc_xpc_h" "$ac_includes_default"
-if test "x$ac_cv_header_xpc_xpc_h" = xyes; then :
-  $as_echo "#define HAVE_XPC 1" >>confdefs.h
+				ac_fn_c_check_header_compile "$LINENO" "xpc/xpc.h" "ac_cv_header_xpc_xpc_h" "$ac_includes_default"
+if test "x$ac_cv_header_xpc_xpc_h" = xyes
+then :
+  printf "%s\n" "#define HAVE_XPC 1" >>confdefs.h
 
 			INSTALLXPC="install-xpc"
 fi
 
-
                 ;;
 esac
 
 
-cat >>confdefs.h <<_ACEOF
-#define CUPS_DEFAULT_PRINTOPERATOR_AUTH "$CUPS_DEFAULT_PRINTOPERATOR_AUTH"
-_ACEOF
+printf "%s\n" "#define CUPS_DEFAULT_PRINTOPERATOR_AUTH \"$CUPS_DEFAULT_PRINTOPERATOR_AUTH\"" >>confdefs.h
 
-cat >>confdefs.h <<_ACEOF
-#define CUPS_DEFAULT_SYSTEM_AUTHKEY "$CUPS_DEFAULT_SYSTEM_AUTHKEY"
-_ACEOF
+printf "%s\n" "#define CUPS_DEFAULT_SYSTEM_AUTHKEY \"$CUPS_DEFAULT_SYSTEM_AUTHKEY\"" >>confdefs.h
 
 
 
@@ -6021,7 +6763,8 @@ COMPONENTS="all"
 
 
 # Check whether --with-components was given.
-if test "${with_components+set}" = set; then :
+if test ${with_components+y}
+then :
   withval=$with_components; COMPONENTS="$withval"
 fi
 
@@ -6042,7 +6785,7 @@ case "$COMPONENTS" in
 		;;
 
 	corelite)
-		$as_echo "#define CUPS_LITE 1" >>confdefs.h
+		printf "%s\n" "#define CUPS_LITE 1" >>confdefs.h
 
 		BUILDDIRS="tools examples locale"
 		cupsimagebase=""
@@ -6057,7 +6800,7 @@ case "$COMPONENTS" in
 		;;
 
 	libcupslite)
-		$as_echo "#define CUPS_LITE 1" >>confdefs.h
+		printf "%s\n" "#define CUPS_LITE 1" >>confdefs.h
 
 		BUILDDIRS="locale"
 		cupsimagebase=""
@@ -6096,18 +6839,14 @@ if test "$bindir" = "\${exec_prefix}/bin
 	bindir="$exec_prefix/bin"
 fi
 
-cat >>confdefs.h <<_ACEOF
-#define CUPS_BINDIR "$bindir"
-_ACEOF
+printf "%s\n" "#define CUPS_BINDIR \"$bindir\"" >>confdefs.h
 
 
 if test "$sbindir" = "\${exec_prefix}/sbin"; then
 	sbindir="$exec_prefix/sbin"
 fi
 
-cat >>confdefs.h <<_ACEOF
-#define CUPS_SBINDIR "$sbindir"
-_ACEOF
+printf "%s\n" "#define CUPS_SBINDIR \"$sbindir\"" >>confdefs.h
 
 
 if test "$sharedstatedir" = "\${prefix}/com" -a "$prefix" = "/"; then
@@ -6172,9 +6911,10 @@ fi
 
 
 # Check whether --with-privateinclude was given.
-if test "${with_privateinclude+set}" = set; then :
+if test ${with_privateinclude+y}
+then :
   withval=$with_privateinclude; privateinclude="$withval"
-else
+else $as_nop
   privateinclude=""
 fi
 
@@ -6189,9 +6929,10 @@ fi
 
 
 # Check whether --with-lpdconfig was given.
-if test "${with_lpdconfig+set}" = set; then :
+if test ${with_lpdconfig+y}
+then :
   withval=$with_lpdconfig; LPDCONFIG="$withval"
-else
+else $as_nop
   LPDCONFIG=""
 fi
 
@@ -6205,22 +6946,19 @@ if test "x$LPDCONFIG" = x; then
 fi
 
 if test "x$LPDCONFIG" = xoff; then
-	cat >>confdefs.h <<_ACEOF
-#define CUPS_DEFAULT_LPD_CONFIG ""
-_ACEOF
+	printf "%s\n" "#define CUPS_DEFAULT_LPD_CONFIG \"\"" >>confdefs.h
 
 else
-	cat >>confdefs.h <<_ACEOF
-#define CUPS_DEFAULT_LPD_CONFIG "$LPDCONFIG"
-_ACEOF
+	printf "%s\n" "#define CUPS_DEFAULT_LPD_CONFIG \"$LPDCONFIG\"" >>confdefs.h
 
 fi
 
 
 # Check whether --with-smbconfig was given.
-if test "${with_smbconfig+set}" = set; then :
+if test ${with_smbconfig+y}
+then :
   withval=$with_smbconfig; SMBCONFIG="$withval"
-else
+else $as_nop
   SMBCONFIG=""
 fi
 
@@ -6239,23 +6977,20 @@ if test "x$SMBCONFIG" = x; then
 fi
 
 if test "x$SMBCONFIG" = xoff; then
-	cat >>confdefs.h <<_ACEOF
-#define CUPS_DEFAULT_SMB_CONFIG ""
-_ACEOF
+	printf "%s\n" "#define CUPS_DEFAULT_SMB_CONFIG \"\"" >>confdefs.h
 
 else
-	cat >>confdefs.h <<_ACEOF
-#define CUPS_DEFAULT_SMB_CONFIG "$SMBCONFIG"
-_ACEOF
+	printf "%s\n" "#define CUPS_DEFAULT_SMB_CONFIG \"$SMBCONFIG\"" >>confdefs.h
 
 fi
 
 # Cache data...
 
 # Check whether --with-cachedir was given.
-if test "${with_cachedir+set}" = set; then :
+if test ${with_cachedir+y}
+then :
   withval=$with_cachedir; cachedir="$withval"
-else
+else $as_nop
   cachedir=""
 fi
 
@@ -6269,26 +7004,23 @@ if test x$cachedir = x; then
 else
 	CUPS_CACHEDIR="$cachedir"
 fi
-cat >>confdefs.h <<_ACEOF
-#define CUPS_CACHEDIR "$CUPS_CACHEDIR"
-_ACEOF
+printf "%s\n" "#define CUPS_CACHEDIR \"$CUPS_CACHEDIR\"" >>confdefs.h
 
 
 
 # Data files
 CUPS_DATADIR="$datadir/cups"
-cat >>confdefs.h <<_ACEOF
-#define CUPS_DATADIR "$datadir/cups"
-_ACEOF
+printf "%s\n" "#define CUPS_DATADIR \"$datadir/cups\"" >>confdefs.h
 
 
 
 # Icon directory
 
 # Check whether --with-icondir was given.
-if test "${with_icondir+set}" = set; then :
+if test ${with_icondir+y}
+then :
   withval=$with_icondir; icondir="$withval"
-else
+else $as_nop
   icondir=""
 fi
 
@@ -6304,9 +7036,10 @@ fi
 # Menu directory
 
 # Check whether --with-menudir was given.
-if test "${with_menudir+set}" = set; then :
+if test ${with_menudir+y}
+then :
   withval=$with_menudir; menudir="$withval"
-else
+else $as_nop
   menudir=""
 fi
 
@@ -6322,9 +7055,10 @@ fi
 # Documentation files
 
 # Check whether --with-docdir was given.
-if test "${with_docdir+set}" = set; then :
+if test ${with_docdir+y}
+then :
   withval=$with_docdir; docdir="$withval"
-else
+else $as_nop
   docdir=""
 fi
 
@@ -6336,18 +7070,17 @@ else
 	CUPS_DOCROOT="$docdir"
 fi
 
-cat >>confdefs.h <<_ACEOF
-#define CUPS_DOCROOT "$docdir"
-_ACEOF
+printf "%s\n" "#define CUPS_DOCROOT \"$docdir\"" >>confdefs.h
 
 
 
 # Fonts
 
 # Check whether --with-fontpath was given.
-if test "${with_fontpath+set}" = set; then :
+if test ${with_fontpath+y}
+then :
   withval=$with_fontpath; fontpath="$withval"
-else
+else $as_nop
   fontpath=""
 fi
 
@@ -6359,9 +7092,7 @@ else
 fi
 
 
-cat >>confdefs.h <<_ACEOF
-#define CUPS_FONTPATH "$CUPS_FONTPATH"
-_ACEOF
+printf "%s\n" "#define CUPS_FONTPATH \"$CUPS_FONTPATH\"" >>confdefs.h
 
 
 # Locale data
@@ -6380,47 +7111,45 @@ else
 	CUPS_LOCALEDIR="$localedir"
 fi
 
-cat >>confdefs.h <<_ACEOF
-#define CUPS_LOCALEDIR "$CUPS_LOCALEDIR"
-_ACEOF
+printf "%s\n" "#define CUPS_LOCALEDIR \"$CUPS_LOCALEDIR\"" >>confdefs.h
 
 
 
 # Log files...
 
 # Check whether --with-logdir was given.
-if test "${with_logdir+set}" = set; then :
+if test ${with_logdir+y}
+then :
   withval=$with_logdir; logdir="$withval"
-else
+else $as_nop
   logdir=""
 fi
 
 
 if test x$logdir = x; then
 	CUPS_LOGDIR="$localstatedir/log/cups"
-	cat >>confdefs.h <<_ACEOF
-#define CUPS_LOGDIR "$localstatedir/log/cups"
-_ACEOF
+	printf "%s\n" "#define CUPS_LOGDIR \"$localstatedir/log/cups\"" >>confdefs.h
 
 else
 	CUPS_LOGDIR="$logdir"
 fi
-cat >>confdefs.h <<_ACEOF
-#define CUPS_LOGDIR "$CUPS_LOGDIR"
-_ACEOF
+printf "%s\n" "#define CUPS_LOGDIR \"$CUPS_LOGDIR\"" >>confdefs.h
 
 
 
 # Longer-term spool data
 CUPS_REQUESTS="$localstatedir/spool/cups"
-cat >>confdefs.h <<_ACEOF
-#define CUPS_REQUESTS "$localstatedir/spool/cups"
-_ACEOF
+printf "%s\n" "#define CUPS_REQUESTS \"$localstatedir/spool/cups\"" >>confdefs.h
 
 
 
 # Server executables...
 case "$host_os_name" in
+	*-gnu)
+		# GNUs
+		INSTALL_SYSV="install-sysv"
+		CUPS_SERVERBIN="$exec_prefix/lib/cups"
+		;;
 	*bsd* | darwin*)
 		# *BSD and Darwin (macOS)
 		INSTALL_SYSV=""
@@ -6433,27 +7162,24 @@ case "$host_os_name" in
 		;;
 esac
 
-cat >>confdefs.h <<_ACEOF
-#define CUPS_SERVERBIN "$CUPS_SERVERBIN"
-_ACEOF
+printf "%s\n" "#define CUPS_SERVERBIN \"$CUPS_SERVERBIN\"" >>confdefs.h
 
 
 
 
 # Configuration files
 CUPS_SERVERROOT="$sysconfdir/cups"
-cat >>confdefs.h <<_ACEOF
-#define CUPS_SERVERROOT "$sysconfdir/cups"
-_ACEOF
+printf "%s\n" "#define CUPS_SERVERROOT \"$sysconfdir/cups\"" >>confdefs.h
 
 
 
 # Transient run-time state
 
 # Check whether --with-rundir was given.
-if test "${with_rundir+set}" = set; then :
+if test ${with_rundir+y}
+then :
   withval=$with_rundir; CUPS_STATEDIR="$withval"
-else
+else $as_nop
 
 	case "$host_os_name" in
 		darwin*)
@@ -6467,9 +7193,7 @@ else
 	esac
 fi
 
-cat >>confdefs.h <<_ACEOF
-#define CUPS_STATEDIR "$CUPS_STATEDIR"
-_ACEOF
+printf "%s\n" "#define CUPS_STATEDIR \"$CUPS_STATEDIR\"" >>confdefs.h
 
 
 
@@ -6499,7 +7223,8 @@ PICFLAG=1
 DSOFLAGS="${DSOFLAGS:=}"
 
 # Check whether --enable-shared was given.
-if test "${enable_shared+set}" = set; then :
+if test ${enable_shared+y}
+then :
   enableval=$enable_shared;
 fi
 
@@ -6617,7 +7342,8 @@ fi
 
 
 # Check whether --enable-libtool_unsupported was given.
-if test "${enable_libtool_unsupported+set}" = set; then :
+if test ${enable_libtool_unsupported+y}
+then :
   enableval=$enable_libtool_unsupported; if test x$enable_libtool_unsupported != xno; then
 		if test x$enable_libtool_unsupported == xyes; then
 			as_fn_error $? "Use --enable-libtool-unsupported=/path/to/libtool." "$LINENO" 5
@@ -6676,31 +7402,36 @@ INSTALL_STRIP=""
 
 
 # Check whether --with-optim was given.
-if test "${with_optim+set}" = set; then :
+if test ${with_optim+y}
+then :
   withval=$with_optim; OPTIM="$withval"
-else
+else $as_nop
   OPTIM=""
 fi
 
 
 
 # Check whether --enable-debug was given.
-if test "${enable_debug+set}" = set; then :
+if test ${enable_debug+y}
+then :
   enableval=$enable_debug;
 fi
 
 # Check whether --enable-debug_guards was given.
-if test "${enable_debug_guards+set}" = set; then :
+if test ${enable_debug_guards+y}
+then :
   enableval=$enable_debug_guards;
 fi
 
 # Check whether --enable-debug_printfs was given.
-if test "${enable_debug_printfs+set}" = set; then :
+if test ${enable_debug_printfs+y}
+then :
   enableval=$enable_debug_printfs;
 fi
 
 # Check whether --enable-unit_tests was given.
-if test "${enable_unit_tests+set}" = set; then :
+if test ${enable_unit_tests+y}
+then :
   enableval=$enable_unit_tests;
 fi
 
@@ -6734,13 +7465,15 @@ fi
 
 
 # Check whether --with-archflags was given.
-if test "${with_archflags+set}" = set; then :
+if test ${with_archflags+y}
+then :
   withval=$with_archflags;
 fi
 
 
 # Check whether --with-ldarchflags was given.
-if test "${with_ldarchflags+set}" = set; then :
+if test ${with_ldarchflags+y}
+then :
   withval=$with_ldarchflags;
 fi
 
@@ -6766,13 +7499,15 @@ fi
 
 
 # Check whether --enable-relro was given.
-if test "${enable_relro+set}" = set; then :
+if test ${enable_relro+y}
+then :
   enableval=$enable_relro;
 fi
 
 
 # Check whether --enable-sanitizer was given.
-if test "${enable_sanitizer+set}" = set; then :
+if test ${enable_sanitizer+y}
+then :
   enableval=$enable_sanitizer;
 fi
 
@@ -6818,35 +7553,36 @@ if test -n "$GCC"; then
 	# The -fstack-protector option is available with some versions of
 	# GCC and adds "stack canaries" which detect when the return address
 	# has been overwritten, preventing many types of exploit attacks.
-	{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether compiler supports -fstack-protector" >&5
-$as_echo_n "checking whether compiler supports -fstack-protector... " >&6; }
+	{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking whether compiler supports -fstack-protector" >&5
+printf %s "checking whether compiler supports -fstack-protector... " >&6; }
 	OLDCFLAGS="$CFLAGS"
 	CFLAGS="$CFLAGS -fstack-protector"
 	cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
 
 int
-main ()
+main (void)
 {
 
   ;
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
+if ac_fn_c_try_link "$LINENO"
+then :
   if test "x$LSB_BUILD" = xy; then
 			# Can't use stack-protector with LSB binaries...
 			OPTIM="$OPTIM -fno-stack-protector"
 		else
 			OPTIM="$OPTIM -fstack-protector"
 		fi
-		{ $as_echo "$as_me:${as_lineno-$LINENO}: result: yes" >&5
-$as_echo "yes" >&6; }
-else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
+		{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: yes" >&5
+printf "%s\n" "yes" >&6; }
+else $as_nop
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: no" >&5
+printf "%s\n" "no" >&6; }
 fi
-rm -f core conftest.err conftest.$ac_objext \
+rm -f core conftest.err conftest.$ac_objext conftest.beam \
     conftest$ac_exeext conftest.$ac_ext
 	CFLAGS="$OLDCFLAGS"
 
@@ -6856,8 +7592,8 @@ rm -f core conftest.err conftest.$ac_obj
 		# exploits that depend on a fixed address for common functions.
 		#
 		# Not available to LSB binaries...
-		{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether compiler supports -fPIE" >&5
-$as_echo_n "checking whether compiler supports -fPIE... " >&6; }
+		{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking whether compiler supports -fPIE" >&5
+printf %s "checking whether compiler supports -fPIE... " >&6; }
 		OLDCFLAGS="$CFLAGS"
 		case "$host_os_name" in
 			darwin*)
@@ -6866,23 +7602,24 @@ $as_echo_n "checking whether compiler su
 /* end confdefs.h.  */
 
 int
-main ()
+main (void)
 {
 
   ;
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_compile "$LINENO"; then :
+if ac_fn_c_try_compile "$LINENO"
+then :
 
 					PIEFLAGS="-fPIE -Wl,-pie"
-					{ $as_echo "$as_me:${as_lineno-$LINENO}: result: yes" >&5
-$as_echo "yes" >&6; }
-else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
+					{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: yes" >&5
+printf "%s\n" "yes" >&6; }
+else $as_nop
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: no" >&5
+printf "%s\n" "no" >&6; }
 fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
+rm -f core conftest.err conftest.$ac_objext conftest.beam conftest.$ac_ext
 				;;
 
 			*)
@@ -6891,30 +7628,31 @@ rm -f core conftest.err conftest.$ac_obj
 /* end confdefs.h.  */
 
 int
-main ()
+main (void)
 {
 
   ;
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_compile "$LINENO"; then :
+if ac_fn_c_try_compile "$LINENO"
+then :
 
 					PIEFLAGS="-fPIE -pie"
-					{ $as_echo "$as_me:${as_lineno-$LINENO}: result: yes" >&5
-$as_echo "yes" >&6; }
-else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
+					{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: yes" >&5
+printf "%s\n" "yes" >&6; }
+else $as_nop
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: no" >&5
+printf "%s\n" "no" >&6; }
 fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
+rm -f core conftest.err conftest.$ac_objext conftest.beam conftest.$ac_ext
 				;;
 		esac
 		CFLAGS="$OLDCFLAGS"
 	fi
 
 	# Add useful warning options for tracking down problems...
-	WARNING_OPTIONS="-Wall -Wno-format-y2k -Wunused -Wno-unused-result -Wsign-conversion"
+	WARNING_OPTIONS="-Wall -Wno-format-y2k -Wunused -Wno-unused-result -Wsign-conversion -Wno-deprecated-declarations"
 
 	# Test GCC version for certain warning flags since -Werror
 	# doesn't trigger...
@@ -6978,17 +7716,18 @@ ac_fn_c_check_header_compile "$LINENO" "
 #include <netinet/in_systm.h>
 #include <netinet/ip.h>
 "
-if test "x$ac_cv_header_resolv_h" = xyes; then :
-  $as_echo "#define HAVE_RESOLV_H 1" >>confdefs.h
+if test "x$ac_cv_header_resolv_h" = xyes
+then :
+  printf "%s\n" "#define HAVE_RESOLV_H 1" >>confdefs.h
 
 fi
 
-
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for library containing socket" >&5
-$as_echo_n "checking for library containing socket... " >&6; }
-if ${ac_cv_search_socket+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for library containing socket" >&5
+printf %s "checking for library containing socket... " >&6; }
+if test ${ac_cv_search_socket+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   ac_func_search_save_LIBS=$LIBS
 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
@@ -6996,55 +7735,58 @@ cat confdefs.h - <<_ACEOF >conftest.$ac_
 /* Override any GCC internal prototype to avoid an error.
    Use char because int might match the return type of a GCC
    builtin and then its argument prototype would still apply.  */
-#ifdef __cplusplus
-extern "C"
-#endif
 char socket ();
 int
-main ()
+main (void)
 {
 return socket ();
   ;
   return 0;
 }
 _ACEOF
-for ac_lib in '' socket; do
+for ac_lib in '' socket
+do
   if test -z "$ac_lib"; then
     ac_res="none required"
   else
     ac_res=-l$ac_lib
     LIBS="-l$ac_lib  $ac_func_search_save_LIBS"
   fi
-  if ac_fn_c_try_link "$LINENO"; then :
+  if ac_fn_c_try_link "$LINENO"
+then :
   ac_cv_search_socket=$ac_res
 fi
-rm -f core conftest.err conftest.$ac_objext \
+rm -f core conftest.err conftest.$ac_objext conftest.beam \
     conftest$ac_exeext
-  if ${ac_cv_search_socket+:} false; then :
+  if test ${ac_cv_search_socket+y}
+then :
   break
 fi
 done
-if ${ac_cv_search_socket+:} false; then :
+if test ${ac_cv_search_socket+y}
+then :
 
-else
+else $as_nop
   ac_cv_search_socket=no
 fi
 rm conftest.$ac_ext
 LIBS=$ac_func_search_save_LIBS
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_search_socket" >&5
-$as_echo "$ac_cv_search_socket" >&6; }
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_search_socket" >&5
+printf "%s\n" "$ac_cv_search_socket" >&6; }
 ac_res=$ac_cv_search_socket
-if test "$ac_res" != no; then :
+if test "$ac_res" != no
+then :
   test "$ac_res" = "none required" || LIBS="$ac_res $LIBS"
 
 fi
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for library containing gethostbyaddr" >&5
-$as_echo_n "checking for library containing gethostbyaddr... " >&6; }
-if ${ac_cv_search_gethostbyaddr+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for library containing gethostbyaddr" >&5
+printf %s "checking for library containing gethostbyaddr... " >&6; }
+if test ${ac_cv_search_gethostbyaddr+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   ac_func_search_save_LIBS=$LIBS
 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
@@ -7052,55 +7794,58 @@ cat confdefs.h - <<_ACEOF >conftest.$ac_
 /* Override any GCC internal prototype to avoid an error.
    Use char because int might match the return type of a GCC
    builtin and then its argument prototype would still apply.  */
-#ifdef __cplusplus
-extern "C"
-#endif
 char gethostbyaddr ();
 int
-main ()
+main (void)
 {
 return gethostbyaddr ();
   ;
   return 0;
 }
 _ACEOF
-for ac_lib in '' nsl; do
+for ac_lib in '' nsl
+do
   if test -z "$ac_lib"; then
     ac_res="none required"
   else
     ac_res=-l$ac_lib
     LIBS="-l$ac_lib  $ac_func_search_save_LIBS"
   fi
-  if ac_fn_c_try_link "$LINENO"; then :
+  if ac_fn_c_try_link "$LINENO"
+then :
   ac_cv_search_gethostbyaddr=$ac_res
 fi
-rm -f core conftest.err conftest.$ac_objext \
+rm -f core conftest.err conftest.$ac_objext conftest.beam \
     conftest$ac_exeext
-  if ${ac_cv_search_gethostbyaddr+:} false; then :
+  if test ${ac_cv_search_gethostbyaddr+y}
+then :
   break
 fi
 done
-if ${ac_cv_search_gethostbyaddr+:} false; then :
+if test ${ac_cv_search_gethostbyaddr+y}
+then :
 
-else
+else $as_nop
   ac_cv_search_gethostbyaddr=no
 fi
 rm conftest.$ac_ext
 LIBS=$ac_func_search_save_LIBS
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_search_gethostbyaddr" >&5
-$as_echo "$ac_cv_search_gethostbyaddr" >&6; }
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_search_gethostbyaddr" >&5
+printf "%s\n" "$ac_cv_search_gethostbyaddr" >&6; }
 ac_res=$ac_cv_search_gethostbyaddr
-if test "$ac_res" != no; then :
+if test "$ac_res" != no
+then :
   test "$ac_res" = "none required" || LIBS="$ac_res $LIBS"
 
 fi
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for library containing getifaddrs" >&5
-$as_echo_n "checking for library containing getifaddrs... " >&6; }
-if ${ac_cv_search_getifaddrs+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for library containing getifaddrs" >&5
+printf %s "checking for library containing getifaddrs... " >&6; }
+if test ${ac_cv_search_getifaddrs+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   ac_func_search_save_LIBS=$LIBS
 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
@@ -7108,56 +7853,59 @@ cat confdefs.h - <<_ACEOF >conftest.$ac_
 /* Override any GCC internal prototype to avoid an error.
    Use char because int might match the return type of a GCC
    builtin and then its argument prototype would still apply.  */
-#ifdef __cplusplus
-extern "C"
-#endif
 char getifaddrs ();
 int
-main ()
+main (void)
 {
 return getifaddrs ();
   ;
   return 0;
 }
 _ACEOF
-for ac_lib in '' nsl; do
+for ac_lib in '' nsl
+do
   if test -z "$ac_lib"; then
     ac_res="none required"
   else
     ac_res=-l$ac_lib
     LIBS="-l$ac_lib  $ac_func_search_save_LIBS"
   fi
-  if ac_fn_c_try_link "$LINENO"; then :
+  if ac_fn_c_try_link "$LINENO"
+then :
   ac_cv_search_getifaddrs=$ac_res
 fi
-rm -f core conftest.err conftest.$ac_objext \
+rm -f core conftest.err conftest.$ac_objext conftest.beam \
     conftest$ac_exeext
-  if ${ac_cv_search_getifaddrs+:} false; then :
+  if test ${ac_cv_search_getifaddrs+y}
+then :
   break
 fi
 done
-if ${ac_cv_search_getifaddrs+:} false; then :
+if test ${ac_cv_search_getifaddrs+y}
+then :
 
-else
+else $as_nop
   ac_cv_search_getifaddrs=no
 fi
 rm conftest.$ac_ext
 LIBS=$ac_func_search_save_LIBS
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_search_getifaddrs" >&5
-$as_echo "$ac_cv_search_getifaddrs" >&6; }
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_search_getifaddrs" >&5
+printf "%s\n" "$ac_cv_search_getifaddrs" >&6; }
 ac_res=$ac_cv_search_getifaddrs
-if test "$ac_res" != no; then :
+if test "$ac_res" != no
+then :
   test "$ac_res" = "none required" || LIBS="$ac_res $LIBS"
-  $as_echo "#define HAVE_GETIFADDRS 1" >>confdefs.h
+  printf "%s\n" "#define HAVE_GETIFADDRS 1" >>confdefs.h
 
 fi
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for library containing hstrerror" >&5
-$as_echo_n "checking for library containing hstrerror... " >&6; }
-if ${ac_cv_search_hstrerror+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for library containing hstrerror" >&5
+printf %s "checking for library containing hstrerror... " >&6; }
+if test ${ac_cv_search_hstrerror+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   ac_func_search_save_LIBS=$LIBS
 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
@@ -7165,56 +7913,59 @@ cat confdefs.h - <<_ACEOF >conftest.$ac_
 /* Override any GCC internal prototype to avoid an error.
    Use char because int might match the return type of a GCC
    builtin and then its argument prototype would still apply.  */
-#ifdef __cplusplus
-extern "C"
-#endif
 char hstrerror ();
 int
-main ()
+main (void)
 {
 return hstrerror ();
   ;
   return 0;
 }
 _ACEOF
-for ac_lib in '' nsl socket resolv; do
+for ac_lib in '' nsl socket resolv
+do
   if test -z "$ac_lib"; then
     ac_res="none required"
   else
     ac_res=-l$ac_lib
     LIBS="-l$ac_lib  $ac_func_search_save_LIBS"
   fi
-  if ac_fn_c_try_link "$LINENO"; then :
+  if ac_fn_c_try_link "$LINENO"
+then :
   ac_cv_search_hstrerror=$ac_res
 fi
-rm -f core conftest.err conftest.$ac_objext \
+rm -f core conftest.err conftest.$ac_objext conftest.beam \
     conftest$ac_exeext
-  if ${ac_cv_search_hstrerror+:} false; then :
+  if test ${ac_cv_search_hstrerror+y}
+then :
   break
 fi
 done
-if ${ac_cv_search_hstrerror+:} false; then :
+if test ${ac_cv_search_hstrerror+y}
+then :
 
-else
+else $as_nop
   ac_cv_search_hstrerror=no
 fi
 rm conftest.$ac_ext
 LIBS=$ac_func_search_save_LIBS
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_search_hstrerror" >&5
-$as_echo "$ac_cv_search_hstrerror" >&6; }
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_search_hstrerror" >&5
+printf "%s\n" "$ac_cv_search_hstrerror" >&6; }
 ac_res=$ac_cv_search_hstrerror
-if test "$ac_res" != no; then :
+if test "$ac_res" != no
+then :
   test "$ac_res" = "none required" || LIBS="$ac_res $LIBS"
-  $as_echo "#define HAVE_HSTRERROR 1" >>confdefs.h
+  printf "%s\n" "#define HAVE_HSTRERROR 1" >>confdefs.h
 
 fi
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for library containing rresvport_af" >&5
-$as_echo_n "checking for library containing rresvport_af... " >&6; }
-if ${ac_cv_search_rresvport_af+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for library containing rresvport_af" >&5
+printf %s "checking for library containing rresvport_af... " >&6; }
+if test ${ac_cv_search_rresvport_af+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   ac_func_search_save_LIBS=$LIBS
 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
@@ -7222,56 +7973,59 @@ cat confdefs.h - <<_ACEOF >conftest.$ac_
 /* Override any GCC internal prototype to avoid an error.
    Use char because int might match the return type of a GCC
    builtin and then its argument prototype would still apply.  */
-#ifdef __cplusplus
-extern "C"
-#endif
 char rresvport_af ();
 int
-main ()
+main (void)
 {
 return rresvport_af ();
   ;
   return 0;
 }
 _ACEOF
-for ac_lib in '' nsl; do
+for ac_lib in '' nsl
+do
   if test -z "$ac_lib"; then
     ac_res="none required"
   else
     ac_res=-l$ac_lib
     LIBS="-l$ac_lib  $ac_func_search_save_LIBS"
   fi
-  if ac_fn_c_try_link "$LINENO"; then :
+  if ac_fn_c_try_link "$LINENO"
+then :
   ac_cv_search_rresvport_af=$ac_res
 fi
-rm -f core conftest.err conftest.$ac_objext \
+rm -f core conftest.err conftest.$ac_objext conftest.beam \
     conftest$ac_exeext
-  if ${ac_cv_search_rresvport_af+:} false; then :
+  if test ${ac_cv_search_rresvport_af+y}
+then :
   break
 fi
 done
-if ${ac_cv_search_rresvport_af+:} false; then :
+if test ${ac_cv_search_rresvport_af+y}
+then :
 
-else
+else $as_nop
   ac_cv_search_rresvport_af=no
 fi
 rm conftest.$ac_ext
 LIBS=$ac_func_search_save_LIBS
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_search_rresvport_af" >&5
-$as_echo "$ac_cv_search_rresvport_af" >&6; }
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_search_rresvport_af" >&5
+printf "%s\n" "$ac_cv_search_rresvport_af" >&6; }
 ac_res=$ac_cv_search_rresvport_af
-if test "$ac_res" != no; then :
+if test "$ac_res" != no
+then :
   test "$ac_res" = "none required" || LIBS="$ac_res $LIBS"
-  $as_echo "#define HAVE_RRESVPORT_AF 1" >>confdefs.h
+  printf "%s\n" "#define HAVE_RRESVPORT_AF 1" >>confdefs.h
 
 fi
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for library containing __res_init" >&5
-$as_echo_n "checking for library containing __res_init... " >&6; }
-if ${ac_cv_search___res_init+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for library containing __res_init" >&5
+printf %s "checking for library containing __res_init... " >&6; }
+if test ${ac_cv_search___res_init+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   ac_func_search_save_LIBS=$LIBS
 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
@@ -7279,55 +8033,58 @@ cat confdefs.h - <<_ACEOF >conftest.$ac_
 /* Override any GCC internal prototype to avoid an error.
    Use char because int might match the return type of a GCC
    builtin and then its argument prototype would still apply.  */
-#ifdef __cplusplus
-extern "C"
-#endif
 char __res_init ();
 int
-main ()
+main (void)
 {
 return __res_init ();
   ;
   return 0;
 }
 _ACEOF
-for ac_lib in '' resolv bind; do
+for ac_lib in '' resolv bind
+do
   if test -z "$ac_lib"; then
     ac_res="none required"
   else
     ac_res=-l$ac_lib
     LIBS="-l$ac_lib  $ac_func_search_save_LIBS"
   fi
-  if ac_fn_c_try_link "$LINENO"; then :
+  if ac_fn_c_try_link "$LINENO"
+then :
   ac_cv_search___res_init=$ac_res
 fi
-rm -f core conftest.err conftest.$ac_objext \
+rm -f core conftest.err conftest.$ac_objext conftest.beam \
     conftest$ac_exeext
-  if ${ac_cv_search___res_init+:} false; then :
+  if test ${ac_cv_search___res_init+y}
+then :
   break
 fi
 done
-if ${ac_cv_search___res_init+:} false; then :
+if test ${ac_cv_search___res_init+y}
+then :
 
-else
+else $as_nop
   ac_cv_search___res_init=no
 fi
 rm conftest.$ac_ext
 LIBS=$ac_func_search_save_LIBS
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_search___res_init" >&5
-$as_echo "$ac_cv_search___res_init" >&6; }
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_search___res_init" >&5
+printf "%s\n" "$ac_cv_search___res_init" >&6; }
 ac_res=$ac_cv_search___res_init
-if test "$ac_res" != no; then :
+if test "$ac_res" != no
+then :
   test "$ac_res" = "none required" || LIBS="$ac_res $LIBS"
-  $as_echo "#define HAVE_RES_INIT 1" >>confdefs.h
+  printf "%s\n" "#define HAVE_RES_INIT 1" >>confdefs.h
 
-else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking for library containing res_9_init" >&5
-$as_echo_n "checking for library containing res_9_init... " >&6; }
-if ${ac_cv_search_res_9_init+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+else $as_nop
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for library containing res_9_init" >&5
+printf %s "checking for library containing res_9_init... " >&6; }
+if test ${ac_cv_search_res_9_init+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   ac_func_search_save_LIBS=$LIBS
 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
@@ -7335,55 +8092,58 @@ cat confdefs.h - <<_ACEOF >conftest.$ac_
 /* Override any GCC internal prototype to avoid an error.
    Use char because int might match the return type of a GCC
    builtin and then its argument prototype would still apply.  */
-#ifdef __cplusplus
-extern "C"
-#endif
 char res_9_init ();
 int
-main ()
+main (void)
 {
 return res_9_init ();
   ;
   return 0;
 }
 _ACEOF
-for ac_lib in '' resolv bind; do
+for ac_lib in '' resolv bind
+do
   if test -z "$ac_lib"; then
     ac_res="none required"
   else
     ac_res=-l$ac_lib
     LIBS="-l$ac_lib  $ac_func_search_save_LIBS"
   fi
-  if ac_fn_c_try_link "$LINENO"; then :
+  if ac_fn_c_try_link "$LINENO"
+then :
   ac_cv_search_res_9_init=$ac_res
 fi
-rm -f core conftest.err conftest.$ac_objext \
+rm -f core conftest.err conftest.$ac_objext conftest.beam \
     conftest$ac_exeext
-  if ${ac_cv_search_res_9_init+:} false; then :
+  if test ${ac_cv_search_res_9_init+y}
+then :
   break
 fi
 done
-if ${ac_cv_search_res_9_init+:} false; then :
+if test ${ac_cv_search_res_9_init+y}
+then :
 
-else
+else $as_nop
   ac_cv_search_res_9_init=no
 fi
 rm conftest.$ac_ext
 LIBS=$ac_func_search_save_LIBS
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_search_res_9_init" >&5
-$as_echo "$ac_cv_search_res_9_init" >&6; }
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_search_res_9_init" >&5
+printf "%s\n" "$ac_cv_search_res_9_init" >&6; }
 ac_res=$ac_cv_search_res_9_init
-if test "$ac_res" != no; then :
+if test "$ac_res" != no
+then :
   test "$ac_res" = "none required" || LIBS="$ac_res $LIBS"
-  $as_echo "#define HAVE_RES_INIT 1" >>confdefs.h
+  printf "%s\n" "#define HAVE_RES_INIT 1" >>confdefs.h
 
-else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking for library containing res_init" >&5
-$as_echo_n "checking for library containing res_init... " >&6; }
-if ${ac_cv_search_res_init+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+else $as_nop
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for library containing res_init" >&5
+printf %s "checking for library containing res_init... " >&6; }
+if test ${ac_cv_search_res_init+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   ac_func_search_save_LIBS=$LIBS
 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
@@ -7391,48 +8151,50 @@ cat confdefs.h - <<_ACEOF >conftest.$ac_
 /* Override any GCC internal prototype to avoid an error.
    Use char because int might match the return type of a GCC
    builtin and then its argument prototype would still apply.  */
-#ifdef __cplusplus
-extern "C"
-#endif
 char res_init ();
 int
-main ()
+main (void)
 {
 return res_init ();
   ;
   return 0;
 }
 _ACEOF
-for ac_lib in '' resolv bind; do
+for ac_lib in '' resolv bind
+do
   if test -z "$ac_lib"; then
     ac_res="none required"
   else
     ac_res=-l$ac_lib
     LIBS="-l$ac_lib  $ac_func_search_save_LIBS"
   fi
-  if ac_fn_c_try_link "$LINENO"; then :
+  if ac_fn_c_try_link "$LINENO"
+then :
   ac_cv_search_res_init=$ac_res
 fi
-rm -f core conftest.err conftest.$ac_objext \
+rm -f core conftest.err conftest.$ac_objext conftest.beam \
     conftest$ac_exeext
-  if ${ac_cv_search_res_init+:} false; then :
+  if test ${ac_cv_search_res_init+y}
+then :
   break
 fi
 done
-if ${ac_cv_search_res_init+:} false; then :
+if test ${ac_cv_search_res_init+y}
+then :
 
-else
+else $as_nop
   ac_cv_search_res_init=no
 fi
 rm conftest.$ac_ext
 LIBS=$ac_func_search_save_LIBS
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_search_res_init" >&5
-$as_echo "$ac_cv_search_res_init" >&6; }
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_search_res_init" >&5
+printf "%s\n" "$ac_cv_search_res_init" >&6; }
 ac_res=$ac_cv_search_res_init
-if test "$ac_res" != no; then :
+if test "$ac_res" != no
+then :
   test "$ac_res" = "none required" || LIBS="$ac_res $LIBS"
-  $as_echo "#define HAVE_RES_INIT 1" >>confdefs.h
+  printf "%s\n" "#define HAVE_RES_INIT 1" >>confdefs.h
 
 fi
 
@@ -7444,11 +8206,12 @@ fi
 # Tru64 5.1b leaks file descriptors with these functions; disable until
 # we can come up with a test for this...
 if test "$host_os_name" != "osf1"; then
-	{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for library containing getaddrinfo" >&5
-$as_echo_n "checking for library containing getaddrinfo... " >&6; }
-if ${ac_cv_search_getaddrinfo+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+	{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for library containing getaddrinfo" >&5
+printf %s "checking for library containing getaddrinfo... " >&6; }
+if test ${ac_cv_search_getaddrinfo+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   ac_func_search_save_LIBS=$LIBS
 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
@@ -7456,56 +8219,59 @@ cat confdefs.h - <<_ACEOF >conftest.$ac_
 /* Override any GCC internal prototype to avoid an error.
    Use char because int might match the return type of a GCC
    builtin and then its argument prototype would still apply.  */
-#ifdef __cplusplus
-extern "C"
-#endif
 char getaddrinfo ();
 int
-main ()
+main (void)
 {
 return getaddrinfo ();
   ;
   return 0;
 }
 _ACEOF
-for ac_lib in '' nsl; do
+for ac_lib in '' nsl
+do
   if test -z "$ac_lib"; then
     ac_res="none required"
   else
     ac_res=-l$ac_lib
     LIBS="-l$ac_lib  $ac_func_search_save_LIBS"
   fi
-  if ac_fn_c_try_link "$LINENO"; then :
+  if ac_fn_c_try_link "$LINENO"
+then :
   ac_cv_search_getaddrinfo=$ac_res
 fi
-rm -f core conftest.err conftest.$ac_objext \
+rm -f core conftest.err conftest.$ac_objext conftest.beam \
     conftest$ac_exeext
-  if ${ac_cv_search_getaddrinfo+:} false; then :
+  if test ${ac_cv_search_getaddrinfo+y}
+then :
   break
 fi
 done
-if ${ac_cv_search_getaddrinfo+:} false; then :
+if test ${ac_cv_search_getaddrinfo+y}
+then :
 
-else
+else $as_nop
   ac_cv_search_getaddrinfo=no
 fi
 rm conftest.$ac_ext
 LIBS=$ac_func_search_save_LIBS
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_search_getaddrinfo" >&5
-$as_echo "$ac_cv_search_getaddrinfo" >&6; }
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_search_getaddrinfo" >&5
+printf "%s\n" "$ac_cv_search_getaddrinfo" >&6; }
 ac_res=$ac_cv_search_getaddrinfo
-if test "$ac_res" != no; then :
+if test "$ac_res" != no
+then :
   test "$ac_res" = "none required" || LIBS="$ac_res $LIBS"
-  $as_echo "#define HAVE_GETADDRINFO 1" >>confdefs.h
+  printf "%s\n" "#define HAVE_GETADDRINFO 1" >>confdefs.h
 
 fi
 
-	{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for library containing getnameinfo" >&5
-$as_echo_n "checking for library containing getnameinfo... " >&6; }
-if ${ac_cv_search_getnameinfo+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+	{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for library containing getnameinfo" >&5
+printf %s "checking for library containing getnameinfo... " >&6; }
+if test ${ac_cv_search_getnameinfo+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   ac_func_search_save_LIBS=$LIBS
 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
@@ -7513,48 +8279,50 @@ cat confdefs.h - <<_ACEOF >conftest.$ac_
 /* Override any GCC internal prototype to avoid an error.
    Use char because int might match the return type of a GCC
    builtin and then its argument prototype would still apply.  */
-#ifdef __cplusplus
-extern "C"
-#endif
 char getnameinfo ();
 int
-main ()
+main (void)
 {
 return getnameinfo ();
   ;
   return 0;
 }
 _ACEOF
-for ac_lib in '' nsl; do
+for ac_lib in '' nsl
+do
   if test -z "$ac_lib"; then
     ac_res="none required"
   else
     ac_res=-l$ac_lib
     LIBS="-l$ac_lib  $ac_func_search_save_LIBS"
   fi
-  if ac_fn_c_try_link "$LINENO"; then :
+  if ac_fn_c_try_link "$LINENO"
+then :
   ac_cv_search_getnameinfo=$ac_res
 fi
-rm -f core conftest.err conftest.$ac_objext \
+rm -f core conftest.err conftest.$ac_objext conftest.beam \
     conftest$ac_exeext
-  if ${ac_cv_search_getnameinfo+:} false; then :
+  if test ${ac_cv_search_getnameinfo+y}
+then :
   break
 fi
 done
-if ${ac_cv_search_getnameinfo+:} false; then :
+if test ${ac_cv_search_getnameinfo+y}
+then :
 
-else
+else $as_nop
   ac_cv_search_getnameinfo=no
 fi
 rm conftest.$ac_ext
 LIBS=$ac_func_search_save_LIBS
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_search_getnameinfo" >&5
-$as_echo "$ac_cv_search_getnameinfo" >&6; }
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_search_getnameinfo" >&5
+printf "%s\n" "$ac_cv_search_getnameinfo" >&6; }
 ac_res=$ac_cv_search_getnameinfo
-if test "$ac_res" != no; then :
+if test "$ac_res" != no
+then :
   test "$ac_res" = "none required" || LIBS="$ac_res $LIBS"
-  $as_echo "#define HAVE_GETNAMEINFO 1" >>confdefs.h
+  printf "%s\n" "#define HAVE_GETNAMEINFO 1" >>confdefs.h
 
 fi
 
@@ -7562,25 +8330,27 @@ fi
 
 ac_fn_c_check_member "$LINENO" "struct sockaddr" "sa_len" "ac_cv_member_struct_sockaddr_sa_len" "#include <sys/socket.h>
 "
-if test "x$ac_cv_member_struct_sockaddr_sa_len" = xyes; then :
+if test "x$ac_cv_member_struct_sockaddr_sa_len" = xyes
+then :
 
 fi
 
-ac_fn_c_check_header_mongrel "$LINENO" "sys/sockio.h" "ac_cv_header_sys_sockio_h" "$ac_includes_default"
-if test "x$ac_cv_header_sys_sockio_h" = xyes; then :
-  $as_echo "#define HAVE_SYS_SOCKIO_H 1" >>confdefs.h
+ac_fn_c_check_header_compile "$LINENO" "sys/sockio.h" "ac_cv_header_sys_sockio_h" "$ac_includes_default"
+if test "x$ac_cv_header_sys_sockio_h" = xyes
+then :
+  printf "%s\n" "#define HAVE_SYS_SOCKIO_H 1" >>confdefs.h
 
 fi
 
 
-
 CUPS_DEFAULT_DOMAINSOCKET=""
 
 
 # Check whether --with-domainsocket was given.
-if test "${with_domainsocket+set}" = set; then :
+if test ${with_domainsocket+y}
+then :
   withval=$with_domainsocket; default_domainsocket="$withval"
-else
+else $as_nop
   default_domainsocket=""
 fi
 
@@ -7603,9 +8373,7 @@ if test x$enable_domainsocket != xno -a
 
 	CUPS_LISTEN_DOMAINSOCKET="Listen $CUPS_DEFAULT_DOMAINSOCKET"
 
-	cat >>confdefs.h <<_ACEOF
-#define CUPS_DEFAULT_DOMAINSOCKET "$CUPS_DEFAULT_DOMAINSOCKET"
-_ACEOF
+	printf "%s\n" "#define CUPS_DEFAULT_DOMAINSOCKET \"$CUPS_DEFAULT_DOMAINSOCKET\"" >>confdefs.h
 
 else
 	CUPS_LISTEN_DOMAINSOCKET=""
@@ -7616,27 +8384,31 @@ fi
 
 
 ac_fn_c_check_func "$LINENO" "poll" "ac_cv_func_poll"
-if test "x$ac_cv_func_poll" = xyes; then :
-  $as_echo "#define HAVE_POLL 1" >>confdefs.h
+if test "x$ac_cv_func_poll" = xyes
+then :
+  printf "%s\n" "#define HAVE_POLL 1" >>confdefs.h
 
 fi
 
 ac_fn_c_check_func "$LINENO" "epoll_create" "ac_cv_func_epoll_create"
-if test "x$ac_cv_func_epoll_create" = xyes; then :
-  $as_echo "#define HAVE_EPOLL 1" >>confdefs.h
+if test "x$ac_cv_func_epoll_create" = xyes
+then :
+  printf "%s\n" "#define HAVE_EPOLL 1" >>confdefs.h
 
 fi
 
 ac_fn_c_check_func "$LINENO" "kqueue" "ac_cv_func_kqueue"
-if test "x$ac_cv_func_kqueue" = xyes; then :
-  $as_echo "#define HAVE_KQUEUE 1" >>confdefs.h
+if test "x$ac_cv_func_kqueue" = xyes
+then :
+  printf "%s\n" "#define HAVE_KQUEUE 1" >>confdefs.h
 
 fi
 
 
 
 # Check whether --enable-gssapi was given.
-if test "${enable_gssapi+set}" = set; then :
+if test ${enable_gssapi+y}
+then :
   enableval=$enable_gssapi;
 fi
 
@@ -7648,11 +8420,12 @@ if test x$enable_gssapi != xno; then
 	if test -n "$ac_tool_prefix"; then
   # Extract the first word of "${ac_tool_prefix}krb5-config", so it can be a program name with args.
 set dummy ${ac_tool_prefix}krb5-config; ac_word=$2
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
-$as_echo_n "checking for $ac_word... " >&6; }
-if ${ac_cv_path_KRB5CONFIG+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
+printf %s "checking for $ac_word... " >&6; }
+if test ${ac_cv_path_KRB5CONFIG+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   case $KRB5CONFIG in
   [\\/]* | ?:[\\/]*)
   ac_cv_path_KRB5CONFIG="$KRB5CONFIG" # Let the user override the test with a path.
@@ -7662,11 +8435,15 @@ else
 for as_dir in $PATH
 do
   IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
+  case $as_dir in #(((
+    '') as_dir=./ ;;
+    */) ;;
+    *) as_dir=$as_dir/ ;;
+  esac
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
-    ac_cv_path_KRB5CONFIG="$as_dir/$ac_word$ac_exec_ext"
-    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
+  if as_fn_executable_p "$as_dir$ac_word$ac_exec_ext"; then
+    ac_cv_path_KRB5CONFIG="$as_dir$ac_word$ac_exec_ext"
+    printf "%s\n" "$as_me:${as_lineno-$LINENO}: found $as_dir$ac_word$ac_exec_ext" >&5
     break 2
   fi
 done
@@ -7678,11 +8455,11 @@ esac
 fi
 KRB5CONFIG=$ac_cv_path_KRB5CONFIG
 if test -n "$KRB5CONFIG"; then
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $KRB5CONFIG" >&5
-$as_echo "$KRB5CONFIG" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $KRB5CONFIG" >&5
+printf "%s\n" "$KRB5CONFIG" >&6; }
 else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: no" >&5
+printf "%s\n" "no" >&6; }
 fi
 
 
@@ -7691,11 +8468,12 @@ if test -z "$ac_cv_path_KRB5CONFIG"; the
   ac_pt_KRB5CONFIG=$KRB5CONFIG
   # Extract the first word of "krb5-config", so it can be a program name with args.
 set dummy krb5-config; ac_word=$2
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
-$as_echo_n "checking for $ac_word... " >&6; }
-if ${ac_cv_path_ac_pt_KRB5CONFIG+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
+printf %s "checking for $ac_word... " >&6; }
+if test ${ac_cv_path_ac_pt_KRB5CONFIG+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   case $ac_pt_KRB5CONFIG in
   [\\/]* | ?:[\\/]*)
   ac_cv_path_ac_pt_KRB5CONFIG="$ac_pt_KRB5CONFIG" # Let the user override the test with a path.
@@ -7705,11 +8483,15 @@ else
 for as_dir in $PATH
 do
   IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
+  case $as_dir in #(((
+    '') as_dir=./ ;;
+    */) ;;
+    *) as_dir=$as_dir/ ;;
+  esac
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
-    ac_cv_path_ac_pt_KRB5CONFIG="$as_dir/$ac_word$ac_exec_ext"
-    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
+  if as_fn_executable_p "$as_dir$ac_word$ac_exec_ext"; then
+    ac_cv_path_ac_pt_KRB5CONFIG="$as_dir$ac_word$ac_exec_ext"
+    printf "%s\n" "$as_me:${as_lineno-$LINENO}: found $as_dir$ac_word$ac_exec_ext" >&5
     break 2
   fi
 done
@@ -7721,11 +8503,11 @@ esac
 fi
 ac_pt_KRB5CONFIG=$ac_cv_path_ac_pt_KRB5CONFIG
 if test -n "$ac_pt_KRB5CONFIG"; then
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_pt_KRB5CONFIG" >&5
-$as_echo "$ac_pt_KRB5CONFIG" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_pt_KRB5CONFIG" >&5
+printf "%s\n" "$ac_pt_KRB5CONFIG" >&6; }
 else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: no" >&5
+printf "%s\n" "no" >&6; }
 fi
 
   if test "x$ac_pt_KRB5CONFIG" = x; then
@@ -7733,8 +8515,8 @@ fi
   else
     case $cross_compiling:$ac_tool_warned in
 yes:)
-{ $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: using cross tools not prefixed with host triplet" >&5
-$as_echo "$as_me: WARNING: using cross tools not prefixed with host triplet" >&2;}
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: WARNING: using cross tools not prefixed with host triplet" >&5
+printf "%s\n" "$as_me: WARNING: using cross tools not prefixed with host triplet" >&2;}
 ac_tool_warned=yes ;;
 esac
     KRB5CONFIG=$ac_pt_KRB5CONFIG
@@ -7748,24 +8530,25 @@ fi
 			darwin)
 				# macOS weak-links to the Kerberos framework...
 				LIBGSSAPI="-weak_framework Kerberos"
-				{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for GSS framework" >&5
-$as_echo_n "checking for GSS framework... " >&6; }
+				{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for GSS framework" >&5
+printf %s "checking for GSS framework... " >&6; }
 				if test -d /System/Library/Frameworks/GSS.framework; then
-					{ $as_echo "$as_me:${as_lineno-$LINENO}: result: yes" >&5
-$as_echo "yes" >&6; }
+					{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: yes" >&5
+printf "%s\n" "yes" >&6; }
 					LIBGSSAPI="$LIBGSSAPI -weak_framework GSS"
 				else
-					{ $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
+					{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: no" >&5
+printf "%s\n" "no" >&6; }
 				fi
 				;;
 			sunos*)
 				# Solaris has a non-standard krb5-config, don't use it!
-				{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for gss_display_status in -lgss" >&5
-$as_echo_n "checking for gss_display_status in -lgss... " >&6; }
-if ${ac_cv_lib_gss_gss_display_status+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+				{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for gss_display_status in -lgss" >&5
+printf %s "checking for gss_display_status in -lgss... " >&6; }
+if test ${ac_cv_lib_gss_gss_display_status+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lgss  $LIBS"
 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
@@ -7774,32 +8557,31 @@ cat confdefs.h - <<_ACEOF >conftest.$ac_
 /* Override any GCC internal prototype to avoid an error.
    Use char because int might match the return type of a GCC
    builtin and then its argument prototype would still apply.  */
-#ifdef __cplusplus
-extern "C"
-#endif
 char gss_display_status ();
 int
-main ()
+main (void)
 {
 return gss_display_status ();
   ;
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
+if ac_fn_c_try_link "$LINENO"
+then :
   ac_cv_lib_gss_gss_display_status=yes
-else
+else $as_nop
   ac_cv_lib_gss_gss_display_status=no
 fi
-rm -f core conftest.err conftest.$ac_objext \
+rm -f core conftest.err conftest.$ac_objext conftest.beam \
     conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_lib_gss_gss_display_status" >&5
-$as_echo "$ac_cv_lib_gss_gss_display_status" >&6; }
-if test "x$ac_cv_lib_gss_gss_display_status" = xyes; then :
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_lib_gss_gss_display_status" >&5
+printf "%s\n" "$ac_cv_lib_gss_gss_display_status" >&6; }
+if test "x$ac_cv_lib_gss_gss_display_status" = xyes
+then :
 
-$as_echo "#define HAVE_GSSAPI 1" >>confdefs.h
+printf "%s\n" "#define HAVE_GSSAPI 1" >>confdefs.h
 
 					CFLAGS="`$KRB5CONFIG --cflags` $CFLAGS"
 					CPPFLAGS="`$KRB5CONFIG --cflags` $CPPFLAGS"
@@ -7815,17 +8597,18 @@ fi
 				;;
 		esac
 
-$as_echo "#define HAVE_GSSAPI 1" >>confdefs.h
+printf "%s\n" "#define HAVE_GSSAPI 1" >>confdefs.h
 
 	else
 		# Check for vendor-specific implementations...
 		case "$host_os_name" in
 			hp-ux*)
-				{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for gss_display_status in -lgss" >&5
-$as_echo_n "checking for gss_display_status in -lgss... " >&6; }
-if ${ac_cv_lib_gss_gss_display_status+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+				{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for gss_display_status in -lgss" >&5
+printf %s "checking for gss_display_status in -lgss... " >&6; }
+if test ${ac_cv_lib_gss_gss_display_status+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lgss  $LIBS"
 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
@@ -7834,43 +8617,43 @@ cat confdefs.h - <<_ACEOF >conftest.$ac_
 /* Override any GCC internal prototype to avoid an error.
    Use char because int might match the return type of a GCC
    builtin and then its argument prototype would still apply.  */
-#ifdef __cplusplus
-extern "C"
-#endif
 char gss_display_status ();
 int
-main ()
+main (void)
 {
 return gss_display_status ();
   ;
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
+if ac_fn_c_try_link "$LINENO"
+then :
   ac_cv_lib_gss_gss_display_status=yes
-else
+else $as_nop
   ac_cv_lib_gss_gss_display_status=no
 fi
-rm -f core conftest.err conftest.$ac_objext \
+rm -f core conftest.err conftest.$ac_objext conftest.beam \
     conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_lib_gss_gss_display_status" >&5
-$as_echo "$ac_cv_lib_gss_gss_display_status" >&6; }
-if test "x$ac_cv_lib_gss_gss_display_status" = xyes; then :
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_lib_gss_gss_display_status" >&5
+printf "%s\n" "$ac_cv_lib_gss_gss_display_status" >&6; }
+if test "x$ac_cv_lib_gss_gss_display_status" = xyes
+then :
 
-$as_echo "#define HAVE_GSSAPI 1" >>confdefs.h
+printf "%s\n" "#define HAVE_GSSAPI 1" >>confdefs.h
 
 					LIBGSSAPI="-lgss -lgssapi_krb5"
 fi
 
 				;;
 			sunos*)
-				{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for gss_display_status in -lgss" >&5
-$as_echo_n "checking for gss_display_status in -lgss... " >&6; }
-if ${ac_cv_lib_gss_gss_display_status+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+				{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for gss_display_status in -lgss" >&5
+printf %s "checking for gss_display_status in -lgss... " >&6; }
+if test ${ac_cv_lib_gss_gss_display_status+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lgss  $LIBS"
 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
@@ -7879,32 +8662,31 @@ cat confdefs.h - <<_ACEOF >conftest.$ac_
 /* Override any GCC internal prototype to avoid an error.
    Use char because int might match the return type of a GCC
    builtin and then its argument prototype would still apply.  */
-#ifdef __cplusplus
-extern "C"
-#endif
 char gss_display_status ();
 int
-main ()
+main (void)
 {
 return gss_display_status ();
   ;
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
+if ac_fn_c_try_link "$LINENO"
+then :
   ac_cv_lib_gss_gss_display_status=yes
-else
+else $as_nop
   ac_cv_lib_gss_gss_display_status=no
 fi
-rm -f core conftest.err conftest.$ac_objext \
+rm -f core conftest.err conftest.$ac_objext conftest.beam \
     conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_lib_gss_gss_display_status" >&5
-$as_echo "$ac_cv_lib_gss_gss_display_status" >&6; }
-if test "x$ac_cv_lib_gss_gss_display_status" = xyes; then :
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_lib_gss_gss_display_status" >&5
+printf "%s\n" "$ac_cv_lib_gss_gss_display_status" >&6; }
+if test "x$ac_cv_lib_gss_gss_display_status" = xyes
+then :
 
-$as_echo "#define HAVE_GSSAPI 1" >>confdefs.h
+printf "%s\n" "#define HAVE_GSSAPI 1" >>confdefs.h
 
 					LIBGSSAPI="-lgss"
 fi
@@ -7914,130 +8696,134 @@ fi
 	fi
 
 	if test "x$LIBGSSAPI" != x; then
-		ac_fn_c_check_header_mongrel "$LINENO" "krb5.h" "ac_cv_header_krb5_h" "$ac_includes_default"
-if test "x$ac_cv_header_krb5_h" = xyes; then :
-  $as_echo "#define HAVE_KRB5_H 1" >>confdefs.h
+		ac_fn_c_check_header_compile "$LINENO" "krb5.h" "ac_cv_header_krb5_h" "$ac_includes_default"
+if test "x$ac_cv_header_krb5_h" = xyes
+then :
+  printf "%s\n" "#define HAVE_KRB5_H 1" >>confdefs.h
 
 fi
 
-
 		if test -d /System/Library/Frameworks/GSS.framework; then
-			ac_fn_c_check_header_mongrel "$LINENO" "GSS/gssapi.h" "ac_cv_header_GSS_gssapi_h" "$ac_includes_default"
-if test "x$ac_cv_header_GSS_gssapi_h" = xyes; then :
-  $as_echo "#define HAVE_GSS_GSSAPI_H 1" >>confdefs.h
+			ac_fn_c_check_header_compile "$LINENO" "GSS/gssapi.h" "ac_cv_header_GSS_gssapi_h" "$ac_includes_default"
+if test "x$ac_cv_header_GSS_gssapi_h" = xyes
+then :
+  printf "%s\n" "#define HAVE_GSS_GSSAPI_H 1" >>confdefs.h
 
 fi
 
-
-			ac_fn_c_check_header_mongrel "$LINENO" "GSS/gssapi_generic.h" "ac_cv_header_GSS_gssapi_generic_h" "$ac_includes_default"
-if test "x$ac_cv_header_GSS_gssapi_generic_h" = xyes; then :
-  $as_echo "#define HAVE_GSS_GSSAPI_GENERIC_H 1" >>confdefs.h
+			ac_fn_c_check_header_compile "$LINENO" "GSS/gssapi_generic.h" "ac_cv_header_GSS_gssapi_generic_h" "$ac_includes_default"
+if test "x$ac_cv_header_GSS_gssapi_generic_h" = xyes
+then :
+  printf "%s\n" "#define HAVE_GSS_GSSAPI_GENERIC_H 1" >>confdefs.h
 
 fi
 
-
-			ac_fn_c_check_header_mongrel "$LINENO" "GSS/gssapi_spi.h" "ac_cv_header_GSS_gssapi_spi_h" "$ac_includes_default"
-if test "x$ac_cv_header_GSS_gssapi_spi_h" = xyes; then :
-  $as_echo "#define HAVE_GSS_GSSAPI_SPI_H 1" >>confdefs.h
+			ac_fn_c_check_header_compile "$LINENO" "GSS/gssapi_spi.h" "ac_cv_header_GSS_gssapi_spi_h" "$ac_includes_default"
+if test "x$ac_cv_header_GSS_gssapi_spi_h" = xyes
+then :
+  printf "%s\n" "#define HAVE_GSS_GSSAPI_SPI_H 1" >>confdefs.h
 
 fi
 
-
 		else
-			ac_fn_c_check_header_mongrel "$LINENO" "gssapi.h" "ac_cv_header_gssapi_h" "$ac_includes_default"
-if test "x$ac_cv_header_gssapi_h" = xyes; then :
-  $as_echo "#define HAVE_GSSAPI_H 1" >>confdefs.h
+			ac_fn_c_check_header_compile "$LINENO" "gssapi.h" "ac_cv_header_gssapi_h" "$ac_includes_default"
+if test "x$ac_cv_header_gssapi_h" = xyes
+then :
+  printf "%s\n" "#define HAVE_GSSAPI_H 1" >>confdefs.h
 
 fi
 
-
-			ac_fn_c_check_header_mongrel "$LINENO" "gssapi/gssapi.h" "ac_cv_header_gssapi_gssapi_h" "$ac_includes_default"
-if test "x$ac_cv_header_gssapi_gssapi_h" = xyes; then :
-  $as_echo "#define HAVE_GSSAPI_GSSAPI_H 1" >>confdefs.h
+			ac_fn_c_check_header_compile "$LINENO" "gssapi/gssapi.h" "ac_cv_header_gssapi_gssapi_h" "$ac_includes_default"
+if test "x$ac_cv_header_gssapi_gssapi_h" = xyes
+then :
+  printf "%s\n" "#define HAVE_GSSAPI_GSSAPI_H 1" >>confdefs.h
 
 fi
 
-
 		fi
 
 		SAVELIBS="$LIBS"
 		LIBS="$LIBS $LIBGSSAPI"
 
 		ac_fn_c_check_func "$LINENO" "__ApplePrivate_gss_acquire_cred_ex_f" "ac_cv_func___ApplePrivate_gss_acquire_cred_ex_f"
-if test "x$ac_cv_func___ApplePrivate_gss_acquire_cred_ex_f" = xyes; then :
-  $as_echo "#define HAVE_GSS_ACQUIRE_CRED_EX_F 1" >>confdefs.h
+if test "x$ac_cv_func___ApplePrivate_gss_acquire_cred_ex_f" = xyes
+then :
+  printf "%s\n" "#define HAVE_GSS_ACQUIRE_CRED_EX_F 1" >>confdefs.h
 
 fi
 
 
-		{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for GSS_C_NT_HOSTBASED_SERVICE" >&5
-$as_echo_n "checking for GSS_C_NT_HOSTBASED_SERVICE... " >&6; }
+		{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for GSS_C_NT_HOSTBASED_SERVICE" >&5
+printf %s "checking for GSS_C_NT_HOSTBASED_SERVICE... " >&6; }
 		if test x$ac_cv_header_gssapi_gssapi_h = xyes; then
 			cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
  #include <gssapi/gssapi.h>
 int
-main ()
+main (void)
 {
  gss_OID foo = GSS_C_NT_HOSTBASED_SERVICE;
   ;
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_compile "$LINENO"; then :
-  $as_echo "#define HAVE_GSS_C_NT_HOSTBASED_SERVICE 1" >>confdefs.h
-
-				       { $as_echo "$as_me:${as_lineno-$LINENO}: result: yes" >&5
-$as_echo "yes" >&6; }
-else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
+if ac_fn_c_try_compile "$LINENO"
+then :
+  printf "%s\n" "#define HAVE_GSS_C_NT_HOSTBASED_SERVICE 1" >>confdefs.h
+
+				       { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: yes" >&5
+printf "%s\n" "yes" >&6; }
+else $as_nop
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: no" >&5
+printf "%s\n" "no" >&6; }
 fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
+rm -f core conftest.err conftest.$ac_objext conftest.beam conftest.$ac_ext
 		elif test x$ac_cv_header_gss_gssapi_h = xyes; then
 			cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
  #include <GSS/gssapi.h>
 int
-main ()
+main (void)
 {
  gss_OID foo = GSS_C_NT_HOSTBASED_SERVICE;
   ;
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_compile "$LINENO"; then :
-  $as_echo "#define HAVE_GSS_C_NT_HOSTBASED_SERVICE 1" >>confdefs.h
-
-				       { $as_echo "$as_me:${as_lineno-$LINENO}: result: yes" >&5
-$as_echo "yes" >&6; }
-else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
+if ac_fn_c_try_compile "$LINENO"
+then :
+  printf "%s\n" "#define HAVE_GSS_C_NT_HOSTBASED_SERVICE 1" >>confdefs.h
+
+				       { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: yes" >&5
+printf "%s\n" "yes" >&6; }
+else $as_nop
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: no" >&5
+printf "%s\n" "no" >&6; }
 fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
+rm -f core conftest.err conftest.$ac_objext conftest.beam conftest.$ac_ext
 		else
 			cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
  #include <gssapi.h>
 int
-main ()
+main (void)
 {
  gss_OID foo = GSS_C_NT_HOSTBASED_SERVICE;
   ;
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_compile "$LINENO"; then :
-  $as_echo "#define HAVE_GSS_C_NT_HOSTBASED_SERVICE 1" >>confdefs.h
-
-				       { $as_echo "$as_me:${as_lineno-$LINENO}: result: yes" >&5
-$as_echo "yes" >&6; }
-else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
+if ac_fn_c_try_compile "$LINENO"
+then :
+  printf "%s\n" "#define HAVE_GSS_C_NT_HOSTBASED_SERVICE 1" >>confdefs.h
+
+				       { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: yes" >&5
+printf "%s\n" "yes" >&6; }
+else $as_nop
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: no" >&5
+printf "%s\n" "no" >&6; }
 fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
+rm -f core conftest.err conftest.$ac_objext conftest.beam conftest.$ac_ext
 		fi
 
 		LIBS="$SAVELIBS"
@@ -8046,9 +8832,10 @@ fi
 
 
 # Check whether --with-gssservicename was given.
-if test "${with_gssservicename+set}" = set; then :
+if test ${with_gssservicename+y}
+then :
   withval=$with_gssservicename; default_gssservicename="$withval"
-else
+else $as_nop
   default_gssservicename="default"
 fi
 
@@ -8064,14 +8851,13 @@ else
 fi
 
 
-cat >>confdefs.h <<_ACEOF
-#define CUPS_DEFAULT_GSSSERVICENAME "$CUPS_DEFAULT_GSSSERVICENAME"
-_ACEOF
+printf "%s\n" "#define CUPS_DEFAULT_GSSSERVICENAME \"$CUPS_DEFAULT_GSSSERVICENAME\"" >>confdefs.h
 
 
 
 # Check whether --enable-threads was given.
-if test "${enable_threads+set}" = set; then :
+if test ${enable_threads+y}
+then :
   enableval=$enable_threads;
 fi
 
@@ -8080,40 +8866,41 @@ have_pthread=no
 PTHREAD_FLAGS=""
 
 if test "x$enable_threads" != xno; then
-	ac_fn_c_check_header_mongrel "$LINENO" "pthread.h" "ac_cv_header_pthread_h" "$ac_includes_default"
-if test "x$ac_cv_header_pthread_h" = xyes; then :
-  $as_echo "#define HAVE_PTHREAD_H 1" >>confdefs.h
+	ac_fn_c_check_header_compile "$LINENO" "pthread.h" "ac_cv_header_pthread_h" "$ac_includes_default"
+if test "x$ac_cv_header_pthread_h" = xyes
+then :
+  printf "%s\n" "#define HAVE_PTHREAD_H 1" >>confdefs.h
 
 fi
 
 
-
 	if test x$ac_cv_header_pthread_h = xyes; then
 				for flag in -lpthreads -lpthread -pthread; do
-        		{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for pthread_create using $flag" >&5
-$as_echo_n "checking for pthread_create using $flag... " >&6; }
+        		{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for pthread_create using $flag" >&5
+printf %s "checking for pthread_create using $flag... " >&6; }
 			SAVELIBS="$LIBS"
 			LIBS="$flag $LIBS"
         		cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
 #include <pthread.h>
 int
-main ()
+main (void)
 {
 pthread_create(0, 0, 0, 0);
   ;
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
+if ac_fn_c_try_link "$LINENO"
+then :
   have_pthread=yes
-else
+else $as_nop
   LIBS="$SAVELIBS"
 fi
-rm -f core conftest.err conftest.$ac_objext \
+rm -f core conftest.err conftest.$ac_objext conftest.beam \
     conftest$ac_exeext conftest.$ac_ext
-        		{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $have_pthread" >&5
-$as_echo "$have_pthread" >&6; }
+        		{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $have_pthread" >&5
+printf "%s\n" "$have_pthread" >&6; }
 
 			if test $have_pthread = yes; then
 				PTHREAD_FLAGS="-D_THREAD_SAFE -D_REENTRANT"
@@ -8133,17 +8920,20 @@ fi
 
 
 # Check whether --enable-ssl was given.
-if test "${enable_ssl+set}" = set; then :
+if test ${enable_ssl+y}
+then :
   enableval=$enable_ssl;
 fi
 
 # Check whether --enable-cdsassl was given.
-if test "${enable_cdsassl+set}" = set; then :
+if test ${enable_cdsassl+y}
+then :
   enableval=$enable_cdsassl;
 fi
 
 # Check whether --enable-gnutls was given.
-if test "${enable_gnutls+set}" = set; then :
+if test ${enable_gnutls+y}
+then :
   enableval=$enable_gnutls;
 fi
 
@@ -8156,40 +8946,40 @@ CUPS_SERVERKEYCHAIN=""
 if test x$enable_ssl != xno; then
         if test $have_ssl = 0 -a "x$enable_cdsassl" != "xno"; then
 	if test $host_os_name = darwin; then
-	    ac_fn_c_check_header_mongrel "$LINENO" "Security/SecureTransport.h" "ac_cv_header_Security_SecureTransport_h" "$ac_includes_default"
-if test "x$ac_cv_header_Security_SecureTransport_h" = xyes; then :
+	    ac_fn_c_check_header_compile "$LINENO" "Security/SecureTransport.h" "ac_cv_header_Security_SecureTransport_h" "$ac_includes_default"
+if test "x$ac_cv_header_Security_SecureTransport_h" = xyes
+then :
 
 	    	have_ssl=1
-		$as_echo "#define HAVE_SSL 1" >>confdefs.h
+		printf "%s\n" "#define HAVE_SSL 1" >>confdefs.h
 
-		$as_echo "#define HAVE_CDSASSL 1" >>confdefs.h
+		printf "%s\n" "#define HAVE_CDSASSL 1" >>confdefs.h
 
 		CUPS_SERVERKEYCHAIN="/Library/Keychains/System.keychain"
 
-				ac_fn_c_check_header_mongrel "$LINENO" "Security/SecCertificate.h" "ac_cv_header_Security_SecCertificate_h" "$ac_includes_default"
-if test "x$ac_cv_header_Security_SecCertificate_h" = xyes; then :
-  $as_echo "#define HAVE_SECCERTIFICATE_H 1" >>confdefs.h
+				ac_fn_c_check_header_compile "$LINENO" "Security/SecCertificate.h" "ac_cv_header_Security_SecCertificate_h" "$ac_includes_default"
+if test "x$ac_cv_header_Security_SecCertificate_h" = xyes
+then :
+  printf "%s\n" "#define HAVE_SECCERTIFICATE_H 1" >>confdefs.h
 
 fi
 
-
-		ac_fn_c_check_header_mongrel "$LINENO" "Security/SecItem.h" "ac_cv_header_Security_SecItem_h" "$ac_includes_default"
-if test "x$ac_cv_header_Security_SecItem_h" = xyes; then :
-  $as_echo "#define HAVE_SECITEM_H 1" >>confdefs.h
+		ac_fn_c_check_header_compile "$LINENO" "Security/SecItem.h" "ac_cv_header_Security_SecItem_h" "$ac_includes_default"
+if test "x$ac_cv_header_Security_SecItem_h" = xyes
+then :
+  printf "%s\n" "#define HAVE_SECITEM_H 1" >>confdefs.h
 
 fi
 
-
-		ac_fn_c_check_header_mongrel "$LINENO" "Security/SecPolicy.h" "ac_cv_header_Security_SecPolicy_h" "$ac_includes_default"
-if test "x$ac_cv_header_Security_SecPolicy_h" = xyes; then :
-  $as_echo "#define HAVE_SECPOLICY_H 1" >>confdefs.h
+		ac_fn_c_check_header_compile "$LINENO" "Security/SecPolicy.h" "ac_cv_header_Security_SecPolicy_h" "$ac_includes_default"
+if test "x$ac_cv_header_Security_SecPolicy_h" = xyes
+then :
+  printf "%s\n" "#define HAVE_SECPOLICY_H 1" >>confdefs.h
 
 fi
 
-
 fi
 
-
 	fi
     fi
 
@@ -8197,11 +8987,12 @@ fi
     	if test -n "$ac_tool_prefix"; then
   # Extract the first word of "${ac_tool_prefix}libgnutls-config", so it can be a program name with args.
 set dummy ${ac_tool_prefix}libgnutls-config; ac_word=$2
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
-$as_echo_n "checking for $ac_word... " >&6; }
-if ${ac_cv_path_LIBGNUTLSCONFIG+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
+printf %s "checking for $ac_word... " >&6; }
+if test ${ac_cv_path_LIBGNUTLSCONFIG+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   case $LIBGNUTLSCONFIG in
   [\\/]* | ?:[\\/]*)
   ac_cv_path_LIBGNUTLSCONFIG="$LIBGNUTLSCONFIG" # Let the user override the test with a path.
@@ -8211,11 +9002,15 @@ else
 for as_dir in $PATH
 do
   IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
+  case $as_dir in #(((
+    '') as_dir=./ ;;
+    */) ;;
+    *) as_dir=$as_dir/ ;;
+  esac
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
-    ac_cv_path_LIBGNUTLSCONFIG="$as_dir/$ac_word$ac_exec_ext"
-    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
+  if as_fn_executable_p "$as_dir$ac_word$ac_exec_ext"; then
+    ac_cv_path_LIBGNUTLSCONFIG="$as_dir$ac_word$ac_exec_ext"
+    printf "%s\n" "$as_me:${as_lineno-$LINENO}: found $as_dir$ac_word$ac_exec_ext" >&5
     break 2
   fi
 done
@@ -8227,11 +9022,11 @@ esac
 fi
 LIBGNUTLSCONFIG=$ac_cv_path_LIBGNUTLSCONFIG
 if test -n "$LIBGNUTLSCONFIG"; then
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $LIBGNUTLSCONFIG" >&5
-$as_echo "$LIBGNUTLSCONFIG" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $LIBGNUTLSCONFIG" >&5
+printf "%s\n" "$LIBGNUTLSCONFIG" >&6; }
 else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: no" >&5
+printf "%s\n" "no" >&6; }
 fi
 
 
@@ -8240,11 +9035,12 @@ if test -z "$ac_cv_path_LIBGNUTLSCONFIG"
   ac_pt_LIBGNUTLSCONFIG=$LIBGNUTLSCONFIG
   # Extract the first word of "libgnutls-config", so it can be a program name with args.
 set dummy libgnutls-config; ac_word=$2
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
-$as_echo_n "checking for $ac_word... " >&6; }
-if ${ac_cv_path_ac_pt_LIBGNUTLSCONFIG+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
+printf %s "checking for $ac_word... " >&6; }
+if test ${ac_cv_path_ac_pt_LIBGNUTLSCONFIG+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   case $ac_pt_LIBGNUTLSCONFIG in
   [\\/]* | ?:[\\/]*)
   ac_cv_path_ac_pt_LIBGNUTLSCONFIG="$ac_pt_LIBGNUTLSCONFIG" # Let the user override the test with a path.
@@ -8254,11 +9050,15 @@ else
 for as_dir in $PATH
 do
   IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
+  case $as_dir in #(((
+    '') as_dir=./ ;;
+    */) ;;
+    *) as_dir=$as_dir/ ;;
+  esac
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
-    ac_cv_path_ac_pt_LIBGNUTLSCONFIG="$as_dir/$ac_word$ac_exec_ext"
-    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
+  if as_fn_executable_p "$as_dir$ac_word$ac_exec_ext"; then
+    ac_cv_path_ac_pt_LIBGNUTLSCONFIG="$as_dir$ac_word$ac_exec_ext"
+    printf "%s\n" "$as_me:${as_lineno-$LINENO}: found $as_dir$ac_word$ac_exec_ext" >&5
     break 2
   fi
 done
@@ -8270,11 +9070,11 @@ esac
 fi
 ac_pt_LIBGNUTLSCONFIG=$ac_cv_path_ac_pt_LIBGNUTLSCONFIG
 if test -n "$ac_pt_LIBGNUTLSCONFIG"; then
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_pt_LIBGNUTLSCONFIG" >&5
-$as_echo "$ac_pt_LIBGNUTLSCONFIG" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_pt_LIBGNUTLSCONFIG" >&5
+printf "%s\n" "$ac_pt_LIBGNUTLSCONFIG" >&6; }
 else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: no" >&5
+printf "%s\n" "no" >&6; }
 fi
 
   if test "x$ac_pt_LIBGNUTLSCONFIG" = x; then
@@ -8282,8 +9082,8 @@ fi
   else
     case $cross_compiling:$ac_tool_warned in
 yes:)
-{ $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: using cross tools not prefixed with host triplet" >&5
-$as_echo "$as_me: WARNING: using cross tools not prefixed with host triplet" >&2;}
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: WARNING: using cross tools not prefixed with host triplet" >&5
+printf "%s\n" "$as_me: WARNING: using cross tools not prefixed with host triplet" >&2;}
 ac_tool_warned=yes ;;
 esac
     LIBGNUTLSCONFIG=$ac_pt_LIBGNUTLSCONFIG
@@ -8296,17 +9096,17 @@ fi
 	    have_ssl=1
 	    SSLLIBS=`$PKGCONFIG --libs gnutls`
 	    SSLFLAGS=`$PKGCONFIG --cflags gnutls`
-	    $as_echo "#define HAVE_SSL 1" >>confdefs.h
+	    printf "%s\n" "#define HAVE_SSL 1" >>confdefs.h
 
-	    $as_echo "#define HAVE_GNUTLS 1" >>confdefs.h
+	    printf "%s\n" "#define HAVE_GNUTLS 1" >>confdefs.h
 
 	elif test "x$LIBGNUTLSCONFIG" != x; then
 	    have_ssl=1
 	    SSLLIBS=`$LIBGNUTLSCONFIG --libs`
 	    SSLFLAGS=`$LIBGNUTLSCONFIG --cflags`
-	    $as_echo "#define HAVE_SSL 1" >>confdefs.h
+	    printf "%s\n" "#define HAVE_SSL 1" >>confdefs.h
 
-	    $as_echo "#define HAVE_GNUTLS 1" >>confdefs.h
+	    printf "%s\n" "#define HAVE_GNUTLS 1" >>confdefs.h
 
 	fi
 
@@ -8316,14 +9116,16 @@ fi
 	    SAVELIBS="$LIBS"
 	    LIBS="$LIBS $SSLLIBS"
 	    ac_fn_c_check_func "$LINENO" "gnutls_transport_set_pull_timeout_function" "ac_cv_func_gnutls_transport_set_pull_timeout_function"
-if test "x$ac_cv_func_gnutls_transport_set_pull_timeout_function" = xyes; then :
-  $as_echo "#define HAVE_GNUTLS_TRANSPORT_SET_PULL_TIMEOUT_FUNCTION 1" >>confdefs.h
+if test "x$ac_cv_func_gnutls_transport_set_pull_timeout_function" = xyes
+then :
+  printf "%s\n" "#define HAVE_GNUTLS_TRANSPORT_SET_PULL_TIMEOUT_FUNCTION 1" >>confdefs.h
 
 fi
 
 	    ac_fn_c_check_func "$LINENO" "gnutls_priority_set_direct" "ac_cv_func_gnutls_priority_set_direct"
-if test "x$ac_cv_func_gnutls_priority_set_direct" = xyes; then :
-  $as_echo "#define HAVE_GNUTLS_PRIORITY_SET_DIRECT 1" >>confdefs.h
+if test "x$ac_cv_func_gnutls_priority_set_direct" = xyes
+then :
+  printf "%s\n" "#define HAVE_GNUTLS_PRIORITY_SET_DIRECT 1" >>confdefs.h
 
 fi
 
@@ -8334,10 +9136,10 @@ fi
 
 IPPALIASES="http"
 if test $have_ssl = 1; then
-    { $as_echo "$as_me:${as_lineno-$LINENO}: result:     Using SSLLIBS=\"$SSLLIBS\"" >&5
-$as_echo "    Using SSLLIBS=\"$SSLLIBS\"" >&6; }
-    { $as_echo "$as_me:${as_lineno-$LINENO}: result:     Using SSLFLAGS=\"$SSLFLAGS\"" >&5
-$as_echo "    Using SSLFLAGS=\"$SSLFLAGS\"" >&6; }
+    { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result:     Using SSLLIBS=\"$SSLLIBS\"" >&5
+printf "%s\n" "    Using SSLLIBS=\"$SSLLIBS\"" >&6; }
+    { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result:     Using SSLFLAGS=\"$SSLFLAGS\"" >&5
+printf "%s\n" "    Using SSLFLAGS=\"$SSLFLAGS\"" >&6; }
     IPPALIASES="http https ipps"
 elif test x$enable_cdsa = xyes -o x$enable_gnutls = xyes; then
     as_fn_error $? "Unable to enable SSL support." "$LINENO" 5
@@ -8353,13 +9155,15 @@ EXPORT_SSLLIBS="$SSLLIBS"
 
 
 # Check whether --enable-pam was given.
-if test "${enable_pam+set}" = set; then :
+if test ${enable_pam+y}
+then :
   enableval=$enable_pam;
 fi
 
 
 # Check whether --with-pam_module was given.
-if test "${with_pam_module+set}" = set; then :
+if test ${with_pam_module+y}
+then :
   withval=$with_pam_module;
 fi
 
@@ -8373,11 +9177,12 @@ PAMMODAUTH="pam_unknown.so"
 if test x$enable_pam != xno; then
 	SAVELIBS="$LIBS"
 
-	{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for dlopen in -ldl" >&5
-$as_echo_n "checking for dlopen in -ldl... " >&6; }
-if ${ac_cv_lib_dl_dlopen+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+	{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for dlopen in -ldl" >&5
+printf %s "checking for dlopen in -ldl... " >&6; }
+if test ${ac_cv_lib_dl_dlopen+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-ldl  $LIBS"
 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
@@ -8386,43 +9191,41 @@ cat confdefs.h - <<_ACEOF >conftest.$ac_
 /* Override any GCC internal prototype to avoid an error.
    Use char because int might match the return type of a GCC
    builtin and then its argument prototype would still apply.  */
-#ifdef __cplusplus
-extern "C"
-#endif
 char dlopen ();
 int
-main ()
+main (void)
 {
 return dlopen ();
   ;
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
+if ac_fn_c_try_link "$LINENO"
+then :
   ac_cv_lib_dl_dlopen=yes
-else
+else $as_nop
   ac_cv_lib_dl_dlopen=no
 fi
-rm -f core conftest.err conftest.$ac_objext \
+rm -f core conftest.err conftest.$ac_objext conftest.beam \
     conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_lib_dl_dlopen" >&5
-$as_echo "$ac_cv_lib_dl_dlopen" >&6; }
-if test "x$ac_cv_lib_dl_dlopen" = xyes; then :
-  cat >>confdefs.h <<_ACEOF
-#define HAVE_LIBDL 1
-_ACEOF
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_lib_dl_dlopen" >&5
+printf "%s\n" "$ac_cv_lib_dl_dlopen" >&6; }
+if test "x$ac_cv_lib_dl_dlopen" = xyes
+then :
+  printf "%s\n" "#define HAVE_LIBDL 1" >>confdefs.h
 
   LIBS="-ldl $LIBS"
 
 fi
 
-	{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for pam_start in -lpam" >&5
-$as_echo_n "checking for pam_start in -lpam... " >&6; }
-if ${ac_cv_lib_pam_pam_start+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+	{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for pam_start in -lpam" >&5
+printf %s "checking for pam_start in -lpam... " >&6; }
+if test ${ac_cv_lib_pam_pam_start+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lpam  $LIBS"
 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
@@ -8431,43 +9234,41 @@ cat confdefs.h - <<_ACEOF >conftest.$ac_
 /* Override any GCC internal prototype to avoid an error.
    Use char because int might match the return type of a GCC
    builtin and then its argument prototype would still apply.  */
-#ifdef __cplusplus
-extern "C"
-#endif
 char pam_start ();
 int
-main ()
+main (void)
 {
 return pam_start ();
   ;
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
+if ac_fn_c_try_link "$LINENO"
+then :
   ac_cv_lib_pam_pam_start=yes
-else
+else $as_nop
   ac_cv_lib_pam_pam_start=no
 fi
-rm -f core conftest.err conftest.$ac_objext \
+rm -f core conftest.err conftest.$ac_objext conftest.beam \
     conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_lib_pam_pam_start" >&5
-$as_echo "$ac_cv_lib_pam_pam_start" >&6; }
-if test "x$ac_cv_lib_pam_pam_start" = xyes; then :
-  cat >>confdefs.h <<_ACEOF
-#define HAVE_LIBPAM 1
-_ACEOF
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_lib_pam_pam_start" >&5
+printf "%s\n" "$ac_cv_lib_pam_pam_start" >&6; }
+if test "x$ac_cv_lib_pam_pam_start" = xyes
+then :
+  printf "%s\n" "#define HAVE_LIBPAM 1" >>confdefs.h
 
   LIBS="-lpam $LIBS"
 
 fi
 
-	{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for pam_set_item in -lpam" >&5
-$as_echo_n "checking for pam_set_item in -lpam... " >&6; }
-if ${ac_cv_lib_pam_pam_set_item+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+	{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for pam_set_item in -lpam" >&5
+printf %s "checking for pam_set_item in -lpam... " >&6; }
+if test ${ac_cv_lib_pam_pam_set_item+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lpam  $LIBS"
 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
@@ -8476,39 +9277,39 @@ cat confdefs.h - <<_ACEOF >conftest.$ac_
 /* Override any GCC internal prototype to avoid an error.
    Use char because int might match the return type of a GCC
    builtin and then its argument prototype would still apply.  */
-#ifdef __cplusplus
-extern "C"
-#endif
 char pam_set_item ();
 int
-main ()
+main (void)
 {
 return pam_set_item ();
   ;
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
+if ac_fn_c_try_link "$LINENO"
+then :
   ac_cv_lib_pam_pam_set_item=yes
-else
+else $as_nop
   ac_cv_lib_pam_pam_set_item=no
 fi
-rm -f core conftest.err conftest.$ac_objext \
+rm -f core conftest.err conftest.$ac_objext conftest.beam \
     conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_lib_pam_pam_set_item" >&5
-$as_echo "$ac_cv_lib_pam_pam_set_item" >&6; }
-if test "x$ac_cv_lib_pam_pam_set_item" = xyes; then :
-  $as_echo "#define HAVE_PAM_SET_ITEM 1" >>confdefs.h
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_lib_pam_pam_set_item" >&5
+printf "%s\n" "$ac_cv_lib_pam_pam_set_item" >&6; }
+if test "x$ac_cv_lib_pam_pam_set_item" = xyes
+then :
+  printf "%s\n" "#define HAVE_PAM_SET_ITEM 1" >>confdefs.h
 
 fi
 
-	{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for pam_setcred in -lpam" >&5
-$as_echo_n "checking for pam_setcred in -lpam... " >&6; }
-if ${ac_cv_lib_pam_pam_setcred+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+	{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for pam_setcred in -lpam" >&5
+printf %s "checking for pam_setcred in -lpam... " >&6; }
+if test ${ac_cv_lib_pam_pam_setcred+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lpam  $LIBS"
 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
@@ -8517,48 +9318,47 @@ cat confdefs.h - <<_ACEOF >conftest.$ac_
 /* Override any GCC internal prototype to avoid an error.
    Use char because int might match the return type of a GCC
    builtin and then its argument prototype would still apply.  */
-#ifdef __cplusplus
-extern "C"
-#endif
 char pam_setcred ();
 int
-main ()
+main (void)
 {
 return pam_setcred ();
   ;
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
+if ac_fn_c_try_link "$LINENO"
+then :
   ac_cv_lib_pam_pam_setcred=yes
-else
+else $as_nop
   ac_cv_lib_pam_pam_setcred=no
 fi
-rm -f core conftest.err conftest.$ac_objext \
+rm -f core conftest.err conftest.$ac_objext conftest.beam \
     conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_lib_pam_pam_setcred" >&5
-$as_echo "$ac_cv_lib_pam_pam_setcred" >&6; }
-if test "x$ac_cv_lib_pam_pam_setcred" = xyes; then :
-  $as_echo "#define HAVE_PAM_SETCRED 1" >>confdefs.h
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_lib_pam_pam_setcred" >&5
+printf "%s\n" "$ac_cv_lib_pam_pam_setcred" >&6; }
+if test "x$ac_cv_lib_pam_pam_setcred" = xyes
+then :
+  printf "%s\n" "#define HAVE_PAM_SETCRED 1" >>confdefs.h
 
 fi
 
-	ac_fn_c_check_header_mongrel "$LINENO" "security/pam_appl.h" "ac_cv_header_security_pam_appl_h" "$ac_includes_default"
-if test "x$ac_cv_header_security_pam_appl_h" = xyes; then :
+	ac_fn_c_check_header_compile "$LINENO" "security/pam_appl.h" "ac_cv_header_security_pam_appl_h" "$ac_includes_default"
+if test "x$ac_cv_header_security_pam_appl_h" = xyes
+then :
 
 fi
 
-
 	if test x$ac_cv_header_security_pam_appl_h != xyes; then
-		ac_fn_c_check_header_mongrel "$LINENO" "pam/pam_appl.h" "ac_cv_header_pam_pam_appl_h" "$ac_includes_default"
-if test "x$ac_cv_header_pam_pam_appl_h" = xyes; then :
-  $as_echo "#define HAVE_PAM_PAM_APPL_H 1" >>confdefs.h
+		ac_fn_c_check_header_compile "$LINENO" "pam/pam_appl.h" "ac_cv_header_pam_pam_appl_h" "$ac_includes_default"
+if test "x$ac_cv_header_pam_pam_appl_h" = xyes
+then :
+  printf "%s\n" "#define HAVE_PAM_PAM_APPL_H 1" >>confdefs.h
 
 fi
 
-
 	fi
 
 	if test x$ac_cv_lib_pam_pam_start != xno; then
@@ -8632,17 +9432,19 @@ fi
 
 
 # Check whether --enable-largefile was given.
-if test "${enable_largefile+set}" = set; then :
+if test ${enable_largefile+y}
+then :
   enableval=$enable_largefile;
 fi
 
 if test "$enable_largefile" != no; then
 
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking for special C compiler options needed for large files" >&5
-$as_echo_n "checking for special C compiler options needed for large files... " >&6; }
-if ${ac_cv_sys_largefile_CC+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for special C compiler options needed for large files" >&5
+printf %s "checking for special C compiler options needed for large files... " >&6; }
+if test ${ac_cv_sys_largefile_CC+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   ac_cv_sys_largefile_CC=no
      if test "$GCC" != yes; then
        ac_save_CC=$CC
@@ -8656,44 +9458,47 @@ else
     We can't simply define LARGE_OFF_T to be 9223372036854775807,
     since some C++ compilers masquerading as C compilers
     incorrectly reject 9223372036854775807.  */
-#define LARGE_OFF_T (((off_t) 1 << 62) - 1 + ((off_t) 1 << 62))
+#define LARGE_OFF_T (((off_t) 1 << 31 << 31) - 1 + ((off_t) 1 << 31 << 31))
   int off_t_is_large[(LARGE_OFF_T % 2147483629 == 721
 		       && LARGE_OFF_T % 2147483647 == 1)
 		      ? 1 : -1];
 int
-main ()
+main (void)
 {
 
   ;
   return 0;
 }
 _ACEOF
-	 if ac_fn_c_try_compile "$LINENO"; then :
+	 if ac_fn_c_try_compile "$LINENO"
+then :
   break
 fi
-rm -f core conftest.err conftest.$ac_objext
+rm -f core conftest.err conftest.$ac_objext conftest.beam
 	 CC="$CC -n32"
-	 if ac_fn_c_try_compile "$LINENO"; then :
+	 if ac_fn_c_try_compile "$LINENO"
+then :
   ac_cv_sys_largefile_CC=' -n32'; break
 fi
-rm -f core conftest.err conftest.$ac_objext
+rm -f core conftest.err conftest.$ac_objext conftest.beam
 	 break
        done
        CC=$ac_save_CC
        rm -f conftest.$ac_ext
     fi
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_sys_largefile_CC" >&5
-$as_echo "$ac_cv_sys_largefile_CC" >&6; }
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_sys_largefile_CC" >&5
+printf "%s\n" "$ac_cv_sys_largefile_CC" >&6; }
   if test "$ac_cv_sys_largefile_CC" != no; then
     CC=$CC$ac_cv_sys_largefile_CC
   fi
 
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking for _FILE_OFFSET_BITS value needed for large files" >&5
-$as_echo_n "checking for _FILE_OFFSET_BITS value needed for large files... " >&6; }
-if ${ac_cv_sys_file_offset_bits+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for _FILE_OFFSET_BITS value needed for large files" >&5
+printf %s "checking for _FILE_OFFSET_BITS value needed for large files... " >&6; }
+if test ${ac_cv_sys_file_offset_bits+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   while :; do
   cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
@@ -8702,22 +9507,23 @@ else
     We can't simply define LARGE_OFF_T to be 9223372036854775807,
     since some C++ compilers masquerading as C compilers
     incorrectly reject 9223372036854775807.  */
-#define LARGE_OFF_T (((off_t) 1 << 62) - 1 + ((off_t) 1 << 62))
+#define LARGE_OFF_T (((off_t) 1 << 31 << 31) - 1 + ((off_t) 1 << 31 << 31))
   int off_t_is_large[(LARGE_OFF_T % 2147483629 == 721
 		       && LARGE_OFF_T % 2147483647 == 1)
 		      ? 1 : -1];
 int
-main ()
+main (void)
 {
 
   ;
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_compile "$LINENO"; then :
+if ac_fn_c_try_compile "$LINENO"
+then :
   ac_cv_sys_file_offset_bits=no; break
 fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
+rm -f core conftest.err conftest.$ac_objext conftest.beam conftest.$ac_ext
   cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
 #define _FILE_OFFSET_BITS 64
@@ -8726,43 +9532,43 @@ rm -f core conftest.err conftest.$ac_obj
     We can't simply define LARGE_OFF_T to be 9223372036854775807,
     since some C++ compilers masquerading as C compilers
     incorrectly reject 9223372036854775807.  */
-#define LARGE_OFF_T (((off_t) 1 << 62) - 1 + ((off_t) 1 << 62))
+#define LARGE_OFF_T (((off_t) 1 << 31 << 31) - 1 + ((off_t) 1 << 31 << 31))
   int off_t_is_large[(LARGE_OFF_T % 2147483629 == 721
 		       && LARGE_OFF_T % 2147483647 == 1)
 		      ? 1 : -1];
 int
-main ()
+main (void)
 {
 
   ;
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_compile "$LINENO"; then :
+if ac_fn_c_try_compile "$LINENO"
+then :
   ac_cv_sys_file_offset_bits=64; break
 fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
+rm -f core conftest.err conftest.$ac_objext conftest.beam conftest.$ac_ext
   ac_cv_sys_file_offset_bits=unknown
   break
 done
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_sys_file_offset_bits" >&5
-$as_echo "$ac_cv_sys_file_offset_bits" >&6; }
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_sys_file_offset_bits" >&5
+printf "%s\n" "$ac_cv_sys_file_offset_bits" >&6; }
 case $ac_cv_sys_file_offset_bits in #(
   no | unknown) ;;
   *)
-cat >>confdefs.h <<_ACEOF
-#define _FILE_OFFSET_BITS $ac_cv_sys_file_offset_bits
-_ACEOF
+printf "%s\n" "#define _FILE_OFFSET_BITS $ac_cv_sys_file_offset_bits" >>confdefs.h
 ;;
 esac
 rm -rf conftest*
   if test $ac_cv_sys_file_offset_bits = unknown; then
-    { $as_echo "$as_me:${as_lineno-$LINENO}: checking for _LARGE_FILES value needed for large files" >&5
-$as_echo_n "checking for _LARGE_FILES value needed for large files... " >&6; }
-if ${ac_cv_sys_large_files+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+    { printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for _LARGE_FILES value needed for large files" >&5
+printf %s "checking for _LARGE_FILES value needed for large files... " >&6; }
+if test ${ac_cv_sys_large_files+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   while :; do
   cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
@@ -8771,22 +9577,23 @@ else
     We can't simply define LARGE_OFF_T to be 9223372036854775807,
     since some C++ compilers masquerading as C compilers
     incorrectly reject 9223372036854775807.  */
-#define LARGE_OFF_T (((off_t) 1 << 62) - 1 + ((off_t) 1 << 62))
+#define LARGE_OFF_T (((off_t) 1 << 31 << 31) - 1 + ((off_t) 1 << 31 << 31))
   int off_t_is_large[(LARGE_OFF_T % 2147483629 == 721
 		       && LARGE_OFF_T % 2147483647 == 1)
 		      ? 1 : -1];
 int
-main ()
+main (void)
 {
 
   ;
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_compile "$LINENO"; then :
+if ac_fn_c_try_compile "$LINENO"
+then :
   ac_cv_sys_large_files=no; break
 fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
+rm -f core conftest.err conftest.$ac_objext conftest.beam conftest.$ac_ext
   cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
 #define _LARGE_FILES 1
@@ -8795,40 +9602,37 @@ rm -f core conftest.err conftest.$ac_obj
     We can't simply define LARGE_OFF_T to be 9223372036854775807,
     since some C++ compilers masquerading as C compilers
     incorrectly reject 9223372036854775807.  */
-#define LARGE_OFF_T (((off_t) 1 << 62) - 1 + ((off_t) 1 << 62))
+#define LARGE_OFF_T (((off_t) 1 << 31 << 31) - 1 + ((off_t) 1 << 31 << 31))
   int off_t_is_large[(LARGE_OFF_T % 2147483629 == 721
 		       && LARGE_OFF_T % 2147483647 == 1)
 		      ? 1 : -1];
 int
-main ()
+main (void)
 {
 
   ;
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_compile "$LINENO"; then :
+if ac_fn_c_try_compile "$LINENO"
+then :
   ac_cv_sys_large_files=1; break
 fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
+rm -f core conftest.err conftest.$ac_objext conftest.beam conftest.$ac_ext
   ac_cv_sys_large_files=unknown
   break
 done
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_sys_large_files" >&5
-$as_echo "$ac_cv_sys_large_files" >&6; }
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_sys_large_files" >&5
+printf "%s\n" "$ac_cv_sys_large_files" >&6; }
 case $ac_cv_sys_large_files in #(
   no | unknown) ;;
   *)
-cat >>confdefs.h <<_ACEOF
-#define _LARGE_FILES $ac_cv_sys_large_files
-_ACEOF
+printf "%s\n" "#define _LARGE_FILES $ac_cv_sys_large_files" >>confdefs.h
 ;;
 esac
 rm -rf conftest*
   fi
-
-
 fi
 
 
@@ -8846,11 +9650,12 @@ if test x$enable_largefile != xno; then
 fi
 
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for long long int" >&5
-$as_echo_n "checking for long long int... " >&6; }
-if ${ac_cv_c_long_long+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for long long int" >&5
+printf %s "checking for long long int... " >&6; }
+if test ${ac_cv_c_long_long+y}
+then :
+  printf %s "(cached) " >&6
+else $as_nop
   if test "$GCC" = yes; then
 		ac_cv_c_long_long=yes
 	else
@@ -8858,57 +9663,63 @@ else
 /* end confdefs.h.  */
 
 int
-main ()
+main (void)
 {
 long long int i;
   ;
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_compile "$LINENO"; then :
+if ac_fn_c_try_compile "$LINENO"
+then :
   ac_cv_c_long_long=yes
-else
+else $as_nop
   ac_cv_c_long_long=no
 fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
+rm -f core conftest.err conftest.$ac_objext conftest.beam conftest.$ac_ext
 	fi
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_c_long_long" >&5
-$as_echo "$ac_cv_c_long_long" >&6; }
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $ac_cv_c_long_long" >&5
+printf "%s\n" "$ac_cv_c_long_long" >&6; }
 
 if test $ac_cv_c_long_long = yes; then
-	$as_echo "#define HAVE_LONG_LONG 1" >>confdefs.h
+	printf "%s\n" "#define HAVE_LONG_LONG 1" >>confdefs.h
 
 fi
 
 ac_fn_c_check_func "$LINENO" "strtoll" "ac_cv_func_strtoll"
-if test "x$ac_cv_func_strtoll" = xyes; then :
-  $as_echo "#define HAVE_STRTOLL 1" >>confdefs.h
+if test "x$ac_cv_func_strtoll" = xyes
+then :
+  printf "%s\n" "#define HAVE_STRTOLL 1" >>confdefs.h
 
 fi
 
 
 
 # Check whether --enable-avahi was given.
-if test "${enable_avahi+set}" = set; then :
+if test ${enable_avahi+y}
+then :
   enableval=$enable_avahi;
 fi
 
 # Check whether --enable-dnssd was given.
-if test "${enable_dnssd+set}" = set; then :
+if test ${enable_dnssd+y}
+then :
   enableval=$enable_dnssd;
 fi
 
 
 # Check whether --with-dnssd-libs was given.
-if test "${with_dnssd_libs+set}" = set; then :
+if test ${with_dnssd_libs+y}
+then :
   withval=$with_dnssd_libs; LDFLAGS="-L$withval $LDFLAGS"
 	DSOFLAGS="-L$withval $DSOFLAGS"
 fi
 
 
 # Check whether --with-dnssd-includes was given.
-if test "${with_dnssd_includes+set}" = set; then :
+if test ${with_dnssd_includes+y}
+then :
   withval=$with_dnssd_includes; CFLAGS="-I$withval $CFLAGS"
 	CPPFLAGS="-I$withval $CPPFLAGS"
 fi
@@ -8920,32 +9731,33 @@ IPPFIND_BIN=""
 IPPFIND_MAN=""
 
 if test "x$PKGCONFIG" != x -a x$enable_avahi != xno -a x$host_os_name != xdarwin; then
-	{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for Avahi" >&5
-$as_echo_n "checking for Avahi... " >&6; }
+	{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for Avahi" >&5
+printf %s "checking for Avahi... " >&6; }
 	if $PKGCONFIG --exists avahi-client; then
-		{ $as_echo "$as_me:${as_lineno-$LINENO}: result: yes" >&5
-$as_echo "yes" >&6; }
+		{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: yes" >&5
+printf "%s\n" "yes" >&6; }
 		CFLAGS="$CFLAGS `$PKGCONFIG --cflags avahi-client`"
 		DNSSDLIBS="`$PKGCONFIG --libs avahi-client`"
 		DNSSD_BACKEND="dnssd"
 		IPPFIND_BIN="ippfind"
 		IPPFIND_MAN="ippfind.1"
-		$as_echo "#define HAVE_AVAHI 1" >>confdefs.h
+		printf "%s\n" "#define HAVE_AVAHI 1" >>confdefs.h
 
 	else
-		{ $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
+		{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: no" >&5
+printf "%s\n" "no" >&6; }
 	fi
 fi
 
 if test "x$DNSSD_BACKEND" = x -a x$enable_dnssd != xno; then
-	ac_fn_c_check_header_mongrel "$LINENO" "dns_sd.h" "ac_cv_header_dns_sd_h" "$ac_includes_default"
-if test "x$ac_cv_header_dns_sd_h" = xyes; then :
+	ac_fn_c_check_header_compile "$LINENO" "dns_sd.h" "ac_cv_header_dns_sd_h" "$ac_includes_default"
+if test "x$ac_cv_header_dns_sd_h" = xyes
+then :
 
 		case "$host_os_name" in
 			darwin*)
 				# Darwin and macOS...
-				$as_echo "#define HAVE_DNSSD 1" >>confdefs.h
+				printf "%s\n" "#define HAVE_DNSSD 1" >>confdefs.h
 
 				DNSSD_BACKEND="dnssd"
 				IPPFIND_BIN="ippfind"
@@ -8953,15 +9765,15 @@ if test "x$ac_cv_header_dns_sd_h" = xyes
 				;;
 			*)
 				# All others...
-				{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for current version of dns_sd library" >&5
-$as_echo_n "checking for current version of dns_sd library... " >&6; }
+				{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for current version of dns_sd library" >&5
+printf %s "checking for current version of dns_sd library... " >&6; }
 				SAVELIBS="$LIBS"
 				LIBS="$LIBS -ldns_sd"
 				cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
 #include <dns_sd.h>
 int
-main ()
+main (void)
 {
 int constant = kDNSServiceFlagsShareConnection;
 					unsigned char txtRecord[100];
@@ -8972,27 +9784,27 @@ int constant = kDNSServiceFlagsShareConn
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_compile "$LINENO"; then :
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: yes" >&5
-$as_echo "yes" >&6; }
-					$as_echo "#define HAVE_DNSSD 1" >>confdefs.h
+if ac_fn_c_try_compile "$LINENO"
+then :
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: yes" >&5
+printf "%s\n" "yes" >&6; }
+					printf "%s\n" "#define HAVE_DNSSD 1" >>confdefs.h
 
 					DNSSDLIBS="-ldns_sd"
 					DNSSD_BACKEND="dnssd"
 					IPPFIND_BIN="ippfind"
 					IPPFIND_MAN="ippfind.1"
-else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
+else $as_nop
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: no" >&5
+printf "%s\n" "no" >&6; }
 fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
+rm -f core conftest.err conftest.$ac_objext conftest.beam conftest.$ac_ext
 				LIBS="$SAVELIBS"
 				;;
 		esac
 
 fi
 
-
 fi
 
 
@@ -9007,7 +9819,8 @@ ONDEMANDLIBS=""
 
 
 # Check whether --enable-launchd was given.
-if test "${enable_launchd+set}" = set; then :
+if test ${enable_launchd+y}
+then :
   enableval=$enable_launchd;
 fi
 
@@ -9016,22 +9829,23 @@ LAUNCHD_DIR=""
 
 if test x$enable_launchd != xno; then
 	ac_fn_c_check_func "$LINENO" "launch_activate_socket" "ac_cv_func_launch_activate_socket"
-if test "x$ac_cv_func_launch_activate_socket" = xyes; then :
+if test "x$ac_cv_func_launch_activate_socket" = xyes
+then :
 
-		$as_echo "#define HAVE_LAUNCHD 1" >>confdefs.h
+		printf "%s\n" "#define HAVE_LAUNCHD 1" >>confdefs.h
 
-		$as_echo "#define HAVE_ONDEMAND 1" >>confdefs.h
+		printf "%s\n" "#define HAVE_ONDEMAND 1" >>confdefs.h
 
 fi
 
-	ac_fn_c_check_header_mongrel "$LINENO" "launch.h" "ac_cv_header_launch_h" "$ac_includes_default"
-if test "x$ac_cv_header_launch_h" = xyes; then :
-  $as_echo "#define HAVE_LAUNCH_H 1" >>confdefs.h
+	ac_fn_c_check_header_compile "$LINENO" "launch.h" "ac_cv_header_launch_h" "$ac_includes_default"
+if test "x$ac_cv_header_launch_h" = xyes
+then :
+  printf "%s\n" "#define HAVE_LAUNCH_H 1" >>confdefs.h
 
 fi
 
 
-
 	if test "$host_os_name" = darwin; then
 	        LAUNCHD_DIR="/System/Library/LaunchDaemons"
 		# liblaunch is already part of libSystem
@@ -9039,15 +9853,17 @@ fi
 fi
 
 # Check whether --enable-systemd was given.
-if test "${enable_systemd+set}" = set; then :
+if test ${enable_systemd+y}
+then :
   enableval=$enable_systemd;
 fi
 
 
 # Check whether --with-systemd was given.
-if test "${with_systemd+set}" = set; then :
+if test ${with_systemd+y}
+then :
   withval=$with_systemd; SYSTEMD_DIR="$withval"
-else
+else $as_nop
   SYSTEMD_DIR=""
 fi
 
@@ -9060,17 +9876,17 @@ if test x$enable_systemd != xno; then
                 fi
         else
         	have_systemd=no
-        	{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for libsystemd" >&5
-$as_echo_n "checking for libsystemd... " >&6; }
+        	{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for libsystemd" >&5
+printf %s "checking for libsystemd... " >&6; }
                 if $PKGCONFIG --exists libsystemd; then
-                        { $as_echo "$as_me:${as_lineno-$LINENO}: result: yes" >&5
-$as_echo "yes" >&6; }
+                        { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: yes" >&5
+printf "%s\n" "yes" >&6; }
                         have_systemd=yes
                         ONDEMANDFLAGS=`$PKGCONFIG --cflags libsystemd`
                         ONDEMANDLIBS=`$PKGCONFIG --libs libsystemd`
 		elif $PKGCONFIG --exists libsystemd-daemon; then
-			{ $as_echo "$as_me:${as_lineno-$LINENO}: result: yes - legacy" >&5
-$as_echo "yes - legacy" >&6; }
+			{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: yes - legacy" >&5
+printf "%s\n" "yes - legacy" >&6; }
                         have_systemd=yes
 			ONDEMANDFLAGS=`$PKGCONFIG --cflags libsystemd-daemon`
 			ONDEMANDLIBS=`$PKGCONFIG --libs libsystemd-daemon`
@@ -9080,22 +9896,22 @@ $as_echo "yes - legacy" >&6; }
 				ONDEMANDLIBS="$ONDEMANDLIBS `$PKGCONFIG --libs libsystemd-journal`"
 			fi
                 else
-                        { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
+                        { printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: no" >&5
+printf "%s\n" "no" >&6; }
                 fi
 
 		if test $have_systemd = yes; then
-                        $as_echo "#define HAVE_SYSTEMD 1" >>confdefs.h
+                        printf "%s\n" "#define HAVE_SYSTEMD 1" >>confdefs.h
 
-                        $as_echo "#define HAVE_ONDEMAND 1" >>confdefs.h
+                        printf "%s\n" "#define HAVE_ONDEMAND 1" >>confdefs.h
 
-			ac_fn_c_check_header_mongrel "$LINENO" "systemd/sd-journal.h" "ac_cv_header_systemd_sd_journal_h" "$ac_includes_default"
-if test "x$ac_cv_header_systemd_sd_journal_h" = xyes; then :
-  $as_echo "#define HAVE_SYSTEMD_SD_JOURNAL_H 1" >>confdefs.h
+			ac_fn_c_check_header_compile "$LINENO" "systemd/sd-journal.h" "ac_cv_header_systemd_sd_journal_h" "$ac_includes_default"
+if test "x$ac_cv_header_systemd_sd_journal_h" = xyes
+then :
+  printf "%s\n" "#define HAVE_SYSTEMD_SD_JOURNAL_H 1" >>confdefs.h
 
 fi
 
-
 			if test "x$SYSTEMD_DIR" = x; then
 			        SYSTEMD_DIR="`$PKGCONFIG --variable=systemdsystemunitdir systemd`"
                         fi
@@ -9104,7 +9920,8 @@ fi
 fi
 
 # Check whether --enable-upstart was given.
-if test "${enable_upstart+set}" = set; then :
+if test ${enable_upstart+y}
+then :
   enableval=$enable_upstart;
 fi
 
@@ -9112,9 +9929,9 @@ if test "x$enable_upstart" = "xyes"; the
 	if test "x$have_systemd" = "xyes"; then
 		as_fn_error $? "Cannot support both systemd and upstart." "$LINENO" 5
 	fi
-	$as_echo "#define HAVE_UPSTART 1" >>confdefs.h
+	printf "%s\n" "#define HAVE_UPSTART 1" >>confdefs.h
 
-	$as_echo "#define HAVE_ONDEMAND 1" >>confdefs.h
+	printf "%s\n" "#define HAVE_ONDEMAND 1" >>confdefs.h
 
 fi
 
@@ -9122,40 +9939,45 @@ SMFMANIFESTDIR=""
 
 
 # Check whether --with-smfmanifestdir was given.
-if test "${with_smfmanifestdir+set}" = set; then :
+if test ${with_smfmanifestdir+y}
+then :
   withval=$with_smfmanifestdir; SMFMANIFESTDIR="$withval"
 fi
 
 
 
 # Check whether --with-rcdir was given.
-if test "${with_rcdir+set}" = set; then :
+if test ${with_rcdir+y}
+then :
   withval=$with_rcdir; rcdir="$withval"
-else
+else $as_nop
   rcdir=""
 fi
 
 
 # Check whether --with-rclevels was given.
-if test "${with_rclevels+set}" = set; then :
+if test ${with_rclevels+y}
+then :
   withval=$with_rclevels; rclevels="$withval"
-else
+else $as_nop
   rclevels="2 3 5"
 fi
 
 
 # Check whether --with-rcstart was given.
-if test "${with_rcstart+set}" = set; then :
+if test ${with_rcstart+y}
+then :
   withval=$with_rcstart; rcstart="$withval"
-else
+else $as_nop
   rcstart=""
 fi
 
 
 # Check whether --with-rcstop was given.
-if test "${with_rcstop+set}" = set; then :
+if test ${with_rcstop+y}
+then :
   withval=$with_rcstop; rcstop="$withval"
-else
+else $as_nop
   rcstop=""
 fi
 
@@ -9232,9 +10054,10 @@ fi
 
 
 # Check whether --with-xinetd was given.
-if test "${with_xinetd+set}" = set; then :
+if test ${with_xinetd+y}
+then :
   withval=$with_xinetd; xinetd="$withval"
-else
+else $as_nop
   xinetd=""
 fi
 
@@ -9259,7 +10082,8 @@ LANGUAGES="`ls -1 locale/cups_*.po 2>/de
 
 
 # Check whether --with-languages was given.
-if test "${with_languages+set}" = set; then :
+if test ${with_languages+y}
+then :
   withval=$with_languages;
 	case "$withval" in
 		none | no) LANGUAGES="" ;;
@@ -9272,9 +10096,10 @@ fi
 
 
 # Check whether --with-bundledir was given.
-if test "${with_bundledir+set}" = set; then :
+if test ${with_bundledir+y}
+then :
   withval=$with_bundledir; CUPS_BUNDLEDIR="$withval"
-else
+else $as_nop
 
 	if test "x$host_os_name" = xdarwin -a $host_os_version -ge 100; then
 		CUPS_BUNDLEDIR="/System/Library/Frameworks/ApplicationServices.framework/Versions/A/Frameworks/PrintCore.framework/Versions/A"
@@ -9287,17 +10112,16 @@ fi
 
 
 if test "x$CUPS_BUNDLEDIR" != x; then
-	cat >>confdefs.h <<_ACEOF
-#define CUPS_BUNDLEDIR "$CUPS_BUNDLEDIR"
-_ACEOF
+	printf "%s\n" "#define CUPS_BUNDLEDIR \"$CUPS_BUNDLEDIR\"" >>confdefs.h
 
 fi
 
 
 # Check whether --with-bundlelang was given.
-if test "${with_bundlelang+set}" = set; then :
+if test ${with_bundlelang+y}
+then :
   withval=$with_bundlelang; cups_bundlelang="$withval"
-else
+else $as_nop
 
 	if test $host_os_version -ge 190; then
 		cups_bundlelang="en"
@@ -9316,11 +10140,12 @@ fi
 
 
 # Check whether --with-exe_file_perm was given.
-if test "${with_exe_file_perm+set}" = set; then :
+if test ${with_exe_file_perm+y}
+then :
   withval=$with_exe_file_perm; CUPS_EXE_FILE_PERM="$withval"
-else
+else $as_nop
   case "$host_os_name" in
-		linux* | gnu*)
+		linux* | gnu* | *-gnu)
 			CUPS_EXE_FILE_PERM="755"
 			;;
 		*)
@@ -9333,9 +10158,10 @@ fi
 
 
 # Check whether --with-config_file_perm was given.
-if test "${with_config_file_perm+set}" = set; then :
+if test ${with_config_file_perm+y}
+then :
   withval=$with_config_file_perm; CUPS_CONFIG_FILE_PERM="$withval"
-else
+else $as_nop
   if test "x$host_os_name" = xdarwin; then
 		CUPS_CONFIG_FILE_PERM="644"
 	else
@@ -9344,16 +10170,15 @@ else
 fi
 
 
-cat >>confdefs.h <<_ACEOF
-#define CUPS_DEFAULT_CONFIG_FILE_PERM 0$CUPS_CONFIG_FILE_PERM
-_ACEOF
+printf "%s\n" "#define CUPS_DEFAULT_CONFIG_FILE_PERM 0$CUPS_CONFIG_FILE_PERM" >>confdefs.h
 
 
 
 # Check whether --with-cupsd_file_perm was given.
-if test "${with_cupsd_file_perm+set}" = set; then :
+if test ${with_cupsd_file_perm+y}
+then :
   withval=$with_cupsd_file_perm; CUPS_CUPSD_FILE_PERM="$withval"
-else
+else $as_nop
   case "$host_os_name" in
 		linux* | gnu*)
 			CUPS_CUPSD_FILE_PERM="700"
@@ -9368,90 +10193,85 @@ fi
 
 
 # Check whether --with-log_file_perm was given.
-if test "${with_log_file_perm+set}" = set; then :
+if test ${with_log_file_perm+y}
+then :
   withval=$with_log_file_perm; CUPS_LOG_FILE_PERM="$withval"
-else
+else $as_nop
   CUPS_LOG_FILE_PERM="644"
 fi
 
 
-cat >>confdefs.h <<_ACEOF
-#define CUPS_DEFAULT_LOG_FILE_PERM 0$CUPS_LOG_FILE_PERM
-_ACEOF
+printf "%s\n" "#define CUPS_DEFAULT_LOG_FILE_PERM 0$CUPS_LOG_FILE_PERM" >>confdefs.h
 
 
 
 # Check whether --with-max_log_size was given.
-if test "${with_max_log_size+set}" = set; then :
+if test ${with_max_log_size+y}
+then :
   withval=$with_max_log_size; CUPS_MAX_LOG_SIZE="$withval"
-else
+else $as_nop
   CUPS_MAX_LOG_SIZE="1m"
 fi
 
 
-cat >>confdefs.h <<_ACEOF
-#define CUPS_DEFAULT_MAX_LOG_SIZE "$CUPS_MAX_LOG_SIZE"
-_ACEOF
+printf "%s\n" "#define CUPS_DEFAULT_MAX_LOG_SIZE \"$CUPS_MAX_LOG_SIZE\"" >>confdefs.h
 
 
 
 # Check whether --with-error_policy was given.
-if test "${with_error_policy+set}" = set; then :
+if test ${with_error_policy+y}
+then :
   withval=$with_error_policy; CUPS_ERROR_POLICY="$withval"
-else
+else $as_nop
   CUPS_ERROR_POLICY="stop-printer"
 fi
 
 
-cat >>confdefs.h <<_ACEOF
-#define CUPS_DEFAULT_ERROR_POLICY "$CUPS_ERROR_POLICY"
-_ACEOF
+printf "%s\n" "#define CUPS_DEFAULT_ERROR_POLICY \"$CUPS_ERROR_POLICY\"" >>confdefs.h
 
 
 
 # Check whether --with-fatal_errors was given.
-if test "${with_fatal_errors+set}" = set; then :
+if test ${with_fatal_errors+y}
+then :
   withval=$with_fatal_errors; CUPS_FATAL_ERRORS="$withval"
-else
+else $as_nop
   CUPS_FATAL_ERRORS="config"
 fi
 
 
-cat >>confdefs.h <<_ACEOF
-#define CUPS_DEFAULT_FATAL_ERRORS "$CUPS_FATAL_ERRORS"
-_ACEOF
+printf "%s\n" "#define CUPS_DEFAULT_FATAL_ERRORS \"$CUPS_FATAL_ERRORS\"" >>confdefs.h
 
 
 
 # Check whether --with-log_level was given.
-if test "${with_log_level+set}" = set; then :
+if test ${with_log_level+y}
+then :
   withval=$with_log_level; CUPS_LOG_LEVEL="$withval"
-else
+else $as_nop
   CUPS_LOG_LEVEL="warn"
 fi
 
 
-cat >>confdefs.h <<_ACEOF
-#define CUPS_DEFAULT_LOG_LEVEL "$CUPS_LOG_LEVEL"
-_ACEOF
+printf "%s\n" "#define CUPS_DEFAULT_LOG_LEVEL \"$CUPS_LOG_LEVEL\"" >>confdefs.h
 
 
 
 # Check whether --with-access_log_level was given.
-if test "${with_access_log_level+set}" = set; then :
+if test ${with_access_log_level+y}
+then :
   withval=$with_access_log_level; CUPS_ACCESS_LOG_LEVEL="$withval"
-else
+else $as_nop
   CUPS_ACCESS_LOG_LEVEL="none"
 fi
 
 
-cat >>confdefs.h <<_ACEOF
-#define CUPS_DEFAULT_ACCESS_LOG_LEVEL "$CUPS_ACCESS_LOG_LEVEL"
-_ACEOF
+printf "%s\n" "#define CUPS_DEFAULT_ACCESS_LOG_LEVEL \"$CUPS_ACCESS_LOG_LEVEL\"" >>confdefs.h
 
 
 # Check whether --enable-page_logging was given.
-if test "${enable_page_logging+set}" = set; then :
+if test ${enable_page_logging+y}
+then :
   enableval=$enable_page_logging;
 fi
 
@@ -9463,13 +10283,14 @@ fi
 
 
 # Check whether --enable-sync_on_close was given.
-if test "${enable_sync_on_close+set}" = set; then :
+if test ${enable_sync_on_close+y}
+then :
   enableval=$enable_sync_on_close;
 fi
 
 if test "x$enable_sync_on_close" = xyes; then
 	CUPS_SYNC_ON_CLOSE="Yes"
-	$as_echo "#define CUPS_DEFAULT_SYNC_ON_CLOSE 1" >>confdefs.h
+	printf "%s\n" "#define CUPS_DEFAULT_SYNC_ON_CLOSE 1" >>confdefs.h
 
 else
 	CUPS_SYNC_ON_CLOSE="No"
@@ -9477,30 +10298,28 @@ fi
 
 
 # Check whether --enable-browsing was given.
-if test "${enable_browsing+set}" = set; then :
+if test ${enable_browsing+y}
+then :
   enableval=$enable_browsing;
 fi
 
 if test "x$enable_browsing" = xno; then
 	CUPS_BROWSING="No"
-	cat >>confdefs.h <<_ACEOF
-#define CUPS_DEFAULT_BROWSING 0
-_ACEOF
+	printf "%s\n" "#define CUPS_DEFAULT_BROWSING 0" >>confdefs.h
 
 else
 	CUPS_BROWSING="Yes"
-	cat >>confdefs.h <<_ACEOF
-#define CUPS_DEFAULT_BROWSING 1
-_ACEOF
+	printf "%s\n" "#define CUPS_DEFAULT_BROWSING 1" >>confdefs.h
 
 fi
 
 
 
 # Check whether --with-local_protocols was given.
-if test "${with_local_protocols+set}" = set; then :
+if test ${with_local_protocols+y}
+then :
   withval=$with_local_protocols; default_local_protocols="$withval"
-else
+else $as_nop
   default_local_protocols="default"
 fi
 
@@ -9520,66 +10339,62 @@ else
 fi
 
 
-cat >>confdefs.h <<_ACEOF
-#define CUPS_DEFAULT_BROWSE_LOCAL_PROTOCOLS "$CUPS_BROWSE_LOCAL_PROTOCOLS"
-_ACEOF
+printf "%s\n" "#define CUPS_DEFAULT_BROWSE_LOCAL_PROTOCOLS \"$CUPS_BROWSE_LOCAL_PROTOCOLS\"" >>confdefs.h
 
 
 # Check whether --enable-default_shared was given.
-if test "${enable_default_shared+set}" = set; then :
+if test ${enable_default_shared+y}
+then :
   enableval=$enable_default_shared;
 fi
 
 if test "x$enable_default_shared" = xno; then
 	CUPS_DEFAULT_SHARED="No"
-	cat >>confdefs.h <<_ACEOF
-#define CUPS_DEFAULT_DEFAULT_SHARED 0
-_ACEOF
+	printf "%s\n" "#define CUPS_DEFAULT_DEFAULT_SHARED 0" >>confdefs.h
 
 else
 	CUPS_DEFAULT_SHARED="Yes"
-	cat >>confdefs.h <<_ACEOF
-#define CUPS_DEFAULT_DEFAULT_SHARED 1
-_ACEOF
+	printf "%s\n" "#define CUPS_DEFAULT_DEFAULT_SHARED 1" >>confdefs.h
 
 fi
 
 
 
 # Check whether --with-cups_user was given.
-if test "${with_cups_user+set}" = set; then :
+if test ${with_cups_user+y}
+then :
   withval=$with_cups_user; CUPS_USER="$withval"
-else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking for default print user" >&5
-$as_echo_n "checking for default print user... " >&6; }
+else $as_nop
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for default print user" >&5
+printf %s "checking for default print user... " >&6; }
 	if test x$host_os_name = xdarwin; then
 		if test x`id -u _lp 2>/dev/null` = x; then
 			CUPS_USER="lp";
 		else
 			CUPS_USER="_lp";
 		fi
-		{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $CUPS_USER" >&5
-$as_echo "$CUPS_USER" >&6; }
+		{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $CUPS_USER" >&5
+printf "%s\n" "$CUPS_USER" >&6; }
 	elif test -f /etc/passwd; then
 		CUPS_USER=""
 		for user in lp lpd guest daemon nobody; do
 			if test "`grep \^${user}: /etc/passwd`" != ""; then
 				CUPS_USER="$user"
-				{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $user" >&5
-$as_echo "$user" >&6; }
+				{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $user" >&5
+printf "%s\n" "$user" >&6; }
 				break;
 			fi
 		done
 
 		if test x$CUPS_USER = x; then
 			CUPS_USER="nobody"
-			{ $as_echo "$as_me:${as_lineno-$LINENO}: result: not found" >&5
-$as_echo "not found" >&6; }
+			{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: not found" >&5
+printf "%s\n" "not found" >&6; }
 		fi
 	else
 		CUPS_USER="nobody"
-		{ $as_echo "$as_me:${as_lineno-$LINENO}: result: no password file" >&5
-$as_echo "no password file" >&6; }
+		{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: no password file" >&5
+printf "%s\n" "no password file" >&6; }
 	fi
 fi
 
@@ -9590,40 +10405,41 @@ fi
 
 
 # Check whether --with-cups_group was given.
-if test "${with_cups_group+set}" = set; then :
+if test ${with_cups_group+y}
+then :
   withval=$with_cups_group; CUPS_GROUP="$withval"
-else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking for default print group" >&5
-$as_echo_n "checking for default print group... " >&6; }
+else $as_nop
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for default print group" >&5
+printf %s "checking for default print group... " >&6; }
 	if test x$host_os_name = xdarwin; then
 		if test x`id -g _lp 2>/dev/null` = x; then
 			CUPS_GROUP="lp";
 		else
 			CUPS_GROUP="_lp";
 		fi
-		{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $CUPS_GROUP" >&5
-$as_echo "$CUPS_GROUP" >&6; }
+		{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $CUPS_GROUP" >&5
+printf "%s\n" "$CUPS_GROUP" >&6; }
 	elif test -f /etc/group; then
 		GROUP_LIST="_lp lp nobody"
 		CUPS_GROUP=""
 		for group in $GROUP_LIST; do
 			if test "`grep \^${group}: /etc/group`" != ""; then
 				CUPS_GROUP="$group"
-				{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $group" >&5
-$as_echo "$group" >&6; }
+				{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: $group" >&5
+printf "%s\n" "$group" >&6; }
 				break;
 			fi
 		done
 
 		if test x$CUPS_GROUP = x; then
 			CUPS_GROUP="nobody"
-			{ $as_echo "$as_me:${as_lineno-$LINENO}: result: not found" >&5
-$as_echo "not found" >&6; }
+			{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: not found" >&5
+printf "%s\n" "not found" >&6; }
 		fi
 	else
 		CUPS_GROUP="nobody"
-		{ $as_echo "$as_me:${as_lineno-$LINENO}: result: no group file" >&5
-$as_echo "no group file" >&6; }
+		{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: no group file" >&5
+printf "%s\n" "no group file" >&6; }
 	fi
 fi
 
@@ -9634,14 +10450,15 @@ fi
 
 
 # Check whether --with-system_groups was given.
-if test "${with_system_groups+set}" = set; then :
+if test ${with_system_groups+y}
+then :
   withval=$with_system_groups; CUPS_SYSTEM_GROUPS="$withval"
-else
+else $as_nop
   if test x$host_os_name = xdarwin; then
 		CUPS_SYSTEM_GROUPS="admin"
 	else
-		{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for default system groups" >&5
-$as_echo_n "checking for default system groups... " >&6; }
+		{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: checking for default system groups" >&5
+printf %s "checking for default system groups... " >&6; }
 		if test -f /etc/group; then
 			CUPS_SYSTEM_GROUPS=""
 			GROUP_LIST="lpadmin sys system root wheel"
@@ -9657,16 +10474,16 @@ $as_echo_n "checking for default system
 
 			if test "x$CUPS_SYSTEM_GROUPS" = x; then
 				CUPS_SYSTEM_GROUPS="$GROUP_LIST"
-				{ $as_echo "$as_me:${as_lineno-$LINENO}: result: no groups found" >&5
-$as_echo "no groups found" >&6; }
+				{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: no groups found" >&5
+printf "%s\n" "no groups found" >&6; }
 			else
-				{ $as_echo "$as_me:${as_lineno-$LINENO}: result: \"$CUPS_SYSTEM_GROUPS\"" >&5
-$as_echo "\"$CUPS_SYSTEM_GROUPS\"" >&6; }
+				{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: \"$CUPS_SYSTEM_GROUPS\"" >&5
+printf "%s\n" "\"$CUPS_SYSTEM_GROUPS\"" >&6; }
 			fi
 		else
 			CUPS_SYSTEM_GROUPS="$GROUP_LIST"
-			{ $as_echo "$as_me:${as_lineno-$LINENO}: result: no group file" >&5
-$as_echo "no group file" >&6; }
+			{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: result: no group file" >&5
+printf "%s\n" "no group file" >&6; }
 		fi
 	fi
 fi
@@ -9685,24 +10502,19 @@ done
 
 
 
-cat >>confdefs.h <<_ACEOF
-#define CUPS_DEFAULT_USER "$CUPS_USER"
-_ACEOF
+printf "%s\n" "#define CUPS_DEFAULT_USER \"$CUPS_USER\"" >>confdefs.h
 
-cat >>confdefs.h <<_ACEOF
-#define CUPS_DEFAULT_GROUP "$CUPS_GROUP"
-_ACEOF
+printf "%s\n" "#define CUPS_DEFAULT_GROUP \"$CUPS_GROUP\"" >>confdefs.h
 
-cat >>confdefs.h <<_ACEOF
-#define CUPS_DEFAULT_SYSTEM_GROUPS "$CUPS_SYSTEM_GROUPS"
-_ACEOF
+printf "%s\n" "#define CUPS_DEFAULT_SYSTEM_GROUPS \"$CUPS_SYSTEM_GROUPS\"" >>confdefs.h
 
 
 
 # Check whether --with-printcap was given.
-if test "${with_printcap+set}" = set; then :
+if test ${with_printcap+y}
+then :
   withval=$with_printcap; default_printcap="$withval"
-else
+else $as_nop
   default_printcap="default"
 fi
 
@@ -9732,16 +10544,15 @@ else
 fi
 
 
-cat >>confdefs.h <<_ACEOF
-#define CUPS_DEFAULT_PRINTCAP "$CUPS_DEFAULT_PRINTCAP"
-_ACEOF
+printf "%s\n" "#define CUPS_DEFAULT_PRINTCAP \"$CUPS_DEFAULT_PRINTCAP\"" >>confdefs.h
 
 
 
 # Check whether --with-lpdconfigfile was given.
-if test "${with_lpdconfigfile+set}" = set; then :
+if test ${with_lpdconfigfile+y}
+then :
   withval=$with_lpdconfigfile; default_lpdconfigfile="$withval"
-else
+else $as_nop
   default_lpdconfigfile="default"
 fi
 
@@ -9767,17 +10578,16 @@ else
 	CUPS_DEFAULT_LPD_CONFIG_FILE=""
 fi
 
-cat >>confdefs.h <<_ACEOF
-#define CUPS_DEFAULT_LPD_CONFIG_FILE "$CUPS_DEFAULT_LPD_CONFIG_FILE"
-_ACEOF
+printf "%s\n" "#define CUPS_DEFAULT_LPD_CONFIG_FILE \"$CUPS_DEFAULT_LPD_CONFIG_FILE\"" >>confdefs.h
 
 
 
 
 # Check whether --with-smbconfigfile was given.
-if test "${with_smbconfigfile+set}" = set; then :
+if test ${with_smbconfigfile+y}
+then :
   withval=$with_smbconfigfile; default_smbconfigfile="$withval"
-else
+else $as_nop
   default_smbconfigfile="default"
 fi
 
@@ -9796,29 +10606,27 @@ else
 	CUPS_DEFAULT_SMB_CONFIG_FILE=""
 fi
 
-cat >>confdefs.h <<_ACEOF
-#define CUPS_DEFAULT_SMB_CONFIG_FILE "$CUPS_DEFAULT_SMB_CONFIG_FILE"
-_ACEOF
+printf "%s\n" "#define CUPS_DEFAULT_SMB_CONFIG_FILE \"$CUPS_DEFAULT_SMB_CONFIG_FILE\"" >>confdefs.h
 
 
 
 
 # Check whether --with-max-copies was given.
-if test "${with_max_copies+set}" = set; then :
+if test ${with_max_copies+y}
+then :
   withval=$with_max_copies; CUPS_MAX_COPIES="$withval"
-else
+else $as_nop
   CUPS_MAX_COPIES="9999"
 fi
 
 
 
-cat >>confdefs.h <<_ACEOF
-#define CUPS_DEFAULT_MAX_COPIES $CUPS_MAX_COPIES
-_ACEOF
+printf "%s\n" "#define CUPS_DEFAULT_MAX_COPIES $CUPS_MAX_COPIES" >>confdefs.h
 
 
 # Check whether --enable-raw_printing was given.
-if test "${enable_raw_printing+set}" = set; then :
+if test ${enable_raw_printing+y}
+then :
   enableval=$enable_raw_printing;
 fi
 
@@ -9831,13 +10639,14 @@ fi
 
 
 # Check whether --with-snmp-address was given.
-if test "${with_snmp_address+set}" = set; then :
+if test ${with_snmp_address+y}
+then :
   withval=$with_snmp_address; if test "x$withval" = x; then
 		CUPS_SNMP_ADDRESS=""
 	else
 		CUPS_SNMP_ADDRESS="Address $withval"
 	fi
-else
+else $as_nop
   if test "x$host_os_name" = xdarwin; then
 		CUPS_SNMP_ADDRESS=""
 	else
@@ -9848,9 +10657,10 @@ fi
 
 
 # Check whether --with-snmp-community was given.
-if test "${with_snmp_community+set}" = set; then :
+if test ${with_snmp_community+y}
+then :
   withval=$with_snmp_community; CUPS_SNMP_COMMUNITY="Community $withval"
-else
+else $as_nop
   CUPS_SNMP_COMMUNITY="Community public"
 fi
 
@@ -9860,21 +10670,21 @@ fi
 
 
 # Check whether --with-ipp-port was given.
-if test "${with_ipp_port+set}" = set; then :
+if test ${with_ipp_port+y}
+then :
   withval=$with_ipp_port; DEFAULT_IPP_PORT="$withval"
-else
+else $as_nop
   DEFAULT_IPP_PORT="631"
 fi
 
 
 
-cat >>confdefs.h <<_ACEOF
-#define CUPS_DEFAULT_IPP_PORT $DEFAULT_IPP_PORT
-_ACEOF
+printf "%s\n" "#define CUPS_DEFAULT_IPP_PORT $DEFAULT_IPP_PORT" >>confdefs.h
 
 
 # Check whether --enable-webif was given.
-if test "${enable_webif+set}" = set; then :
+if test ${enable_webif+y}
+then :
   enableval=$enable_webif;
 fi
 
@@ -9899,9 +10709,7 @@ case "x$enable_webif" in
 esac
 
 
-cat >>confdefs.h <<_ACEOF
-#define CUPS_DEFAULT_WEBIF $CUPS_DEFAULT_WEBIF
-_ACEOF
+printf "%s\n" "#define CUPS_DEFAULT_WEBIF $CUPS_DEFAULT_WEBIF" >>confdefs.h
 
 
 
@@ -9957,8 +10765,8 @@ _ACEOF
     case $ac_val in #(
     *${as_nl}*)
       case $ac_var in #(
-      *_cv_*) { $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: cache variable $ac_var contains a newline" >&5
-$as_echo "$as_me: WARNING: cache variable $ac_var contains a newline" >&2;} ;;
+      *_cv_*) { printf "%s\n" "$as_me:${as_lineno-$LINENO}: WARNING: cache variable $ac_var contains a newline" >&5
+printf "%s\n" "$as_me: WARNING: cache variable $ac_var contains a newline" >&2;} ;;
       esac
       case $ac_var in #(
       _ | IFS | as_nl) ;; #(
@@ -9988,15 +10796,15 @@ $as_echo "$as_me: WARNING: cache variabl
      /^ac_cv_env_/b end
      t clear
      :clear
-     s/^\([^=]*\)=\(.*[{}].*\)$/test "${\1+set}" = set || &/
+     s/^\([^=]*\)=\(.*[{}].*\)$/test ${\1+y} || &/
      t end
      s/^\([^=]*\)=\(.*\)$/\1=${\1=\2}/
      :end' >>confcache
 if diff "$cache_file" confcache >/dev/null 2>&1; then :; else
   if test -w "$cache_file"; then
     if test "x$cache_file" != "x/dev/null"; then
-      { $as_echo "$as_me:${as_lineno-$LINENO}: updating cache $cache_file" >&5
-$as_echo "$as_me: updating cache $cache_file" >&6;}
+      { printf "%s\n" "$as_me:${as_lineno-$LINENO}: updating cache $cache_file" >&5
+printf "%s\n" "$as_me: updating cache $cache_file" >&6;}
       if test ! -f "$cache_file" || test -h "$cache_file"; then
 	cat confcache >"$cache_file"
       else
@@ -10010,8 +10818,8 @@ $as_echo "$as_me: updating cache $cache_
       fi
     fi
   else
-    { $as_echo "$as_me:${as_lineno-$LINENO}: not updating unwritable cache $cache_file" >&5
-$as_echo "$as_me: not updating unwritable cache $cache_file" >&6;}
+    { printf "%s\n" "$as_me:${as_lineno-$LINENO}: not updating unwritable cache $cache_file" >&5
+printf "%s\n" "$as_me: not updating unwritable cache $cache_file" >&6;}
   fi
 fi
 rm -f confcache
@@ -10028,7 +10836,7 @@ U=
 for ac_i in : $LIBOBJS; do test "x$ac_i" = x: && continue
   # 1. Remove the extension, and $U if already installed.
   ac_script='s/\$U\././;s/\.o$//;s/\.obj$//'
-  ac_i=`$as_echo "$ac_i" | sed "$ac_script"`
+  ac_i=`printf "%s\n" "$ac_i" | sed "$ac_script"`
   # 2. Prepend LIBOBJDIR.  When used with automake>=1.10 LIBOBJDIR
   #    will be set to the directory where LIBOBJS objects are built.
   as_fn_append ac_libobjs " \${LIBOBJDIR}$ac_i\$U.$ac_objext"
@@ -10044,8 +10852,8 @@ LTLIBOBJS=$ac_ltlibobjs
 ac_write_fail=0
 ac_clean_files_save=$ac_clean_files
 ac_clean_files="$ac_clean_files $CONFIG_STATUS"
-{ $as_echo "$as_me:${as_lineno-$LINENO}: creating $CONFIG_STATUS" >&5
-$as_echo "$as_me: creating $CONFIG_STATUS" >&6;}
+{ printf "%s\n" "$as_me:${as_lineno-$LINENO}: creating $CONFIG_STATUS" >&5
+printf "%s\n" "$as_me: creating $CONFIG_STATUS" >&6;}
 as_write_fail=0
 cat >$CONFIG_STATUS <<_ASEOF || as_write_fail=1
 #! $SHELL
@@ -10068,14 +10876,16 @@ cat >>$CONFIG_STATUS <<\_ASEOF || as_wri
 
 # Be more Bourne compatible
 DUALCASE=1; export DUALCASE # for MKS sh
-if test -n "${ZSH_VERSION+set}" && (emulate sh) >/dev/null 2>&1; then :
+as_nop=:
+if test ${ZSH_VERSION+y} && (emulate sh) >/dev/null 2>&1
+then :
   emulate sh
   NULLCMD=:
   # Pre-4.2 versions of Zsh do word splitting on ${1+"$@"}, which
   # is contrary to our usage.  Disable this feature.
   alias -g '${1+"$@"}'='"$@"'
   setopt NO_GLOB_SUBST
-else
+else $as_nop
   case `(set -o) 2>/dev/null` in #(
   *posix*) :
     set -o posix ;; #(
@@ -10085,46 +10895,46 @@ esac
 fi
 
 
+
+# Reset variables that may have inherited troublesome values from
+# the environment.
+
+# IFS needs to be set, to space, tab, and newline, in precisely that order.
+# (If _AS_PATH_WALK were called with IFS unset, it would have the
+# side effect of setting IFS to empty, thus disabling word splitting.)
+# Quoting is to prevent editors from complaining about space-tab.
 as_nl='
 '
 export as_nl
-# Printing a long string crashes Solaris 7 /usr/bin/printf.
-as_echo='\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\'
-as_echo=$as_echo$as_echo$as_echo$as_echo$as_echo
-as_echo=$as_echo$as_echo$as_echo$as_echo$as_echo$as_echo
-# Prefer a ksh shell builtin over an external printf program on Solaris,
-# but without wasting forks for bash or zsh.
-if test -z "$BASH_VERSION$ZSH_VERSION" \
-    && (test "X`print -r -- $as_echo`" = "X$as_echo") 2>/dev/null; then
-  as_echo='print -r --'
-  as_echo_n='print -rn --'
-elif (test "X`printf %s $as_echo`" = "X$as_echo") 2>/dev/null; then
-  as_echo='printf %s\n'
-  as_echo_n='printf %s'
-else
-  if test "X`(/usr/ucb/echo -n -n $as_echo) 2>/dev/null`" = "X-n $as_echo"; then
-    as_echo_body='eval /usr/ucb/echo -n "$1$as_nl"'
-    as_echo_n='/usr/ucb/echo -n'
-  else
-    as_echo_body='eval expr "X$1" : "X\\(.*\\)"'
-    as_echo_n_body='eval
-      arg=$1;
-      case $arg in #(
-      *"$as_nl"*)
-	expr "X$arg" : "X\\(.*\\)$as_nl";
-	arg=`expr "X$arg" : ".*$as_nl\\(.*\\)"`;;
-      esac;
-      expr "X$arg" : "X\\(.*\\)" | tr -d "$as_nl"
-    '
-    export as_echo_n_body
-    as_echo_n='sh -c $as_echo_n_body as_echo'
-  fi
-  export as_echo_body
-  as_echo='sh -c $as_echo_body as_echo'
-fi
+IFS=" ""	$as_nl"
+
+PS1='$ '
+PS2='> '
+PS4='+ '
+
+# Ensure predictable behavior from utilities with locale-dependent output.
+LC_ALL=C
+export LC_ALL
+LANGUAGE=C
+export LANGUAGE
+
+# We cannot yet rely on "unset" to work, but we need these variables
+# to be unset--not just set to an empty or harmless value--now, to
+# avoid bugs in old shells (e.g. pre-3.0 UWIN ksh).  This construct
+# also avoids known problems related to "unset" and subshell syntax
+# in other old shells (e.g. bash 2.01 and pdksh 5.2.14).
+for as_var in BASH_ENV ENV MAIL MAILPATH CDPATH
+do eval test \${$as_var+y} \
+  && ( (unset $as_var) || exit 1) >/dev/null 2>&1 && unset $as_var || :
+done
+
+# Ensure that fds 0, 1, and 2 are open.
+if (exec 3>&0) 2>/dev/null; then :; else exec 0</dev/null; fi
+if (exec 3>&1) 2>/dev/null; then :; else exec 1>/dev/null; fi
+if (exec 3>&2)            ; then :; else exec 2>/dev/null; fi
 
 # The user is always right.
-if test "${PATH_SEPARATOR+set}" != set; then
+if ${PATH_SEPARATOR+false} :; then
   PATH_SEPARATOR=:
   (PATH='/bin;/bin'; FPATH=$PATH; sh -c :) >/dev/null 2>&1 && {
     (PATH='/bin:/bin'; FPATH=$PATH; sh -c :) >/dev/null 2>&1 ||
@@ -10133,13 +10943,6 @@ if test "${PATH_SEPARATOR+set}" != set;
 fi
 
 
-# IFS
-# We need space, tab and new line, in precisely that order.  Quoting is
-# there to prevent editors from complaining about space-tab.
-# (If _AS_PATH_WALK were called with IFS unset, it would disable word
-# splitting by setting IFS to empty value.)
-IFS=" ""	$as_nl"
-
 # Find who we are.  Look in the path if we contain no directory separator.
 as_myself=
 case $0 in #((
@@ -10148,8 +10951,12 @@ case $0 in #((
 for as_dir in $PATH
 do
   IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
-    test -r "$as_dir/$0" && as_myself=$as_dir/$0 && break
+  case $as_dir in #(((
+    '') as_dir=./ ;;
+    */) ;;
+    *) as_dir=$as_dir/ ;;
+  esac
+    test -r "$as_dir$0" && as_myself=$as_dir$0 && break
   done
 IFS=$as_save_IFS
 
@@ -10161,30 +10968,10 @@ if test "x$as_myself" = x; then
   as_myself=$0
 fi
 if test ! -f "$as_myself"; then
-  $as_echo "$as_myself: error: cannot find myself; rerun with an absolute file name" >&2
+  printf "%s\n" "$as_myself: error: cannot find myself; rerun with an absolute file name" >&2
   exit 1
 fi
 
-# Unset variables that we do not need and which cause bugs (e.g. in
-# pre-3.0 UWIN ksh).  But do not cause bugs in bash 2.01; the "|| exit 1"
-# suppresses any "Segmentation fault" message there.  '((' could
-# trigger a bug in pdksh 5.2.14.
-for as_var in BASH_ENV ENV MAIL MAILPATH
-do eval test x\${$as_var+set} = xset \
-  && ( (unset $as_var) || exit 1) >/dev/null 2>&1 && unset $as_var || :
-done
-PS1='$ '
-PS2='> '
-PS4='+ '
-
-# NLS nuisances.
-LC_ALL=C
-export LC_ALL
-LANGUAGE=C
-export LANGUAGE
-
-# CDPATH.
-(unset CDPATH) >/dev/null 2>&1 && unset CDPATH
 
 
 # as_fn_error STATUS ERROR [LINENO LOG_FD]
@@ -10197,13 +10984,14 @@ as_fn_error ()
   as_status=$1; test $as_status -eq 0 && as_status=1
   if test "$4"; then
     as_lineno=${as_lineno-"$3"} as_lineno_stack=as_lineno_stack=$as_lineno_stack
-    $as_echo "$as_me:${as_lineno-$LINENO}: error: $2" >&$4
+    printf "%s\n" "$as_me:${as_lineno-$LINENO}: error: $2" >&$4
   fi
-  $as_echo "$as_me: error: $2" >&2
+  printf "%s\n" "$as_me: error: $2" >&2
   as_fn_exit $as_status
 } # as_fn_error
 
 
+
 # as_fn_set_status STATUS
 # -----------------------
 # Set $? to STATUS, without forking.
@@ -10230,18 +11018,20 @@ as_fn_unset ()
   { eval $1=; unset $1;}
 }
 as_unset=as_fn_unset
+
 # as_fn_append VAR VALUE
 # ----------------------
 # Append the text in VALUE to the end of the definition contained in VAR. Take
 # advantage of any shell optimizations that allow amortized linear growth over
 # repeated appends, instead of the typical quadratic growth present in naive
 # implementations.
-if (eval "as_var=1; as_var+=2; test x\$as_var = x12") 2>/dev/null; then :
+if (eval "as_var=1; as_var+=2; test x\$as_var = x12") 2>/dev/null
+then :
   eval 'as_fn_append ()
   {
     eval $1+=\$2
   }'
-else
+else $as_nop
   as_fn_append ()
   {
     eval $1=\$$1\$2
@@ -10253,12 +11043,13 @@ fi # as_fn_append
 # Perform arithmetic evaluation on the ARGs, and store the result in the
 # global $as_val. Take advantage of shells that can avoid forks. The arguments
 # must be portable across $(()) and expr.
-if (eval "test \$(( 1 + 1 )) = 2") 2>/dev/null; then :
+if (eval "test \$(( 1 + 1 )) = 2") 2>/dev/null
+then :
   eval 'as_fn_arith ()
   {
     as_val=$(( $* ))
   }'
-else
+else $as_nop
   as_fn_arith ()
   {
     as_val=`expr "$@" || test $? -eq 1`
@@ -10289,7 +11080,7 @@ as_me=`$as_basename -- "$0" ||
 $as_expr X/"$0" : '.*/\([^/][^/]*\)/*$' \| \
 	 X"$0" : 'X\(//\)$' \| \
 	 X"$0" : 'X\(/\)' \| . 2>/dev/null ||
-$as_echo X/"$0" |
+printf "%s\n" X/"$0" |
     sed '/^.*\/\([^/][^/]*\)\/*$/{
 	    s//\1/
 	    q
@@ -10311,6 +11102,10 @@ as_cr_Letters=$as_cr_letters$as_cr_LETTE
 as_cr_digits='0123456789'
 as_cr_alnum=$as_cr_Letters$as_cr_digits
 
+
+# Determine whether it's possible to make 'echo' print without a newline.
+# These variables are no longer used directly by Autoconf, but are AC_SUBSTed
+# for compatibility with existing Makefiles.
 ECHO_C= ECHO_N= ECHO_T=
 case `echo -n x` in #(((((
 -n*)
@@ -10324,6 +11119,12 @@ case `echo -n x` in #(((((
   ECHO_N='-n';;
 esac
 
+# For backward compatibility with old third-party macros, we provide
+# the shell variables $as_echo and $as_echo_n.  New code should use
+# AS_ECHO(["message"]) and AS_ECHO_N(["message"]), respectively.
+as_echo='printf %s\n'
+as_echo_n='printf %s'
+
 rm -f conf$$ conf$$.exe conf$$.file
 if test -d conf$$.dir; then
   rm -f conf$$.dir/conf$$.file
@@ -10365,7 +11166,7 @@ as_fn_mkdir_p ()
     as_dirs=
     while :; do
       case $as_dir in #(
-      *\'*) as_qdir=`$as_echo "$as_dir" | sed "s/'/'\\\\\\\\''/g"`;; #'(
+      *\'*) as_qdir=`printf "%s\n" "$as_dir" | sed "s/'/'\\\\\\\\''/g"`;; #'(
       *) as_qdir=$as_dir;;
       esac
       as_dirs="'$as_qdir' $as_dirs"
@@ -10374,7 +11175,7 @@ $as_expr X"$as_dir" : 'X\(.*[^/]\)//*[^/
 	 X"$as_dir" : 'X\(//\)[^/]' \| \
 	 X"$as_dir" : 'X\(//\)$' \| \
 	 X"$as_dir" : 'X\(/\)' \| . 2>/dev/null ||
-$as_echo X"$as_dir" |
+printf "%s\n" X"$as_dir" |
     sed '/^X\(.*[^/]\)\/\/*[^/][^/]*\/*$/{
 	    s//\1/
 	    q
@@ -10436,8 +11237,8 @@ cat >>$CONFIG_STATUS <<\_ACEOF || ac_wri
 # report actual input values of CONFIG_FILES etc. instead of their
 # values after options handling.
 ac_log="
-This file was extended by CUPS $as_me 2.3.3op1, which was
-generated by GNU Autoconf 2.69.  Invocation command line was
+This file was extended by CUPS $as_me 2.3.3op2, which was
+generated by GNU Autoconf 2.70.  Invocation command line was
 
   CONFIG_FILES    = $CONFIG_FILES
   CONFIG_HEADERS  = $CONFIG_HEADERS
@@ -10496,14 +11297,16 @@ Report bugs to <https://github.com/openp
 CUPS home page: <https://openprinting.github.io/>."
 
 _ACEOF
+ac_cs_config=`printf "%s\n" "$ac_configure_args" | sed "$ac_safe_unquote"`
+ac_cs_config_escaped=`printf "%s\n" "$ac_cs_config" | sed "s/^ //; s/'/'\\\\\\\\''/g"`
 cat >>$CONFIG_STATUS <<_ACEOF || ac_write_fail=1
-ac_cs_config="`$as_echo "$ac_configure_args" | sed 's/^ //; s/[\\""\`\$]/\\\\&/g'`"
+ac_cs_config='$ac_cs_config_escaped'
 ac_cs_version="\\
-CUPS config.status 2.3.3op1
-configured by $0, generated by GNU Autoconf 2.69,
+CUPS config.status 2.3.3op2
+configured by $0, generated by GNU Autoconf 2.70,
   with options \\"\$ac_cs_config\\"
 
-Copyright (C) 2012 Free Software Foundation, Inc.
+Copyright (C) 2020 Free Software Foundation, Inc.
 This config.status script is free software; the Free Software Foundation
 gives unlimited permission to copy, distribute and modify it."
 
@@ -10541,15 +11344,15 @@ do
   -recheck | --recheck | --rechec | --reche | --rech | --rec | --re | --r)
     ac_cs_recheck=: ;;
   --version | --versio | --versi | --vers | --ver | --ve | --v | -V )
-    $as_echo "$ac_cs_version"; exit ;;
+    printf "%s\n" "$ac_cs_version"; exit ;;
   --config | --confi | --conf | --con | --co | --c )
-    $as_echo "$ac_cs_config"; exit ;;
+    printf "%s\n" "$ac_cs_config"; exit ;;
   --debug | --debu | --deb | --de | --d | -d )
     debug=: ;;
   --file | --fil | --fi | --f )
     $ac_shift
     case $ac_optarg in
-    *\'*) ac_optarg=`$as_echo "$ac_optarg" | sed "s/'/'\\\\\\\\''/g"` ;;
+    *\'*) ac_optarg=`printf "%s\n" "$ac_optarg" | sed "s/'/'\\\\\\\\''/g"` ;;
     '') as_fn_error $? "missing file argument" ;;
     esac
     as_fn_append CONFIG_FILES " '$ac_optarg'"
@@ -10557,7 +11360,7 @@ do
   --header | --heade | --head | --hea )
     $ac_shift
     case $ac_optarg in
-    *\'*) ac_optarg=`$as_echo "$ac_optarg" | sed "s/'/'\\\\\\\\''/g"` ;;
+    *\'*) ac_optarg=`printf "%s\n" "$ac_optarg" | sed "s/'/'\\\\\\\\''/g"` ;;
     esac
     as_fn_append CONFIG_HEADERS " '$ac_optarg'"
     ac_need_defaults=false;;
@@ -10566,7 +11369,7 @@ do
     as_fn_error $? "ambiguous option: \`$1'
 Try \`$0 --help' for more information.";;
   --help | --hel | -h )
-    $as_echo "$ac_cs_usage"; exit ;;
+    printf "%s\n" "$ac_cs_usage"; exit ;;
   -q | -quiet | --quiet | --quie | --qui | --qu | --q \
   | -silent | --silent | --silen | --sile | --sil | --si | --s)
     ac_cs_silent=: ;;
@@ -10594,7 +11397,7 @@ cat >>$CONFIG_STATUS <<_ACEOF || ac_writ
 if \$ac_cs_recheck; then
   set X $SHELL '$0' $ac_configure_args \$ac_configure_extra_args --no-create --no-recursion
   shift
-  \$as_echo "running CONFIG_SHELL=$SHELL \$*" >&6
+  \printf "%s\n" "running CONFIG_SHELL=$SHELL \$*" >&6
   CONFIG_SHELL='$SHELL'
   export CONFIG_SHELL
   exec "\$@"
@@ -10608,7 +11411,7 @@ exec 5>>config.log
   sed 'h;s/./-/g;s/^.../## /;s/...$/ ##/;p;x;p;x' <<_ASBOX
 ## Running $as_me. ##
 _ASBOX
-  $as_echo "$ac_log"
+  printf "%s\n" "$ac_log"
 } >&5
 
 _ACEOF
@@ -10653,8 +11456,8 @@ done
 # We use the long form for the default assignment because of an extremely
 # bizarre bug on SunOS 4.1.3.
 if $ac_need_defaults; then
-  test "${CONFIG_FILES+set}" = set || CONFIG_FILES=$config_files
-  test "${CONFIG_HEADERS+set}" = set || CONFIG_HEADERS=$config_headers
+  test ${CONFIG_FILES+y} || CONFIG_FILES=$config_files
+  test ${CONFIG_HEADERS+y} || CONFIG_HEADERS=$config_headers
 fi
 
 # Have a temporary directory for convenience.  Make it in the build tree
@@ -10990,7 +11793,7 @@ do
 	   esac ||
 	   as_fn_error 1 "cannot find input file: \`$ac_f'" "$LINENO" 5;;
       esac
-      case $ac_f in *\'*) ac_f=`$as_echo "$ac_f" | sed "s/'/'\\\\\\\\''/g"`;; esac
+      case $ac_f in *\'*) ac_f=`printf "%s\n" "$ac_f" | sed "s/'/'\\\\\\\\''/g"`;; esac
       as_fn_append ac_file_inputs " '$ac_f'"
     done
 
@@ -10998,17 +11801,17 @@ do
     # use $as_me), people would be surprised to read:
     #    /* config.h.  Generated by config.status.  */
     configure_input='Generated from '`
-	  $as_echo "$*" | sed 's|^[^:]*/||;s|:[^:]*/|, |g'
+	  printf "%s\n" "$*" | sed 's|^[^:]*/||;s|:[^:]*/|, |g'
 	`' by configure.'
     if test x"$ac_file" != x-; then
       configure_input="$ac_file.  $configure_input"
-      { $as_echo "$as_me:${as_lineno-$LINENO}: creating $ac_file" >&5
-$as_echo "$as_me: creating $ac_file" >&6;}
+      { printf "%s\n" "$as_me:${as_lineno-$LINENO}: creating $ac_file" >&5
+printf "%s\n" "$as_me: creating $ac_file" >&6;}
     fi
     # Neutralize special characters interpreted by sed in replacement strings.
     case $configure_input in #(
     *\&* | *\|* | *\\* )
-       ac_sed_conf_input=`$as_echo "$configure_input" |
+       ac_sed_conf_input=`printf "%s\n" "$configure_input" |
        sed 's/[\\\\&|]/\\\\&/g'`;; #(
     *) ac_sed_conf_input=$configure_input;;
     esac
@@ -11025,7 +11828,7 @@ $as_expr X"$ac_file" : 'X\(.*[^/]\)//*[^
 	 X"$ac_file" : 'X\(//\)[^/]' \| \
 	 X"$ac_file" : 'X\(//\)$' \| \
 	 X"$ac_file" : 'X\(/\)' \| . 2>/dev/null ||
-$as_echo X"$ac_file" |
+printf "%s\n" X"$ac_file" |
     sed '/^X\(.*[^/]\)\/\/*[^/][^/]*\/*$/{
 	    s//\1/
 	    q
@@ -11049,9 +11852,9 @@ $as_echo X"$ac_file" |
 case "$ac_dir" in
 .) ac_dir_suffix= ac_top_builddir_sub=. ac_top_build_prefix= ;;
 *)
-  ac_dir_suffix=/`$as_echo "$ac_dir" | sed 's|^\.[\\/]||'`
+  ac_dir_suffix=/`printf "%s\n" "$ac_dir" | sed 's|^\.[\\/]||'`
   # A ".." for each directory in $ac_dir_suffix.
-  ac_top_builddir_sub=`$as_echo "$ac_dir_suffix" | sed 's|/[^\\/]*|/..|g;s|/||'`
+  ac_top_builddir_sub=`printf "%s\n" "$ac_dir_suffix" | sed 's|/[^\\/]*|/..|g;s|/||'`
   case $ac_top_builddir_sub in
   "") ac_top_builddir_sub=. ac_top_build_prefix= ;;
   *)  ac_top_build_prefix=$ac_top_builddir_sub/ ;;
@@ -11104,8 +11907,8 @@ ac_sed_dataroot='
 case `eval "sed -n \"\$ac_sed_dataroot\" $ac_file_inputs"` in
 *datarootdir*) ac_datarootdir_seen=yes;;
 *@datadir@*|*@docdir@*|*@infodir@*|*@localedir@*|*@mandir@*)
-  { $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: $ac_file_inputs seems to ignore the --datarootdir setting" >&5
-$as_echo "$as_me: WARNING: $ac_file_inputs seems to ignore the --datarootdir setting" >&2;}
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: WARNING: $ac_file_inputs seems to ignore the --datarootdir setting" >&5
+printf "%s\n" "$as_me: WARNING: $ac_file_inputs seems to ignore the --datarootdir setting" >&2;}
 _ACEOF
 cat >>$CONFIG_STATUS <<_ACEOF || ac_write_fail=1
   ac_datarootdir_hack='
@@ -11147,9 +11950,9 @@ test -z "$ac_datarootdir_hack$ac_dataroo
   { ac_out=`sed -n '/\${datarootdir}/p' "$ac_tmp/out"`; test -n "$ac_out"; } &&
   { ac_out=`sed -n '/^[	 ]*datarootdir[	 ]*:*=/p' \
       "$ac_tmp/out"`; test -z "$ac_out"; } &&
-  { $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: $ac_file contains a reference to the variable \`datarootdir'
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: WARNING: $ac_file contains a reference to the variable \`datarootdir'
 which seems to be undefined.  Please make sure it is defined" >&5
-$as_echo "$as_me: WARNING: $ac_file contains a reference to the variable \`datarootdir'
+printf "%s\n" "$as_me: WARNING: $ac_file contains a reference to the variable \`datarootdir'
 which seems to be undefined.  Please make sure it is defined" >&2;}
 
   rm -f "$ac_tmp/stdin"
@@ -11165,20 +11968,20 @@ which seems to be undefined.  Please mak
   #
   if test x"$ac_file" != x-; then
     {
-      $as_echo "/* $configure_input  */" \
+      printf "%s\n" "/* $configure_input  */" >&1 \
       && eval '$AWK -f "$ac_tmp/defines.awk"' "$ac_file_inputs"
     } >"$ac_tmp/config.h" \
       || as_fn_error $? "could not create $ac_file" "$LINENO" 5
     if diff "$ac_file" "$ac_tmp/config.h" >/dev/null 2>&1; then
-      { $as_echo "$as_me:${as_lineno-$LINENO}: $ac_file is unchanged" >&5
-$as_echo "$as_me: $ac_file is unchanged" >&6;}
+      { printf "%s\n" "$as_me:${as_lineno-$LINENO}: $ac_file is unchanged" >&5
+printf "%s\n" "$as_me: $ac_file is unchanged" >&6;}
     else
       rm -f "$ac_file"
       mv "$ac_tmp/config.h" "$ac_file" \
 	|| as_fn_error $? "could not create $ac_file" "$LINENO" 5
     fi
   else
-    $as_echo "/* $configure_input  */" \
+    printf "%s\n" "/* $configure_input  */" >&1 \
       && eval '$AWK -f "$ac_tmp/defines.awk"' "$ac_file_inputs" \
       || as_fn_error $? "could not create -" "$LINENO" 5
   fi
@@ -11219,9 +12022,10 @@ if test "$no_create" != yes; then
   $ac_cs_success || as_fn_exit 1
 fi
 if test -n "$ac_unrecognized_opts" && test "$enable_option_checking" != no; then
-  { $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: unrecognized options: $ac_unrecognized_opts" >&5
-$as_echo "$as_me: WARNING: unrecognized options: $ac_unrecognized_opts" >&2;}
+  { printf "%s\n" "$as_me:${as_lineno-$LINENO}: WARNING: unrecognized options: $ac_unrecognized_opts" >&5
+printf "%s\n" "$as_me: WARNING: unrecognized options: $ac_unrecognized_opts" >&2;}
 fi
 
 
 chmod +x cups-config
+
diff -pruN 2.3.3op1-5/configure.ac 2.3.3op2-2/configure.ac
--- 2.3.3op1-5/configure.ac	2020-11-27 14:25:26.000000000 +0000
+++ 2.3.3op2-2/configure.ac	2021-02-01 21:10:25.000000000 +0000
@@ -1,7 +1,7 @@
 dnl
 dnl Configuration script for CUPS.
 dnl
-dnl Copyright © 2020 by Michael R Sweet
+dnl Copyright © 2020-2021 by Michael R Sweet
 dnl Copyright © 2007-2019 by Apple Inc.
 dnl Copyright © 1997-2007 by Easy Software Products, all rights reserved.
 dnl
@@ -13,7 +13,7 @@ dnl We need at least autoconf 2.60...
 AC_PREREQ(2.60)
 
 dnl Package name and version...
-AC_INIT([CUPS], [2.3.3op1], [https://github.com/openprinting/cups/issues], [cups], [https://openprinting.github.io/])
+AC_INIT([CUPS], [2.3.3op2], [https://github.com/openprinting/cups/issues], [cups], [https://openprinting.github.io/])
 
 sinclude(config-scripts/cups-opsys.m4)
 sinclude(config-scripts/cups-common.m4)
diff -pruN 2.3.3op1-5/cups/ipp.c 2.3.3op2-2/cups/ipp.c
--- 2.3.3op1-5/cups/ipp.c	2020-11-27 14:25:26.000000000 +0000
+++ 2.3.3op2-2/cups/ipp.c	2021-02-01 21:10:25.000000000 +0000
@@ -2866,7 +2866,8 @@ ippReadIO(void       *src,		/* I - Data
   unsigned char		*buffer,	/* Data buffer */
 			string[IPP_MAX_TEXT],
 					/* Small string buffer */
-			*bufptr;	/* Pointer into buffer */
+			*bufptr,	/* Pointer into buffer */
+			*bufend;	/* End of buffer */
   ipp_attribute_t	*attr;		/* Current attribute */
   ipp_tag_t		tag;		/* Current tag */
   ipp_tag_t		value_tag;	/* Current value tag */
@@ -3441,6 +3442,7 @@ ippReadIO(void       *src,		/* I - Data
 		}
 
                 bufptr = buffer;
+                bufend = buffer + n;
 
 	       /*
 	        * text-with-language and name-with-language are composite
@@ -3454,7 +3456,7 @@ ippReadIO(void       *src,		/* I - Data
 
 		n = (bufptr[0] << 8) | bufptr[1];
 
-		if ((bufptr + 2 + n) >= (buffer + IPP_BUF_SIZE) || n >= (int)sizeof(string))
+		if ((bufptr + 2 + n + 2) > bufend || n >= (int)sizeof(string))
 		{
 		  _cupsSetError(IPP_STATUS_ERROR_INTERNAL,
 		                _("IPP language length overflows value."), 1);
@@ -3481,7 +3483,7 @@ ippReadIO(void       *src,		/* I - Data
                 bufptr += 2 + n;
 		n = (bufptr[0] << 8) | bufptr[1];
 
-		if ((bufptr + 2 + n) >= (buffer + IPP_BUF_SIZE))
+		if ((bufptr + 2 + n) > bufend)
 		{
 		  _cupsSetError(IPP_STATUS_ERROR_INTERNAL,
 		                _("IPP string length overflows value."), 1);
diff -pruN 2.3.3op1-5/cups/ppd.c 2.3.3op2-2/cups/ppd.c
--- 2.3.3op1-5/cups/ppd.c	2020-11-27 14:25:26.000000000 +0000
+++ 2.3.3op2-2/cups/ppd.c	2021-02-01 21:10:25.000000000 +0000
@@ -1496,7 +1496,7 @@ _ppdOpen(
 	goto error;
       }
 
-      if (!_cups_strcasecmp(option->defchoice, "custom") || !_cups_strncasecmp(option->defchoice, "custom.", 7))
+      if (option && (!_cups_strcasecmp(option->defchoice, "custom") || !_cups_strncasecmp(option->defchoice, "custom.", 7)))
       {
        /*
 	* "*DefaultOption: Custom..." may set the default to a custom value
@@ -1531,7 +1531,7 @@ _ppdOpen(
 	goto error;
       }
 
-      if (!_cups_strcasecmp(option->defchoice, "custom") || !_cups_strncasecmp(option->defchoice, "custom.", 7))
+      if (option && (!_cups_strcasecmp(option->defchoice, "custom") || !_cups_strncasecmp(option->defchoice, "custom.", 7)))
       {
        /*
 	* "*DefaultOption: Custom..." may set the default to a custom value
diff -pruN 2.3.3op1-5/cups/ppd-cache.c 2.3.3op2-2/cups/ppd-cache.c
--- 2.3.3op1-5/cups/ppd-cache.c	2020-11-27 14:25:26.000000000 +0000
+++ 2.3.3op2-2/cups/ppd-cache.c	2021-02-01 21:10:25.000000000 +0000
@@ -1916,8 +1916,10 @@ _ppdCacheCreateWithPPD(ppd_file_t *ppd)
        ppd_attr = ppdFindNextAttr(ppd, "cupsICCProfile", NULL))
     cupsArrayAdd(pc->support_files, ppd_attr->value);
 
+#ifdef HAVE_APPLICATIONSERVICES_H
   if ((ppd_attr = ppdFindAttr(ppd, "APPrinterIconPath", NULL)) != NULL)
     cupsArrayAdd(pc->support_files, ppd_attr->value);
+#endif
 
  /*
   * Return the cache data...
@@ -3751,6 +3753,8 @@ _ppdCreateFromIPP(char   *buffer,	/* I -
     int wrote_color = 0;
     const char *default_color = NULL;	/* Default */
 
+    cupsFilePrintf(fp, "*%% ColorModel from %s\n", ippGetName(attr));
+
     for (i = 0, count = ippGetCount(attr); i < count; i ++)
     {
       keyword = ippGetString(attr, i, NULL);
@@ -3800,7 +3804,7 @@ _ppdCreateFromIPP(char   *buffer,	/* I -
 
         // Apparently some printers only advertise color support, so make sure
         // we also do grayscale for these printers...
-	if (!ippContainsString(attr, "sgray_8") && !ippContainsString(attr, "black_1") && !ippContainsString(attr, "black_8"))
+	if (!ippContainsString(attr, "sgray_8") && !ippContainsString(attr, "black_1") && !ippContainsString(attr, "black_8") && !ippContainsString(attr, "W8") && !ippContainsString(attr, "W8-16"))
 	  PRINTF_COLOROPTION("Gray", _("GrayScale"), CUPS_CSPACE_SW, 8)
       }
       else if (!strcasecmp(keyword, "adobe-rgb_16") || !strcmp(keyword, "ADOBERGB48") || !strcmp(keyword, "ADOBERGB24-48"))
diff -pruN 2.3.3op1-5/cups/snprintf.c 2.3.3op2-2/cups/snprintf.c
--- 2.3.3op1-5/cups/snprintf.c	2020-11-27 14:25:26.000000000 +0000
+++ 2.3.3op2-2/cups/snprintf.c	2021-02-01 21:10:25.000000000 +0000
@@ -1,6 +1,7 @@
 /*
  * snprintf functions for CUPS.
  *
+ * Copyright © 2021 by Michael R Sweet
  * Copyright © 2007-2019 by Apple Inc.
  * Copyright © 1997-2007 by Easy Software Products.
  *
@@ -81,7 +82,8 @@ _cups_vsnprintf(char       *buffer,	/* O
 	format ++;
 	width = va_arg(ap, int);
 
-	snprintf(tptr, sizeof(tformat) - (tptr - tformat), "%d", width);
+        /* Note: Can't use snprintf here since we are implementing this function... */
+	sprintf(tptr, "%d", width);
 	tptr += strlen(tptr);
       }
       else
@@ -113,7 +115,8 @@ _cups_vsnprintf(char       *buffer,	/* O
 	  format ++;
 	  prec = va_arg(ap, int);
 
-	  snprintf(tptr, sizeof(tformat) - (tptr - tformat), "%d", prec);
+          /* Note: Can't use snprintf here since we are implementing this function... */
+	  sprintf(tptr, "%d", prec);
 	  tptr += strlen(tptr);
 	}
 	else
@@ -171,7 +174,8 @@ _cups_vsnprintf(char       *buffer,	/* O
 	    if ((width + 2) > sizeof(temp))
 	      break;
 
-	    snprintf(temp, sizeof(temp), tformat, va_arg(ap, double));
+            /* Note: Can't use snprintf here since we are implementing this function... */
+	    sprintf(temp, tformat, va_arg(ap, double));
 	    templen = strlen(temp);
 
             bytes += (int)templen;
@@ -202,7 +206,8 @@ _cups_vsnprintf(char       *buffer,	/* O
 	    if ((width + 2) > sizeof(temp))
 	      break;
 
-	    snprintf(temp, sizeof(temp), tformat, va_arg(ap, int));
+	    /* Note: Can't use snprintf here since we are implementing this function... */
+	    sprintf(temp, tformat, va_arg(ap, int));
 	    templen = strlen(temp);
 
             bytes += (int)templen;
@@ -226,7 +231,8 @@ _cups_vsnprintf(char       *buffer,	/* O
 	    if ((width + 2) > sizeof(temp))
 	      break;
 
-	    snprintf(temp, sizeof(temp), tformat, va_arg(ap, void *));
+	    /* Note: Can't use snprintf here since we are implementing this function... */
+	    sprintf(temp, tformat, va_arg(ap, void *));
 	    templen = strlen(temp);
 
             bytes += (int)templen;
diff -pruN 2.3.3op1-5/cups/tls-gnutls.c 2.3.3op2-2/cups/tls-gnutls.c
--- 2.3.3op1-5/cups/tls-gnutls.c	2020-11-27 14:25:26.000000000 +0000
+++ 2.3.3op2-2/cups/tls-gnutls.c	2021-02-01 21:10:25.000000000 +0000
@@ -1,6 +1,7 @@
 /*
  * TLS support code for CUPS using GNU TLS.
  *
+ * Copyright © 2020 by Michael R Sweet
  * Copyright © 2007-2019 by Apple Inc.
  * Copyright © 1997-2007 by Easy Software Products, all rights reserved.
  *
@@ -939,7 +940,7 @@ http_gnutls_default_path(char   *buffer,
 					/* Pointer to library globals */
 
 
-  if (cg->home)
+  if (cg->home && getuid())
   {
     snprintf(buffer, bufsize, "%s/.cups", cg->home);
     if (access(buffer, 0))
diff -pruN 2.3.3op1-5/debian/changelog 2.3.3op2-2/debian/changelog
--- 2.3.3op1-5/debian/changelog	2021-01-08 10:35:18.000000000 +0000
+++ 2.3.3op2-2/debian/changelog	2021-02-03 12:13:18.000000000 +0000
@@ -1,3 +1,34 @@
+cups (2.3.3op2-2) unstable; urgency=medium
+
+  * Bump debhelper compat to 13, document not-installed files
+
+ -- Didier Raboud <odyx@debian.org>  Wed, 03 Feb 2021 13:13:18 +0100
+
+cups (2.3.3op2-1) unstable; urgency=medium
+
+  * New OpenPrinting 2.3.3op2 release
+    - CVE-2020-10001: Fixed a buffer (read) overflow in the `ippReadIO`
+      function
+    - Drop 4 patches merged upstream
+  * Update d/copyright authors and years
+
+ -- Didier Raboud <odyx@debian.org>  Tue, 02 Feb 2021 21:20:06 +0100
+
+cups (2.3.3op1-7) unstable; urgency=medium
+
+  [ Helmut Grohne ]
+  * Reduce Build-Depends, move dh_apparmor to B-D-A (Closes: #980104)
+
+ -- Didier Raboud <odyx@debian.org>  Fri, 15 Jan 2021 12:11:30 +0100
+
+cups (2.3.3op1-6) unstable; urgency=medium
+
+  [ Till Kamppeter ]
+  * In the AppArmor profile, allow cupsd to write to /run/systemd/notify to
+    notify that it is up and running (systemd service type "notify")
+
+ -- Didier Raboud <odyx@debian.org>  Mon, 11 Jan 2021 08:31:58 +0100
+
 cups (2.3.3op1-5) unstable; urgency=medium
 
   * Update Homepage and Source fields to point
diff -pruN 2.3.3op1-5/debian/control 2.3.3op2-2/debian/control
--- 2.3.3op1-5/debian/control	2021-01-08 10:35:18.000000000 +0000
+++ 2.3.3op2-2/debian/control	2021-02-03 12:13:18.000000000 +0000
@@ -4,37 +4,26 @@ Uploaders: Didier Raboud <odyx@debian.or
            Till Kamppeter <till.kamppeter@gmail.com>
 Section: net
 Priority: optional
-Build-Depends: debhelper-compat (= 12),
-               dh-apparmor,
+Build-Depends: debhelper-compat (= 13),
                dh-strip-nondeterminism,
                patch,
                autoconf,
                automake,
                libtool,
                pkg-config,
-               ghostscript,
                libavahi-client-dev,
                libavahi-common-dev,
-               libavahi-compat-libdnssd-dev,
                libdbus-1-dev,
-               libfontconfig1-dev,
-               libfreetype6-dev,
                libgnutls28-dev,
-               libijs-dev,
-               libjpeg-dev,
-               libldap2-dev,
                libkrb5-dev,
                libpam0g-dev,
                libpaper-dev,
-               libpng-dev,
                libsystemd-dev [linux-any],
-               libtiff-dev,
                libusb-1.0-0-dev [!hurd-any],
                po4a,
                po-debconf,
-               poppler-utils,
-               sharutils,
                zlib1g-dev
+Build-Depends-Arch: dh-apparmor,
 # libgmp-dev is not GPL-2 compatible before it's 6 release, which makes it also GPL-2+
 Build-Conflicts: libgmp-dev (<< 2:6)
 Standards-Version: 4.5.1
diff -pruN 2.3.3op1-5/debian/copyright 2.3.3op2-2/debian/copyright
--- 2.3.3op1-5/debian/copyright	2021-01-08 10:35:18.000000000 +0000
+++ 2.3.3op2-2/debian/copyright	2021-02-03 12:13:18.000000000 +0000
@@ -2,12 +2,15 @@ Format: https://www.debian.org/doc/packa
 Upstream-Name: CUPS
 Upstream-Contact: Michael Sweet <msweet@apple.com>
 Source: https://github.com/OpenPrinting/cups/
-Copyright: 2005-2019, Apple Inc.
+Copyright: 2020-2021 by Michael R Sweet
+  2007-2019 by Apple Inc.
+  1997-2007 by Easy Software Products.
 License: Apache-2.0-with-GPL2-LGPL2-Exception
 
 Files: *
-Copyright: 2007-2019, Apple Inc.
-  1993-2007, Easy Software Products
+Copyright: 2020-2021 by Michael R Sweet
+  2007-2019 by Apple Inc.
+  1997-2007 by Easy Software Products.
 License: Apache-2.0-with-GPL2-LGPL2-Exception
 
 Files: config-scripts/cups-gssapi.m4
diff -pruN 2.3.3op1-5/debian/local/apparmor-profile 2.3.3op2-2/debian/local/apparmor-profile
--- 2.3.3op1-5/debian/local/apparmor-profile	2021-01-08 10:35:18.000000000 +0000
+++ 2.3.3op2-2/debian/local/apparmor-profile	2021-02-03 12:13:18.000000000 +0000
@@ -47,6 +47,11 @@
   network econet dgram,
   network ash dgram,
 
+  # CUPS is of systemd service type "notify" now, meaning that cupsd notifies
+  # systemd when it is up and running, give CUPS access to systemd's
+  # notification socket
+  /run/systemd/notify w,
+
   /{usr/,}bin/bash ixr,
   /{usr/,}bin/dash ixr,
   /{usr/,}bin/hostname ixr,
diff -pruN 2.3.3op1-5/debian/not-installed 2.3.3op2-2/debian/not-installed
--- 2.3.3op1-5/debian/not-installed	1970-01-01 00:00:00.000000000 +0000
+++ 2.3.3op2-2/debian/not-installed	2021-02-03 12:13:18.000000000 +0000
@@ -0,0 +1,43 @@
+# Debian moves this to /usr/share/cups/cupsd.conf.default
+etc/cups/cupsd.conf
+# Back from CUPS 1.5
+etc/dbus-1/system.d/cups.conf
+# Installed by dh_installpam (debian/cups-daemon.cups.pam)
+etc/pam.d/cups
+# Deprecated, not installed (use xinetd)
+lib/systemd/system/cups-lpd.socket
+lib/systemd/system/cups-lpd@.service
+# Not decided whether worth installing or not yet
+usr/bin/ippeveprinter
+usr/lib/cups/command/ippevepcl
+usr/lib/cups/command/ippeveps
+usr/share/man/man7/ippevepcl.7
+usr/share/man/man7/ippeveps.7
+# Ipptool utils
+usr/share/cups/ipptool/color.jpg
+usr/share/cups/ipptool/document-a4.pdf
+usr/share/cups/ipptool/document-a4.ps
+usr/share/cups/ipptool/document-letter.pdf
+usr/share/cups/ipptool/document-letter.ps
+usr/share/cups/ipptool/gray.jpg
+usr/share/cups/ipptool/onepage-a4.pdf
+usr/share/cups/ipptool/onepage-a4.ps
+usr/share/cups/ipptool/onepage-letter.pdf
+usr/share/cups/ipptool/onepage-letter.ps
+usr/share/cups/ipptool/testfile.jpg
+usr/share/cups/ipptool/testfile.pcl
+usr/share/cups/ipptool/testfile.pdf
+usr/share/cups/ipptool/testfile.ps
+usr/share/cups/ipptool/testfile.txt
+# CUPS "desktop" entry, to access the webinterface
+usr/share/applications/cups.desktop
+usr/share/icons/hicolor/*x*/apps/cups.png
+# Translated manpages only get installed if sufficiently translated
+usr/share/man/de/man1/*.1
+usr/share/man/de/man5/*.5
+usr/share/man/de/man7/*.7
+usr/share/man/de/man8/*.8
+usr/share/man/fr/man1/*.1
+usr/share/man/fr/man5/*.5
+usr/share/man/fr/man7/*.7
+usr/share/man/fr/man8/*.8
diff -pruN 2.3.3op1-5/debian/patches/0001-Apple-AirPrint-support.patch 2.3.3op2-2/debian/patches/0001-Apple-AirPrint-support.patch
--- 2.3.3op1-5/debian/patches/0001-Apple-AirPrint-support.patch	1970-01-01 00:00:00.000000000 +0000
+++ 2.3.3op2-2/debian/patches/0001-Apple-AirPrint-support.patch	2021-02-03 12:13:18.000000000 +0000
@@ -0,0 +1,90 @@
+From: Till Kamppeter <till.kamppeter@gmail.com>
+Date: Tue, 9 Aug 2016 18:11:29 +0200
+Subject: Apple AirPrint support
+
+Bug-Ubuntu: https://bugs.launchpad.net/bugs/711779
+Bug-Ubuntu: https://bugs.launchpad.net/bugs/1054495
+Bug-Debian: https://bugs.debian.org/700961
+Bug: https://github.com/apple/cups/issues/4341
+Bug: https://github.com/OpenPrinting/cups/pull/27
+---
+ conf/mime.convs.in   | 3 +++
+ conf/mime.types      | 3 +++
+ scheduler/conf.c     | 2 +-
+ scheduler/dirsvc.c   | 6 ++++++
+ scheduler/printers.c | 4 +++-
+ 5 files changed, 16 insertions(+), 2 deletions(-)
+
+diff --git a/conf/mime.convs.in b/conf/mime.convs.in
+index 57b459d..e042e01 100644
+--- a/conf/mime.convs.in
++++ b/conf/mime.convs.in
+@@ -44,6 +44,9 @@ application/postscript		application/vnd.cups-postscript	66	pstops
+ application/vnd.cups-raster	image/pwg-raster		100	rastertopwg
+ application/vnd.cups-raster	image/urf			100	rastertopwg
+ 
++# Needed for printing from iOS (AirPrint) clients
++image/urf    	      	       application/pdf			100	-
++
+ ########################################################################
+ #
+ # Raw filter...
+diff --git a/conf/mime.types b/conf/mime.types
+index fcd6b6e..ebb0525 100644
+--- a/conf/mime.types
++++ b/conf/mime.types
+@@ -108,6 +108,9 @@ image/x-alias			pix short(8,8) short(8,24)
+ image/x-bitmap			bmp string(0,BM) + !printable(2,14)
+ image/x-icon			ico
+ 
++# Needed for printing from iOS (AirPrint) clients
++image/urf			urf string(0,UNIRAST<00>)
++
+ ########################################################################
+ #
+ # Text files...
+diff --git a/scheduler/conf.c b/scheduler/conf.c
+index 74531a8..bfd1b0b 100644
+--- a/scheduler/conf.c
++++ b/scheduler/conf.c
+@@ -750,7 +750,7 @@ cupsdReadConfiguration(void)
+   DefaultShared            = CUPS_DEFAULT_DEFAULT_SHARED;
+ 
+ #if defined(HAVE_DNSSD) || defined(HAVE_AVAHI)
+-  cupsdSetString(&DNSSDSubTypes, "_cups,_print");
++  cupsdSetString(&DNSSDSubTypes, "_cups,_print,_universal");
+   cupsdClearString(&DNSSDHostName);
+ #endif /* HAVE_DNSSD || HAVE_AVAHI */
+ 
+diff --git a/scheduler/dirsvc.c b/scheduler/dirsvc.c
+index ddd3701..fb2a305 100644
+--- a/scheduler/dirsvc.c
++++ b/scheduler/dirsvc.c
+@@ -440,6 +440,12 @@ dnssdBuildTxtRecord(
+     keyvalue[count  ][0] = "pdl";
+     keyvalue[count++][1] = p->pdl ? p->pdl : "application/postscript";
+ 
++    /* iOS 6 does not accept this printer as AirPrint printer if there is
++       no URF txt record or "URF=none", "DM3" is the minimum needed found
++       by try and error */
++    keyvalue[count  ][0] = "URF";
++    keyvalue[count++][1] = "DM3";
++
+     if (get_auth_info_required(p, air_str, sizeof(air_str)))
+     {
+       keyvalue[count  ][0] = "air";
+diff --git a/scheduler/printers.c b/scheduler/printers.c
+index 7e9a9f2..3e00874 100644
+--- a/scheduler/printers.c
++++ b/scheduler/printers.c
+@@ -3733,7 +3733,9 @@ add_printer_formats(cupsd_printer_t *p)	/* I - Printer */
+       }
+       else if (!_cups_strcasecmp(type->super, "image"))
+       {
+-        if (!_cups_strcasecmp(type->type, "jpeg"))
++        if (!_cups_strcasecmp(type->type, "urf"))
++	  strlcat(pdl, "image/urf,", sizeof(pdl));
++	else if (!_cups_strcasecmp(type->type, "jpeg"))
+ 	  strlcat(pdl, "image/jpeg,", sizeof(pdl));
+ 	else if (!_cups_strcasecmp(type->type, "png"))
+ 	  strlcat(pdl, "image/png,", sizeof(pdl));
diff -pruN 2.3.3op1-5/debian/patches/0001-Force-a-5-second-sleep-to-wait-for-the-job-control-f.patch 2.3.3op2-2/debian/patches/0001-Force-a-5-second-sleep-to-wait-for-the-job-control-f.patch
--- 2.3.3op1-5/debian/patches/0001-Force-a-5-second-sleep-to-wait-for-the-job-control-f.patch	2021-01-08 10:35:18.000000000 +0000
+++ 2.3.3op2-2/debian/patches/0001-Force-a-5-second-sleep-to-wait-for-the-job-control-f.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,21 +0,0 @@
-From: Michael R Sweet <msweet@msweet.org>
-Date: Sat, 28 Nov 2020 08:43:46 -0500
-Subject: Force a 5 second sleep to wait for the job control file to be
- written.
-
----
- test/run-stp-tests.sh | 1 +
- 1 file changed, 1 insertion(+)
-
-diff --git a/test/run-stp-tests.sh b/test/run-stp-tests.sh
-index 1af6d07..0bf95c5 100755
---- a/test/run-stp-tests.sh
-+++ b/test/run-stp-tests.sh
-@@ -844,6 +844,7 @@ else
- 	echo "PASS"
- 	echo "    PASSED" >>$strfile
- 
-+	sleep 5
- 	./waitjobs.sh >>$strfile
- 
-         echo $ac_n "Verifying that history still exists: $ac_c"
diff -pruN 2.3.3op1-5/debian/patches/0002-Keep-foomatic-PPDs-recommended-stanzas-in-NickNames.patch 2.3.3op2-2/debian/patches/0002-Keep-foomatic-PPDs-recommended-stanzas-in-NickNames.patch
--- 2.3.3op1-5/debian/patches/0002-Keep-foomatic-PPDs-recommended-stanzas-in-NickNames.patch	1970-01-01 00:00:00.000000000 +0000
+++ 2.3.3op2-2/debian/patches/0002-Keep-foomatic-PPDs-recommended-stanzas-in-NickNames.patch	2021-02-03 12:13:18.000000000 +0000
@@ -0,0 +1,37 @@
+From: Till Kampetter <till.kampetter@gmail.com>
+Date: Tue, 9 Aug 2016 18:11:36 +0200
+Subject: Keep foomatic PPDs "(recommended)" stanzas in NickNames
+
+Bug-Upstream: https://github.com/OpenPrinting/cups/pull/33
+---
+ scheduler/cups-driverd.cxx | 10 ----------
+ 1 file changed, 10 deletions(-)
+
+diff --git a/scheduler/cups-driverd.cxx b/scheduler/cups-driverd.cxx
+index 85516eb..874eb3c 100644
+--- a/scheduler/cups-driverd.cxx
++++ b/scheduler/cups-driverd.cxx
+@@ -240,7 +240,6 @@ add_ppd(const char *filename,		/* I - PPD filename */
+ 	const char *scheme)		/* I - PPD scheme */
+ {
+   ppd_info_t	*ppd;			/* PPD */
+-  char		*recommended;		/* Foomatic driver string */
+ 
+ 
+  /*
+@@ -278,15 +277,6 @@ add_ppd(const char *filename,		/* I - PPD filename */
+   strlcpy(ppd->record.device_id, device_id, sizeof(ppd->record.device_id));
+   strlcpy(ppd->record.scheme, scheme, sizeof(ppd->record.scheme));
+ 
+- /*
+-  * Strip confusing (and often wrong) "recommended" suffix added by
+-  * Foomatic drivers...
+-  */
+-
+-  if ((recommended = strstr(ppd->record.make_and_model,
+-                            " (recommended)")) != NULL)
+-    *recommended = '\0';
+-
+  /*
+   * Add the PPD to the PPD arrays...
+   */
diff -pruN 2.3.3op1-5/debian/patches/0002-SERVERBIN-match-host_os_name-on-gnu-first-to-catch-k.patch 2.3.3op2-2/debian/patches/0002-SERVERBIN-match-host_os_name-on-gnu-first-to-catch-k.patch
--- 2.3.3op1-5/debian/patches/0002-SERVERBIN-match-host_os_name-on-gnu-first-to-catch-k.patch	2021-01-08 10:35:18.000000000 +0000
+++ 2.3.3op2-2/debian/patches/0002-SERVERBIN-match-host_os_name-on-gnu-first-to-catch-k.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,28 +0,0 @@
-From: Didier Raboud <odyx@debian.org>
-Date: Thu, 3 Dec 2020 12:32:54 +0100
-Subject: SERVERBIN: match host_os_name on *-gnu first,
- to catch kfreebsd-gnu before *bsd*
-
-Debian's kfreebsd-gnu architectures (kfreebsd-amd64 and kfreebsd-i386) work as Debian/GNU systems, hence with a /usr/lib/cups SERVERBIN, not a /usr/libexec/cups.
-
-Bug-Upstream: https://github.com/OpenPrinting/cups/pull/60
----
- config-scripts/cups-directories.m4 | 5 +++++
- 1 file changed, 5 insertions(+)
-
-diff --git a/config-scripts/cups-directories.m4 b/config-scripts/cups-directories.m4
-index b74083a..1430af3 100644
---- a/config-scripts/cups-directories.m4
-+++ b/config-scripts/cups-directories.m4
-@@ -262,6 +262,11 @@ AC_SUBST(CUPS_REQUESTS)
- 
- # Server executables...
- case "$host_os_name" in
-+	*-gnu)
-+		# GNUs
-+		INSTALL_SYSV="install-sysv"
-+		CUPS_SERVERBIN="$exec_prefix/lib/cups"
-+		;;
- 	*bsd* | darwin*)
- 		# *BSD and Darwin (macOS)
- 		INSTALL_SYSV=""
diff -pruN 2.3.3op1-5/debian/patches/0003-CUPS_EXE_FILE_PERM-also-match-host_os_name-on-gnu-to.patch 2.3.3op2-2/debian/patches/0003-CUPS_EXE_FILE_PERM-also-match-host_os_name-on-gnu-to.patch
--- 2.3.3op1-5/debian/patches/0003-CUPS_EXE_FILE_PERM-also-match-host_os_name-on-gnu-to.patch	2021-01-08 10:35:18.000000000 +0000
+++ 2.3.3op2-2/debian/patches/0003-CUPS_EXE_FILE_PERM-also-match-host_os_name-on-gnu-to.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,25 +0,0 @@
-From: Didier Raboud <odyx@debian.org>
-Date: Thu, 3 Dec 2020 18:33:35 +0100
-Subject: CUPS_EXE_FILE_PERM: also match host_os_name on *-gnu,
- to also catch kfreebsd-gnu
-
-Debian's kfreebsd-gnu architectures (kfreebsd-amd64 and kfreebsd-i386) work as Debian/GNU systems, hence with a 755 CUP_EXE_FILE_PERM, not 555
-
-Bug-Upstream: https://github.com/OpenPrinting/cups/pull/61
----
- config-scripts/cups-defaults.m4 | 2 +-
- 1 file changed, 1 insertion(+), 1 deletion(-)
-
-diff --git a/config-scripts/cups-defaults.m4 b/config-scripts/cups-defaults.m4
-index 7a2d35a..9e05bd4 100644
---- a/config-scripts/cups-defaults.m4
-+++ b/config-scripts/cups-defaults.m4
-@@ -53,7 +53,7 @@ dnl Default executable file permissions
- AC_ARG_WITH(exe_file_perm, [  --with-exe-file-perm    set default executable permissions value, default=0555],
- 	CUPS_EXE_FILE_PERM="$withval",
- 	[case "$host_os_name" in
--		linux* | gnu*)
-+		linux* | gnu* | *-gnu)
- 			CUPS_EXE_FILE_PERM="755"
- 			;;
- 		*)
diff -pruN 2.3.3op1-5/debian/patches/0003-Debian-Set-LogFileGroup-to-adm.patch 2.3.3op2-2/debian/patches/0003-Debian-Set-LogFileGroup-to-adm.patch
--- 2.3.3op1-5/debian/patches/0003-Debian-Set-LogFileGroup-to-adm.patch	1970-01-01 00:00:00.000000000 +0000
+++ 2.3.3op2-2/debian/patches/0003-Debian-Set-LogFileGroup-to-adm.patch	2021-02-03 12:13:18.000000000 +0000
@@ -0,0 +1,23 @@
+From: Martin Pitt <mpitt@debian.org>
+Date: Tue, 9 Aug 2016 18:11:38 +0200
+Subject: Debian: Set LogFileGroup to adm
+
+---
+ conf/cups-files.conf.in | 4 ++++
+ 1 file changed, 4 insertions(+)
+
+diff --git a/conf/cups-files.conf.in b/conf/cups-files.conf.in
+index af11fcc..80ca351 100644
+--- a/conf/cups-files.conf.in
++++ b/conf/cups-files.conf.in
+@@ -29,6 +29,10 @@ SystemGroup @CUPS_SYSTEM_GROUPS@
+ #ConfigFilePerm 0@CUPS_CONFIG_FILE_PERM@
+ #LogFilePerm 0@CUPS_LOG_FILE_PERM@
+ 
++# Specifies the group name or ID that will be used for log files.
++# The default group in Debian is "adm".
++LogFileGroup adm
++
+ # Location of the file logging all access to the scheduler; may be the name
+ # "syslog". If not an absolute path, the value of ServerRoot is used as the
+ # root directory.  Also see the "AccessLogLevel" directive in cupsd.conf.
diff -pruN 2.3.3op1-5/debian/patches/0004-Debian-Move-cupsd.conf.default-from-SERVERROOT-to-DA.patch 2.3.3op2-2/debian/patches/0004-Debian-Move-cupsd.conf.default-from-SERVERROOT-to-DA.patch
--- 2.3.3op1-5/debian/patches/0004-Debian-Move-cupsd.conf.default-from-SERVERROOT-to-DA.patch	1970-01-01 00:00:00.000000000 +0000
+++ 2.3.3op2-2/debian/patches/0004-Debian-Move-cupsd.conf.default-from-SERVERROOT-to-DA.patch	2021-02-03 12:13:18.000000000 +0000
@@ -0,0 +1,62 @@
+From: Didier Raboud <odyx@debian.org>
+Date: Tue, 9 Aug 2016 18:11:24 +0200
+Subject: Debian: Move cupsd.conf.default from SERVERROOT to DATADIR
+
+Origin: vendor
+Bug: https://github.com/apple/cups/issues/4342
+Bug: https://github.com/OpenPrinting/cups/pull/26
+Bug-Debian: https://bugs.debian.org/640124
+---
+ cgi-bin/admin.c | 6 +++++-
+ conf/Makefile   | 5 +++--
+ 2 files changed, 8 insertions(+), 3 deletions(-)
+
+diff --git a/cgi-bin/admin.c b/cgi-bin/admin.c
+index c648938..5ff7501 100644
+--- a/cgi-bin/admin.c
++++ b/cgi-bin/admin.c
+@@ -1636,6 +1636,7 @@ do_config_server(http_t *http)		/* I - HTTP connection */
+     int		ch;			/* Character from file */
+     char	filename[1024];		/* Filename */
+     const char	*server_root;		/* Location of config files */
++    const char	*data_dir;		/* Location of data files */
+ 
+ 
+    /*
+@@ -1719,7 +1720,10 @@ do_config_server(http_t *http)		/* I - HTTP connection */
+     * well...
+     */
+ 
+-    strlcat(filename, ".default", sizeof(filename));
++    if ((data_dir = getenv("CUPS_DATADIR")) == NULL)
++      data_dir = CUPS_DATADIR;
++
++    snprintf(filename, sizeof(filename), "%s/cupsd.conf.default",data_dir);
+ 
+     if (!stat(filename, &info) && info.st_size < (1024 * 1024) &&
+         (cupsd = cupsFileOpen(filename, "r")) != NULL)
+diff --git a/conf/Makefile b/conf/Makefile
+index e249e60..42a123f 100644
+--- a/conf/Makefile
++++ b/conf/Makefile
+@@ -70,7 +70,7 @@ install-data:
+ 		else \
+ 			$(INSTALL_CONFIG) -g $(CUPS_GROUP) $$file $(SERVERROOT) ; \
+ 		fi ; \
+-		$(INSTALL_CONFIG) -g $(CUPS_GROUP) $$file $(SERVERROOT)/$$file.default; \
++		$(INSTALL_CONFIG) -g $(CUPS_GROUP) $$file $(DATADIR)/$$file.default; \
+ 	done
+ 	$(INSTALL_DIR) -m 755 $(DATADIR)/mime
+ 	for file in $(REPLACE); do \
+@@ -118,9 +118,10 @@ install-libs:
+ #
+ 
+ uninstall:
+-	for file in $(KEEP) $(REPLACE) cupsd.conf.default; do \
++	for file in $(KEEP) $(REPLACE); do \
+ 		$(RM) $(SERVERROOT)/$$file; \
+ 	done
++	$(RM) $(DATADIR)/cupsd.conf.default
+ 	-$(RMDIR) $(SERVERROOT)
+ 	for file in $(REPLACE); do \
+ 		$(RM) $(DATADIR)/mime/$$file; \
diff -pruN 2.3.3op1-5/debian/patches/0004-Systemd-Let-cups.service-start-after-nslcd.service.patch 2.3.3op2-2/debian/patches/0004-Systemd-Let-cups.service-start-after-nslcd.service.patch
--- 2.3.3op1-5/debian/patches/0004-Systemd-Let-cups.service-start-after-nslcd.service.patch	2021-01-08 10:35:18.000000000 +0000
+++ 2.3.3op2-2/debian/patches/0004-Systemd-Let-cups.service-start-after-nslcd.service.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,23 +0,0 @@
-From: Wolfgang Schweer <w.schweer@gmx.de>
-Date: Sat, 12 Dec 2020 13:38:52 +0100
-Subject: Systemd: Let cups.service start after nslcd.service
-
-Bug-Debian: #977198
-Bug-Upstream: https://github.com/OpenPrinting/cups/issues/69
----
- scheduler/cups.service.in | 2 +-
- 1 file changed, 1 insertion(+), 1 deletion(-)
-
-diff --git a/scheduler/cups.service.in b/scheduler/cups.service.in
-index 9e70b29..a3fa0e8 100644
---- a/scheduler/cups.service.in
-+++ b/scheduler/cups.service.in
-@@ -1,7 +1,7 @@
- [Unit]
- Description=CUPS Scheduler
- Documentation=man:cupsd(8)
--After=network.target sssd.service ypbind.service
-+After=network.target sssd.service ypbind.service nslcd.service
- Requires=cups.socket
- 
- [Service]
diff -pruN 2.3.3op1-5/debian/patches/0005-Apple-AirPrint-support.patch 2.3.3op2-2/debian/patches/0005-Apple-AirPrint-support.patch
--- 2.3.3op1-5/debian/patches/0005-Apple-AirPrint-support.patch	2021-01-08 10:35:18.000000000 +0000
+++ 2.3.3op2-2/debian/patches/0005-Apple-AirPrint-support.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,90 +0,0 @@
-From: Till Kamppeter <till.kamppeter@gmail.com>
-Date: Tue, 9 Aug 2016 18:11:29 +0200
-Subject: Apple AirPrint support
-
-Bug-Ubuntu: https://bugs.launchpad.net/bugs/711779
-Bug-Ubuntu: https://bugs.launchpad.net/bugs/1054495
-Bug-Debian: https://bugs.debian.org/700961
-Bug: https://github.com/apple/cups/issues/4341
-Bug: https://github.com/OpenPrinting/cups/pull/27
----
- conf/mime.convs.in   | 3 +++
- conf/mime.types      | 3 +++
- scheduler/conf.c     | 2 +-
- scheduler/dirsvc.c   | 6 ++++++
- scheduler/printers.c | 4 +++-
- 5 files changed, 16 insertions(+), 2 deletions(-)
-
-diff --git a/conf/mime.convs.in b/conf/mime.convs.in
-index 57b459d..e042e01 100644
---- a/conf/mime.convs.in
-+++ b/conf/mime.convs.in
-@@ -44,6 +44,9 @@ application/postscript		application/vnd.cups-postscript	66	pstops
- application/vnd.cups-raster	image/pwg-raster		100	rastertopwg
- application/vnd.cups-raster	image/urf			100	rastertopwg
- 
-+# Needed for printing from iOS (AirPrint) clients
-+image/urf    	      	       application/pdf			100	-
-+
- ########################################################################
- #
- # Raw filter...
-diff --git a/conf/mime.types b/conf/mime.types
-index fcd6b6e..ebb0525 100644
---- a/conf/mime.types
-+++ b/conf/mime.types
-@@ -108,6 +108,9 @@ image/x-alias			pix short(8,8) short(8,24)
- image/x-bitmap			bmp string(0,BM) + !printable(2,14)
- image/x-icon			ico
- 
-+# Needed for printing from iOS (AirPrint) clients
-+image/urf			urf string(0,UNIRAST<00>)
-+
- ########################################################################
- #
- # Text files...
-diff --git a/scheduler/conf.c b/scheduler/conf.c
-index 74531a8..bfd1b0b 100644
---- a/scheduler/conf.c
-+++ b/scheduler/conf.c
-@@ -750,7 +750,7 @@ cupsdReadConfiguration(void)
-   DefaultShared            = CUPS_DEFAULT_DEFAULT_SHARED;
- 
- #if defined(HAVE_DNSSD) || defined(HAVE_AVAHI)
--  cupsdSetString(&DNSSDSubTypes, "_cups,_print");
-+  cupsdSetString(&DNSSDSubTypes, "_cups,_print,_universal");
-   cupsdClearString(&DNSSDHostName);
- #endif /* HAVE_DNSSD || HAVE_AVAHI */
- 
-diff --git a/scheduler/dirsvc.c b/scheduler/dirsvc.c
-index ddd3701..fb2a305 100644
---- a/scheduler/dirsvc.c
-+++ b/scheduler/dirsvc.c
-@@ -440,6 +440,12 @@ dnssdBuildTxtRecord(
-     keyvalue[count  ][0] = "pdl";
-     keyvalue[count++][1] = p->pdl ? p->pdl : "application/postscript";
- 
-+    /* iOS 6 does not accept this printer as AirPrint printer if there is
-+       no URF txt record or "URF=none", "DM3" is the minimum needed found
-+       by try and error */
-+    keyvalue[count  ][0] = "URF";
-+    keyvalue[count++][1] = "DM3";
-+
-     if (get_auth_info_required(p, air_str, sizeof(air_str)))
-     {
-       keyvalue[count  ][0] = "air";
-diff --git a/scheduler/printers.c b/scheduler/printers.c
-index 7e9a9f2..3e00874 100644
---- a/scheduler/printers.c
-+++ b/scheduler/printers.c
-@@ -3733,7 +3733,9 @@ add_printer_formats(cupsd_printer_t *p)	/* I - Printer */
-       }
-       else if (!_cups_strcasecmp(type->super, "image"))
-       {
--        if (!_cups_strcasecmp(type->type, "jpeg"))
-+        if (!_cups_strcasecmp(type->type, "urf"))
-+	  strlcat(pdl, "image/urf,", sizeof(pdl));
-+	else if (!_cups_strcasecmp(type->type, "jpeg"))
- 	  strlcat(pdl, "image/jpeg,", sizeof(pdl));
- 	else if (!_cups_strcasecmp(type->type, "png"))
- 	  strlcat(pdl, "image/png,", sizeof(pdl));
diff -pruN 2.3.3op1-5/debian/patches/0005-Debian-Do-not-alter-the-permissions-of-cupsd.conf-ev.patch 2.3.3op2-2/debian/patches/0005-Debian-Do-not-alter-the-permissions-of-cupsd.conf-ev.patch
--- 2.3.3op1-5/debian/patches/0005-Debian-Do-not-alter-the-permissions-of-cupsd.conf-ev.patch	1970-01-01 00:00:00.000000000 +0000
+++ 2.3.3op2-2/debian/patches/0005-Debian-Do-not-alter-the-permissions-of-cupsd.conf-ev.patch	2021-02-03 12:13:18.000000000 +0000
@@ -0,0 +1,27 @@
+From: Martin Pitt <mpitt@debian.org>
+Date: Tue, 9 Aug 2016 18:11:41 +0200
+Subject: Debian: Do not alter the permissions of cupsd.conf, ever
+
+Origin: vendor
+Bug: https://github.com/OpenPrinting/cups/pull/36
+---
+ scheduler/conf.c | 2 ++
+ 1 file changed, 2 insertions(+)
+
+diff --git a/scheduler/conf.c b/scheduler/conf.c
+index bfd1b0b..c8cd5ea 100644
+--- a/scheduler/conf.c
++++ b/scheduler/conf.c
+@@ -1140,10 +1140,12 @@ cupsdReadConfiguration(void)
+ 			     Group, 1, 1) < 0 ||
+        cupsdCheckPermissions(ServerRoot, "ssl", 0700, RunUser,
+ 			     Group, 1, 0) < 0 ||
++       /* Never alter permissions of central conffile
+        cupsdCheckPermissions(ConfigurationFile, NULL, ConfigFilePerm, RunUser,
+ 			     Group, 0, 0) < 0 ||
+        cupsdCheckPermissions(CupsFilesFile, NULL, ConfigFilePerm, RunUser,
+ 			     Group, 0, 0) < 0 ||
++       */
+        cupsdCheckPermissions(ServerRoot, "classes.conf", 0600, RunUser,
+ 			     Group, 0, 0) < 0 ||
+        cupsdCheckPermissions(ServerRoot, "printers.conf", 0600, RunUser,
diff -pruN 2.3.3op1-5/debian/patches/0006-Debian-Show-compile-command-lines.patch 2.3.3op2-2/debian/patches/0006-Debian-Show-compile-command-lines.patch
--- 2.3.3op1-5/debian/patches/0006-Debian-Show-compile-command-lines.patch	1970-01-01 00:00:00.000000000 +0000
+++ 2.3.3op2-2/debian/patches/0006-Debian-Show-compile-command-lines.patch	2021-02-03 12:13:18.000000000 +0000
@@ -0,0 +1,20 @@
+From: Till Kampetter <till.kampetter@gmail.com>
+Date: Tue, 9 Aug 2016 18:11:43 +0200
+Subject: Debian: Show compile command lines
+
+---
+ Makedefs.in | 1 -
+ 1 file changed, 1 deletion(-)
+
+diff --git a/Makedefs.in b/Makedefs.in
+index 9ee7585..038bb94 100644
+--- a/Makedefs.in
++++ b/Makedefs.in
+@@ -263,7 +263,6 @@ USBQUIRKS	=	@USBQUIRKS@
+ # Rules...
+ #
+ 
+-.SILENT:
+ .SUFFIXES:	.a .c .cxx .h .o
+ 
+ .c.o:
diff -pruN 2.3.3op1-5/debian/patches/0006-Keep-foomatic-PPDs-recommended-stanzas-in-NickNames.patch 2.3.3op2-2/debian/patches/0006-Keep-foomatic-PPDs-recommended-stanzas-in-NickNames.patch
--- 2.3.3op1-5/debian/patches/0006-Keep-foomatic-PPDs-recommended-stanzas-in-NickNames.patch	2021-01-08 10:35:18.000000000 +0000
+++ 2.3.3op2-2/debian/patches/0006-Keep-foomatic-PPDs-recommended-stanzas-in-NickNames.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,37 +0,0 @@
-From: Till Kampetter <till.kampetter@gmail.com>
-Date: Tue, 9 Aug 2016 18:11:36 +0200
-Subject: Keep foomatic PPDs "(recommended)" stanzas in NickNames
-
-Bug-Upstream: https://github.com/OpenPrinting/cups/pull/33
----
- scheduler/cups-driverd.cxx | 10 ----------
- 1 file changed, 10 deletions(-)
-
-diff --git a/scheduler/cups-driverd.cxx b/scheduler/cups-driverd.cxx
-index 85516eb..874eb3c 100644
---- a/scheduler/cups-driverd.cxx
-+++ b/scheduler/cups-driverd.cxx
-@@ -240,7 +240,6 @@ add_ppd(const char *filename,		/* I - PPD filename */
- 	const char *scheme)		/* I - PPD scheme */
- {
-   ppd_info_t	*ppd;			/* PPD */
--  char		*recommended;		/* Foomatic driver string */
- 
- 
-  /*
-@@ -278,15 +277,6 @@ add_ppd(const char *filename,		/* I - PPD filename */
-   strlcpy(ppd->record.device_id, device_id, sizeof(ppd->record.device_id));
-   strlcpy(ppd->record.scheme, scheme, sizeof(ppd->record.scheme));
- 
-- /*
--  * Strip confusing (and often wrong) "recommended" suffix added by
--  * Foomatic drivers...
--  */
--
--  if ((recommended = strstr(ppd->record.make_and_model,
--                            " (recommended)")) != NULL)
--    *recommended = '\0';
--
-  /*
-   * Add the PPD to the PPD arrays...
-   */
diff -pruN 2.3.3op1-5/debian/patches/0007-Debian-Set-LogFileGroup-to-adm.patch 2.3.3op2-2/debian/patches/0007-Debian-Set-LogFileGroup-to-adm.patch
--- 2.3.3op1-5/debian/patches/0007-Debian-Set-LogFileGroup-to-adm.patch	2021-01-08 10:35:18.000000000 +0000
+++ 2.3.3op2-2/debian/patches/0007-Debian-Set-LogFileGroup-to-adm.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,23 +0,0 @@
-From: Martin Pitt <mpitt@debian.org>
-Date: Tue, 9 Aug 2016 18:11:38 +0200
-Subject: Debian: Set LogFileGroup to adm
-
----
- conf/cups-files.conf.in | 4 ++++
- 1 file changed, 4 insertions(+)
-
-diff --git a/conf/cups-files.conf.in b/conf/cups-files.conf.in
-index af11fcc..80ca351 100644
---- a/conf/cups-files.conf.in
-+++ b/conf/cups-files.conf.in
-@@ -29,6 +29,10 @@ SystemGroup @CUPS_SYSTEM_GROUPS@
- #ConfigFilePerm 0@CUPS_CONFIG_FILE_PERM@
- #LogFilePerm 0@CUPS_LOG_FILE_PERM@
- 
-+# Specifies the group name or ID that will be used for log files.
-+# The default group in Debian is "adm".
-+LogFileGroup adm
-+
- # Location of the file logging all access to the scheduler; may be the name
- # "syslog". If not an absolute path, the value of ServerRoot is used as the
- # root directory.  Also see the "AccessLogLevel" directive in cupsd.conf.
diff -pruN 2.3.3op1-5/debian/patches/0007-Debian-Use-dpkg-architecture-in-cups-config-to-make-.patch 2.3.3op2-2/debian/patches/0007-Debian-Use-dpkg-architecture-in-cups-config-to-make-.patch
--- 2.3.3op1-5/debian/patches/0007-Debian-Use-dpkg-architecture-in-cups-config-to-make-.patch	1970-01-01 00:00:00.000000000 +0000
+++ 2.3.3op2-2/debian/patches/0007-Debian-Use-dpkg-architecture-in-cups-config-to-make-.patch	2021-02-03 12:13:18.000000000 +0000
@@ -0,0 +1,49 @@
+From: Didier Raboud <odyx@debian.org>
+Date: Tue, 9 Aug 2016 18:11:49 +0200
+Subject: Debian: Use dpkg-architecture in cups-config to make it
+ architecture-independant
+
+ Also filter -L/usr/lib/(triplet) out of LDFLAGS.
+ Also strip unnecessary libs from --libs.
+ Also launch krb5-config at runtime to avoid getting usr/lib/(triplet) from krb5-config
+
+Bug-Debian: https://bugs.debian.org/741519
+Bug-Debian: https://bugs.debian.org/727058
+Bug-Debian: https://bugs.debian.org/730838
+Bug-Debian: https://bugs.debian.org/751157
+---
+ cups-config.in | 7 ++++---
+ 1 file changed, 4 insertions(+), 3 deletions(-)
+
+diff --git a/cups-config.in b/cups-config.in
+index 9dd094d..b073a07 100755
+--- a/cups-config.in
++++ b/cups-config.in
+@@ -17,7 +17,7 @@ prefix=@prefix@
+ exec_prefix=@exec_prefix@
+ bindir=@bindir@
+ includedir=@includedir@
+-libdir=@libdir@
++libdir=${prefix}/lib/$(dpkg-architecture -qDEB_HOST_MULTIARCH)
+ datarootdir=@datadir@
+ datadir=@datadir@
+ sysconfdir=@sysconfdir@
+@@ -29,7 +29,8 @@ INSTALLSTATIC=@INSTALLSTATIC@
+ # flags for compiler and linker...
+ CFLAGS=""
+ LDFLAGS="@EXPORT_LDFLAGS@"
+-LIBS="@LIBGSSAPI@ @DNSSDLIBS@ @EXPORT_SSLLIBS@ @LIBZ@ @LIBS@"
++LIBGSSAPI=`[ ! -x /usr/bin/krb5-config ] || /usr/bin/krb5-config --libs`
++LIBS="$LIBGSSAPI @DNSSDLIBS@ @EXPORT_SSLLIBS@ @LIBZ@ @LIBS@"
+ 
+ # Check for local invocation...
+ selfdir=`dirname $0`
+@@ -43,7 +44,7 @@ else
+ 	CFLAGS="$CFLAGS -I$includedir"
+     fi
+ 
+-    if test $libdir != /usr/lib -a $libdir != /usr/lib32 -a $libdir != /usr/lib64; then
++    if test $libdir != /usr/lib -a $libdir != /usr/lib32 -a $libdir != /usr/lib64 -a $libdir != /usr/lib/$(dpkg-architecture -qDEB_HOST_MULTIARCH); then
+ 	LDFLAGS="$LDFLAGS -L$libdir"
+     fi
+ fi
diff -pruN 2.3.3op1-5/debian/patches/0008-Debian-Build-mantohtml-with-the-build-architecture-c.patch 2.3.3op2-2/debian/patches/0008-Debian-Build-mantohtml-with-the-build-architecture-c.patch
--- 2.3.3op1-5/debian/patches/0008-Debian-Build-mantohtml-with-the-build-architecture-c.patch	1970-01-01 00:00:00.000000000 +0000
+++ 2.3.3op2-2/debian/patches/0008-Debian-Build-mantohtml-with-the-build-architecture-c.patch	2021-02-03 12:13:18.000000000 +0000
@@ -0,0 +1,110 @@
+From: Helmut Grohne <helmut@subdivi.de>
+Date: Tue, 9 Aug 2016 18:11:49 +0200
+Subject: Debian: Build mantohtml with the build architecture compiler
+
+mantohtml is run during build. Thus it needs to be built with the build
+architecture compiler (or execution fails). The obvious part is switching to
+CC_FOR_BUILD. That also depends on it not requiring any other cups components.
+In particular, removing uses of strlcpy and replacing host architecture-
+specific includes is thus needed.
+
+Bug-Debian: https://bugs.debian.org/837936
+---
+ Makedefs.in     |  1 +
+ configure.ac    |  9 +++++++++
+ man/Makefile    |  5 ++---
+ man/mantohtml.c | 15 ++++++++++-----
+ 4 files changed, 22 insertions(+), 8 deletions(-)
+
+diff --git a/Makedefs.in b/Makedefs.in
+index 038bb94..291099c 100644
+--- a/Makedefs.in
++++ b/Makedefs.in
+@@ -22,6 +22,7 @@ CUPS_VERSION    =       @CUPS_VERSION@
+ AR		=	@AR@
+ AWK		=	@AWK@
+ CC		=	@LIBTOOL_CC@ @CC@
++CC_FOR_BUILD	=	@CC_FOR_BUILD@
+ CHMOD		=	@CHMOD@
+ CXX		=	@LIBTOOL_CXX@ @CXX@
+ DSO		=	@DSO@
+diff --git a/configure.ac b/configure.ac
+index 93a4b97..b60b832 100644
+--- a/configure.ac
++++ b/configure.ac
+@@ -20,6 +20,15 @@ sinclude(config-scripts/cups-common.m4)
+ sinclude(config-scripts/cups-directories.m4)
+ sinclude(config-scripts/cups-manpages.m4)
+ 
++AC_MSG_CHECKING([for build system compiler])
++if test "$cross_compiling" = yes; then
++	CC_FOR_BUILD=${CC_FOR_BUILD-cc}
++else
++	CC_FOR_BUILD=${CC}
++fi
++AC_MSG_RESULT(${CC_FOR_BUILD})
++AC_SUBST(CC_FOR_BUILD)
++
+ sinclude(config-scripts/cups-sharedlibs.m4)
+ sinclude(config-scripts/cups-libtool.m4)
+ sinclude(config-scripts/cups-compiler.m4)
+diff --git a/man/Makefile b/man/Makefile
+index 621fe60..e01591a 100644
+--- a/man/Makefile
++++ b/man/Makefile
+@@ -222,6 +222,5 @@ html:	$(MAN1) $(MAN5) $(MAN7) $(MAN8) mantohtml
+ 		./mantohtml $$file >../doc/help/man-`basename $$file .8`.html; \
+ 	done
+ 
+-mantohtml:	mantohtml.o ../cups/$(LIBCUPSSTATIC)
+-	$(LD_CC) $(ARCHFLAGS) $(ALL_LDFLAGS) -o $@ mantohtml.o $(LINKCUPSSTATIC)
+-	$(CODE_SIGN) -s "$(CODE_SIGN_IDENTITY)" $@
++mantohtml:	mantohtml.c
++	$(CC_FOR_BUILD) -o $@ $<
+diff --git a/man/mantohtml.c b/man/mantohtml.c
+index 2a9353a..6223f17 100644
+--- a/man/mantohtml.c
++++ b/man/mantohtml.c
+@@ -11,8 +11,10 @@
+  * Include necessary headers.
+  */
+ 
+-#include <cups/string-private.h>
+-#include <cups/array-private.h>
++#include <ctype.h>
++#include <stdio.h>
++#include <stdlib.h>
++#include <string.h>
+ #include <unistd.h>
+ 
+ 
+@@ -811,7 +813,8 @@ main(int  argc,				/* I - Number of command-line args */
+         * Anchor for HTML output...
+         */
+ 
+-        strlcpy(anchor, line + 4, sizeof(anchor));
++        strncpy(anchor, line + 4, sizeof(anchor) - 1);
++        anchor[sizeof(anchor) - 1] = '\0';
+       }
+       else if (strncmp(line, ".\\\"", 3))
+       {
+@@ -940,7 +943,8 @@ html_alternate(const char *s,		/* I - String */
+ 		manfile[1024],		/* Man page filename */
+ 		manurl[1024];		/* Man page URL */
+ 
+-        strlcpy(name, s, sizeof(name));
++        strncpy(name, s, sizeof(name) - 1);
++        name[sizeof(name) - 1] = '\0';
+         if ((size_t)(end - s) < sizeof(name))
+           name[end - s] = '\0';
+ 
+@@ -1173,7 +1177,8 @@ html_fputs(const char *s,		/* I  - String */
+       if (end[-1] == ',' || end[-1] == '.' || end[-1] == ')')
+         end --;
+ 
+-      strlcpy(temp, s, sizeof(temp));
++      strncpy(temp, s, sizeof(temp) - 1);
++      temp[sizeof(temp) - 1] = '\0';
+       if ((size_t)(end -s) < sizeof(temp))
+         temp[end - s] = '\0';
+ 
diff -pruN 2.3.3op1-5/debian/patches/0008-Debian-Move-cupsd.conf.default-from-SERVERROOT-to-DA.patch 2.3.3op2-2/debian/patches/0008-Debian-Move-cupsd.conf.default-from-SERVERROOT-to-DA.patch
--- 2.3.3op1-5/debian/patches/0008-Debian-Move-cupsd.conf.default-from-SERVERROOT-to-DA.patch	2021-01-08 10:35:18.000000000 +0000
+++ 2.3.3op2-2/debian/patches/0008-Debian-Move-cupsd.conf.default-from-SERVERROOT-to-DA.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,62 +0,0 @@
-From: Didier Raboud <odyx@debian.org>
-Date: Tue, 9 Aug 2016 18:11:24 +0200
-Subject: Debian: Move cupsd.conf.default from SERVERROOT to DATADIR
-
-Origin: vendor
-Bug: https://github.com/apple/cups/issues/4342
-Bug: https://github.com/OpenPrinting/cups/pull/26
-Bug-Debian: https://bugs.debian.org/640124
----
- cgi-bin/admin.c | 6 +++++-
- conf/Makefile   | 5 +++--
- 2 files changed, 8 insertions(+), 3 deletions(-)
-
-diff --git a/cgi-bin/admin.c b/cgi-bin/admin.c
-index c648938..5ff7501 100644
---- a/cgi-bin/admin.c
-+++ b/cgi-bin/admin.c
-@@ -1636,6 +1636,7 @@ do_config_server(http_t *http)		/* I - HTTP connection */
-     int		ch;			/* Character from file */
-     char	filename[1024];		/* Filename */
-     const char	*server_root;		/* Location of config files */
-+    const char	*data_dir;		/* Location of data files */
- 
- 
-    /*
-@@ -1719,7 +1720,10 @@ do_config_server(http_t *http)		/* I - HTTP connection */
-     * well...
-     */
- 
--    strlcat(filename, ".default", sizeof(filename));
-+    if ((data_dir = getenv("CUPS_DATADIR")) == NULL)
-+      data_dir = CUPS_DATADIR;
-+
-+    snprintf(filename, sizeof(filename), "%s/cupsd.conf.default",data_dir);
- 
-     if (!stat(filename, &info) && info.st_size < (1024 * 1024) &&
-         (cupsd = cupsFileOpen(filename, "r")) != NULL)
-diff --git a/conf/Makefile b/conf/Makefile
-index e249e60..42a123f 100644
---- a/conf/Makefile
-+++ b/conf/Makefile
-@@ -70,7 +70,7 @@ install-data:
- 		else \
- 			$(INSTALL_CONFIG) -g $(CUPS_GROUP) $$file $(SERVERROOT) ; \
- 		fi ; \
--		$(INSTALL_CONFIG) -g $(CUPS_GROUP) $$file $(SERVERROOT)/$$file.default; \
-+		$(INSTALL_CONFIG) -g $(CUPS_GROUP) $$file $(DATADIR)/$$file.default; \
- 	done
- 	$(INSTALL_DIR) -m 755 $(DATADIR)/mime
- 	for file in $(REPLACE); do \
-@@ -118,9 +118,10 @@ install-libs:
- #
- 
- uninstall:
--	for file in $(KEEP) $(REPLACE) cupsd.conf.default; do \
-+	for file in $(KEEP) $(REPLACE); do \
- 		$(RM) $(SERVERROOT)/$$file; \
- 	done
-+	$(RM) $(DATADIR)/cupsd.conf.default
- 	-$(RMDIR) $(SERVERROOT)
- 	for file in $(REPLACE); do \
- 		$(RM) $(DATADIR)/mime/$$file; \
diff -pruN 2.3.3op1-5/debian/patches/0009-Debian-Do-not-alter-the-permissions-of-cupsd.conf-ev.patch 2.3.3op2-2/debian/patches/0009-Debian-Do-not-alter-the-permissions-of-cupsd.conf-ev.patch
--- 2.3.3op1-5/debian/patches/0009-Debian-Do-not-alter-the-permissions-of-cupsd.conf-ev.patch	2021-01-08 10:35:18.000000000 +0000
+++ 2.3.3op2-2/debian/patches/0009-Debian-Do-not-alter-the-permissions-of-cupsd.conf-ev.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,27 +0,0 @@
-From: Martin Pitt <mpitt@debian.org>
-Date: Tue, 9 Aug 2016 18:11:41 +0200
-Subject: Debian: Do not alter the permissions of cupsd.conf, ever
-
-Origin: vendor
-Bug: https://github.com/OpenPrinting/cups/pull/36
----
- scheduler/conf.c | 2 ++
- 1 file changed, 2 insertions(+)
-
-diff --git a/scheduler/conf.c b/scheduler/conf.c
-index bfd1b0b..c8cd5ea 100644
---- a/scheduler/conf.c
-+++ b/scheduler/conf.c
-@@ -1140,10 +1140,12 @@ cupsdReadConfiguration(void)
- 			     Group, 1, 1) < 0 ||
-        cupsdCheckPermissions(ServerRoot, "ssl", 0700, RunUser,
- 			     Group, 1, 0) < 0 ||
-+       /* Never alter permissions of central conffile
-        cupsdCheckPermissions(ConfigurationFile, NULL, ConfigFilePerm, RunUser,
- 			     Group, 0, 0) < 0 ||
-        cupsdCheckPermissions(CupsFilesFile, NULL, ConfigFilePerm, RunUser,
- 			     Group, 0, 0) < 0 ||
-+       */
-        cupsdCheckPermissions(ServerRoot, "classes.conf", 0600, RunUser,
- 			     Group, 0, 0) < 0 ||
-        cupsdCheckPermissions(ServerRoot, "printers.conf", 0600, RunUser,
diff -pruN 2.3.3op1-5/debian/patches/0009-Debian-po4a-infrastructure-and-translations-for-manp.patch 2.3.3op2-2/debian/patches/0009-Debian-po4a-infrastructure-and-translations-for-manp.patch
--- 2.3.3op1-5/debian/patches/0009-Debian-po4a-infrastructure-and-translations-for-manp.patch	1970-01-01 00:00:00.000000000 +0000
+++ 2.3.3op2-2/debian/patches/0009-Debian-po4a-infrastructure-and-translations-for-manp.patch	2021-02-03 12:13:18.000000000 +0000
@@ -0,0 +1,341 @@
+From: Didier Raboud <odyx@debian.org>
+Date: Tue, 9 Aug 2016 18:11:50 +0200
+Subject: Debian: po4a infrastructure and translations for manpages
+MIME-Version: 1.0
+Content-Type: text/plain; charset="utf-8"
+Content-Transfer-Encoding: 8bit
+
+Author: Nicolas François <nicolas.francois@centraliens.net>, Helge Kreutzmann <debian@helgefjell.de>
+Origin: vendor
+Bug-Debian: https://bugs.debian.org/478597
+---
+ man/Makefile      |  17 +++-
+ man/Makefile.l10n | 235 ++++++++++++++++++++++++++++++++++++++++++++++++++++++
+ man/de/Makefile   |   7 ++
+ man/fr/Makefile   |   7 ++
+ 4 files changed, 264 insertions(+), 2 deletions(-)
+ create mode 100644 man/Makefile.l10n
+ create mode 100644 man/de/Makefile
+ create mode 100644 man/fr/Makefile
+
+diff --git a/man/Makefile b/man/Makefile
+index e01591a..48f06c4 100644
+--- a/man/Makefile
++++ b/man/Makefile
+@@ -63,12 +63,18 @@ MAN8	=	cupsaccept.8 \
+ 		lpmove.8 \
+ 		lpc.8
+ 
++LANGUAGES=de fr
+ 
+ #
+ # Make everything...
+ #
+ 
+-all:	$(MAN1) $(MAN5) $(MAN7) $(MAN8)
++all:	$(MAN1) $(MAN5) $(MAN7) $(MAN8) translations
++
++translations:
++	# Update the translations and build the translated material
++	po4a --previous ../debian/manpage-po4a/cups.cfg
++	for lang in $(LANGUAGES); do $(MAKE) -C $$lang; done
+ 
+ 
+ #
+@@ -91,6 +97,12 @@ unittests:
+ 
+ clean:
+ 	$(RM) mantohtml mantohtml.o
++	$(RM) $(MAN1) $(MAN5) $(MAN7) $(MAN8)
++	for lang in $(LANGUAGES); do $(MAKE) -C $$lang clean; done
++	# Make sure the PO files are updated and remove generated
++	# translations.
++	po4a --previous --rm-translations ../debian/manpage-po4a/cups.cfg
++	$(RM) ../debian/manpage-po4a/po/cups.pot
+ 
+ 
+ #
+@@ -142,6 +154,7 @@ install-data: all
+ 		$(RM) $(MANDIR)/man8/$$file; \
+ 		$(LN) cupsd-helper.8 $(MANDIR)/man8/$$file; \
+ 	done
++	for lang in $(LANGUAGES); do $(MAKE) -C $$lang install; done
+ 
+ 
+ #
+@@ -189,7 +202,7 @@ uninstall:
+ 	for file in $(MAN8) cupsenable.8 cupsreject.8 cups-deviced.8 cups-driverd.8 cups-exec.8; do \
+ 		$(RM) $(MANDIR)/man8/$$file; \
+ 	done
+-	-$(RMDIR) $(MANDIR)/man8
++	-$(RMDIR) $(AMANDIR)/man$(MAN8DIR)
+ 
+ 
+ #
+diff --git a/man/Makefile.l10n b/man/Makefile.l10n
+new file mode 100644
+index 0000000..08390f5
+--- /dev/null
++++ b/man/Makefile.l10n
+@@ -0,0 +1,235 @@
++#
++# Man page makefile for CUPS.
++#
++# Copyright © 2007-2019 by Apple Inc.
++# Copyright © 1993-2006 by Easy Software Products.
++#
++# Licensed under Apache License v2.0.  See the file "LICENSE" for more
++# information.
++#
++
++include ../../Makedefs
++
++
++#
++# Man pages...
++#
++
++MAN1	=	cancel.1 \
++		cups.1 \
++		cups-config.1 \
++		cupstestppd.1 \
++		ippeveprinter.1 \
++		$(IPPFIND_MAN) \
++		ipptool.1 \
++		lp.1 \
++		lpoptions.1 \
++		lpq.1 \
++		lprm.1 \
++		lpr.1 \
++		lpstat.1 \
++		ppdc.1 \
++		ppdhtml.1 \
++		ppdi.1 \
++		ppdmerge.1 \
++		ppdpo.1
++MAN5	=	classes.conf.5 \
++		client.conf.5 \
++		cups-files.conf.5 \
++		cups-snmp.conf.5 \
++		cupsd.conf.5 \
++		cupsd-logs.5 \
++		ipptoolfile.5 \
++		mailto.conf.5 \
++		mime.convs.5 \
++		mime.types.5 \
++		ppdcfile.5 \
++		printers.conf.5 \
++		subscriptions.conf.5
++MAN7	=	backend.7 \
++		filter.7 \
++		ippevepcl.7 \
++		notifier.7
++MAN8	=	cupsaccept.8 \
++		cupsctl.8 \
++		cupsfilter.8 \
++		cups-lpd.8 \
++		cups-snmp.8 \
++		cupsd.8 \
++		cupsd-helper.8 \
++		cupsenable.8 \
++		lpadmin.8 \
++		lpinfo.8 \
++		lpmove.8 \
++		lpc.8
++
++
++#
++# Make everything...
++#
++
++# Debian-specific patch: Just assume all files are here.
++all:
++
++
++#
++# Make library targets...
++#
++
++libs:
++
++
++#
++# Make unit tests...
++#
++
++unittests:
++
++
++#
++# Clean all config and object files...
++#
++
++clean:
++	$(RM) mantohtml mantohtml.o
++
++
++#
++# Dummy depend target...
++#
++
++depend:
++
++
++#
++# Install all targets...
++#
++
++# Debian-specific patch: directory-based language namespace
++MANDIR := $(MANDIR)/$(LANGUAGE)
++
++install:	all install-data install-headers install-libs install-exec
++
++
++#
++# Install data files...
++#
++
++# Debian-specific patch: skip if doesn't exist
++install-data: all
++	echo Installing man pages in $(MANDIR)/man1...
++	$(INSTALL_DIR) -m 755 $(MANDIR)/man1
++	for file in $(MAN1); do \
++		[ ! -r $$file ] || \
++		$(INSTALL_MAN) $$file $(MANDIR)/man1; \
++	done
++	echo Installing man pages in $(MANDIR)/man5...
++	$(INSTALL_DIR) -m 755 $(MANDIR)/man5
++	for file in $(MAN5); do \
++		[ ! -r $$file ] || \
++		$(INSTALL_MAN) $$file $(MANDIR)/man5; \
++	done
++	echo Installing man pages in $(MANDIR)/man7...
++	$(INSTALL_DIR) -m 755 $(MANDIR)/man7
++	for file in $(MAN7); do \
++		[ ! -r $$file ] || \
++		$(INSTALL_MAN) $$file $(MANDIR)/man7; \
++	done
++	$(RM) $(MANDIR)/man7/ippeveps.7
++	$(LN) ippevepcl.7 $(MANDIR)/man7/ippeveps.7
++	echo Installing man pages in $(MANDIR)/man8...
++	$(INSTALL_DIR) -m 755 $(MANDIR)/man8
++	for file in $(MAN8); do \
++		[ ! -r $$file ] || \
++		$(INSTALL_MAN) $$file $(MANDIR)/man8; \
++	done
++	$(RM) $(MANDIR)/man8/cupsdisable.8
++	$(LN) cupsenable.8 $(MANDIR)/man8/cupsdisable.8
++	$(RM) $(MANDIR)/man8/cupsreject.8
++	$(LN) cupsaccept.8 $(MANDIR)/man8/cupsreject.8
++	for file in cups-deviced.8 cups-driverd.8 cups-exec.8; do \
++		$(RM) $(MANDIR)/man8/$$file; \
++		$(LN) cupsd-helper.8 $(MANDIR)/man8/$$file; \
++	done
++
++
++#
++# Install programs...
++#
++
++install-exec:
++
++
++#
++# Install headers...
++#
++
++install-headers:
++
++
++#
++# Install libraries...
++#
++
++install-libs:
++
++
++#
++# Uninstall files...
++#
++
++uninstall:
++	echo Uninstalling man pages from $(MANDIR)/man1...
++	for file in $(MAN1); do \
++		$(RM) $(MANDIR)/man1/$$file; \
++	done
++	-$(RMDIR) $(MANDIR)/man1
++	echo Uninstalling man pages from $(MANDIR)/man5...
++	for file in $(MAN5); do \
++		$(RM) $(MANDIR)/man5/$$file; \
++	done
++	-$(RMDIR) $(MANDIR)/man5
++	echo Uninstalling man pages from $(MANDIR)/man7...
++	for file in $(MAN7) ippeveps.7; do \
++		$(RM) $(MANDIR)/man7/$$file; \
++	done
++	-$(RMDIR) $(MANDIR)/man7
++	echo Uninstalling man pages from $(MANDIR)/man8...
++	for file in $(MAN8) cupsenable.8 cupsreject.8 cups-deviced.8 cups-driverd.8 cups-exec.8; do \
++		$(RM) $(MANDIR)/man8/$$file; \
++	done
++	-$(RMDIR) $(MANDIR)/man8
++
++
++#
++# Local programs (not built when cross-compiling...)
++#
++
++local:	html
++
++
++#
++# Make html versions of man pages...
++#
++
++html:	$(MAN1) $(MAN5) $(MAN7) $(MAN8) mantohtml
++	echo Converting man pages to HTML...
++	for file in $(MAN1); do \
++		echo "    $$file..."; \
++		./mantohtml $$file >../doc/help/man-`basename $$file .1`.html; \
++	done
++	for file in $(MAN5); do \
++		echo "    $$file..."; \
++		./mantohtml $$file >../doc/help/man-`basename $$file .5`.html; \
++	done
++	for file in $(MAN7); do \
++		echo "    $$file..."; \
++		./mantohtml $$file >../doc/help/man-`basename $$file .7`.html; \
++	done
++	for file in $(MAN8); do \
++		echo "    $$file..."; \
++		./mantohtml $$file >../doc/help/man-`basename $$file .8`.html; \
++	done
++
++mantohtml:	mantohtml.c
++	$(CC_FOR_BUILD) -o $@ $<
+diff --git a/man/de/Makefile b/man/de/Makefile
+new file mode 100644
+index 0000000..7c23784
+--- /dev/null
++++ b/man/de/Makefile
+@@ -0,0 +1,7 @@
++#
++#   Man page makefile for the Common UNIX Printing System (CUPS).
++#
++
++LANGUAGE=de
++
++include ../Makefile.l10n
+diff --git a/man/fr/Makefile b/man/fr/Makefile
+new file mode 100644
+index 0000000..6a50e93
+--- /dev/null
++++ b/man/fr/Makefile
+@@ -0,0 +1,7 @@
++#
++#   Man page makefile for the Common UNIX Printing System (CUPS).
++#
++
++LANGUAGE=fr
++
++include ../Makefile.l10n
diff -pruN 2.3.3op1-5/debian/patches/0010-Debian-Show-compile-command-lines.patch 2.3.3op2-2/debian/patches/0010-Debian-Show-compile-command-lines.patch
--- 2.3.3op1-5/debian/patches/0010-Debian-Show-compile-command-lines.patch	2021-01-08 10:35:18.000000000 +0000
+++ 2.3.3op2-2/debian/patches/0010-Debian-Show-compile-command-lines.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,20 +0,0 @@
-From: Till Kampetter <till.kampetter@gmail.com>
-Date: Tue, 9 Aug 2016 18:11:43 +0200
-Subject: Debian: Show compile command lines
-
----
- Makedefs.in | 1 -
- 1 file changed, 1 deletion(-)
-
-diff --git a/Makedefs.in b/Makedefs.in
-index 9ee7585..038bb94 100644
---- a/Makedefs.in
-+++ b/Makedefs.in
-@@ -263,7 +263,6 @@ USBQUIRKS	=	@USBQUIRKS@
- # Rules...
- #
- 
--.SILENT:
- .SUFFIXES:	.a .c .cxx .h .o
- 
- .c.o:
diff -pruN 2.3.3op1-5/debian/patches/0011-Debian-Use-dpkg-architecture-in-cups-config-to-make-.patch 2.3.3op2-2/debian/patches/0011-Debian-Use-dpkg-architecture-in-cups-config-to-make-.patch
--- 2.3.3op1-5/debian/patches/0011-Debian-Use-dpkg-architecture-in-cups-config-to-make-.patch	2021-01-08 10:35:18.000000000 +0000
+++ 2.3.3op2-2/debian/patches/0011-Debian-Use-dpkg-architecture-in-cups-config-to-make-.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,49 +0,0 @@
-From: Didier Raboud <odyx@debian.org>
-Date: Tue, 9 Aug 2016 18:11:49 +0200
-Subject: Debian: Use dpkg-architecture in cups-config to make it
- architecture-independant
-
- Also filter -L/usr/lib/(triplet) out of LDFLAGS.
- Also strip unnecessary libs from --libs.
- Also launch krb5-config at runtime to avoid getting usr/lib/(triplet) from krb5-config
-
-Bug-Debian: https://bugs.debian.org/741519
-Bug-Debian: https://bugs.debian.org/727058
-Bug-Debian: https://bugs.debian.org/730838
-Bug-Debian: https://bugs.debian.org/751157
----
- cups-config.in | 7 ++++---
- 1 file changed, 4 insertions(+), 3 deletions(-)
-
-diff --git a/cups-config.in b/cups-config.in
-index 9dd094d..b073a07 100755
---- a/cups-config.in
-+++ b/cups-config.in
-@@ -17,7 +17,7 @@ prefix=@prefix@
- exec_prefix=@exec_prefix@
- bindir=@bindir@
- includedir=@includedir@
--libdir=@libdir@
-+libdir=${prefix}/lib/$(dpkg-architecture -qDEB_HOST_MULTIARCH)
- datarootdir=@datadir@
- datadir=@datadir@
- sysconfdir=@sysconfdir@
-@@ -29,7 +29,8 @@ INSTALLSTATIC=@INSTALLSTATIC@
- # flags for compiler and linker...
- CFLAGS=""
- LDFLAGS="@EXPORT_LDFLAGS@"
--LIBS="@LIBGSSAPI@ @DNSSDLIBS@ @EXPORT_SSLLIBS@ @LIBZ@ @LIBS@"
-+LIBGSSAPI=`[ ! -x /usr/bin/krb5-config ] || /usr/bin/krb5-config --libs`
-+LIBS="$LIBGSSAPI @DNSSDLIBS@ @EXPORT_SSLLIBS@ @LIBZ@ @LIBS@"
- 
- # Check for local invocation...
- selfdir=`dirname $0`
-@@ -43,7 +44,7 @@ else
- 	CFLAGS="$CFLAGS -I$includedir"
-     fi
- 
--    if test $libdir != /usr/lib -a $libdir != /usr/lib32 -a $libdir != /usr/lib64; then
-+    if test $libdir != /usr/lib -a $libdir != /usr/lib32 -a $libdir != /usr/lib64 -a $libdir != /usr/lib/$(dpkg-architecture -qDEB_HOST_MULTIARCH); then
- 	LDFLAGS="$LDFLAGS -L$libdir"
-     fi
- fi
diff -pruN 2.3.3op1-5/debian/patches/0012-Debian-Build-mantohtml-with-the-build-architecture-c.patch 2.3.3op2-2/debian/patches/0012-Debian-Build-mantohtml-with-the-build-architecture-c.patch
--- 2.3.3op1-5/debian/patches/0012-Debian-Build-mantohtml-with-the-build-architecture-c.patch	2021-01-08 10:35:18.000000000 +0000
+++ 2.3.3op2-2/debian/patches/0012-Debian-Build-mantohtml-with-the-build-architecture-c.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,110 +0,0 @@
-From: Helmut Grohne <helmut@subdivi.de>
-Date: Tue, 9 Aug 2016 18:11:49 +0200
-Subject: Debian: Build mantohtml with the build architecture compiler
-
-mantohtml is run during build. Thus it needs to be built with the build
-architecture compiler (or execution fails). The obvious part is switching to
-CC_FOR_BUILD. That also depends on it not requiring any other cups components.
-In particular, removing uses of strlcpy and replacing host architecture-
-specific includes is thus needed.
-
-Bug-Debian: https://bugs.debian.org/837936
----
- Makedefs.in     |  1 +
- configure.ac    |  9 +++++++++
- man/Makefile    |  5 ++---
- man/mantohtml.c | 15 ++++++++++-----
- 4 files changed, 22 insertions(+), 8 deletions(-)
-
-diff --git a/Makedefs.in b/Makedefs.in
-index 038bb94..291099c 100644
---- a/Makedefs.in
-+++ b/Makedefs.in
-@@ -22,6 +22,7 @@ CUPS_VERSION    =       @CUPS_VERSION@
- AR		=	@AR@
- AWK		=	@AWK@
- CC		=	@LIBTOOL_CC@ @CC@
-+CC_FOR_BUILD	=	@CC_FOR_BUILD@
- CHMOD		=	@CHMOD@
- CXX		=	@LIBTOOL_CXX@ @CXX@
- DSO		=	@DSO@
-diff --git a/configure.ac b/configure.ac
-index b22e24f..176c44f 100644
---- a/configure.ac
-+++ b/configure.ac
-@@ -20,6 +20,15 @@ sinclude(config-scripts/cups-common.m4)
- sinclude(config-scripts/cups-directories.m4)
- sinclude(config-scripts/cups-manpages.m4)
- 
-+AC_MSG_CHECKING([for build system compiler])
-+if test "$cross_compiling" = yes; then
-+	CC_FOR_BUILD=${CC_FOR_BUILD-cc}
-+else
-+	CC_FOR_BUILD=${CC}
-+fi
-+AC_MSG_RESULT(${CC_FOR_BUILD})
-+AC_SUBST(CC_FOR_BUILD)
-+
- sinclude(config-scripts/cups-sharedlibs.m4)
- sinclude(config-scripts/cups-libtool.m4)
- sinclude(config-scripts/cups-compiler.m4)
-diff --git a/man/Makefile b/man/Makefile
-index 621fe60..e01591a 100644
---- a/man/Makefile
-+++ b/man/Makefile
-@@ -222,6 +222,5 @@ html:	$(MAN1) $(MAN5) $(MAN7) $(MAN8) mantohtml
- 		./mantohtml $$file >../doc/help/man-`basename $$file .8`.html; \
- 	done
- 
--mantohtml:	mantohtml.o ../cups/$(LIBCUPSSTATIC)
--	$(LD_CC) $(ARCHFLAGS) $(ALL_LDFLAGS) -o $@ mantohtml.o $(LINKCUPSSTATIC)
--	$(CODE_SIGN) -s "$(CODE_SIGN_IDENTITY)" $@
-+mantohtml:	mantohtml.c
-+	$(CC_FOR_BUILD) -o $@ $<
-diff --git a/man/mantohtml.c b/man/mantohtml.c
-index 2a9353a..6223f17 100644
---- a/man/mantohtml.c
-+++ b/man/mantohtml.c
-@@ -11,8 +11,10 @@
-  * Include necessary headers.
-  */
- 
--#include <cups/string-private.h>
--#include <cups/array-private.h>
-+#include <ctype.h>
-+#include <stdio.h>
-+#include <stdlib.h>
-+#include <string.h>
- #include <unistd.h>
- 
- 
-@@ -811,7 +813,8 @@ main(int  argc,				/* I - Number of command-line args */
-         * Anchor for HTML output...
-         */
- 
--        strlcpy(anchor, line + 4, sizeof(anchor));
-+        strncpy(anchor, line + 4, sizeof(anchor) - 1);
-+        anchor[sizeof(anchor) - 1] = '\0';
-       }
-       else if (strncmp(line, ".\\\"", 3))
-       {
-@@ -940,7 +943,8 @@ html_alternate(const char *s,		/* I - String */
- 		manfile[1024],		/* Man page filename */
- 		manurl[1024];		/* Man page URL */
- 
--        strlcpy(name, s, sizeof(name));
-+        strncpy(name, s, sizeof(name) - 1);
-+        name[sizeof(name) - 1] = '\0';
-         if ((size_t)(end - s) < sizeof(name))
-           name[end - s] = '\0';
- 
-@@ -1173,7 +1177,8 @@ html_fputs(const char *s,		/* I  - String */
-       if (end[-1] == ',' || end[-1] == '.' || end[-1] == ')')
-         end --;
- 
--      strlcpy(temp, s, sizeof(temp));
-+      strncpy(temp, s, sizeof(temp) - 1);
-+      temp[sizeof(temp) - 1] = '\0';
-       if ((size_t)(end -s) < sizeof(temp))
-         temp[end - s] = '\0';
- 
diff -pruN 2.3.3op1-5/debian/patches/0013-Debian-po4a-infrastructure-and-translations-for-manp.patch 2.3.3op2-2/debian/patches/0013-Debian-po4a-infrastructure-and-translations-for-manp.patch
--- 2.3.3op1-5/debian/patches/0013-Debian-po4a-infrastructure-and-translations-for-manp.patch	2021-01-08 10:35:18.000000000 +0000
+++ 2.3.3op2-2/debian/patches/0013-Debian-po4a-infrastructure-and-translations-for-manp.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,341 +0,0 @@
-From: Didier Raboud <odyx@debian.org>
-Date: Tue, 9 Aug 2016 18:11:50 +0200
-Subject: Debian: po4a infrastructure and translations for manpages
-MIME-Version: 1.0
-Content-Type: text/plain; charset="utf-8"
-Content-Transfer-Encoding: 8bit
-
-Author: Nicolas François <nicolas.francois@centraliens.net>, Helge Kreutzmann <debian@helgefjell.de>
-Origin: vendor
-Bug-Debian: https://bugs.debian.org/478597
----
- man/Makefile      |  17 +++-
- man/Makefile.l10n | 235 ++++++++++++++++++++++++++++++++++++++++++++++++++++++
- man/de/Makefile   |   7 ++
- man/fr/Makefile   |   7 ++
- 4 files changed, 264 insertions(+), 2 deletions(-)
- create mode 100644 man/Makefile.l10n
- create mode 100644 man/de/Makefile
- create mode 100644 man/fr/Makefile
-
-diff --git a/man/Makefile b/man/Makefile
-index e01591a..48f06c4 100644
---- a/man/Makefile
-+++ b/man/Makefile
-@@ -63,12 +63,18 @@ MAN8	=	cupsaccept.8 \
- 		lpmove.8 \
- 		lpc.8
- 
-+LANGUAGES=de fr
- 
- #
- # Make everything...
- #
- 
--all:	$(MAN1) $(MAN5) $(MAN7) $(MAN8)
-+all:	$(MAN1) $(MAN5) $(MAN7) $(MAN8) translations
-+
-+translations:
-+	# Update the translations and build the translated material
-+	po4a --previous ../debian/manpage-po4a/cups.cfg
-+	for lang in $(LANGUAGES); do $(MAKE) -C $$lang; done
- 
- 
- #
-@@ -91,6 +97,12 @@ unittests:
- 
- clean:
- 	$(RM) mantohtml mantohtml.o
-+	$(RM) $(MAN1) $(MAN5) $(MAN7) $(MAN8)
-+	for lang in $(LANGUAGES); do $(MAKE) -C $$lang clean; done
-+	# Make sure the PO files are updated and remove generated
-+	# translations.
-+	po4a --previous --rm-translations ../debian/manpage-po4a/cups.cfg
-+	$(RM) ../debian/manpage-po4a/po/cups.pot
- 
- 
- #
-@@ -142,6 +154,7 @@ install-data: all
- 		$(RM) $(MANDIR)/man8/$$file; \
- 		$(LN) cupsd-helper.8 $(MANDIR)/man8/$$file; \
- 	done
-+	for lang in $(LANGUAGES); do $(MAKE) -C $$lang install; done
- 
- 
- #
-@@ -189,7 +202,7 @@ uninstall:
- 	for file in $(MAN8) cupsenable.8 cupsreject.8 cups-deviced.8 cups-driverd.8 cups-exec.8; do \
- 		$(RM) $(MANDIR)/man8/$$file; \
- 	done
--	-$(RMDIR) $(MANDIR)/man8
-+	-$(RMDIR) $(AMANDIR)/man$(MAN8DIR)
- 
- 
- #
-diff --git a/man/Makefile.l10n b/man/Makefile.l10n
-new file mode 100644
-index 0000000..08390f5
---- /dev/null
-+++ b/man/Makefile.l10n
-@@ -0,0 +1,235 @@
-+#
-+# Man page makefile for CUPS.
-+#
-+# Copyright © 2007-2019 by Apple Inc.
-+# Copyright © 1993-2006 by Easy Software Products.
-+#
-+# Licensed under Apache License v2.0.  See the file "LICENSE" for more
-+# information.
-+#
-+
-+include ../../Makedefs
-+
-+
-+#
-+# Man pages...
-+#
-+
-+MAN1	=	cancel.1 \
-+		cups.1 \
-+		cups-config.1 \
-+		cupstestppd.1 \
-+		ippeveprinter.1 \
-+		$(IPPFIND_MAN) \
-+		ipptool.1 \
-+		lp.1 \
-+		lpoptions.1 \
-+		lpq.1 \
-+		lprm.1 \
-+		lpr.1 \
-+		lpstat.1 \
-+		ppdc.1 \
-+		ppdhtml.1 \
-+		ppdi.1 \
-+		ppdmerge.1 \
-+		ppdpo.1
-+MAN5	=	classes.conf.5 \
-+		client.conf.5 \
-+		cups-files.conf.5 \
-+		cups-snmp.conf.5 \
-+		cupsd.conf.5 \
-+		cupsd-logs.5 \
-+		ipptoolfile.5 \
-+		mailto.conf.5 \
-+		mime.convs.5 \
-+		mime.types.5 \
-+		ppdcfile.5 \
-+		printers.conf.5 \
-+		subscriptions.conf.5
-+MAN7	=	backend.7 \
-+		filter.7 \
-+		ippevepcl.7 \
-+		notifier.7
-+MAN8	=	cupsaccept.8 \
-+		cupsctl.8 \
-+		cupsfilter.8 \
-+		cups-lpd.8 \
-+		cups-snmp.8 \
-+		cupsd.8 \
-+		cupsd-helper.8 \
-+		cupsenable.8 \
-+		lpadmin.8 \
-+		lpinfo.8 \
-+		lpmove.8 \
-+		lpc.8
-+
-+
-+#
-+# Make everything...
-+#
-+
-+# Debian-specific patch: Just assume all files are here.
-+all:
-+
-+
-+#
-+# Make library targets...
-+#
-+
-+libs:
-+
-+
-+#
-+# Make unit tests...
-+#
-+
-+unittests:
-+
-+
-+#
-+# Clean all config and object files...
-+#
-+
-+clean:
-+	$(RM) mantohtml mantohtml.o
-+
-+
-+#
-+# Dummy depend target...
-+#
-+
-+depend:
-+
-+
-+#
-+# Install all targets...
-+#
-+
-+# Debian-specific patch: directory-based language namespace
-+MANDIR := $(MANDIR)/$(LANGUAGE)
-+
-+install:	all install-data install-headers install-libs install-exec
-+
-+
-+#
-+# Install data files...
-+#
-+
-+# Debian-specific patch: skip if doesn't exist
-+install-data: all
-+	echo Installing man pages in $(MANDIR)/man1...
-+	$(INSTALL_DIR) -m 755 $(MANDIR)/man1
-+	for file in $(MAN1); do \
-+		[ ! -r $$file ] || \
-+		$(INSTALL_MAN) $$file $(MANDIR)/man1; \
-+	done
-+	echo Installing man pages in $(MANDIR)/man5...
-+	$(INSTALL_DIR) -m 755 $(MANDIR)/man5
-+	for file in $(MAN5); do \
-+		[ ! -r $$file ] || \
-+		$(INSTALL_MAN) $$file $(MANDIR)/man5; \
-+	done
-+	echo Installing man pages in $(MANDIR)/man7...
-+	$(INSTALL_DIR) -m 755 $(MANDIR)/man7
-+	for file in $(MAN7); do \
-+		[ ! -r $$file ] || \
-+		$(INSTALL_MAN) $$file $(MANDIR)/man7; \
-+	done
-+	$(RM) $(MANDIR)/man7/ippeveps.7
-+	$(LN) ippevepcl.7 $(MANDIR)/man7/ippeveps.7
-+	echo Installing man pages in $(MANDIR)/man8...
-+	$(INSTALL_DIR) -m 755 $(MANDIR)/man8
-+	for file in $(MAN8); do \
-+		[ ! -r $$file ] || \
-+		$(INSTALL_MAN) $$file $(MANDIR)/man8; \
-+	done
-+	$(RM) $(MANDIR)/man8/cupsdisable.8
-+	$(LN) cupsenable.8 $(MANDIR)/man8/cupsdisable.8
-+	$(RM) $(MANDIR)/man8/cupsreject.8
-+	$(LN) cupsaccept.8 $(MANDIR)/man8/cupsreject.8
-+	for file in cups-deviced.8 cups-driverd.8 cups-exec.8; do \
-+		$(RM) $(MANDIR)/man8/$$file; \
-+		$(LN) cupsd-helper.8 $(MANDIR)/man8/$$file; \
-+	done
-+
-+
-+#
-+# Install programs...
-+#
-+
-+install-exec:
-+
-+
-+#
-+# Install headers...
-+#
-+
-+install-headers:
-+
-+
-+#
-+# Install libraries...
-+#
-+
-+install-libs:
-+
-+
-+#
-+# Uninstall files...
-+#
-+
-+uninstall:
-+	echo Uninstalling man pages from $(MANDIR)/man1...
-+	for file in $(MAN1); do \
-+		$(RM) $(MANDIR)/man1/$$file; \
-+	done
-+	-$(RMDIR) $(MANDIR)/man1
-+	echo Uninstalling man pages from $(MANDIR)/man5...
-+	for file in $(MAN5); do \
-+		$(RM) $(MANDIR)/man5/$$file; \
-+	done
-+	-$(RMDIR) $(MANDIR)/man5
-+	echo Uninstalling man pages from $(MANDIR)/man7...
-+	for file in $(MAN7) ippeveps.7; do \
-+		$(RM) $(MANDIR)/man7/$$file; \
-+	done
-+	-$(RMDIR) $(MANDIR)/man7
-+	echo Uninstalling man pages from $(MANDIR)/man8...
-+	for file in $(MAN8) cupsenable.8 cupsreject.8 cups-deviced.8 cups-driverd.8 cups-exec.8; do \
-+		$(RM) $(MANDIR)/man8/$$file; \
-+	done
-+	-$(RMDIR) $(MANDIR)/man8
-+
-+
-+#
-+# Local programs (not built when cross-compiling...)
-+#
-+
-+local:	html
-+
-+
-+#
-+# Make html versions of man pages...
-+#
-+
-+html:	$(MAN1) $(MAN5) $(MAN7) $(MAN8) mantohtml
-+	echo Converting man pages to HTML...
-+	for file in $(MAN1); do \
-+		echo "    $$file..."; \
-+		./mantohtml $$file >../doc/help/man-`basename $$file .1`.html; \
-+	done
-+	for file in $(MAN5); do \
-+		echo "    $$file..."; \
-+		./mantohtml $$file >../doc/help/man-`basename $$file .5`.html; \
-+	done
-+	for file in $(MAN7); do \
-+		echo "    $$file..."; \
-+		./mantohtml $$file >../doc/help/man-`basename $$file .7`.html; \
-+	done
-+	for file in $(MAN8); do \
-+		echo "    $$file..."; \
-+		./mantohtml $$file >../doc/help/man-`basename $$file .8`.html; \
-+	done
-+
-+mantohtml:	mantohtml.c
-+	$(CC_FOR_BUILD) -o $@ $<
-diff --git a/man/de/Makefile b/man/de/Makefile
-new file mode 100644
-index 0000000..7c23784
---- /dev/null
-+++ b/man/de/Makefile
-@@ -0,0 +1,7 @@
-+#
-+#   Man page makefile for the Common UNIX Printing System (CUPS).
-+#
-+
-+LANGUAGE=de
-+
-+include ../Makefile.l10n
-diff --git a/man/fr/Makefile b/man/fr/Makefile
-new file mode 100644
-index 0000000..6a50e93
---- /dev/null
-+++ b/man/fr/Makefile
-@@ -0,0 +1,7 @@
-+#
-+#   Man page makefile for the Common UNIX Printing System (CUPS).
-+#
-+
-+LANGUAGE=fr
-+
-+include ../Makefile.l10n
diff -pruN 2.3.3op1-5/debian/patches/series 2.3.3op2-2/debian/patches/series
--- 2.3.3op1-5/debian/patches/series	2021-01-08 10:35:18.000000000 +0000
+++ 2.3.3op2-2/debian/patches/series	2021-02-03 12:13:18.000000000 +0000
@@ -1,13 +1,9 @@
-0001-Force-a-5-second-sleep-to-wait-for-the-job-control-f.patch
-0002-SERVERBIN-match-host_os_name-on-gnu-first-to-catch-k.patch
-0003-CUPS_EXE_FILE_PERM-also-match-host_os_name-on-gnu-to.patch
-0004-Systemd-Let-cups.service-start-after-nslcd.service.patch
-0005-Apple-AirPrint-support.patch
-0006-Keep-foomatic-PPDs-recommended-stanzas-in-NickNames.patch
-0007-Debian-Set-LogFileGroup-to-adm.patch
-0008-Debian-Move-cupsd.conf.default-from-SERVERROOT-to-DA.patch
-0009-Debian-Do-not-alter-the-permissions-of-cupsd.conf-ev.patch
-0010-Debian-Show-compile-command-lines.patch
-0011-Debian-Use-dpkg-architecture-in-cups-config-to-make-.patch
-0012-Debian-Build-mantohtml-with-the-build-architecture-c.patch
-0013-Debian-po4a-infrastructure-and-translations-for-manp.patch
+0001-Apple-AirPrint-support.patch
+0002-Keep-foomatic-PPDs-recommended-stanzas-in-NickNames.patch
+0003-Debian-Set-LogFileGroup-to-adm.patch
+0004-Debian-Move-cupsd.conf.default-from-SERVERROOT-to-DA.patch
+0005-Debian-Do-not-alter-the-permissions-of-cupsd.conf-ev.patch
+0006-Debian-Show-compile-command-lines.patch
+0007-Debian-Use-dpkg-architecture-in-cups-config-to-make-.patch
+0008-Debian-Build-mantohtml-with-the-build-architecture-c.patch
+0009-Debian-po4a-infrastructure-and-translations-for-manp.patch
diff -pruN 2.3.3op1-5/doc/help/man-cupsd.conf.html 2.3.3op2-2/doc/help/man-cupsd.conf.html
--- 2.3.3op1-5/doc/help/man-cupsd.conf.html	2020-11-27 14:25:26.000000000 +0000
+++ 2.3.3op2-2/doc/help/man-cupsd.conf.html	2021-02-01 21:10:25.000000000 +0000
@@ -163,6 +163,7 @@ The default is "0" which disables the li
 <dd style="margin-left: 5.0em">Listens to the specified address and port or domain socket path for connections.
 Multiple Listen directives can be provided to listen on multiple addresses.
 The Listen directive is similar to the Port directive but allows you to restrict access to specific interfaces or networks.
+Note: "Listen *:<i>port</i>" and "Port <i>port</i>" effectively listen on all IP addresses, so you cannot combine them with Listen directives for explicit IPv4 or IPv6 addresses on the same port.
 <dt><a name="ListenBackLog"></a><b>ListenBackLog </b><i>number</i>
 <dd style="margin-left: 5.0em">Specifies the number of pending connections that will be allowed.
 This normally only affects very busy servers that have reached the MaxClients limit, but can also be triggered by large numbers of simultaneous connections.
@@ -624,6 +625,8 @@ Require authentication for accesses from
 <b>subscriptions.conf</b>(5),
 CUPS Online Help (<a href="http://localhost:631/help">http://localhost:631/help</a>)
 <h2 class="title"><a name="COPYRIGHT">Copyright</a></h2>
+Copyright &copy; 2020 by Michael R Sweet
+<br>
 Copyright &copy; 2007-2019 by Apple Inc.
 
 </body>
diff -pruN 2.3.3op1-5/doc/help/man-cups-files.conf.html 2.3.3op2-2/doc/help/man-cups-files.conf.html
--- 2.3.3op1-5/doc/help/man-cups-files.conf.html	2020-11-27 14:25:26.000000000 +0000
+++ 2.3.3op2-2/doc/help/man-cups-files.conf.html	2021-02-01 21:10:25.000000000 +0000
@@ -213,6 +213,7 @@ command is used instead.
 CUPS Online Help (<a href="http://localhost:631/help">http://localhost:631/help</a>)
 <h2 class="title"><a name="COPYRIGHT">Copyright</a></h2>
 Copyright &copy; 2020 by Michael R Sweet
+<br>
 Copyright &copy; 2007-2019 by Apple Inc.
 
 </body>
diff -pruN 2.3.3op1-5/INSTALL.md 2.3.3op2-2/INSTALL.md
--- 2.3.3op1-5/INSTALL.md	2020-11-27 14:25:26.000000000 +0000
+++ 2.3.3op2-2/INSTALL.md	2021-02-01 21:10:25.000000000 +0000
@@ -1,4 +1,4 @@
-INSTALL - CUPS v2.3.3op1 - 2020-11-27
+INSTALL - CUPS v2.3.3op2 - 2021-02-01
 =====================================
 
 This file describes how to compile and install CUPS from source code. For more
diff -pruN 2.3.3op1-5/man/cupsd.conf.5 2.3.3op2-2/man/cupsd.conf.5
--- 2.3.3op1-5/man/cupsd.conf.5	2020-11-27 14:25:26.000000000 +0000
+++ 2.3.3op2-2/man/cupsd.conf.5	2021-02-01 21:10:25.000000000 +0000
@@ -1,13 +1,14 @@
 .\"
 .\" cupsd.conf man page for CUPS.
 .\"
+.\" Copyright © 2020 by Michael R Sweet
 .\" Copyright © 2007-2019 by Apple Inc.
 .\" Copyright © 1997-2006 by Easy Software Products.
 .\"
 .\" Licensed under Apache License v2.0.  See the file "LICENSE" for more
 .\" information.
 .\"
-.TH cupsd.conf 5 "CUPS" "16 July 2019" "Apple Inc."
+.TH cupsd.conf 5 "CUPS" "28 November 2020" "Apple Inc."
 .SH NAME
 cupsd.conf \- server configuration file for cups
 .SH DESCRIPTION
@@ -245,6 +246,7 @@ The default is "0" which disables the li
 Listens to the specified address and port or domain socket path for connections.
 Multiple Listen directives can be provided to listen on multiple addresses.
 The Listen directive is similar to the Port directive but allows you to restrict access to specific interfaces or networks.
+Note: "Listen *:\fIport\fR" and "Port \fIport\fR" effectively listen on all IP addresses, so you cannot combine them with Listen directives for explicit IPv4 or IPv6 addresses on the same port.
 .\"#ListenBackLog
 .TP 5
 \fBListenBackLog \fInumber\fR
@@ -902,4 +904,6 @@ Require authentication for accesses from
 .BR subscriptions.conf (5),
 CUPS Online Help (http://localhost:631/help)
 .SH COPYRIGHT
+Copyright \[co] 2020 by Michael R Sweet
+.br
 Copyright \[co] 2007-2019 by Apple Inc.
diff -pruN 2.3.3op1-5/man/cups-files.conf.5 2.3.3op2-2/man/cups-files.conf.5
--- 2.3.3op1-5/man/cups-files.conf.5	2020-11-27 14:25:26.000000000 +0000
+++ 2.3.3op2-2/man/cups-files.conf.5	2021-02-01 21:10:25.000000000 +0000
@@ -295,4 +295,5 @@ command is used instead.
 CUPS Online Help (http://localhost:631/help)
 .SH COPYRIGHT
 Copyright \[co] 2020 by Michael R Sweet
+.br
 Copyright \[co] 2007-2019 by Apple Inc.
diff -pruN 2.3.3op1-5/NOTICE 2.3.3op2-2/NOTICE
--- 2.3.3op1-5/NOTICE	2020-11-27 14:25:26.000000000 +0000
+++ 2.3.3op2-2/NOTICE	2021-02-01 21:10:25.000000000 +0000
@@ -1,5 +1,6 @@
 CUPS
 
+Copyright © 2020-2021 by Michael R Sweet
 Copyright © 2007-2019 by Apple Inc.
 Copyright © 1997-2007 by Easy Software Products.
 
diff -pruN 2.3.3op1-5/packaging/cups.spec 2.3.3op2-2/packaging/cups.spec
--- 2.3.3op1-5/packaging/cups.spec	2020-11-27 14:25:35.000000000 +0000
+++ 2.3.3op2-2/packaging/cups.spec	2021-02-01 21:10:49.000000000 +0000
@@ -41,12 +41,12 @@
 
 Summary: CUPS
 Name: cups
-Version: 2.3.3op1
+Version: 2.3.3op2
 Release: 0
 Epoch: 1
 License: GPL
 Group: System Environment/Daemons
-Source: https://github.com/openprinting/cups/releases/download/v2.3.3op1/cups-2.3.3op1-source.tar.gz
+Source: https://github.com/openprinting/cups/releases/download/v2.3.3op2/cups-2.3.3op2-source.tar.gz
 Url: http://www.cups.org
 Packager: Anonymous <anonymous@example.com>
 Vendor: OpenPrinting
diff -pruN 2.3.3op1-5/README.md 2.3.3op2-2/README.md
--- 2.3.3op1-5/README.md	2020-11-27 14:25:26.000000000 +0000
+++ 2.3.3op2-2/README.md	2021-02-01 21:10:25.000000000 +0000
@@ -1,9 +1,9 @@
-README - CUPS v2.3.3op1 - 2020-11-27
+README - CUPS v2.3.3op2 - 2021-02-01
 ====================================
 
 ![Version](https://img.shields.io/github/v/release/openprinting/cups?include_prereleases)
 ![Apache 2.0](https://img.shields.io/github/license/openprinting/cups)
-[![Build Status](https://travis-ci.org/openprinting/cups.svg?branch=master)](https://travis-ci.org/github/openprinting/cups)
+[![Build and Test](https://github.com/OpenPrinting/cups/workflows/Build%20and%20Test/badge.svg)](https://github.com/OpenPrinting/cups/actions)
 
 > *Note:* This version of CUPS is being maintained by the OpenPrinting
 > organization.  It tracks the current Apple CUPS sources and includes common
@@ -167,6 +167,7 @@ This will prevent the filters from misin
 LEGAL STUFF
 -----------
 
+Copyright © 2020-2021 by Michael R Sweet
 Copyright © 2007-2019 by Apple Inc.
 Copyright © 1997-2007 by Easy Software Products.
 
diff -pruN 2.3.3op1-5/scheduler/cups.service.in 2.3.3op2-2/scheduler/cups.service.in
--- 2.3.3op1-5/scheduler/cups.service.in	2020-11-27 14:25:26.000000000 +0000
+++ 2.3.3op2-2/scheduler/cups.service.in	2021-02-01 21:10:25.000000000 +0000
@@ -1,7 +1,7 @@
 [Unit]
 Description=CUPS Scheduler
 Documentation=man:cupsd(8)
-After=network.target sssd.service ypbind.service
+After=network.target sssd.service ypbind.service nslcd.service
 Requires=cups.socket
 
 [Service]
diff -pruN 2.3.3op1-5/test/run-stp-tests.sh 2.3.3op2-2/test/run-stp-tests.sh
--- 2.3.3op1-5/test/run-stp-tests.sh	2020-11-27 14:25:26.000000000 +0000
+++ 2.3.3op2-2/test/run-stp-tests.sh	2021-02-01 21:10:25.000000000 +0000
@@ -3,6 +3,7 @@
 # Perform the complete set of IPP compliance tests specified in the
 # CUPS Software Test Plan.
 #
+# Copyright © 2020 by Michael R Sweet
 # Copyright © 2007-2019 by Apple Inc.
 # Copyright © 1997-2007 by Easy Software Products, all rights reserved.
 #
@@ -844,6 +845,7 @@ else
 	echo "PASS"
 	echo "    PASSED" >>$strfile
 
+	sleep 5
 	./waitjobs.sh >>$strfile
 
         echo $ac_n "Verifying that history still exists: $ac_c"
@@ -851,7 +853,8 @@ else
 	echo "    ls -l $BASE/spool" >>$strfile
 	count=`ls -1 $BASE/spool | wc -l`
 	if test $count = 1; then
-		echo "FAIL"
+		echo "FAIL (job control files not present)"
+		ls -l $BASE/spool
 		echo "    FAILED (job control files not present)" >>$strfile
 		ls -l $BASE/spool >>$strfile
 		fail=`expr $fail + 1`
@@ -870,7 +873,8 @@ else
 		echo "    ls -l $BASE/spool" >>$strfile
 		count=`ls -1 $BASE/spool | wc -l`
 		if test $count != 1; then
-			echo "FAIL"
+			echo "FAIL (job control files still present)"
+			ls -l $BASE/spool
 			echo "    FAILED (job control files still present)" >>$strfile
 			ls -l $BASE/spool >>$strfile
 			fail=`expr $fail + 1`
diff -pruN 2.3.3op1-5/vcnet/config.h 2.3.3op2-2/vcnet/config.h
--- 2.3.3op1-5/vcnet/config.h	2020-11-27 14:25:26.000000000 +0000
+++ 2.3.3op2-2/vcnet/config.h	2021-02-01 21:10:25.000000000 +0000
@@ -1,6 +1,7 @@
 /*
  * Configuration file for CUPS on Windows.
  *
+ * Copyright © 2021 by Michael R Sweet
  * Copyright © 2007-2019 by Apple Inc.
  * Copyright © 1997-2007 by Easy Software Products.
  *
@@ -41,8 +42,10 @@
 #define open		_open
 #define read	        _read
 #define rmdir		_rmdir
+#define snprintf	_snprintf
 #define strdup		_strdup
 #define unlink		_unlink
+#define vsnprintf	_vsnprintf
 #define write		_write
 
 
@@ -97,8 +100,8 @@ typedef unsigned long useconds_t;
  * Version of software...
  */
 
-#define CUPS_SVERSION "CUPS v2.3.3op1"
-#define CUPS_MINIMAL "CUPS/2.3.3op1"
+#define CUPS_SVERSION "CUPS v2.3.3op2"
+#define CUPS_MINIMAL "CUPS/2.3.3op2"
 
 
 /*
@@ -345,9 +348,8 @@ typedef unsigned long useconds_t;
  * Do we have the (v)snprintf() functions?
  */
 
-/* Windows snprintf/vsnprintf are non-conforming */
-/* #undef HAVE_SNPRINTF */
-/* #undef HAVE_VSNPRINTF */
+#define HAVE_SNPRINTF 1
+#define HAVE_VSNPRINTF 1
 
 
 /*
diff -pruN 2.3.3op1-5/xcode/config.h 2.3.3op2-2/xcode/config.h
--- 2.3.3op1-5/xcode/config.h	2020-11-27 14:25:26.000000000 +0000
+++ 2.3.3op2-2/xcode/config.h	2021-02-01 21:10:25.000000000 +0000
@@ -1,8 +1,9 @@
 /*
  * Configuration file for CUPS and Xcode.
  *
- * Copyright 2007-2019 by Apple Inc.
- * Copyright 1997-2007 by Easy Software Products.
+ * Copyright © 2021 by Michael R Sweet
+ * Copyright © 2007-2019 by Apple Inc.
+ * Copyright © 1997-2007 by Easy Software Products.
  *
  * Licensed under Apache License v2.0.  See the file "LICENSE" for more information.
  */
@@ -18,8 +19,8 @@
  * Version of software...
  */
 
-#define CUPS_SVERSION "CUPS v2.3.3op1"
-#define CUPS_MINIMAL "CUPS/2.3.3op1"
+#define CUPS_SVERSION "CUPS v2.3.3op2"
+#define CUPS_MINIMAL "CUPS/2.3.3op2"
 
 
 /*
